<?php
//
// This file is auto generated with .langedit.php
// Characters are UTF-8 encoded
//
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
//
// Furthermore, nothing else than the language array is saved
// when using the .langedit.php editor!
//
$translation = array(
'edituser'                => 'Rediger bruger',
'username'                => 'Brugernavn',
'realname'                => 'Fulde navn',
'emailaddress'            => 'Email adresse',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Meddelelsestype',
'group'                   => 'Gruppe',
'accountenabled'          => 'Konto aktiv',
'updatedetails'           => 'Gem',
'setglobally'             => 'Denne preference er sat globalt',
'usergroupmanage'         => 'Bruger og gruppe administration',
'newuser'                 => 'Opret ny bruger',
'newgroup'                => 'Opret ny gruppe',
'yes'                     => 'Ja',
'no'                      => 'Nej',
'editgroup'               => 'Ret gruppe',
'groupname'               => 'Gruppenavn',
'description'             => 'Beskrivelse',
'admin'                   => 'Administrator gruppe',
'opennewtasks'            => 'Åbn nye opgaver',
'modifytasks'             => 'Rediger opgaver',
'addcomments'             => 'Tilføj kommentar',
'attachfiles'             => 'Vedhæft fil',
'vote'                    => 'Stem',
'groupenabled'            => 'Medlemmer kan logge ind',
'groupopen'               => 'Medlemmer kan logge ind',
'tasktypelist'            => 'Opgave typer',
'categorylist'            => 'Kategorier',
'oslist'                  => 'Operativsystemer',
'resolutionlist'          => 'Erklæringsliste',
'versionlist'             => 'Versions liste',
'severitylist'            => 'Vigtighedsliste',
'listnote'                => 'NB! Fjernelse af markeringen "vis" kan ændre opgaver ved redigering. Ændring af navne feltet vil ændre alle opgaver med det navn. Enheder der ikke kan slettes, er beskyttede fordi de bruges andre steder i systemet.',
'name'                    => 'Navn',
'order'                   => 'Sortering',
'back'                    => 'Tilbage',
'text'                    => 'Tekst',
'highlight'               => 'Fremhæv',
'show'                    => 'Vis',
'owner'                   => 'Ejer',
'selectowner'             => 'Vælg ejer',
'update'                  => 'Opdater',
'addnew'                  => 'Tilføj ny',
'flysprayprefs'           => 'Flyspray indstillinger',
'projecttitle'            => 'Projekt titel',
'baseurl'                 => 'URL for denne installation',
'replyaddress'            => 'Email-fra adresse ved meddelelser',
'themestyle'              => 'Tema',
'language'                => 'Sprog',
'anonview'                => 'Tillad anonyme brugere at se denne opgave',
'allowanon'               => 'Tillad anonyme brugere at oprette nye opgaver',
'never'                   => 'Aldrig',
'anonymously'             => 'Anonymt',
'afterregister'           => 'Kun efter registrering',
'spamproof'               => 'Aktiver bekræftelseskode for nye brugere',
'anongroup'               => 'Standard gruppe for nye brugere',
'groupassigned'           => 'Medlemmer i disse grupper kan tildeles opgaver',
'forcenotify'             => 'Tving opgave meddelelser som',
'neversend'               => 'Send aldrig',
'userchoose'              => 'Lad hver bruger selv vælge',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Standard kategori ejer',
'noone'                   => 'Ingen',
'jabbernotify'            => 'Jabber meddelelser',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Brugernavn',
'jabberpass'              => 'Kodeord',
'saveoptions'             => 'Gem',
'editcomment'             => 'Rediger kommentar',
'commentby'               => 'Kommenteret af',
'saveeditedcomment'       => 'Gem ændringer',
'projectprefs'            => 'Projekt indstillinger',
'pagetitle'               => 'Side titel',
'defaultproject'          => 'Standard projekt',
'projectlists'            => 'Projekter',
'showlogo'                => 'Vis titel-logo billede',
'intromessage'            => 'Introduktions besked',
'isactive'                => 'Projektet er aktivt',
'createproject'           => 'Opret nyt projekt',
'nopermission'            => 'Du har ikke adgang til denne side',
'listordertip'            => 'Rækkefølgen som disse vil fremstå i listen',
'listshowtip'             => 'Vis denne i listen',
'categoryownertip'        => 'Denne person vil modtage besked når nye opgaver oprettes i denne kategori',
'categoryparenttip'       => 'Overordnet kategori til denne',
'notsubcategory'          => 'Ingen (øverste kategori)',
'showinlineimages'        => 'Vis vedhæftede billeder inline',
'dateformat'              => 'Datoformat',
'dateformat_extended'     => 'Langt datoformat',
'cache_feeds'             => 'Cache feeds',
'no_cache'                => 'Ingen caching',
'cache_disk'              => 'Cache på disk',
'cache_db'                => 'Cache i databasen',
'subcategoryof'           => 'Underkategori af',
'visiblecolumns'          => 'Kolonner vist i opgavelisten',
'tense'                   => 'Tid',
'listtensetip'            => 'Datid, nutid eller fremtid',
'past'                    => 'Datid',
'present'                 => 'Nutid',
'future'                  => 'Fremtid',
'oldpass'                 => 'Gammelt kodeord',
'nooldpass'               => 'Gammelt kodeord er ikke angivet',
'oldpasswrong'            => 'Gammelt kodeord er ikke korrekt',
'changepass'              => 'Skift kodeord',
'confirmpass'             => 'Bekræft kodeord',
'projectmanager'          => 'Projektansvarlig',
'viewtasks'               => 'Vis opgaver',
'modifyowntasks'          => 'Rediger egne opgaver',
'modifyalltasks'          => 'Rediger andres opgaver',
'viewcomments'            => 'Vis kommentarer',
'editcomments'            => 'Ret kommentarer',
'deletecomments'          => 'Slet kommentarer',
'viewattachments'         => 'Vis vedhæftede filer',
'createattachments'       => 'Vedhæft fil',
'deleteattachments'       => 'Slet vedhæftet fil',
'viewhistory'             => 'Vis tidligere (history)',
'closeowntasks'           => 'Luk egne opgaver',
'closeothertasks'         => 'Luk andres opgaver',
'assigntoself'            => 'Tildel opgaver til dig selv som ikke er tildelte til andre',
'assignotherstoself'      => 'Tildel andres opgaver til dig selv',
'viewreports'             => 'Vis log',
'othersview'              => 'Tillad alle at se dette projekt',
'usersandgroups'          => 'Brugere og grupper',
'globalgroup'             => 'Global gruppe',
'globalgroups'            => 'Globale grupper',
'defaultglobalgroup'      => 'Standard global gruppe for nye brugere',
'addtogroup'              => 'Tilføj til gruppe',
'moveuserstogroup'        => 'Flyt brugere til gruppe',
'nogroup'                 => 'Ingen gruppe - Fjerne fra dette projekt',
'eventdesc'               => 'Event beskrivelse',
'requestedby'             => 'Anmodet af',
'daterequested'           => 'Anmodningsdato',
'closetask'               => 'Luk opgave',
'reopentask'              => 'Genåbn opgave',
'applymember'             => 'Anmod om projekt medlemsskab',
'forcurrentproj'          => 'Til dette projekt',
'lostpw'                  => 'Glemt kodeord',
'lostpwexplain'           => 'Skriv dit brugernavn, så sender vi et link til den Email der er angivet i din profil.',
'sendlink'                => 'Send',
'savenewpass'             => 'Gem nyt kodeord',
'anonreg'                 => 'Tillad oprettelse af nye brugere',
'allowanonopentask'       => 'Tillad anonyme brugere at oprette opgaver',
'editglobalgroup'         => 'Rediger global gruppe',
'editgroupforproj'        => 'Rediger gruppe til projekt ???',
'notshownforadmin'        => 'Rettigeheder vises ikke for administratorgruppen, da de ikke skal redigeres.',
'general'                 => 'Generelt',
'userregistration'        => 'Opret bruger',
'notifications'           => 'Meddelelser',
'resetoptions'            => 'Nulstil',
'preferences'             => 'Indstillinger',
'tasktypes'               => 'Opgavetyper',
'resolutions'             => 'Erklæringer',
'categories'              => 'Kategorier',
'operatingsystems'        => 'Operativsystemer',
'versions'                => 'Versioner',
'admintoolboxlong'        => 'Admin værktøjskasse',
'newproject'              => 'Nyt projekt',
'delete'                  => 'Slet',
'listdeletetip'           => 'Slet fra denne liste',
'lookandfeel'             => 'Udseende',
'globaltheme'             => 'Globalt tema',
'emailnotify'             => 'Email meddelelser',
'fromaddress'             => 'Fra adresse',
'smtpserver'              => 'SMTP server',
'smtpuser'                => 'SMTP brugernavn',
'smtppass'                => 'SMTP kodeord',
'addrewrite'              => 'Brug "URL rewriting"',
'usereminderdaemon'       => 'Aktiver påmindelser',
'tasksperpage'            => 'Antal opgaver pr side',
'addtoassignees'          => 'Tilføj dig selv til modtagere',
'taskstatuses'            => 'Opgavestatus',
'canvote'                 => 'Kan stemme for opgaver',
'loginsuccessful'         => 'Du er logget ind',
'youareloggedout'         => 'Du er logget af',
'waitwhiletransfer'       => 'Vent venligst mens du viderestilles',
'clicknowait'             => 'Klik her hvis du ikke ønsker at vente',
'accountdisabled'         => 'Din konto er lukket! Kontakt administrator.',
'task'                    => 'Opgave',
'edittask'                => 'Rediger denne opgave',
'openedby'                => 'Oprettet af',
'editedby'                => 'Sidst rettet af',
'tasktype'                => 'Opgavetype',
'category'                => 'Kategori',
'status'                  => 'Status',
'assignedto'              => 'Tildelt til',
'operatingsystem'         => 'Operativsystem',
'severity'                => 'Vigtighed',
'reportedversion'         => 'Rapporteret version',
'dueinversion'            => 'Forfalder i version',
'undecided'               => 'Ubesluttet',
'percentcomplete'         => 'Procent færdig',
'details'                 => 'Detaljer',
'savedetails'             => 'Gem',
'canceledit'              => 'Fortryd',
'anonymous'               => 'Anonym afsender',
'complete'                => 'Færdig',
'closedby'                => 'Lukket af',
'reasonforclosing'        => 'Årsag til lukning',
'reopenthistask'          => 'Genåbn denne opgave',
'comments'                => 'Kommentarer',
'attachments'             => 'Vedhæftede filer',
'relatedtasks'            => 'Relaterede opgaver',
'edit'                    => 'Rediger',
'addcomment'              => 'Tilføj kommentar',
'fileuploadedby'          => 'Fil tilføjet af',
'uploadafile'             => 'Vedhæft en fil',
'uploadnow'               => 'Upload nu!',
'thesearerelated'         => 'Opgaver relateret til denne opgave',
'remove'                  => 'Fjern',
'addnewrelated'           => 'Tilføj ny relateret opgave',
'add'                     => 'Tilføj',
'otherrelated'            => 'Andre opgaver som denne er relateret til',
'receivenotify'           => 'Disse brugere vil modtage detaljerede meddelelser når denne opgave opdateres',
'addusertolist'           => 'Tilføj bruger til denne liste',
'addtolist'               => 'Tilføj til liste',
'addmyself'               => 'Tilføj mig selv til denne liste',
'removemyself'            => 'Fjern mig selv fra denne liste',
'theseusersnotify'        => 'Disse brugere vil modtage detaljerede meddelelser hver gang denne opgave opdateres',
'attachedtoproject'       => 'Tilknyttet til projekt',
'reminders'               => 'Påmindelser',
'system'                  => 'System',
'remindthisuser'          => 'Påmind denne bruger',
'thisoften'               => 'Så tit (this often)',
'startafter'              => 'Vent før påmindelser startes (Wait before starting reminders)',
'hours'                   => 'Time(r)',
'days'                    => 'Dag(e)',
'weeks'                   => 'Uge(r)',
'addreminder'             => 'Tilføj påmindelse',
'defaultreminder'         => 'Dette er en påmindelse om at se på følgende Flyspray opgave:',
'message'                 => 'Besked',
'closed'                  => 'Lukket',
'filename'                => 'Filnavn',
'date'                    => 'Dato',
'filesize'                => 'Fil størrelse:',
'closurecomment'          => 'Yderligere kommentarer vedr. lukning:',
'history'                 => 'History ???',
'nohistory'               => 'Ingen (history) tilgængelig',
'eventdate'               => 'Dato',
'user'                    => 'Bruger',
'event'                   => 'Aktivitet',
'fieldchanged'            => 'Fil ændret',
'taskopened'              => 'Opgave åbnet',
'taskreopened'            => 'Opgave genåbnet',
'taskclosed'              => 'Opgave lukket',
'commentadded'            => 'Kommentar tilføjet',
'commentedited'           => 'Kommentar redigeret',
'commentdeleted'          => 'Kommentar slettet',
'attachmentadded'         => 'Fil tilføjet',
'attachmentdeleted'       => 'Fil slettet',
'taskedited'              => 'Opgavebeskrivelse redigeret',
'notificationadded'       => 'Bruger tilføjet til meddelelsesliste',
'notificationdeleted'     => 'Bruger slettet fra meddelelsesliste',
'relatedadded'            => 'Relateret opgave tilføjet',
'relateddeleted'          => 'Relateret opgave fjernet',
'taskassigned'            => 'Opgave tildelt til',
'taskreassigned'          => 'Opgave gen-tildelt til',
'assignmentremoved'       => 'Tildeling flyttet',
'summary'                 => 'Resumé',
'addedasrelated'          => 'Opgave tilføjet til relateret liste af',
'deletedasrelated'        => 'Opgave lettet fra relateret liste af',
'reminderadded'           => 'Påmindelse aktiveret',
'reminderdeleted'         => 'Påmindelse slettet',
'priority'                => 'Prioritet',
'previousvalue'           => 'Før',
'newvalue'                => 'Nu',
'selectareason'           => 'Vælg en årsag',
'assigntome'              => 'Tildel til mig',
'reopenrequest'           => 'Anmod om genåbning',
'requestclose'            => 'Anmod om lukning',
'ownershiptaken'          => 'Bruger tog ejerskab',
'closerequestmade'        => 'Anmodet opgave lukket',
'reopenrequestmade'       => 'Anmodet opgave genåbnet',
'taskdependson'           => 'Denne opgave er sammenkædet med',
'taskblocks'              => 'Denne opgave blokerer disse fra lukning',
'depadded'                => 'Sammenkædning tilføjet',
'depaddedother'           => 'Denne opgave er sammenkædet med',
'depremoved'              => 'Sammenkædning fjernet',
'depremovedother'         => 'Denne opgave er flyttet fra anden opgaves sammenkædningsliste',
'showdetailserror'        => 'Denne opgave er enten slettet eller du har ikke rettigheder til at se den.',
'makeprivate'             => 'Privat',
'makepublic'              => 'Offentlig',
'taskmadeprivate'         => 'Denne opgave er privat',
'taskmadepublic'          => 'Denne opgave er offentlig',
'confirmdeletecomment'    => "Er du sikker på at du vil slette denne kommentar ? %s",
'confirmdeleteattach'     => 'Er du sikker på at du vil slette denne fil ?',
'selectedhistory'         => 'Log detaljer',
'showallhistory'          => 'Vis fuld log (tab) igen',
'hidethis'                => 'Skjul dette område',
'mark100'                 => 'Marker opgave 100% færdig',
'watchtask'               => 'Overvåg opgave',
'stopwatching'            => 'Stop overvågning',
'commentlink'             => 'Link til denne kommentar',
'submitreq'               => 'Send anmodning',
'reasonforreq'            => 'Årsag for anmodning',
'pmreqdenied'             => 'En projektansvarlig afviste anmodning',
'taskpendingreq'          => 'Afventer projektansvarlig. Se log for detaljer.',
'previoustask'            => 'Forrige opgave',
'nexttask'                => 'Næste opgave',
'duedate'                 => 'Forfalds dato',
'attachnoperms'           => 'Der er vedhæftede filer til denne kommentar, men du har ikke rettigheder til at se dem.',
'open'                    => 'Åbne',
'depgraph'                => 'Vis sammenkædnings graf',
'reset'                   => 'Nulstil',
'selectusers'             => 'Vælg brugere',
'addmetoassignees'        => 'Tilføj mig til modtagere',
'addedtoassignees'        => 'Bruger tilføjet til modtagerliste',
'dependencygraph'         => 'Sammenkædnings graf',
'attachanotherfile'       => 'Vedhæft yderligere fil(er)',
'OK'                      => 'OK',
'addvote'                 => 'Tilføj stemme',
'notifyfromfs'            => 'Meddelelse fra Flyspray',
'autogenerated'           => 'DETTE ER EN AUTOMATISK GENERERET MEDDELELSE SOM IKKE KAN BESVARES!!!',
'forward'                 => 'Næste (forward)',
'previous'                => 'Forrige',
'next'                    => 'Næste',
'first'                   => 'Første',
'last'                    => 'Sidste',
'page'                    => 'Side %d af %d',
'search'                  => 'Søg',
'alltasktypes'            => 'Alle opgave typer',
'allseverities'           => 'Alle vigtigheder',
'alldevelopers'           => 'Alle udviklere',
'notyetassigned'          => 'Endnu ikke tildelte',
'allcategories'           => 'Alle kategorier',
'allstatuses'             => 'Alle statusser',
'allopentasks'            => 'Alle åbne opgaver',
'sortthiscolumn'          => 'Sorter efter denne kolonne',
'id'                      => 'ID',
'project'                 => 'Projekt',
'dateopened'              => 'Oprettet den',
'progress'                => 'Forløb',
'searchthisproject'       => 'Søg i dette projekt',
'dueanyversion'           => 'Forfald i hvilken som helst version',
'anyversion'              => 'Rapporteret i hvilken som helst version',
'dueversion'              => 'Forfald i version',
'lastedit'                => 'Sidst opdateret',
'os'                      => 'Operativsystem',
'reportedin'              => 'Rapporteret i',
'taskrange'               => 'Viser opgaver %d - %d af %d',
'noresults'               => 'Din søgning gav ingen resultater',
'takeaction'              => 'Skrid til handling (Take action)',
'watchtasks'              => 'Overvåg valgte opgaver',
'stopwatchingtasks'       => 'Stop overvågning af valgte opgaver',
'assigntaskstome'         => 'Tildel valgte opgaver til mig',
'dueby'                   => 'Til forfald den',
'dueanytime'              => 'Til forfald lige om straks',
'selectduedate'           => 'Vælg forfaldsdato',
'toggleselected'          => 'Skift mellem valgte (inverter ???)',
'due'                     => 'Forfald',
'assignedtome'            => 'Tildelte til mig selv',
'tasklist'                => 'Opgaveliste',
'dateclosed'              => 'Lukket dato',
'advanced'                => 'Avanceret',
'searchcomments'          => 'Søg i kommentarer',
'searchforall'            => 'Søg efter alle ord',
'anonusers'               => 'Anonyme brugere',
'miscellaneous'           => 'Diverse',
'users'                   => 'Brugere',
'taskproperties'          => 'Opgave indstillinger',
'selectsincedate'         => 'Vælg Redigeret siden',
'changedsince'            => 'Ændret siden',
'updatefs'                => 'Venligst opdater Flyspray.',
'currentversion'          => 'Din nuværende version er',
'latestversion'           => 'og den nyeste version er',
'hidemessage'             => '(udsæt til senere)',
'saveas'                  => 'Gem søgning som',
'nosearches'              => 'Ingen gemte søgninger',
'saving'                  => 'Gemmer...',
'votes'                   => 'Stemmer',
'allclosedtasks'          => 'Alle lukkede opgaver',
'password'                => 'Kodeord',
'login'                   => 'Log ind',
'rememberme'              => 'Husk mig',
'lostpassword'            => 'Glemt kodeord ?',
'lostpwforfs'             => 'Glemt kodeord til Flyspray ?',
'lostpwmsg1'              => "Hej\n\nJeg har glemt mit kodeord til Flyspray på (on) ???  _",
'lostpwmsg2'              => ", vil I venligst lave et nyt kodeord til mig.\n\nBrugernavn: _",
'regards'                 => "\nMed venlig hilsen",
'yourusername'            => '_ dit brugernavn _',
'locale'                  => 'da-DK',
'filenotexist'            => 'Filen eksisterer ikke eller du har ikke rettigheder til at se den.',
'showtask'                => 'Vis opgave',
'now'                     => 'Nu',
'go'                      => 'Gå til (Go) ???',
'opentaskanon'            => 'Åbn ny opgave anonymt',
'register'                => 'Opret (register) ???',
'addnewtask'              => 'Tilføj ny opgave',
'reports'                 => 'Aktivitetslog',
'editmydetails'           => 'Rediger mine oplysninger',
'logout'                  => 'Log af',
'disabledaccount'         => 'Din konto er lukket!<br />Du logges af...',
'poweredby'               => 'Powered by Flyspray',
'projects'                => 'Projekter',
'allprojects'             => 'Alle projekter',
'selectproject'           => 'til projekt:',
'tasksall'                => 'Alle opgaver',
'tasksassigned'           => 'Opgaver tildelt mig',
'tasksreported'           => 'Opgaver oprettet af mig',
'taskswatched'            => 'Opgaver jeg overvåger',
'mysearch'                => 'Mine søgninger',
'admintoolbox'            => 'Admin værktøjskasse',
'manageproject'           => 'Administrer projekt',
'permissions'             => 'Rettigheder',
'hide'                    => 'Skjul',
'pendingreq'              => 'PM anmodning venter',
'errorpage'               => "Flyspray kunne ikke finde siden.\nDette kan hænde hvis du har forsøgt at få adgang til en opgave der ikke længere eksisterer, eller hvis du ikke har de nødvendige rettigheder.",
'permissionsforproject'   => 'Rettigheder til _',
'switchto'                => 'Skift til',
'lastsearch'              => 'Sidste søgning',
'modify'                  => 'Rediger',
'noticefrom'              => 'Besked fra',
'hasopened'               => 'har oprettet en ny opgave og tildelt den til dig:',
'moreinfonew'             => 'Du kan finde mere information om denne fejl på Flyspray siden:',
'newtaskcategory'         => 'Der er oprettet en ny Flyspray opgave i denne kategori',
'categoryowner'           => 'Du får denne besked fordi du er listet som ejer af kategorien.',
'tasksummary'             => 'Opgave resumé',
'newtaskadded'            => 'Din opgave er tilføjet.',
'summaryanddetails'       => 'Du skal skrive både resumé og beskrivelse.',
'goback'                  => 'Tilbage.',
'messagefrom'             => 'Dette er en besked fra Flyspray på _',
'hasjustmodified'         => 'har lige redigeret nedenstående opgave.',
'changedfields'           => 'Ændrede felter er markeret med stjerner (**)',
'moreinfomodify'          => 'Du kan få mere information om denne opgave på adressen:',
'nolongerassigned'        => 'Nedenstående opgave er ikke længere tildelt dig, men er nu tildelt til',
'hasassigned'             => 'har tildelt følgende Flyspray opgave til dig:',
'taskupdated'             => 'Opgave opdateret.',
'hasclosedassigned'       => 'har lukket følgende Flyspray opgave som var tildelt dig:',
'unassigned'              => 'Ikke tildelt',
'hasclosed'               => 'har lukket nedenstående opgave.',
'youonnotify'             => 'Du modtager dette fordi du er skrevet på meddelelses listen',
'taskclosedmsg'           => 'Opgave lukket.',
'returntotask'            => 'Gå tilbage til opgavebeskrivelsen.',
'backtoindex'             => 'Gå tilbage til opgavelisten.',
'noclosereason'           => 'Du har ikke valgt en årsag til lukning af denne opgave.',
'hasreopened'             => 'har genåbnet følgende Flyspray opgave som du lukkede:',
'taskreopenedmsg'         => 'Opgave genåbnet.',
'backtotask'              => 'Gå tilbage til opgaven.',
'commentaddedmsg'         => 'Kommentar tilføjet.',
'commenttoassigned'       => 'har tilføjet en kommentar til en opgave som er tildelt dig:',
'commenttotask'           => 'har tilføjet nedenstående kommentar til denne opgave.',
'nocommententered'        => 'Du bør tilføje en kommentar.',
'fillinfields'            => 'Du har ikke udfyldt alle felter.',
'notcurrentpass'          => 'Dette er ikke dit nuværende kodeord!',
'passchanged'             => 'Dit kodeord er ændret.',
'closewindow'             => 'Du kan nu lukke dette vindue.',
'passnomatch'             => 'Det nye kodeord er ikke skrevet ens begge gange!',
'usernametaken'           => 'Dette brugernavn er allerede i brug. Du skal vælge et andet.',
'newusercreated'          => 'Ny bruger konto er oprettet',
'accountcreated'          => 'Din bruger konto er oprettet.',
'newuserwarning'          => 'Bemærk at det kan være at din bruger konto skal godkendes af en administrator. Hvis du ikke kan logge ind med det samme, kan dette evt. være årsagen.',
'nomatchpass'             => 'Kodeord stemmer ikke overens.',
'confirmwrong'            => 'Bekræftelseskode er forkert!',
'formnotcomplete'         => 'Formularen er ikke udfyldt korrekt.',
'formnotnumeric'          => 'De indtastede data er ikke numeriske!',
'groupnametaken'          => 'Dette gruppenavn er allerede i brug.',
'newgroupadded'           => 'Ny gruppe oprettet.',
'optionssaved'            => 'Flyspray indstillinger er gemt.',
'hasuploaded'             => 'har vedhæftet en fil til en opgave som er tildelt dig:',
'hasattached'             => 'har vedhæftet en fil til nedenstående opgave.',
'fileuploaded'            => 'Filen er vedhæftet.',
'fileerror'               => 'Der skete en fejl ved upload af filen. Dette kan hænde hvis rettighederne på <i>attachments/</i> mappen ikke er sat rigtigt.',
'contactadmin'            => 'Kontakt administratoren af dette projekt.',
'selectfileerror'         => 'Du har ikke valgt en fil.',
'userupdated'             => 'Brugeroplysninger er opdaterede.',
'realandemail'            => 'Du har ikke udfyldt felterne til din Email og dit fulde navn.',
'groupupdated'            => 'Gruppedefinition opdateret.',
'groupanddesc'            => 'Du har ikke skrevet et gruppenavn.',
'fillallfields'           => 'Du skal ydfylde alle felter.',
'listPmustN'              => '"Sortering" skal være et heltal.',
'listupdated'             => 'Listen er opdateret.',
'listitemadded'           => 'Nyt emne til listen er tilføjet.',
'relatedaddedmsg'         => 'Relateret opgave er tilføjet til listen.',
'relatederror'            => 'Denne opgave er allerede på den relaterede opgaveliste.',
'relatedremoved'          => 'Relateret opgave slettet fra listen.',
'notifyadded'             => 'Bruger tilføjet til påmindelsesliste.',
'notifyerror'             => 'Denne bruger er allerede på listen for denne opgave.',
'notifyremoved'           => 'Bruger slettet fra liste.',
'editcommentsaved'        => 'Opdateret kommentar gemt.',
'commentdeletedmsg'       => 'Kommentar slettet.',
'gotonewtask'             => 'Gå til den nye opgave som du lige har oprettet.',
'projectcreated'          => 'Dit nye projekt er nu oprettet og du kan begynde at administrere det.',
'customiseproject'        => 'Administrer dette projekt',
'projectupdated'          => 'Projekt indstillinger opdaterede',
'emptytitle'              => 'Du har ikke indtastet en titel til projektet. Gå tilbage og ret.',
'loginbelow'              => 'Du kan nu prøve at logg ind.',
'attachmentdeletedmsg'    => 'Filen er slettet.',
'reminderaddedmsg'        => 'Påmindelsen er tilføjet.',
'reminderdeletedmsg'      => 'Den valgte påmindelse er slettet.',
'flyspraytask'            => 'Flyspray opgave',
'fieldsmissing'           => 'Et eller flere felter indeholder forkerte eller ingen data.',
'relatedinvalid'          => 'Den opgave findes ikke.',
'relatedproject'          => 'Denne opgave er tilknyttet et andet projekt. Opret relation alligevel ?',
'addanyway'               => 'Tilføj alligevel ?',
'cancel'                  => 'Annuller',
'alreadyedited'           => "Denne opgave er blevet opdateret af en anden inden du gemte dine ændringer. Er du sikker på at du vil gemme dine ændringer ?\nDette kan medføre at den andens ændringer overskrives!",
'saveanyway'              => 'Gem mine ændringer',
'nouserselected'          => 'Ingen bruger valgt. Vælg mindst en før du forsøger igen.',
'groupswitchupdated'      => 'Brugergrupper modificeret.',
'takenownershipmsg'       => 'Denne opgave er nu tildelt dig.',
'adminrequestmade'        => 'Din anmodning er nu sendt til den projektansvarlige.',
'newdepnotify'            => 'En ny sammenkædning er tilføjet opgaven:',
'dependadded'             => 'Opgavesammenkædning er tilføjet.',
'dependaddfailed'         => 'Der skete en fejl ved sammenkædningen. Check at der ikke er nogen gensidige blokeringer.',
'depremovedmsg'           => 'Opgavesammenkædning er fjernet.',
'newdepis'                => 'Den nye sammenkædning er',
'magicurlsent'            => 'En besked er sendt til din Email. Den indeholder et link til en side hvor du kan færdiggøre denne handling.',
'changefspass'            => 'Skift Flyspray kodeord',
'magicurlmessage'         => 'Brug nedenstående link for at skifte dit Flyspray kodeord:',
'erroronform'             => 'Der var et problem med udfyldelsen af formularen.',
'addressused'             => 'Denne adresse er allerede brugt på en anden konto. Du kan vælge at ignorere denne besked og benytte nedenstående link til at færdiggøre oprettelsen, eller du kan forsøge igen med en ny.',
'confirmcodeis'           => 'Din bekræftelseskode er:',
'codesent'                => 'Din bekræftelseskode er afsendt. Følg instruktionerne i meddelelsen.',
'codenotsent'             => 'Din bekræftelseskode kunne ikke sendes på nuværende tidspunkt. Prøv igen lidt senere.',
'taskmadeprivatemsg'      => 'Denne opgave er privat.',
'taskmadepublicmsg'       => 'Denne opgave er offentlig igen.',
'realandnotify'           => 'Du skal skrive dit fulde navn og enten din Email adresse eller dit Jabber ID.',
'pmreqdeniedmsg'          => 'En projektansvarlig anmodning afvist.',
'massopsuccess'           => 'Alle operationer er gennemført hvor rettighederne har tilladt dette.',
'usernotexist'            => 'Denne bruger eksisterer ikke i denne installation.',
'commentattachperms'      => 'Du kan ikke slette denne kommentar, da du ikke har rettigheder til at slette de vedhæftede filer.',
'voterecorded'            => 'Din stemme er registreret.',
'votefailed'              => 'Din stemme kunne ikke registreres på nuværende tidspunkt.',
'createnewgroup'          => 'Opret ny gruppe',
'requiredfields'          => 'Felter der skal udfyldes er markeret med',
'addthisgroup'            => 'Tilføj denne gruppe',
'createnewproject'        => 'Opret nyt projekt',
'addnewproject'           => 'Tilføj nyt projekt',
'htmlallowed'             => 'HTML kode tilladt',
'createthisproject'       => 'Opret dette projekt',
'inlineimages'            => 'Vis billeder inline',
'createnewtask'           => 'Opret ny opgave i projekt:',
'addanother'              => 'Tilføj ny opgave efter denne',
'addthistask'             => 'Tilføj denne opgave',
'notifyme'                => 'Giv mig besked når denne opgave ændres.',
'newtask'                 => 'Ny opgave',
'attachafile'             => 'Vedhæft en fil',
'registernewuser'         => 'Opret ny bruger',
'none'                    => 'Ingen',
'registeraccount'         => 'Opret denne konto',
'both'                    => 'Begge',
'notifyfrom'              => 'Besked fra _',
'donotreply'              => 'DETTE ER EN AUTOMATISK GENERERET MEDDELELSE SOM IKKE KAN BESVARES!!!',
'disclaimer'              => 'Du modtager denne besked fordi du er tilmeldt Flyspray opgave system. Hvis du ikke vil modtage flere beskeder i fremtiden, kan du ændre dine indstillinger ved at følge adressen herover.',
'userwho'                 => 'Bruger som gjorde dette',
'moreinfo'                => 'Der findes mere information på adressen:',
'newtaskopened'           => 'En ny Flyspray opgave er oprettet. Se flere detaljer herunder.',
'notify.taskclosed'       => 'Følgende opgave er blevet lukket:',
'notify.taskreopened'     => 'Følgende opgave er blevet genåbnet:',
'newdep'                  => 'Der er tilføjet en sammenkædning til opgaven:',
'notify.depremoved'       => 'Der er fjernet en sammenkædning fra opgaven:',
'olddepwas'               => 'Den forhenværende sammenkædning var',
'notify.commentadded'     => 'Der er tilføjet en kommentar til opgaven:',
'commentis'               => 'Kommentaren er skrevet herunder.',
'newattachment'           => 'En ny fil er vedhæftet følgende opgave:',
'detailsbelow'            => 'Se detaljer herunder.',
'notify.relatedadded'     => 'En ny relateret opgave er tilføjet opgaven:',
'relatedis'               => 'Den relaterede opgave er',
'assignedtoyou'           => 'Du er blevet tildelt opgaven:',
'takenownership'          => 'har taget ejerskab over opgaven:',
'requiresaction'          => 'Der mangler en handling fra en projektansvarlig på opgaven:',
'requiresactionnotify'    => 'Opgaven mangler handling fra en projektansvarlig',
'pmdeny'                  => 'En projektansvarlig har afvist den afventende anmodning på opgaven:',
'pmdenynotify'            => 'En projektansvarlig har afvist anmodningen',
'fileaddedtoo'            => 'En eller flere filer er vedhæftet.',
'taskwatching'            => 'Opgaven som du overvåger',
'isdepfor'                => 'er en sammenkædning til',
'denialreason'            => 'Årsag til afvisning',
'taskchanged'             => 'Der er foretaget ændringer på nedenstående opgave. Ændringerne er listet herunder. For mere information, følg adressen og klik på Log.',
'useraddedtoassignees'    => 'En bruger har tildelt sig selv denne opgave.',
'removeddepis'            => 'Den fjernede sammenkædning er',
'isnodepfor'              => 'er ikke længere en sammenkædning for',
'usergroups'              => 'Brugergrupper',
'pmtoolbox'               => 'Projektansvarliges værktøjskasse',
'groupmanage'             => 'Gruppe administration',
'pendingrequests'         => 'Ventende anmodninger',
'reasongiven'             => 'Årsag',
'nopendingreq'            => 'Der er ingen ventende projektansvarlige anmodninger.',
'givereason'              => 'Skriv en årsag',
'catlisted'               => 'Kategori-liste editor',
'oslisted'                => 'Operativsystem-liste editor',
'verlisted'               => 'Version-liste editor',
'tasktypeed'              => 'Opgavetype-liste editor',
'resed'                   => 'Erklæringsliste editor',
'deny'                    => 'Afvis',
'notifiedwhen'            => 'Besked, når ???',
'onlynewtasks'            => 'Nye opgaver er oprettet',
'allevents'               => 'Ved enhver aktivitet i enhver opgave ???',
'feeds'                   => 'Newsfeed',
'feeddescription'         => 'Newsfeed beskrivelse',
'feedimgurl'              => 'Newsfeed billede URL',
'notifysubject'           => 'Emne ved beskeder',
'notifysubjectinfo'       => '(%p = projekt titel, %s = opgave resumé, %t = opgave id, %a = aktivitet, %u = bruger)',
'priority6'               => 'Flash',
'priority5'               => 'Omgående',
'priority4'               => 'Vigtig',
'priority3'               => 'Høj',
'priority2'               => 'Normal',
'priority1'               => 'Lav',
'sendcode'                => 'Send kode',
'entercode'               => 'Skriv bekræftelseskoden som du fik i din Email, samt det ønskede kodeord til din brugerkonto.',
'confirmationcode'        => 'Bekræftelseskode',
'registererror'           => 'Du skal udfylde alle påkrævede felter korrekt, samt sørge for at vælge hvorledes du vil modtage beskeder fra systemet. ',
'validusername'           => '(kun alphanumeriske tegn og -_. er tilladte)',
'emailtaken'              => 'Email adressen eller Jabber ID\'et er allerede i brug. Vælg venligst noget andet.',
'note'                    => '<strong>NB!</strong> Du får tilsendt en bekræftelseskode som du skal bekræfte før din konto aktiveres. Koden sendes som du har valgt det ovenfor.<br />Hvis du skriver forkerte data vil du <strong>ikke modtage din bekræftelseskode!</strong>.',
'changelog'               => 'Ændringslog',
'changeloggen'            => 'Ændringslog generator',
'listfrom'                => 'Vis log fra',
'to'                      => 'til',
'oldestfirst'             => 'Ældste først',
'recentfirst'             => 'Nyeste først',
'severityrep'             => 'Vigtighedsrapport',
'totalopen'               => 'Totalt antal åbne opgaver',
'age'                     => 'Alder',
'agerep'                  => 'Aldersrapport',
'eventsrep'               => 'Aktivitetsrapport',
'events'                  => 'Aktiviteter',
'Tasks'                   => 'Opgaver',
'opened'                  => 'Oprettet',
'edited'                  => 'Redigeret',
'assigned'                => 'Tildelte',
'within'                  => 'Mellem (Within) ???',
'pastday'                 => 'Den seneste dag',
'pastweek'                => 'Den seneste uge',
'pastmonth'               => 'Den seneste måned',
'pastyear'                => 'Det seneste år',
'nolimit'                 => 'Ingen grænse',
'from'                    => 'Fra',
'duein'                   => 'Forfald i',
'selectfromdate'          => 'Vælg fra dato',
'selecttodate'            => 'Vælg Til dato',
'showvoters'              => 'Vis/skjul stemmegivere',
'roadmap'                 => 'Roadmap',
'roadmapfor'              => 'Roadmap for version',
'tasks'                   => 'opgaver',
'completed'               => 'færdige.',
'opentasks'               => 'åbne opagver',
'of'                      => '% af',
'severity5'               => 'Kritisk',
'severity4'               => 'Høj',
'severity3'               => 'Medium',
'severity2'               => 'Lav',
'severity1'               => 'Meget lav',
'Redirect'                => 'Videresend',
'redirectmsg'             => 'Hvis du ikke sendes videre indenfor et øjeblik, så klik %sHERE%s',
'allowclosedcomments'     => 'Tillad kommentarer på lukkede opgaver',
'comment'                 => 'Kommentar',
'editowncomments'         => 'Rediger egne kommentarer',
'reopened'                => 'Genåbnet',
'loading'                 => 'Loading...',
'notifyown'               => 'Giv besked ved egne ændringer',
'youremail'               => 'Din Email adresse',
'thankyouforbug'          => 'Tak for at rapportere din problem. Du kan se opgaven og følge dens udvikling fra adressen:',
'anonuser'                => 'Anonym bruger',
'conflict'                => 'Konflikt',
'file'                    => 'Fil',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => 'Størrelse',
'projectgroup'            => 'Projektgruppe',
'profile'                 => 'Profil:',
'viewprofile'             => 'Vis profil',
'regdate'                 => 'Oprettet siden',
'tasksopened'             => 'Opgaver åbnet',
'replyto'                 => 'Svar til',
'notifytypes'             => 'Beskedtyper',
'pm.taskchanged'          => 'Opgave ændret',
'pm.taskreopened'         => 'Opgave genåbnet',
'pm.depadded'             => 'Sammenkædning tilføjet',
'pm.depremoved'           => 'Sammenkædning fjernet',
'pmrequest'               => 'PL anmodning',
'pmrequestdenied'         => 'PL anmodning afvist',
'newassignee'             => 'Ny modtager',
'revdepadded'             => 'Modsat sammenkædning tilføjet',
'revdepaddedremoved'      => 'Modsat sammenkædning fjernet',
'assigneeadded'           => 'Modtager tilføjet',
'addusergroup'            => 'Bruger tilføjet til gruppe',
'groupmembers'            => 'Gruppe medlemmer',
'deleteuser'              => 'Slet denne bruger',
'userdeleted'             => 'Bruger slettet',
'autoassign'              => 'Auto-tildel opgaver til kategori ejer',
'ssl'                     => 'SSL',
'updatewrong'             => "Du har valgt at du vil modtage information om nye opdateringer, men der skete en fejl da systemet prøvede at kontakte Flyspray serveren. Dette kan skyldes problemer på netværket, eller en indstilling i en firewall.\nGå til Flysprays hjemmeside for at se om du benytter den nyeste version.",
'deleteproject'           => 'Slet dette projekt og flyt indhold til',
'projectdeleted'          => 'Projektet blev slettet',
'feedforall'              => 'Newsfeed fra alle projekter',
'usercreated'             => 'Bruger oprettet',
'created'                 => 'Oprettet',
'deleted'                 => 'Slettet',
'userid'                  => 'Bruger ID',
'editassignments'         => 'Rediger tildelinger',
'preview'                 => 'Vis',
'tasksrelated'            => 'Opgaver relateret til denne opgave',
'duplicatetasks'          => 'Kopier af denne opgave',
'databasemodfailed'       => 'Modificering af dabasen mislykkes. Dette kan skyldes manglende rettigheder.',
'frequency'               => 'Hyppighed',
'newuserregistered'       => 'En ny bruger har registreret sig i din Flyspray installation med følgende data:',
'newuserregisterednotify' => 'Ny brugeroprettelse',
'notify_registration'     => 'Send besked til administratorer når nye brugerre oprettes',
'textversion'             => 'Tekst version',
'onlyprimary'             => 'Opgaver der ikke blokerer andre opgaver',
'switch'                  => 'Skift',
'max'                     => 'max.',
'dates'                   => 'Datoer',
'selectduedatefrom'       => 'Forfaldsdato fra',
'selectduedateto'         => 'til',
'selectsincedatefrom'     => 'Redigeret fra',
'selectsincedateto'       => 'til',
'selectdate'              => 'Vælg dato',
'selectopenedfrom'        => 'Oprettet fra',
'selectopenedto'          => 'til',
'selectclosedfrom'        => 'Lukket fra',
'selectclosedto'          => 'til',
'startat'                 => 'Startet fra',
'hasattachment'           => 'Har vedhæftede filer',
'private'                 => 'Privat',
'watching'                => 'Overvåger',
'alreadyvotedthistask'    => 'Du stemte',
'visibility'              => 'Synlighed',
'public'                  => 'Offentlig',
'leaveemptyauto'          => 'Udfyld ikke kodeord hvis det skal autogenereres.',
'novalidemail'            => 'Du har ikke skrevet en gyldig Email adresse.',
'novalidjabber'           => 'Du har ikke skrevet et gyldigt Jabber ID.',
'missingrequired'         => 'Du har ikke udfyldt alle felter.',
'entervalidusername'      => 'Du skal skrive et gyldigt brugernavn, samt det fulde navn.',
'couldnotaddusernotif'    => 'Denne bruger kunne ikke tilføjes påmindelseslisten.',
'defaulttask'             => 'Standard opgavebeskrivelse',
'all'                     => 'alle',
'events.useraddedtoassignees'=> 'Bruger tildelt denne opgave',
'vote(s)'                 => 'Stemme(r)',
'eventlog'                => 'Aktivitetslog',
'assignmentchanged'       => 'Tildeling ændret',
'detailedinfo'            => 'Detaljer',
'All'                     => 'Alle',
'tasksireported'          => 'Opgaver jeg har oprettet',
'recentlyopened'          => 'Nyligt åbnede',
'stats'                   => 'Statistik',
'totaltasks'              => 'opgaver i alt',
'mostwanted'              => 'Mest populære opgaver',
'defaultentry'            => 'Standardside (Default entry page) ???',
'overview'                => 'Oversigt',
'error#'                  => 'Fejl #',
'error1'                  => 'Du har ikke rettigheder til at se den vedhæftede fil.',
'error3'                  => 'Gentaget handling. Du videresendes til forsiden. ???',
'error4'                  => 'Du har ikke administrative rettigheder.',
'error5'                  => 'Denne bruger eksisterer ikke.',
'error6'                  => 'Forkert administrationsområde (Invalid admin area) ???',
'error7'                  => 'Forkert brugernavn eller kodeord!',
'error71'                 => 'Din brugerkonto er låst i %d minutter grundet for mange mislykkede forsøg på at logge ind!',
'error8'                  => 'Du har ikke skrevet både brugernavn og kodeord.',
'error9'                  => 'Opgaven eksisterer ikke eller du har ikke rettigheder til at se den.',
'error10'                 => 'Opgaven eksisterer ikke.',
'error101'                => 'Du har ikke rettigheder til at se denne opgave.',
'error102'                => 'Du har ikke rettigheder til at se denne opgave. Du skal logge ind først.',
'error11'                 => 'Du har ikke rettigheder til at redigere denne kommentar.',
'error13'                 => 'Anonyme brugere har ikke en profil.',
'error14'                 => 'Du har ikke rettigheder til at oprette grupper.',
'error15'                 => 'Du har ikke rettigheder til at åbne opgaver.',
'error16'                 => 'Du er ikke projektansvarlig',
'error17'                 => 'Ugyldigt PM område (PM = PA) ???',
'error18'                 => 'Ugyldig Magic URL',
'error19'                 => 'Denne bruger eksisterer ikke.',
'error20'                 => 'Ugyldig database modificering.',
'error21'                 => 'En eller flere mails kunne ikke sendes. Check din cinfiguration.',
'error22'                 => 'Der er lukket for oprettelse af nye brugere.',
'error23'                 => 'Bruger eller gruppe ikke aktiveret for log ind.',
'error24'                 => 'Der er hverken angivet en dot executable eller en offentlig dot server.',
'error25'                 => 'Roadmap er kun tilgængelig for et specifikt projekt.',
'done'                    => 'færdig',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projektet kunne ikke slettes.',
'GMT'                     => 'GMT',
'timezone'                => 'Tids zone',
'accept'                  => 'Accept',
'reasonfordeinal'         => 'Årsag til afvisning',
'lastuser'                => 'Den sidste bruger kan ikke slettes.',
'allprivate'              => 'Alle projekter er private.',
'deletegroup'             => 'Slet denne gruppe og flyt brugere til',
'parent'                  => 'Overordnet',
'allpriorities'           => 'Alle prioriteter',
'expand'                  => 'Fold ud',
'collapse'                => 'Fold sammen',
'expandall'               => 'Fold alle ud',
'collapseall'             => 'Fold alle sammen',
'minpwsize'               => 'Kodeord skal minimum bestå af 5 tegn',
'passwordtoosmall'        => 'Kodeord er for kort.',
'accountwaslocked'        => 'Din brugerkonto er blevet lukket grundet for mange mislykkede forsøg på at logge ind.',
'failedattempts'          => '%d mislykkede forsøg på at logge ind.',
'groupnotexist'           => 'Den valgte gruppe er ikke tilkyttet dette projekt.',
'find'                    => 'Søg (find) ???',
'tls'                     => 'TLS',
);

?>
