<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
//
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
//
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => '编辑用户',
'accountenabled'          => '账户启用',
'editallusers'            => '查看所有用户',
'username'                => '用户名',
'usersupdated'            => '用户成功地更新',
'realname'                => '真实姓名',
'emailaddress'            => '邮件地址',
'jabberid'                => 'Jabber ID',
'profileimage'            => '资料图片',
'notifytype'              => '通知类型',
'group'                   => '群组',
'enableaccounts'          => '启用帐户',
'disableaccounts'         => '禁用帐户',
'deleteaccounts'          => '删除账户',
'updatedetails'           => '更新详细信息',
'setglobally'             => '这个常规设置被设为全局的了.',
'usergroupmanage'         => '用户和群组管理',
'newuser'                 => '注册新用户',
'newuserbulk'             => '注册多个新用户',
'bulkuserstoadd'          => '新用户列表',
'optionsforallusers'      => '所有新用户选项',
'newgroup'                => '创建群组',
'yes'                     => '是',
'no'                      => '否',
'editgroup'               => '编辑群组',
'groupname'               => '群组名',
'description'             => '描述',
'admin'                   => '管理群组',
'opennewtasks'            => '打开新任务',
'modifytasks'             => '修改任务',
'addcomments'             => '添加评论',
'attachfiles'             => '附件',
'vote'                    => '投票',
'groupenabled'            => '成员可以登录',
'groupopen'               => '允许用户登录',
'tasktypelist'            => '任务类型列表',
'categorylist'            => '模块列表',
'oslist'                  => '操作系统列表',
'resolutionlist'          => '解决方式列表',
'versionlist'             => '版本列表',
'severitylist'            => '问题严重性列表',
'listnote'                => '注意:  在编辑模式下，取消 "显示"复选框会改变一些任务. 修改 "名称"字段会用这个名称修改全部任务.',
'name'                    => '名称',
'order'                   => '顺序',
'back'                    => '后退',
'text'                    => '文本',
'highlight'               => '高亮',
'show'                    => '显示',
'owner'                   => '主管',
'selectowner'             => '选择所有者',
'update'                  => '更新',
'addnew'                  => '增加',
'flysprayprefs'           => 'Flyspray 常规设置',
'projecttitle'            => '项目标题',
'baseurl'                 => 'Base URL for 这个安装',
'replyaddress'            => '通知的回复电子邮件地址',
'themestyle'              => '主题 / 样式',
'customstyle'             => '自定义',
'language'                => '语言',
'anonview'                => '允许匿名用户查看任务',
'allowanon'               => '允许匿名用户打开新任务',
'never'                   => '从不',
'anonymously'             => '匿名',
'afterregister'           => '只有在注册之后',
'spamproof'               => '启用新用户注册确认码',
'anongroup'               => '新用户注册的群组',
'groupassigned'           => '这些群组的成员能被指派任务',
'forcenotify'             => '任务通知方式',
'neversend'               => '不发送',
'userchoose'              => '让用户自己选择',
'email'                   => '电子邮件',
'jabber'                  => 'Jabber',
'defaultcatowner'         => '默认的模块主管',
'noone'                   => '不要',
'jabbernotify'            => 'Jabber通知',
'jabberserver'            => '服务器',
'jabberport'              => '端口',
'jabberuser'              => '账户用户名',
'jabberpass'              => '账户口令',
'saveoptions'             => '保存选项',
'editcomment'             => '编辑评论',
'commentby'               => '评论人',
'saveeditedcomment'       => '保存评论',
'projectprefs'            => '项目常规设置',
'pagetitle'               => '页面标题',
'defaultproject'          => '默认的项目',
'projectlists'            => '项目列表',
'showlogo'                => '显示标题图像',
'showgravatars'           => '显示头像',
'emailNoHTML'             => '没有HTML电子邮件',
'intromessage'            => '介绍性信息',
'active'                  => '活动',
'inactive'                => '不活动',
'isactive'                => '项目是活动的',
'showinactive'            => '显示不活动项目',
'hideinactive'            => '隐藏不活动项目',
'createproject'           => '创建一个新项目',
'nopermission'            => '您没有权限使用这个页面.',
'listordertip'            => '这些条目的顺序将显示在列表里',
'listshowtip'             => '在列表里显示这个条目 ',
'categoryownertip'        => '当这个模块中打开一个任务时，这个人将收到通知',
'categoryparenttip'       => '这个新模块的上级模块将会降级',
'notsubcategory'          => '无 (顶级模块)',
'showinlineimages'        => '嵌入显示图像附件',
'dateformat'              => '日期格式',
'dateformat_extended'     => '详细日期格式',
'cache_feeds'             => '聚合缓存',
'no_cache'                => '不缓存',
'cache_disk'              => '缓存到磁盘',
'cache_db'                => '缓存到数据库',
'subcategoryof'           => '子模块',
'visiblecolumns'          => '任务列表中显示的列',
'visiblefields'           => '当添加/编辑/查看任务时',
'tense'                   => '时间',
'listtensetip'            => '过去的, 现在的或者将来的',
'past'                    => '过去的',
'present'                 => '现在的',
'future'                  => '将来的',
'oldpass'                 => '旧的口令',
'nooldpass'               => '没有设置旧的口令',
'oldpasswrong'            => '旧的口令是错的',
'changepass'              => '修改口令',
'confirmpass'             => '确认口令',
'projectmanager'          => '项目经理',
'viewtasks'               => '查看任务',
'modifyowntasks'          => '修改自己主管的任务',
'modifyalltasks'          => '修改不属于用户主管的任务',
'viewcomments'            => '查看评论',
'editcomments'            => '编辑评论',
'deletecomments'          => '删除评论',
'viewattachments'         => '查看附件',
'createattachments'       => '创建附件',
'deleteattachments'       => '删除附件',
'viewhistory'             => '查看历史',
'closeowntasks'           => '关闭主管任务',
'closeothertasks'         => '任务不是用户主管的关闭',
'assigntoself'            => '如果没有被指派，指派任务给自己',
'assignotherstoself'      => '指派其他人的任务到自己',
'viewreports'             => '查看事件日志',
'othersview'              => '允许任何人查看这个项目的任务',
'othersviewroadmap'       => '允许任何人查看这个项目的视图',
'usersandgroups'          => '用户群组',
'globalgroup'             => '全局群组',
'globalgroups'            => '全局群组',
'defaultglobalgroup'      => '新用户默认的全局群组',
'addtogroup'              => '增加到群组',
'moveuserstogroup'        => '移动用户到群组',
'nogroup'                 => '无群组 - 从项目移除',
'eventdesc'               => '事件描述',
'requestedby'             => '申请人',
'daterequested'           => '申请日期',
'closetask'               => '关闭任务',
'reopentask'              => '重新打开任务',
'applymember'             => '申请项目成员资格',
'forcurrentproj'          => '当前的项目',
'lostpw'                  => '找回丢失的口令',
'lostpwexplain'           => '请输入您的用户名，我们会发送一个修改您口令的链接到您的个人资料中填写的通知邮件地址.',
'sendlink'                => '发送链接',
'savenewpass'             => '保存新口令',
'anonreg'                 => '允许新用户注册',
'allowanonopentask'       => '允许匿名用户打开任务',
'editglobalgroup'         => '编辑全局群组',
'editgroupforproj'        => '编辑项目的群组',
'notshownforadmin'        => '管理群组的权限没有显示.您不需要编辑它们.',
'general'                 => '常用',
'userregistration'        => '用户注册',
'notifications'           => '通知',
'resetoptions'            => '重置选项',
'preferences'             => '常规设置',
'tasktypes'               => '任务类型',
'resolutions'             => '解决方式',
'categories'              => '模块定义',
'categoriesglobal'        => '全局模块',
'categoriesproject'       => '项目模块',
'categoriestarget'        => '目标模块',
'operatingsystems'        => '操作系统',
'versions'                => '版本定义',
'admintoolboxlong'        => '管理员工具箱',
'newproject'              => '新建项目',
'delete'                  => '删除',
'link'                    => '链接',
'referencelinks'          => '参考链接',
'listdeletetip'           => '从列表中删除这个条目',
'lookandfeel'             => '外观',
'globaltheme'             => '全局主题',
'emailnotify'             => '电子邮件 通知',
'fromaddress'             => '发件地址',
'smtpserver'              => 'SMTP 服务器',
'smtpuser'                => 'SMTP 用户名',
'smtppass'                => 'SMTP 口令',
'addrewrite'              => '使用地址重写',
'usereminderdaemon'       => '启用后台提醒服务',
'tasksperpage'            => '每页任务列表显示的任务数',
'addtoassignees'          => '增加自己为被指派人',
'taskstatuses'            => '任务状态',
'canvote'                 => '可以对任务投票',
'loginsuccessful'         => '登录成功.',
'youareloggedout'         => '您已经注销了.',
'waitwhiletransfer'       => '请稍侯...',
'clicknowait'             => '如果您不想等待，请点这里.',
'accountdisabled'         => '您的账户被禁用了. 请联系管理员.',
'task'                    => '任务',
'edittask'                => '编辑这个任务',
'openedby'                => '任务创建者',
'editedby'                => '最后修改人：',
'tasktype'                => '任务类型',
'category'                => '模块',
'status'                  => '状态',
'assignedto'              => '指派到',
'operatingsystem'         => '操作系统',
'severity'                => '严重性',
'reportedversion'         => '报告版本',
'dueinversion'            => '计划完成版本',
'defaultdueinversion'     => '默认新任务计划完成版本',
'undecided'               => '未决定',
'percentcomplete'         => '完成百分比',
'details'                 => '详细信息',
'savedetails'             => '保存详细信息',
'canceledit'              => '取消编辑',
'anonymous'               => '匿名提交者',
'complete'                => '完成',
'closedby'                => '已关闭，操作者：',
'reasonforclosing'        => '关闭的理由:',
'reopenthistask'          => '重新打开这个任务',
'comments'                => '评论数量',
'attachments'             => '附件数量',
'relatedtasks'            => '关联任务',
'edit'                    => '编辑',
'addcomment'              => '增加评论',
'fileuploadedby'          => '文件上传，由',
'uploadafile'             => '附加一个文件',
'addalink'                => '添加一个链接',
'addanotherlink'          => '添加另一个链接',
'uploadnow'               => '现在上传!',
'thesearerelated'         => '这些任务被关联到这个任务了',
'remove'                  => '移除',
'addnewrelated'           => '增加一个新的关联任务',
'add'                     => '增加!',
'otherrelated'            => '这个任务关联的其他的任务',
'receivenotify'           => '当这个任务被修改时，下列用户将收到详细的通知.',
'addusertolist'           => '增加用户到通知列表',
'addtolist'               => '增加到列表',
'addmyself'               => '把我加入到这个列表中',
'removemyself'            => '从这个列表中移除我自己',
'theseusersnotify'        => '当这个任务被修改时，下面的用户将收到详细的通知.',
'attachedtoproject'       => '属于项目',
'reminders'               => '提醒',
'system'                  => '系统',
'systemvalues'            => '系统列表值范围',
'projectvalues'           => '项目的具体列表值',
'remindthisuser'          => '提醒用户',
'thisoften'               => '每隔',
'startafter'              => '启动提醒前等待',
'hour'                    => '小时',
'hours'                   => '小时',
'day'                     => '天',
'days'                    => '天',
'week'                    => '星期',
'weeks'                   => '星期',
'addreminder'             => '增加提醒',
'defaultreminder'         => '下面是 Flyspray 的任务提醒:',
'message'                 => '消息',
'closed'                  => '已解决的',
'filename'                => '文件名称:',
'date'                    => '日期',
'filesize'                => '文件大小:',
'closurecomment'          => '其它关于关闭的评论:',
'history'                 => '历史',
'nohistory'               => '没有历史.',
'eventdate'               => '日期',
'user'                    => '用户',
'event'                   => '事件',
'fieldchanged'            => '字段发生变动',
'taskopened'              => '任务被打开了',
'taskreopened'            => '任务被重新打开了',
'taskclosed'              => '任务被关闭了',
'commentadded'            => '增加了评论',
'commentedited'           => '修改了评论',
'commentdeleted'          => '删除了评论',
'attachmentadded'         => '附件增加了',
'attachmentdeleted'       => '附件删除了',
'taskedited'              => '任务详细信息修改了',
'notificationadded'       => '用户增加到通知列表了',
'notificationdeleted'     => '用户从通知列表中移除了',
'relatedadded'            => '关联任务增加了',
'relateddeleted'          => '关联任务移除了',
'taskassigned'            => '任务被指派到',
'taskreassigned'          => '任务被重新指派到',
'assignmentremoved'       => '指派被移除了',
'summary'                 => '标题',
'addedasrelated'          => '任务增加到其关联列表了：',
'deletedasrelated'        => '任务从其关联列表中移除了',
'reminderadded'           => '提醒增加了',
'reminderdeleted'         => '提醒删除了',
'priority'                => '优先级',
'previousvalue'           => '前一个值',
'newvalue'                => '新值',
'selectareason'           => '选择一个理由',
'assigntome'              => '指派到我',
'reopenrequest'           => '请求重新打开',
'requestclose'            => '请求关闭',
'ownershiptaken'          => '用户成为主管',
'closerequestmade'        => '申请任务关闭',
'reopenrequestmade'       => '申请任务被重新打开',
'taskdependson'           => '这个任务依赖',
'taskdependsontask'       => '任务取决于',
'taskdependsontasks'      => '任务取决于',
'taskblock'               => '这个任务被阻止关闭',
'taskblocks'              => '这个任务被阻止关闭',
'depadded'                => '依赖增加的',
'depaddedother'           => '这个任务增加为依赖',
'depremoved'              => '依赖移除',
'depremovedother'         => '这个任务从其他的任务依赖列表中移除了',
'showdetailserror'        => '任务不存在, 或者您没有查看它的权限。',
'makeprivate'             => '置为不公开',
'makepublic'              => '置为公开',
'taskmadeprivate'         => '任务成为不公开的了',
'taskmadepublic'          => '移除了私有属性 - 任务成为公开的了',
'confirmdeletecomment'    => '真的删除这个评论? %s',
'attachementswilldeleted' => '所有附件也将被删除!',
'confirmdeleteattach'     => '真的删除这个附件?',
'selectedhistory'         => '正在显示选定的历史详细信息',
'showallhistory'          => '重新显示全部历史标签',
'hidethis'                => '重新隐藏这个区域',
'mark100'                 => '标记任务为100%完成',
'watchtask'               => '关注任务',
'stopwatching'            => '停止关注',
'commentlink'             => '链接到这个评论',
'submitreq'               => '提交请求',
'reasonforreq'            => '这个请求的理由',
'pmreqdenied'             => '项目经理拒绝了请求',
'taskpendingreq'          => '项目经理操作被挂起.  进一步详细信息请查看历史页.',
'previoustask'            => '前一个任务',
'nexttask'                => '下一个任务',
'duedate'                 => '计划完成日期',
'attachnoperms'           => '这个评论有附件, 但是您没有权限查看',
'linknoperms'             => '这个评论有链接, 但是您没有权限查看',
'open'                    => '未解决的',
'depgraph'                => '查看依赖图表',
'reset'                   => '重置',
'selectusers'             => '选择用户...',
'addmetoassignees'        => '把我加入被指派人',
'addedtoassignees'        => '用户增加到被指派人列表',
'dependencygraph'         => '依赖图表',
'attachanotherfile'       => '附加另一个 文件',
'OK'                      => '好',
'addvote'                 => '增加投票',
'disable_lostpw'          => '禁止丢失密码检索',
'disable_changepw'        => '禁止密码创建/编辑',
'notifyfromfs'            => '来自Flyspray的通知',
'autogenerated'           => '这个是自动生成的消息,请勿回复',
'forward'                 => '向前',
'previous'                => '前一个',
'next'                    => '下一个',
'first'                   => '第一个',
'last'                    => '最后一个',
'page'                    => '第 %d 页，共 %d 页',
'search'                  => '搜索',
'alltasktypes'            => '全部任务类型',
'allseverities'           => '全部严重性级别',
'alldevelopers'           => '全部开发人员',
'notyetassigned'          => '尚未被指派',
'allcategories'           => '全部模块',
'allstatuses'             => '全部状态',
'allopentasks'            => '全部打开的任务',
'sortthiscolumn'          => '以此列排序',
'id'                      => 'ID',
'project'                 => '项目',
'dateopened'              => '创建时间',
'progress'                => '进度',
'searchthisproject'       => '在项目中搜索',
'dueanyversion'           => '延期到任何版本',
'anyversion'              => '任何版本中的报告',
'dueversion'              => '计划完成版本',
'lastedit'                => '最后修改时间',
'os'                      => '操作系统',
'reportedin'              => '报告',
'taskrange'               => '正在显示 任务 %d - %d (共%d 个)',
'noresults'               => '您的搜索没有返回结果.',
'takeaction'              => '操作',
'watchtasks'              => '关注选定的任务',
'stopwatchingtasks'       => '停止关注选定的任务',
'assigntaskstome'         => '将选定的任务指派给我',
'dueby'                   => '延期，由',
'dueanytime'              => '延期任意事件',
'selectduedate'           => '选择延期日期',
'toggleselected'          => '反选选定的',
'due'                     => '延期',
'assignedtome'            => '指派到我的',
'tasklist'                => '任务列表',
'dateclosed'              => '关闭的日期',
'advanced'                => '高级',
'searchcomments'          => '在评论中搜索',
'searchforall'            => '搜索全部词',
'anonusers'               => '匿名用户',
'miscellaneous'           => '杂项',
'users'                   => '用户',
'taskproperties'          => '任务属性',
'selectsincedate'         => '选择发生变动自从',
'changedsince'            => '发生变动自从',
'updatefs'                => '请更新Flyspray.',
'currentversion'          => '您的当前的版本是',
'latestversion'           => '，最新的版本是',
'hidemessage'             => '(以后提醒我)',
'saveas'                  => '保存搜索为',
'nosearches'              => '没有保存的搜索',
'saving'                  => '保存...',
'votes'                   => '投票',
'tovote'                  => '投票',
'allclosedtasks'          => '全部关闭的任务',
'password'                => '口令',
'login'                   => '登录!',
'rememberme'              => '记住我',
'lostpassword'            => '丢失了口令',
'lostpwforfs'             => '丢失了Flyspray的口令',
'lostpwmsg1'              => "您好。\n\n我丢失了 Flyspray 口令 ",
'lostpwmsg2'              => ", 请提供我一个新口令.\n\nUsername: ",
'regards'                 => "\n\n敬礼,",
'yourusername'            => ' 您的用户名 ',
'locale'                  => 'zh-CN',
'filenotexist'            => '文件不存在, 或者您没有权限访问它.',
'showtask'                => '显示任务',
'now'                     => '现在',
'go'                      => '开始!',
'opentaskanon'            => '匿名打开一个新任务',
'register'                => '注册',
'addnewtask'              => '增加新任务',
'reports'                 => '事件日志',
'editmydetails'           => '编辑我的详细信息',
'logout'                  => '注销',
'disabledaccount'         => '您的账户被禁用了!<br>即刻将您注销...',
'poweredby'               => 'Powered by Flyspray',
'sponsoredby'             => 'Flyspray 发起者',
'projects'                => '项目',
'allprojects'             => '全部项目',
'selectproject'           => '项目:',
'tasksall'                => '全部任务',
'tasksassigned'           => '被指派到我的任务',
'tasksreported'           => '我报告的任务',
'taskswatched'            => '我关注的 ',
'mysearch'                => '我的搜索',
'admintoolbox'            => '管理员工具箱',
'manageproject'           => '管理项目',
'permissions'             => '查看权限',
'hide'                    => '隐藏',
'pendingreq'              => '项目经理请求正在等待',
'errorpage'               => "Flyspray 不能提供您申请的页面 .\n       也许您申请的任务不存在, 或者您\n       没有权限查看您想要的页面.<br /><br />\n       您可能在试图访问数据库.  果真如此, 想想您做的操作.  返回之后, 请不要再做了!",
'permissionsforproject'   => '权限：',
'switchto'                => '切换到',
'lastsearch'              => '上次搜索',
'modify'                  => '修改',
'noticefrom'              => '提醒，来自：',
'hasopened'               => '打开了一个新的任务, 并把它指派给您:',
'moreinfonew'             => '您在下面页面找到关于这个错误的更多信息:',
'newtaskcategory'         => '这个模块中有一个新任务被打开了',
'categoryowner'           => '因为您是这个模块的主管，所以您能收到这个消息.',
'tasksummary'             => '任务标题:',
'newtaskadded'            => '您有一个新任务.',
'summaryanddetails'       => '标题和详细信息您都需要填写.',
'summaryrequired'         => '你需要填写一个简短的任务总结',
'goback'                  => '返回.',
'messagefrom'             => '这个是一个来自Flyspray 错误跟踪系统的消息',
'hasjustmodified'         => '刚刚修改了下面的任务.',
'changedfields'           => '发生了变动的字段由星号(**)前缀',
'moreinfomodify'          => '您能在下面的URL得到更多关于这个任务的信息:',
'nolongerassigned'        => '下面的任务不再被指派到您了,它现在被指派到',
'hasassigned'             => '已经指派给您下面的Flyspray 任务:',
'taskupdated'             => '任务被更新了.',
'tasksupdated'            => '任务已经更新了.',
'hasclosedassigned'       => '已经关闭了下面这些指派到您的任务:',
'unassigned'              => '未指派的',
'hasclosed'               => '已经关闭了下面这些任务.',
'youonnotify'             => '您正在接收这个，因为您在通知列表中.',
'taskclosedmsg'           => '任务已经被关闭了.',
'returntotask'            => '返回到任务详细信息',
'backtoindex'             => '回到任务列表',
'noclosereason'           => '您需要选择一个理由来关闭这个任务.',
'hasreopened'             => '已经重新打开了下面这些被您关闭的Flyspray 任务:',
'taskreopenedmsg'         => '任务被重新打开了.',
'backtotask'              => '回到任务.',
'commentaddedmsg'         => '已增加评论。',
'commenttoassigned'       => '一个指派到您的任务增加了一个评论:',
'commenttotask'           => '已经给这个任务了增加了下面的评论',
'nocommententered'        => '在提交之前，您需要填写评论内容',
'fillinfields'            => '您没有填写全部的信息',
'notcurrentpass'          => '这不是您的当前的口令!',
'passchanged'             => '您的口令被修改了.',
'closewindow'             => '您现在可以关闭这个窗口.',
'passnomatch'             => '您的输入的两个新口令不一致!',
'usernametaken'           => '这个用户名已经存在了.  您需要再选择一个.',
'usernametakenbulk'       => '用户名已经被占用了.',
'newusercreated'          => '新用户账户被创建了.',
'accountcreated'          => '您的账户被创建了',
'newuserwarning'          => '注意全局常规设置可能需要由管理员批准您的账户. 如果您不能登录, 可能是因为这个原因.',
'nomatchpass'             => '口令不匹配.',
'confirmwrong'            => '确认码不正确!',
'formnotcomplete'         => '表单没有完全填写.',
'formnotnumeric'          => '插入的数据不是数字!',
'groupnametaken'          => '这个群组名称已经被占用了.',
'newgroupadded'           => '增加了一个新群组.',
'optionssaved'            => 'Flyspray 的选项保存了.',
'hasuploaded'             => '上传了一个文件附件到被指派的任务:',
'hasattached'             => '附加了一个文件到下面的 任务.',
'fileuploaded'            => '上传了一个文件.',
'fileerror'               => '上传您的文件时发生错误. 也许<i>附件/</i>目录的权限不正确.',
'contactadmin'            => '联系这个项目的管理员.',
'selectfileerror'         => '您没有选择文件.',
'userupdated'             => '用户的详细信息已经被更新了',
'realandemail'            => '您没有填写真实名称和电子邮件地址.',
'groupupdated'            => '群组定义更新了.',
'groupanddesc'            => '您没有填写群组名称.',
'fillallfields'           => '请填写全部信息.',
'listPmustN'              => '"顺序" 这里只能填写数字.',
'listupdated'             => '列表更新了.',
'listitemadded'           => '增加了一个新列表条目.',
'relatedaddedmsg'         => '关联任务增加到列表中了.',
'relatederror'            => '这个任务已经在这个关联任务列表里了.',
'relatedremoved'          => '关联任务从列表中移除了.',
'notifyadded'             => '用户增加到通知列表了.',
'notifyerror'             => '这个用户已经在任务的通知列表中了.',
'notifyremoved'           => '用户从通知列表中移除了.',
'editcommentsaved'        => '更新的评论已保存。',
'commentdeletedmsg'       => '评论已经被删除了。',
'gotonewtask'             => '到您刚刚创建的新任务去',
'projectcreated'          => '您创建了新项目.  点击下面链接设置模块, 操作系统和版本列表',
'customiseproject'        => '定制这个项目',
'projectupdated'          => '项目常规设置更新了',
'emptytitle'              => '您没有输入项目标题.',
'loginbelow'              => '您现在可以登录了.',
'attachmentdeletedmsg'    => '附件被删除了',
'reminderaddedmsg'        => '增加了一个您的提醒.',
'reminderdeletedmsg'      => '选中的提醒被删除了.',
'flyspraytask'            => 'Flyspray任务',
'fieldsmissing'           => '一些字段没有数据或者数据无效.',
'relatedinvalid'          => '没有这个任务.',
'relatedproject'          => '这个任务属于不同的项目. 还要增加关联吗?',
'addanyway'               => '增加',
'cancel'                  => '取消',
'alreadyedited'           => '这个任务在您保存之前被其他人修改了.您还要继续保存吗?',
'saveanyway'              => '继续保存',
'nouserselected'          => '没有选择用户. 选择只少一个用户再试一次.',
'groupswitchupdated'      => '用户群组 修改 成功地.',
'takenownershipmsg'       => '这个任务现在被指派给您了.',
'adminrequestmade'        => '您的请求被发送到项目经理了.',
'newdepnotify'            => '一个新的依赖被增加到下面的任务:',
'dependadded'             => '增加了一个任务依赖',
'dependaddfailed'         => '增加依赖时出现错误. 检查任务是否存在，以及任务之间没有相互阻止.',
'depremovedmsg'           => '任务依赖被移除了',
'newdepis'                => '新的依赖是',
'magicurlsent'            => '向您的通知地址发送了消息. 包含一个完成任务所需要的链接.',
'changefspass'            => '修改Flyspray口令',
'magicurlmessage'         => '请进入下面地址以修改口令:',
'erroronform'             => '提交表单时出现问题',
'addressused'             => '这个信息是用于注册Flyspray账户.  如果这是您不需要的信息，请删除它. 进入下面的链接完成注册:',
'confirmcodeis'           => '您的确认码是:',
'codesent'                => '您的确认码发出了.  请按照消息中的提示操作.',
'codenotsent'             => '无法发送确认码, 请稍候重试.',
'taskmadeprivatemsg'      => '这个任务被置为不公开了',
'taskmadepublicmsg'       => '这个任务被重新置为公开了',
'realandnotify'           => '您需要填写真实姓名字段, 邮件地址和Jabber ID至少要填一项.',
'pmreqdeniedmsg'          => '项目经理请求被拒绝了',
'massopsuccess'           => '批量操作成功',
'usernotexist'            => '用户不存在',
'commentattachperms'      => '您不能删除这个评论- 没有删除附件的权限',
'voterecorded'            => '您的投票被记录了',
'votefailed'              => '您的投票现在不能加入.',
'createnewgroup'          => '创建新的群组',
'requiredfields'          => '必填字段后面标记了一个',
'addthisgroup'            => '增加这个群组',
'createnewproject'        => '创建一个新项目',
'addnewproject'           => '增加新的项目',
'htmlallowed'             => '可以使用HTML代码',
'createthisproject'       => '创建这个项目',
'inlineimages'            => '嵌入显示图片附件',
'createnewtask'           => '在项目中创建一个新的任务:',
'addanother'              => '在此之后，增加另一个任务',
'addthistask'             => '增加这个任务',
'notifyme'                => '当任务发生变化时通知我',
'newtask'                 => '新任务',
'attachafile'             => '附加一个文件',
'registernewuser'         => '注册新用户',
'none'                    => '无',
'registeraccount'         => '注册这个账户',
'registerbulkaccount'     => '注册账户',
'both'                    => '两者都要',
'notifyfrom'              => 'FlySpray通知:来自',
'donotreply'              => '这是一个自动发送的消息，请勿回复.',
'disclaimer'              => '根据您从Flyspray 错误跟踪系统请求，我们发送了这个消息. 您可以进入下面链接取消此类消息的发送.',
'userwho'                 => '做此操作的用户是',
'moreinfo'                => '从下面URL可以得到详细信息:',
'newtaskopened'           => '一个新的Flyspray任务被打开了.  详情如下.',
'notify.taskclosed'       => '下面的任务现在被关闭了:',
'notify.taskreopened'     => '下面的任务已经被重新打开了:',
'newdep'                  => '下面的任务增加了一个新的依赖:',
'notify.depremoved'       => '下面的任务移除了一个依赖:',
'olddepwas'               => '原来的依赖是',
'notify.commentadded'     => '下面的任务增加了一个新的评论:',
'commentis'               => '评论内容如下.',
'newattachment'           => '一个新的文件被附加到下面的任务:',
'detailsbelow'            => '详情如下.',
'notify.relatedadded'     => '一个新的关联任务被增加到下面的任务:',
'relatedis'               => '关联任务是',
'assignedtoyou'           => '您被指派到下面的任务:',
'takenownership'          => '成为了下面的任务的主管:',
'requiresaction'          => '下面的任务需要项目经理的操作:',
'requiresactionnotify'    => '任务需要项目经理的操作',
'pmdeny'                  => '项目经理拒绝了的下面任务的请求挂起:',
'pmdenynotify'            => '项目经理拒绝了请求',
'fileaddedtoo'            => '这个评论有文件附件.',
'taskwatching'            => '您正在关注下面的任务',
'isdepfor'                => '是一个新的依赖，对于',
'denialreason'            => '拒绝的理由',
'taskchanged'             => '下面的任务被变更了.变更列在下面.想得到详细的变更信息,请访问下面链接，并点历史页.',
'useraddedtoassignees'    => '用户把自己加入到这个任务的指派用户了.',
'removeddepis'            => '被移除的依赖是',
'isnodepfor'              => '不再是依赖了，对于',
'usergroups'              => '用户群组',
'pmtoolbox'               => '项目经理工具箱',
'groupmanage'             => '群组管理',
'pendingrequests'         => '挂起的请求',
'reasongiven'             => '给出的理由',
'nopendingreq'            => '没有挂起的项目经理请求.',
'givereason'              => '给出一个理由',
'catlisted'               => '模块列表编辑',
'oslisted'                => '操作系统列表编辑',
'verlisted'               => '版本列表编辑',
'tasktypeed'              => '任务类型列表编辑',
'resed'                   => '解决方式列表编辑',
'deny'                    => '拒绝',
'notifiedwhen'            => '通知在',
'onlynewtasks'            => '新任务被打开了',
'allevents'               => '任何任务中的任何事件',
'feeds'                   => '聚合',
'feeddescription'         => '聚合订阅',
'feedimgurl'              => '聚合图像链接 (没有请不要填)',
'notifysubject'           => '通知主题',
'notifysubjectinfo'       => '(%p =项目标题, %s = 任务标题, %t = 任务ID, %a = 操作, %u = 用户名)',
'priority6'               => '必须马上解决',
'priority5'               => '尽快解决',
'priority4'               => '紧急',
'priority3'               => '高',
'priority2'               => '普通',
'priority1'               => '低',
'sendcode'                => '发送确认码!',
'entercode'               => '输入您收到的确认码. 并输入您的账户口令.',
'confirmationcode'        => '确认码',
'registererror'           => '填写所有必填字段,输入正确的通知类型.',
'validusername'           => '(只可接受数字，英文字符和 - _ . )',
'validemail'              => '(使用 ; 分离多个电子邮件地址)',
'emailtakenbulk'          => '邮件地址已经被占用.',
'emailtaken'              => '邮件地址或Jabber ID被占用了. 您需要再选择一个.',
'note'                    => '<strong>注意:</strong>  在您的账户创建之前，我们将发送给您一个确认码. 确认码使用您上面选择的通知方式.<br />如果您输入的信息是错误的,您将<strong>不会收到确认码</strong>.',
'changelog'               => '变更日志',
'changeloggen'            => '变更日志生成',
'listfrom'                => '列出变更日志项',
'to'                      => '到',
'oldestfirst'             => '旧的在前',
'recentfirst'             => '近期在前',
'severityrep'             => '严重性报告',
'totalopen'               => '全部打开的任务',
'age'                     => '寿命',
'agerep'                  => '寿命报告',
'eventsrep'               => '事件报告',
'events'                  => '事件',
'Tasks'                   => '任务',
'opened'                  => '未解决的',
'edited'                  => '已修改的',
'assigned'                => '指派的',
'within'                  => '居于',
'pastday'                 => '上一日',
'pastweek'                => '上一周',
'pastmonth'               => '上一月',
'pastyear'                => '上一年',
'nolimit'                 => '不限',
'from'                    => '从',
'duein'                   => '延期到',
'selectfromdate'          => '选择开始日期',
'selecttodate'            => '选择结束日期',
'showvoters'              => '显示隐藏投票人',
'roadmap'                 => '路线图',
'roadmapfor'              => '版本的路线图',
'tasks'                   => '任务',
'completed'               => '完成了.',
'opentasks'               => '个打开的任务',
'of'                      => '% ,全部',
'severity5'               => '严重',
'severity4'               => '高',
'severity3'               => '中',
'severity2'               => '低',
'severity1'               => '很低',
'Redirect'                => '转向',
'redirectmsg'             => '如果您的浏览器 不支持HTTP重定向请点这个%sHERE%s链接 ',
'allowclosedcomments'     => '允许对关闭的任务评论',
'comment'                 => '评论',
'editowncomments'         => '编辑自己的评论',
'reopened'                => '重新打开了',
'loading'                 => '载入...',
'notifyown'               => '主管的任务发生变更时也发送通知',
'youremail'               => '您的电子邮件地址',
'thankyouforbug'          => '感谢您报告您的问题. 您可以通过下面的链接看到这个任务并且随时观察它的进度:',
'anonuser'                => '匿名用户',
'conflict'                => '冲突',
'file'                    => '文件',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => '大小',
'projectgroup'            => '项目群组',
'profile'                 => '个人资料:',
'viewprofile'             => '查看个人资料',
'regdate'                 => '注册时间',
'tasksopened'             => '打开的任务',
'replyto'                 => '回复到',
'notifytypes'             => '通知类型',
'pm.taskchanged'          => '任务变更了',
'pm.taskreopened'         => '任务重新打开了',
'pm.depadded'             => '依赖增加了',
'pm.depremoved'           => '依赖移除了',
'pmrequest'               => '项目经理请求',
'pmrequestdenied'         => '项目经理请求被拒绝了',
'newassignee'             => '新的被指派人',
'revdepadded'             => '反向依赖增加了',
'revdepaddedremoved'      => '反向依赖移除了',
'assigneeadded'           => '增加了被指派人',
'addusergroup'            => '向这个组增加用户',
'groupmembers'            => '群组成员',
'deleteuser'              => '删除这个用户',
'userdeleted'             => '用户删除了',
'autoassign'              => '自动为模块主管分配一个任务',
'ssl'                     => 'SSL',
'updatewrong'             => "您选择了自动更新功能,\n   但是在连结服务器时出现问题, 也许您无法访问因特网\n   或者由于网络故障造成.\n   请访问Flyspray 网站确认您运行的是最新版本的FlySpray.",
'deleteproject'           => '删除这个项目并把内容移至',
'projectdeleted'          => '项目被成功地删除了',
'feedforall'              => '所有项目的聚合',
'usercreated'             => '用户创建了',
'created'                 => '创建了',
'deleted'                 => '删除了',
'userid'                  => '用户ID',
'editassignments'         => '编辑任务指派',
'preview'                 => '预览',
'anyprogress'             => '任何进度',
'tasksrelated'            => '这个任务的关联任务',
'duplicatetasks'          => '这个任务的重复任务',
'databasemodfailed'       => '修改数据库失败. 可能是没有足够的权限.',
'frequency'               => '频度',
'newuserregistered'       => '一个新的用户注册了. 用户的详细情况如下所示:',
'newuserregisterednotify' => '一个新的用户注册了',
'notify_registration'     => '新用户注册时通知管理员',
'textversion'             => '纯文本版本',
'onlyprimary'             => '任务没有阻止其他任务',
'onlyblocker'             => '任务阻止其他任务',
'blockerornoblocker'      => '拦截器或非拦截器,选择两个过滤器选项没有意义。',
'switch'                  => '进入',
'max'                     => '最大',
'dates'                   => '日期',
'selectduedatefrom'       => '延期的 从',
'selectduedateto'         => '到',
'selectsincedatefrom'     => '变更的 从',
'selectsincedateto'       => '到',
'selectdate'              => '选择日期',
'selectopenedfrom'        => '打开的 从',
'selectopenedto'          => '到',
'selectclosedfrom'        => '关闭的从',
'selectclosedto'          => '到',
'startat'                 => '开始于',
'hasattachment'           => '有附件',
'private'                 => '不公开的',
'watching'                => '关注',
'alreadyvotedthistask'    => '您对这个任务投了票',
'alreadyvotedthisday'     => '今天已经投过票了',
'visibility'              => '可见',
'public'                  => '公开',
'leaveemptyauto'          => '如果您想要自动生成口令，请不要填写口令字段.',
'novalidemail'            => '您输入的邮件地址不正确.',
'novalidjabber'           => '您输入的Jabber ID不正确.',
'missingrequired'         => '您没有填写全部的必填字段.',
'entervalidusername'      => '请输入有效的用户名和真实姓名.',
'couldnotaddusernotif'    => '不能把用户加入到通知列表.',
'defaulttask'             => '默认任务描述',
'all'                     => '全部',
'events.useraddedtoassignees'=> '用户成为被指派人',
'eventlog'                => '事件日志',
'assignmentchanged'       => '指派发生了变动',
'detailedinfo'            => '详细信息',
'All'                     => '全部',
'tasksireported'          => '我报告的',
'recentlyopened'          => '最近打开的',
'stats'                   => '状态',
'totaltasks'              => '个全部的任务',
'mostwanted'              => '最想要的任务',
'defaultentry'            => '默认入口页面',
'toplevel'                => '最上级查看',
'overview'                => '总览',
'error#'                  => '错误 #',
'error1'                  => '您没有查看这个附件所需的权限.',
'error3'                  => '重复的操作, 回到主页.',
'error4'                  => '您没有管理权限.',
'error5'                  => '这个用户不存在.',
'error6'                  => '无效的管理员区域.',
'error7'                  => '登录失败(用户名或者口令错误)!',
'error71'                 => '帐户被锁定%d分钟由于太多失败的登录尝试!',
'error8'                  => '您没有用户名或者口令.',
'error9'                  => '任务不存在或者没有权限查看这个任务.',
'error10'                 => '任务不存在或者没有权限查看这个任务.',
'error101'                => '您没有权限查看此任务.',
'error102'                => '您没有权限查看此任务,登录可能会有所帮助.',
'error11'                 => '没有编辑这个评论的权限。',
'error12'                 => '无效的激活码!请核实一下?',
'error13'                 => '匿名用户没有个人资料.',
'error14'                 => '您没有足够的权限创建一个新的群组.',
'error15'                 => '您没有足够的权限打开一个任务.',
'error16'                 => '您不是项目经理.',
'error17'                 => '无效的项目经理区域.',
'error18'                 => '无效的激活地址链接.',
'error19'                 => '用户不存在.',
'error20'                 => '无效的数据库修改.',
'error21'                 => '邮件发送失败，请检查配置.',
'error22'                 => '不允许新用户注册.',
'error23'                 => '用户或群组不允许登录.',
'error24'                 => '被设置的既不是一个可执行文件也不是一个公共服务器.',
'error25'                 => '只有在指定的项目中路线图才可用.',
'error26'                 => '不支持认证提供者.',
'error27'                 => '无法登录。授权我们查看您的电子邮件区域.',
'error28'                 => '你没有权限访问该地区',
'done'                    => '完成',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => '项目不能被删除.',
'GMT'                     => 'GMT',
'timezone'                => '时区',
'accept'                  => '接受',
'reasonfordeinal'         => '拒绝的理由',
'pruneclosedlinks'        => '删除关闭的链接',
'pruneclosedtasks'        => '删除关闭的任务',
'pagegenerated'           => '页面和图形在 %d 秒内生成.',
'pruninglevel'            => '正在删除级别',
'lastuser'                => '最后的用户不能被删除.',
'allprivate'              => '所有的项目都是不公开的.',
'deletegroup'             => '删除这个群组，把用户移到',
'parent'                  => '上级',
'ordertip'                => '条目的顺序会在列表中显示',
'showtip'                 => '在列表中显示这一条',
'deletetip'               => '从列表中删除这一条',
'del'                     => '删除',
'request1'                => '一个任务关闭请求.',
'request2'                => '请求重新打开任务.',
'allpriorities'           => '所有优先级',
'noroadmap'               => '没有可用的路线图(不存在项目特定的“未来”版本)。',
'expand'                  => '展开',
'collapse'                => '折叠',
'expandall'               => '全部展开',
'collapseall'             => '全部折叠',
'minpwsize'               => '最小密码大小是5字符',
'passwordtoosmall'        => '密码长度太小了。',
'accountwaslocked'        => '你的账户被锁,由于太多的失败的登录尝试.',
'failedattempts'          => '有%d失败的登录尝试.',
'groupnotexist'           => '在这个项目选择组不存在.',
'searchindetails'         => '搜索细节',
'showasassignees'         => '显示为受托人',
'find'                    => '搜索',
'tls'                     => 'TLS',
'isadmin'                 => '是管理者',
'addvotes'                => '添加投票',
'removevote'              => '删除投票',
'voteremoved'             => '你的投票被删除',
'voteremovefailed'        => '你的投票不能被删除.',
'novotes'                 => '你现在没有任何可投票.',
'connectedtasks'          => '连接的任务:',
'taskdependencies'        => '任务依赖关系',
'viewgraph'               => '查看图表',
'notaskdependencies'      => '这个任务不依赖于任何其他任务.',
'dependson'               => '依赖于',
'blocks'                  => '块',
'newdependency'           => '新的依赖关系:',
'nouserstoadd'            => '没有用户添加.请确保名称,用户名和电子邮件是为每个用户定义的.',
'dispintro'               => '显示主介绍信息',
'mainmessage'             => '主介绍信息',
'setsupertask'            => '设置Super-Task ID:',
'supertaskmodified'       => 'Super-Task ID被修改',
'set'                     => '设置',
'supertask'               => 'Super-Task',
'setparent'               => '为本任务设置父任务ID',
'selfsupertasknotallowed' => 'Super-Task ID不能和任务ID相同',
'quickaction'             => ' 快速操作',
'updateselectedtasks'     => '更新所选任务',
'notspecified'            => '未指定',
'editselectedtasks'       => '编辑所选任务',
'information'             => '信息',
'taskclosedisabled'       => '禁止关闭当前任务,因依赖任务尚未关闭:-',
'daysleft'                => '天还剩',
'dayoverdue'              => '天过期',
'duetoday'                => '今天到期',
'daysbeforealert'         => '天前提醒',
'associatedsubtask'       => '相关的子任务#FS',
'associatesubtask'        => '为本任务设置子任务ID',
'subtaskid'               => '子任务ID',
'subtaskalreadyhasparent' => '您输入的子任务已经有一个父任务,请明确此关联.',
'subtaskisparent'         => '您输入的子任务是父任务的任务.子任务无关',
'subtasknotexist'         => '您输入的子任务不存在.',
'subtaskremovedmsg'       => '子任务已经成功被移除',
'subtaskadded'            => '添加子任务',
'subtaskremoved'          => '删除子任务',
'addnewsubtask'           => '添加新的子任务',
'hidesubtasks'            => '隐藏子任务',
'voteforthistask'         => '为本任务投票',
'watchthistask'           => '查看这个任务',
'privatethistask'         => '置为不公开任务',
'adddependenttask'        => '增加依赖任务',
'associatetaskid'         => '子任务id',
'parenttaskid'            => '父任务id',
'invalidsupertaskid'      => '父任务id无效.',
'supertaskadded'          => '添加超级任务',
'supertaskremoved'        => '删除超级任务',
'effort'                  => '工作量',
'efforttracking'          => '工作量跟踪',
'useeffort'               => '项目使用的工作量跟踪',
'estimatedeffort'         => '估计工作量',
'totalestimatedeffort'    => '估计总工作量',
'currenteffortdone'       => '当前完成工作量',
'starteffort'             => '开始跟踪',
'endeffort'               => '停止跟踪',
'cleareffort'             => '清除跟踪',
'addeffort'               => '添加跟踪',
'manualeffort'            => '手动添加跟踪(H:M)',
'efforttrackingstarted'   => '开始跟踪这个任务的工作量',
'efforttrackingnotstarted'=> '无法开始跟踪,这个问题已经被跟踪',
'efforttrackingstopped'   => '这个任务的工作量跟踪结束.',
'efforttrackingcancelled' => '这个任务的工作量跟踪被取消.',
'efforttrackingadded'     => '手动记录工作量的任务.',
'trackinginprogress'      => '跟踪过程中',
'viewestimatedeffort'     => '可以查看工作量跟踪',
'viewcurrenteffortdone'   => '可以查看当前工作量做了什么',
'trackeffort'             => '可以跟踪工作量',
'invalideffort'           => '输入的是工作量无效的,必须是一个数字',
'showpass'                => '显示密码',
'chooseafile'             => '请选择一个文件!',
'incorrectfiletype'       => '错误的文件类型.允许:jpg,jpeg,gif,png',
'oauthreqpass'            => '没有密码请求.你注册通过%s',
'addmultipletasks'        => '添加多个任务',
'pendingnewuserrequest'   => '等待请求的新用户',
'adminrequestswaiting'    => '等待管理员请求',
'clicktoedit'             => '点击每个字段快速编辑',
'confirmedit'             => '确认',
'regapprovedbyadmin'      => '由管理员注册批准(禁用确认代码)',
'activity'                => '活动',
'myactivity'              => '我的活动',
'emailverificationwrong'  => '电子邮件不匹配给定的电子邮件地址',
'verifyemailaddress'      => '确认电子邮件地址',
'hideemails'              => '隐藏用户电子邮件地址',
'hidemyemail'             => '隐藏我的电子邮件地址',
'exporttasklist'          => '导出任务列表',
'onedecimal'              => '一个小数',
'manday'                  => '人工日',
'mandays'                 => '人工日',
'mandayabbrev'            => '简写的人工日',
'hourspermanday'          => '一个人工日的工作时 (HH:mm)',
'itemexists'              => '项目%s已经存在于数据库中',
'categoryitemexists'      => '项目%s已经存在在%s数据库类.',
'pageswelcomemsg'         => '页面显示主要介绍信息',
'pagesintromsg'           => '页面显示介绍信息',
'activeoauths'            => '活跃的认证提供者',
'onlyoauthreg'            => '只允许认证者注册',
'estimatedeffortformat'   => '估计工作量显示格式',
'currenteffortdoneformat' => '当前完成工作量显示格式',
'minute'                  => '分钟',
'minutes'                 => '分钟',
'minuteplural'            => '分钟',
'minutesingular'          => '分钟',
'minuteabbrev'            => '最小值',
'hourplural'              => '小时',
'hoursingular'            => '小时',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => '估计开放任务工作量',
'currenteffortdoneopen'   => '当前开放任务耗费工作量',
'signinwith'              => '登录%s',
'canviewroadmap'          => '可以查看路线图',
'enableavatars'           => '启用头像',
'maxavatarsize'           => '最大头像像素值',
'taskhassubtask'          => '这个任务有以下子任务',
'taskhassubtasks'         => '这个任务有以下子任务',
'translations'            => '翻译',
'translate'               => '翻译',
'taskdescription'         => '任务描述',
'notaskdescription'       => '没有任务描述',
'pleaseselect'            => '请选择',
'closeselectedtasks'      => '关闭选择任务',
'closetasks'              => '关闭任务',
'hintforbulkimport'       => "<b>批量导入的技巧:</b>\n<ol>\n<li>从excel电子表格或CSV文件中复制粘贴一整列.</li>\n<li>目前你只能粘贴标题和细节.</li>\n<li>建议当你想为项目指派人员而系统中不存在匹配的人员时，请不要录入人名。</li>\n</ol>",
'taskissubtaskof'         => '本任务的父任务',
'applyfirstline'          => '应用第一行',
'addmorerows'             => '添加更多的行',
'addtasks'                => '添加任务',
'massopsdisabled'         => '对不起,批量编辑目前在Flyspray 1.0被禁止，我们计划在后面的版本进行实现。你可以在源码中启用这个功能，但是此举有可能会造成不可预料的后果，请在启用这个功能前仔细阅读注释。',
'viewroadmap'             => '可以查看路线图',
'nosuicide'               => '亲爱的用户，因为管理员已经禁用了您的帐户，您不允许访问网站或改变用户组。',
'movingtodifferentproject'=> '移动一个父任务或子任务到另一个项目是不允许的.你首先必须打破他们之间的联系。',
'musthavesameproject'     => '父任务和子任务必须属于同一个项目.',
'defaultorderby'          => '排序默认任务列表',
'defaultorderby2'         => '排序',
'viewowntasks'            => '查看自己的任务',
'viewgroupstasks'         => '查看任务组',
'urlrewriting'            => '重写URL',
'enablehtaccess'          => '请在重写URL之前让你的.htaccess文件在Flyspray根目录',
'nomodrewrite'            => '重写在这个服务上似乎不可用，不好意思，我不能重写url在',
'on'                      => '打开',
'off'                     => '关闭',
'defaultorderbydirection' => '按默认方向',
'ascending'               => '升序',
'descending'              => '降序',
'myassignedtasks'         => '我分配的任务',
'commentedon'             => '评论',
'maxvoteperday'           => '每天最多选票',
'votesperproject'         => '在每个项目中用户被限制的选票',
'votelimitreached'        => '你的投票限制为这个项目.在个人资料页面查看哪些任务可以投票.你也可以收回的选票.我们可以看到哪些任务对你是最重要的.解决任务可以收回你的选票.',
'myvotes'                 => '我的选票',
'tag'                     => '标签',
'tags'                    => '标签',
'tagsinfo'                => '使用一个或多个词来形容这个任务的关键点，多个词之间使用英文的分号;分隔，添加标签能让开发者处理同一类问题。',
'novalues'                => '没有条目',
'youhaveregistered'       => '你已经在Flyspray注册,你的详细资料如下:',
'youhaveregisterednotify' => '你在Flyspray上的注册已经被管理员接受.',
'usedintasks'             => '用法',
'freetagging'             => '允许用户定义标签',
'keyboardshortcuts'       => '键盘快捷键',
'testmailsettings'        => '测试当前生效的邮箱设置',
'test'                    => '测试',
'testmailsettingsnotice'  => '并检查您是否在当前用户的电子邮箱中收到测试电子邮件（请参阅“我的详细信息”页面）。',
'invalidinput'            => '噢，有一些不兼容的属性发送或丢失。',
'invalidprogress'         => '请选择一个正确的进度数值。',
'invalidpriority'         => '请选择一个正确的优先级数值。',
'invalidseverity'         => '请选择一个正确的严重性数值。',
'invalidstatus'           => '请选择一个正确的任务状态。',
'invalidcategory'         => '请选择一个正确的模块。',
'invalidreportedversion'  => '请选择一个正确的报告版本。',
'invaliddueversion'       => '请选择一个正确的计划完成版本。',
'invalidos'               => '请选择一个正确的操作系统。',
'invalidtags'             => '请仅选择允许的标签。',
'invalidassignees'        => '请仅选择允许的指派人',
'customize'               => '自定义',
'hidesubs'                => '隐藏子任务',
'hideprivate'             => '隐藏私有的任务',
'hideclosed'              => '隐藏关闭的任务',
'currentproject'          => '当前项目',
'targetproject'           => '目标项目',
'availablekeybshortcuts'  => '可用的键盘快捷键',
'logindialoglogout'       => '登录对话框/注销',
'focustaskidsearch'       => '聚焦任务编号搜索',
'openselectedtask'        => '打开选择的任务',
'movecursorup'            => '向上移动光标',
'movecursordown'          => '向下移动光标',
'taskdetails'             => '任务详情',
'taskediting'             => '任务编辑中',
'savetask'                => '保存任务',
'generalintegration'      => '一般附加内容',
'generalintegrationdesc'  => '这些内容将被放在默认主题的body标签内，在正文内容与底部之间。它真正出现在屏幕上的地方取决于CSS，您可以使用custom_*.css来自定义。',
'footerintegration'       => '底部附加内容',
'footerintegrationdesc'   => '默认情况下，此内容将默认放置在逻辑页脚区域中。它真正出现在屏幕上的地方取决于CSS，您可以使用custom_*.css来自定义。',
'editorbold'              => 'B',
'editorboldhint'          => '粗体',
'editoritalic'            => 'I',
'editoritalichint'        => '斜体',
'editorunderline'         => 'U',
'editorunderlinehint'     => '下划线',
'editorstrikethrough'     => 'S',
'editorstrikethroughhint' => '删除线',
);

?>
