<?php

$translation = array(
'edituser'                => 'Felhasználó szerkesztése',
'username'                => 'Felhasználói név',
'realname'                => 'Teljes név',
'emailaddress'            => 'Email cím',
'jabberid'                => 'Jabber azonosító',
'notifytype'              => 'Értesítés típusa',
'group'                   => 'Csoport',
'accountenabled'          => 'Fiók engedélyezve',
'updatedetails'           => 'Részletek frissítése',
'setglobally'             => 'Ezt a beállítást globálisan kell beállítani.',
'usergroupmanage'         => 'Felhasználó és csoport kezelése',
'newuser'                 => 'Új felhasználó regisztrálása',
'newgroup'                => 'Új csoport regisztálása',
'yes'                     => 'Igen',
'no'                      => 'Nem',
'editgroup'               => 'Csoport szerkesztése',
'groupname'               => 'Csoport neve',
'description'             => 'Leírás',
'admin'                   => 'Admin csoport',
'opennewtasks'            => 'Új hibajegy megnyitása',
'modifytasks'             => 'Meglévő hibajegy módosítása',
'addcomments'             => 'Megjegyzés hozzáadása',
'attachfiles'             => 'Fájl csatolása',
'vote'                    => 'Szavazás',
'groupenabled'            => 'Tagok beléphetnek',
'groupopen'               => 'Tagok beléphetnek',
'tasktypelist'            => 'Hibajegy típusok listája',
'categorylist'            => 'Kategóriák listája',
'oslist'                  => 'Rendszerek listája',
'resolutionlist'          => 'Megoldások listája',
'versionlist'             => 'Változatok listája',
'severitylist'            => 'Súlyosságok listája',
'listnote'                => 'Megjegyzés: A "megjelenít" kijelölőnégyzet törlése megszünteti az adott elem használatát, így ez a módosítás megváltoztathat pár hibajegyet, ahol ez használatban van. A "név" mező megváltozatása az összes olyan hibajegyben megváltozik, ahol ez használatban van. A nem törölhető bejegyzések vagy törlésre védettek, vagy pedig szükségesek a helyes működéshez, illetve már felhasználásra kerültek.',
'name'                    => 'Név',
'order'                   => 'Sorrend',
'back'                    => 'Vissza',
'text'                    => 'Szöveg',
'highlight'               => 'Megjelöl',
'show'                    => 'Megjelenít',
'owner'                   => 'Tulajdonos',
'selectowner'             => 'Tulajdonos kiválasztása',
'update'                  => 'Alkalmaz',
'addnew'                  => 'Új hozzáadása',
'flysprayprefs'           => 'Alkalmazás beállításai',
'projecttitle'            => 'Projekt címe',
'baseurl'                 => 'Az alkalmazás Base URL-je',
'replyaddress'            => 'Válasz email-cím az értesítéshez',
'themestyle'              => 'Téma / Stílus',
'language'                => 'Nyelv',
'anonview'                => 'Névtelen felhasználók megnézhetik ezt a hibajegyet',
'allowanon'               => 'Névtelen felhasználók megnyithatják a hibajegyet',
'never'                   => 'Soha',
'anonymously'             => 'Névtelenül',
'afterregister'           => 'Csak regisztráció után',
'spamproof'               => 'Megerősítési kód engedélyezése új felhasználó regisztrációjakor',
'anongroup'               => 'Az új felhasználó csoportja regisztrációjakor',
'groupassigned'           => 'E csoport tagjai rendelhetőek hozzá a hibajegyekhez',
'forcenotify'             => 'Hibajegy értesítés kikényszerítése:',
'neversend'               => 'Sose küld',
'userchoose'              => 'Felhasználó kiválaszthatja',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Az alapértelmezett kategória tulajdonosa',
'noone'                   => 'Senki',
'jabbernotify'            => 'Jabber értesítés',
'jabberserver'            => 'Szerver',
'jabberport'              => 'Port',
'jabberuser'              => 'Felhasználói név',
'jabberpass'              => 'Jelszó',
'saveoptions'             => 'Alkalmaz',
'editcomment'             => 'Megjegyzés szerkesztése',
'commentby'               => 'Comment by',
'saveeditedcomment'       => 'Szerkesztett megjegyzés mentése',
'projectprefs'            => 'Projekt beállításai',
'pagetitle'               => 'Lap címe',
'defaultproject'          => 'Alapértelmezett projekt',
'projectlists'            => 'Projektek listája',
'showlogo'                => 'Logo mutatása',
'intromessage'            => 'Bemutató üzenet',
'isactive'                => 'A projekt aktív',
'createproject'           => 'Új projekt létrehozása',
'nopermission'            => 'Nincs hozzáférése ehhez az oldalhoz.',
'listordertip'            => 'The order these items will appear in the list',
'listshowtip'             => 'Az elem mutatása a listában',
'categoryownertip'        => 'Ez a személy fog értesítést kapni ha egy hibajegyet nyit ebben a kategóriában',
'categoryparenttip'       => 'The parent category this new one will fall under',
'notsubcategory'          => 'Nincs (legfelső szintű kategória)',
'showinlineimages'        => 'A képek mutatása beágyazva',
'dateformat'              => 'A dátum formátuma',
'dateformat_extended'     => 'A részletes dátum formátuma',
'cache_feeds'             => 'Gyorstár',
'no_cache'                => 'Nincs gyorstár',
'cache_disk'              => 'A gyorstár a lemezen',
'cache_db'                => 'A gyorstár az adatbázisban',
'subcategoryof'           => 'Al kategória a',
'visiblecolumns'          => 'Ezeket az oszlopokat mutasd a hibajegy-listában',
'tense'                   => 'Idő',
'listtensetip'            => 'Múlt, jelen, jövő',
'past'                    => 'Múlt',
'present'                 => 'Jelen',
'future'                  => 'Jövő',
'oldpass'                 => 'Korábbi jelszó',
'nooldpass'               => 'Nincs korábbi jelszó beállítva',
'oldpasswrong'            => 'A korábbi jelszó helytelen',
'changepass'              => 'Jelszó megváltoztatása',
'confirmpass'             => 'Jelszó mégegyszer',
'projectmanager'          => 'Projekt Manager',
'viewtasks'               => 'Hibajegyek megjelenítése',
'modifyowntasks'          => 'Saját hibajegyek módosítása',
'modifyalltasks'          => 'Nem saját hibajegyek módosítása',
'viewcomments'            => 'Megjegyzések megjelenítése',
'editcomments'            => 'Megjegyzések szerkesztése',
'deletecomments'          => 'Megjegyzések törlése',
'viewattachments'         => 'Csatolt állományok megjelenítése',
'createattachments'       => 'Új csatolt állomány',
'deleteattachments'       => 'Csatolt állományok törlése',
'viewhistory'             => 'Történet megtekintése',
'closeowntasks'           => 'Saját hibajegyek lezárása',
'closeothertasks'         => 'Nem saját hibajegyek lezárása',
'assigntoself'            => 'Hibajegyek önmagához rendelése ha még nem történt meg',
'assignotherstoself'      => 'Mások hibajegyeinek hozzárendelése saját magához',
'viewreports'             => 'Eseménynapló megjelenítése',
'othersview'              => 'Bárki számára engedi ezt a projektet megtekinteni',
'usersandgroups'          => 'Felhasználók és csoportok',
'globalgroup'             => 'Csoport',
'globalgroups'            => 'Csoportok',
'defaultglobalgroup'      => 'Alapértelmezett globális csoport az új felhasználóhoz',
'addtogroup'              => 'Csoporthoz hozzáad',
'moveuserstogroup'        => 'Felhasználók mozgatása csoporthoz',
'nogroup'                 => 'Nincs csoport - Törlése a projektból',
'eventdesc'               => 'Esemény leírása',
'requestedby'             => 'Kérte',
'daterequested'           => 'Kérés dátuma',
'closetask'               => 'Hibajegy lezárása',
'reopentask'              => 'Hibajegy újra nyitása',
'applymember'             => 'Projekt tagként hozzárendel',
'forcurrentproj'          => 'A jelenlegi projektnek',
'lostpw'                  => 'Elveszett jelszó kérése',
'lostpwexplain'           => 'Írja be a felhasználói nevét a jelszó megváltoztatásához. A jelszó el lesz küldve a notifikáció szerinti email címre, amit a profilban beállított',
'sendlink'                => 'Hivatkozás küldése',
'savenewpass'             => 'Új jelszó mentése',
'anonreg'                 => 'Új felhasználók regisztrálásának engedélyezése',
'allowanonopentask'       => 'Vendégek hozzáférése a projekt hibajegyeihez',
'editglobalgroup'         => 'Globális csoport szerkesztése',
'editgroupforproj'        => 'Globális csoport szerkesztése a projekthez',
'notshownforadmin'        => 'A jogosultságokat nem mutatja az adminisztrátor csoportjában. Nem szükséges ezeket szerkesztenie.',
'general'                 => 'Általános',
'userregistration'        => 'Felhaszáló regisztráció',
'notifications'           => 'Értesítések típusa',
'resetoptions'            => 'Visszaállít',
'preferences'             => 'Beállítások',
'tasktypes'               => 'Hibajegy típusok',
'resolutions'             => 'Megoldások',
'categories'              => 'Kategóriák',
'operatingsystems'        => 'Rendszerek',
'versions'                => 'Változatok',
'admintoolboxlong'        => 'Adminisztrátor eszközei',
'newproject'              => 'Új projekt',
'delete'                  => 'Töröl',
'listdeletetip'           => 'Ez elem törlése a listából',
'lookandfeel'             => 'Kinézet',
'globaltheme'             => 'Globális téma',
'emailnotify'             => 'Email értesítések',
'fromaddress'             => 'Feladó cím',
'smtpserver'              => 'SMTP szerver',
'smtpuser'                => 'SMTP felhasználói név',
'smtppass'                => 'SMTP jelszó',
'addrewrite'              => 'Cím átírás használata',
'usereminderdaemon'       => 'Háttér figyelmeztető démon engedélyezése',
'tasksperpage'            => 'Megjelenített hibajegyek száma oldalanként',
'addtoassignees'          => 'Önmaga hozzáadása a hozzárendeltekhez',
'taskstatuses'            => 'Hibajegy állapotok',
'canvote'                 => 'Szavazhat a hibajegyre',
'loginsuccessful'         => 'Belépés sikeres.',
'youareloggedout'         => 'Ön kilépett.',
'waitwhiletransfer'       => 'Kérem várjon amíg átirányítjuk...',
'clicknowait'             => 'Klikkeljen ide ha nem kíván várni.',
'accountdisabled'         => 'A felhasználói fiókja le van tiltva. Keresse fel az adminisztrátort.',
'task'                    => 'Hibajegy',
'edittask'                => 'A hibajegy szerkesztése',
'openedby'                => 'Megnyitotta',
'editedby'                => 'Utoljára szerkesztette:',
'tasktype'                => 'Hibajegy típusa',
'category'                => 'Kategória',
'status'                  => 'Státusz',
'assignedto'              => 'Felhasználó hozzárendelése',
'operatingsystem'         => 'Rendszer',
'severity'                => 'Súlyosság',
'reportedversion'         => 'Jelentett változat',
'dueinversion'            => 'Esedékesség',
'undecided'               => 'határozatlan',
'percentcomplete'         => '% kész',
'details'                 => 'Részletes leírás',
'savedetails'             => 'Változtatások mentése',
'canceledit'              => 'Szerkesztés megszakítása',
'anonymous'               => 'Névtelen bejegyző',
'complete'                => 'kész',
'closedby'                => 'Lezárta',
'reasonforclosing'        => 'A lezárása indoka:',
'reopenthistask'          => 'A hibajegy újranyitása',
'comments'                => 'Megjegyzések',
'attachments'             => 'Csatolások',
'relatedtasks'            => 'Kapcsolódó hibajegyek',
'edit'                    => 'Szerkeszt',
'addcomment'              => 'Megjegyzés hozzáadása',
'fileuploadedby'          => 'A fájlt feltöltötte',
'uploadafile'             => 'Fájl csatolása',
'uploadnow'               => 'Feltöltés most!',
'thesearerelated'         => 'Ezek a hibajegyek kapcsolódnak ehhez a hibajegyekhez',
'remove'                  => 'Eltávolít',
'addnewrelated'           => 'Új kapcsolódó hibajegy hozzáadása',
'add'                     => 'Hozzáad',
'otherrelated'            => 'Más hibajegyek melyek ehhez a hibajegyhez kapcsolódnak',
'receivenotify'           => 'Ezek a felhasználók kapnak részletes értesítést ha ez a hibajegy megváltozik.',
'addusertolist'           => 'Felhasználó hozzáadása az értesítési listához:',
'addtolist'               => 'Listához hozzáad',
'addmyself'               => 'Saját magam hozzáadása a listához',
'removemyself'            => 'Saját magam eltávolítása a listáról',
'theseusersnotify'        => 'Ezek a felhasználók kapnak értesítést ha a hibajegy megváltozik.',
'attachedtoproject'       => 'Projekt',
'reminders'               => 'Emlékeztetők',
'system'                  => 'Rendszer',
'remindthisuser'          => 'Emlékeztesse ezt a felhasználót',
'thisoften'               => 'Ilyen gyakran',
'startafter'              => 'Várakozási idő az emlékeztetések indítása előtt',
'hours'                   => 'Órák',
'days'                    => 'Napokt',
'weeks'                   => 'Hetek',
'addreminder'             => 'Emlékeztető hozzáadása',
'defaultreminder'         => 'Ez egy emlékeztető ehhez a hibajegyhez:',
'message'                 => 'Üzenet',
'closed'                  => 'Lezárva',
'filename'                => 'Fájlnév:',
'date'                    => 'Dátum',
'filesize'                => 'Fájl méret:',
'closurecomment'          => 'További megjegyzések a lezárással kapcsolatban',
'history'                 => 'Történet',
'nohistory'               => 'Nincs történet.',
'eventdate'               => 'Dátum',
'user'                    => 'Felhasználó',
'event'                   => 'Esemény',
'fieldchanged'            => 'Mező megváltoztatva',
'taskopened'              => 'Hibajegy megnyitva',
'taskreopened'            => 'Hibajegy újra megnyitva',
'taskclosed'              => 'Hibajegy lezárva',
'commentadded'            => 'Megjegyzés hozzáadva',
'commentedited'           => 'Megjegyzés szerkesztve',
'commentdeleted'          => 'Megjegyzés törölve',
'attachmentadded'         => 'Csatolás hozzáadva',
'attachmentdeleted'       => 'Csatolás törölve',
'taskedited'              => 'Hibajegy részletei szerkesztve',
'notificationadded'       => 'Felhasználó hozzáadva az értesítési listához',
'notificationdeleted'     => 'Felhasználó eltávolítva az értesítési listához',
'relatedadded'            => 'Kapcsolódó hibajegy hozzáadva',
'relateddeleted'          => 'Kapcsolódó hibajegy eltávolítva',
'taskassigned'            => 'Hibajegy hozzárendelve',
'taskreassigned'          => 'Hibajegy újra hozzárendelve',
'assignmentremoved'       => 'Hozzárendelés eltávolítva',
'summary'                 => 'Összegzés',
'addedasrelated'          => 'Hibajegy hozzáadva a kapcsolódó listákhoz a',
'deletedasrelated'        => 'Hibajegy eltávolítva a kapcsolódó listákhoz a',
'reminderadded'           => 'Emlékeztető hozzáadva',
'reminderdeleted'         => 'Emlékeztető törölve',
'priority'                => 'Prioritás',
'previousvalue'           => 'Előző érték',
'newvalue'                => 'Új érték',
'selectareason'           => 'Lezárás indokának kiválasztása',
'assigntome'              => 'Önmagam hozzárendelése a hibajegyhez',
'reopenrequest'           => 'Újranyitás kérése',
'requestclose'            => 'Lezárás kérése',
'ownershiptaken'          => 'Felhasználó átvette a tulajdonjogot',
'closerequestmade'        => 'Hibajegy lezárás kérése',
'reopenrequestmade'       => 'Hibajegy újranyitás kérése',
'taskdependson'           => 'Ez a hibajegy függ',
'taskblocks'              => 'Ez a hibajegy zárolja a lezárástól ezeket',
'depadded'                => 'Függőség hozzáadva',
'depaddedother'           => 'Ez a hibajegy függőségként hozzáadva',
'depremoved'              => 'Függőség eltávolítva',
'depremovedother'         => 'Ez a hibajegy eltávolítva más hibajegyek függőségei közül',
'showdetailserror'        => 'Ez a hibajegy nem létezik vagy nincs jogosultsága megtekinteni.',
'makeprivate'             => 'privátnak beállít',
'makepublic'              => 'publikusnak beállít',
'taskmadeprivate'         => 'A hibajegy privátnak beállítva',
'taskmadepublic'          => 'A hibajegy publikusnak beállítva',
'confirmdeletecomment'    => 'Biztosan törli a megjegyzést? %s',
'confirmdeleteattach'     => 'Biztosan törli a csatolást?',
'selectedhistory'         => 'A kiválasztott történet részleteinek megjelenítése',
'showallhistory'          => 'Teljes történet fülének ismételt megjelenítése',
'hidethis'                => 'Ez a terület ismételt elrejtése',
'mark100'                 => 'A hibajegy megjelölése 100% készre',
'watchtask'               => 'Hibajegy figyelése',
'stopwatching'            => 'Hibajegy figyelésének leállítása',
'commentlink'             => 'Hivatkozás ehhez a megjegyzéshez',
'submitreq'               => 'Kérés küldése',
'reasonforreq'            => 'A kérés oka',
'pmreqdenied'             => 'A projekt manager megtagadta a hozzáférést',
'taskpendingreq'          => 'Projekt manager művelet függőben. Tekintse meg a Történet fület a részles információért.',
'previoustask'            => 'Előző művelet',
'nexttask'                => 'Következő művelet',
'duedate'                 => 'Esedékesség időpontja',
'attachnoperms'           => 'Vannak csatoltások a megjegyzéshez, de nincs joga megtekinteni őket.',
'open'                    => 'Megnyit',
'depgraph'                => 'Függőségi gráf megtekintése',
'reset'                   => 'Visszaállít',
'selectusers'             => 'Felhasználók kiválasztása...',
'addmetoassignees'        => 'Adjon hozzá engem',
'addedtoassignees'        => 'Felhasználó hozzáadva',
'dependencygraph'         => 'Függőségi gráf',
'attachanotherfile'       => 'További fájl csatolása',
'OK'                      => 'OK',
'addvote'                 => 'Szavazás hozzáadása',
'notifyfromfs'            => 'Notification from Flyspray',
'autogenerated'           => 'EZ EGY AUTOMATIKUSAN GENERÁLT ÜZENET, NE VÁLASZOLJON RÁ',
'forward'                 => 'Tovább',
'previous'                => 'Előző',
'next'                    => 'Következő',
'first'                   => 'Első',
'last'                    => 'Utolsó',
'page'                    => '%d.oldal (összesen %d)',
'search'                  => 'Keresés',
'alltasktypes'            => 'Összes hibajegy típus',
'allseverities'           => 'Összes gyakoriság',
'alldevelopers'           => 'Összes fejlesztő',
'notyetassigned'          => 'Még nincs hozzárendelve',
'allcategories'           => 'Összes kategória',
'allstatuses'             => 'Összes státusz',
'allopentasks'            => 'Összes nyitott hibajegy',
'sortthiscolumn'          => 'Sorrendbe állítás az oszlop szerint',
'id'                      => 'Azonosító',
'project'                 => 'Projekt',
'dateopened'              => 'Nyitott',
'progress'                => 'Folyamat',
'searchthisproject'       => 'Keresés (az aktuális projektben)',
'dueanyversion'           => 'Esedékessék bármelyik változatban',
'anyversion'              => 'Jelentve bármelyik változatban',
'dueversion'              => 'Változat esedékesség',
'lastedit'                => 'Utoljára szerkesztve',
'os'                      => 'Rendszer',
'reportedin'              => 'Jelentve ebben',
'taskrange'               => 'Hibajegy megjelenítése %d - %d (%d)',
'noresults'               => 'A keresének nem volt eredménye.',
'takeaction'              => 'Válasszon',
'watchtasks'              => 'A kiválasztott hibajegyek figyelése',
'stopwatchingtasks'       => 'A figyelés leállítása a kiválasztott hibajegyeken',
'assigntaskstome'         => 'A kiválasztott hibajegy hozzám rendelése',
'dueby'                   => 'Due by',
'dueanytime'              => 'Due anytime',
'selectduedate'           => 'Select Due Date',
'toggleselected'          => 'Toggle selected',
'due'                     => 'Due',
'assignedtome'            => 'Hozzárendelés saját magamhoz',
'tasklist'                => 'Hibajegy-lista',
'dateclosed'              => 'Lezárás dátuma',
'advanced'                => 'Részletes',
'searchcomments'          => 'Keresés a megjegyzésekben',
'searchforall'            => 'Keresés az összes szóra',
'anonusers'               => 'Névtelen felhasználó',
'miscellaneous'           => 'Egyéb',
'users'                   => 'Felhasználók',
'taskproperties'          => 'Hibajegy tulajdonságai',
'selectsincedate'         => 'Select changes since',
'changedsince'            => 'Megváltoztatva ez óta',
'updatefs'                => 'Kérem frissítse az alkalmazást.',
'currentversion'          => 'Az Ön változata jelenleg',
'latestversion'           => 'és a legutóbbi változat',
'hidemessage'             => '(értesítsen később)',
'saveas'                  => 'Keresés mentése mint',
'nosearches'              => 'Nincs mentett keresés',
'saving'                   => 'Mentés...',
'votes'                   => 'Szavazatok',
'allclosedtasks'          => 'Összes lezárt hibajegy',
'password'                => 'Jelszó',
'login'                   => 'Belépés',
'rememberme'              => 'Emlékezzen rám',
'lostpassword'            => 'Elfelejtette jelszavát?',
'lostpwforfs'             => 'Elfelejtette jelszavát?',
'lostpwmsg1'              => 'Helló.

Elfelejtettem a jelszavam ',
'lostpwmsg2'              => ', kérem adjon egy újat.

Felhasználói név: ',
'regards'                 => '

Tisztelettel,',
'yourusername'            => ' az ön felhasználói neve ',
'locale'                  => 'hu-HU',
'filenotexist'            => 'A fájl nem létezik vagy nincs jogosultsága elérni azt.',
'showtask'                => 'Ugrás hibajegyre',
'now'                     => 'Most',
'go'                      => 'Végrehajt!',
'opentaskanon'            => 'Új hibajegy nyitása névtelenül',
'register'                => 'Regisztrál',
'addnewtask'              => 'Új hibajegy hozzáadása',
'reports'                 => 'Eseménynapló',
'editmydetails'           => 'Adataim szerkesztése',
'logout'                  => 'Kijelentkezés',
'disabledaccount'         => 'Az Ön hozzáférése letiltva!<br />Kiléptetés azonnal...',
'poweredby'               => 'Powered by Flyspray',
'projects'                => 'Projektek',
'allprojects'             => 'Összes projekt',
'selectproject'           => 'Projekthez:',
'tasksall'                => 'Összes hibajegy',
'tasksassigned'           => 'Hozzám rendelt hibajegyek',
'tasksreported'           => 'Bejelentett hibajegyeim',
'taskswatched'            => 'Figyelt hibajegyek',
'mysearch'                => 'Kereséseim',
'admintoolbox'            => 'Admin eszközök',
'manageproject'           => 'Projekt kezelése',
'permissions'             => 'Hozzáférések megtekintése',
'hide'                    => 'Elrejt',
'pendingreq'              => 'Projekt Manager várakozást kér',
'errorpage'               => 'A rendszer nem tudja szolgáltatni a kért lapot.
                                 Lehetséges hogy elírta, vagy a lap nem létezik, vagy Önnek nincs
                                 hozzáférése ehhez.<br /><br />
                                 Lehetséges hogy hibás hivatkozással próbált meg SQL injekciós műveletet elvégezni,
                                 hogy közvetlen kapcsolatot létesítsen az adatbázissal. Ha ez igaz, akkor ez a művelet
				 szankciókat fog maga után vonni.',
'permissionsforproject'   => 'Projektengedélyek: ',
'switchto'                => 'Átkapcsolás a ',
'lastsearch'              => 'Utolsó keresés',
'modify'                  => 'Módosít',
'noticefrom'              => 'Értesítés a ',
'hasopened'               => 'egy új hibajegyet nyitott, és Önt rendelte hozzá!',
'moreinfonew'             => 'További információkat talál erről a hibajegyről itt:',
'newtaskcategory'         => 'Új hibajegy nyílt ebben a kategóriában',
'categoryowner'           => 'Ön azért kapta ezt azt, mert a hibajegy kategóriájának tulajdonosa.',
'tasksummary'             => 'Hibajegy összefoglalása:',
'newtaskadded'            => 'Az új hibajegy hozzáadva.',
'summaryanddetails'       => 'Ki kell töltenie az összegzést és a részletes leírást is. Továbbá anonym felhasználó esetén ellenőrizze hogy megadott-e e-mail címet!',
'goback'                  => 'Vissza.',
'messagefrom'             => 'Ez egy üzenet a hibajegy rendszertől a ',
'hasjustmodified'         => 'módosította a következő hibajegyet.',
'changedfields'           => 'A megváltozott mezők előtt csillag szerepel (**)',
'moreinfomodify'          => 'További információkat láthat itt: ',
'nolongerassigned'        => 'Ez a hibajegy már nincs Önhöz rendelve. Most már hozzá van rendelve',
'hasassigned'             => 'hozzárendelte a következő hibajegyhez:',
'taskupdated'             => 'Hibajegy aktualizálva.',
'hasclosedassigned'       => 'lezárta a következő hibajegyet amihez Ön is hozzá volt rendelve:',
'unassigned'              => 'Nincs hozzárendelve',
'hasclosed'               => 'lezárta a következő hibajegyet.',
'youonnotify'             => 'Azért kapta ezt az üzenetet, mert Ön szerepel az értesítési listán.',
'taskclosedmsg'           => 'Hibajegy lezárva.',
'returntotask'            => 'Visszatérés a hibajegy részleteihez',
'backtoindex'             => 'Visszatérés a hibajegyek listájához',
'noclosereason'           => 'Nem válaszotta ki az indokot a hibajegy lezárásához',
'hasreopened'             => 'újranyitotta a következő hibajegyet, amit Ön már lezárt:',
'taskreopenedmsg'         => 'Hibajegy újranyitva.',
'backtotask'              => 'Vissza a hibajegyhez.',
'commentaddedmsg'         => 'Megjegyzés hozzáadva.',
'commenttoassigned'       => 'egy megjegyzést adott a következő hibajegyhez amihez Ön is hozzá van rendelve:',
'commenttotask'           => 'egy megjegyzést adott a következő hibajegyhez:.',
'nocommententered'        => 'Önnek mindenképpen kellene valami megjegyzést írnia, mielőtt az Elküld gombra kattint.',
'fillinfields'            => 'Nem töltötte ki az összes mezőt.',
'notcurrentpass'          => 'Ez nem az Ön jelszava!',
'passchanged'             => 'A jelszó megváltozott.',
'closewindow'             => 'Most már bezárhatja ezt az ablakot.',
'passnomatch'             => 'Az új jelszó és a megerősítés nem egyezik!',
'usernametaken'           => 'Ez a felhasználói név már használatban van, másikat kell választania.',
'newusercreated'          => 'Az új felhasználói fiókja létrejött.',
'accountcreated'          => 'Az új felhasználói fiókja létrejött.',
'newuserwarning'          => 'Figyelem: a globális paraméter megkövetelheti hogy Önnek adminisztrátori hozzáférése legyen, amit a szuper adminisztrátor oszthat ki. Ha nem tud belépni, valószínűleg emiatt lehet..',
'nomatchpass'             => 'A jelszavak nem egyeznek.',
'confirmwrong'            => 'Megerősítési kód érvénytelen!',
'formnotcomplete'         => 'Az űrlap teljesen ki lett töltve.',
'formnotnumeric'          => 'A beírt adat nem szám!',
'groupnametaken'          => 'Ez a csoportnév már létezik.',
'newgroupadded'           => 'Új csoport hozzáadva.',
'optionssaved'            => 'Opciók lementve.',
'hasuploaded'             => 'feltöltött egy új fájlt csatolásként, ami hozzá van rendelve:',
'hasattached'             => 'egy fájlt csatolt a következő hibajegyhez.',
'fileuploaded'            => 'Fájl feltöltve.',
'fileerror'               => 'Hiba történt a fájl feltöltése közben. Valószínűleg a jogok a <i>attachments/</i> könyvtáron nem elégségesek.',
'contactadmin'            => 'Lépjen kapcsolatba az adminisztrátorral a projekt miatt.',
'selectfileerror'         => 'Nem választott ki fájlt.',
'userupdated'             => 'Felhasználó részletei aktualizálva',
'realandemail'            => 'Nem töltötte ki a Teljes nevet és az Email címet.',
'groupupdated'            => 'Csoport definíció aktualizálva.',
'groupanddesc'            => 'Nem töltötte ki a csoport nevet.',
'fillallfields'           => 'Kérem töltse ki az összes mezőt.',
'listPmustN'              => '"Sorrend" bejegyzésnek számnak kell lennie.',
'listupdated'             => 'Lista aktualizálva.',
'listitemadded'           => 'Új listaelem hozzáadva.',
'relatedaddedmsg'         => 'Kapcsolódó hibajegy hozzáadva a listához.',
'relatederror'            => 'Ez a felaat már a kapcsolódó hibajegyek listájában van.',
'relatedremoved'          => 'Kapcsolódó hibajegy eltávolítva a listából.',
'notifyadded'             => 'Felhasználó hozzáava az értesítési listához.',
'notifyerror'             => 'Ez a felhasználó már szerepel az értesítési listán.',
'notifyremoved'           => 'Felhasználó eltávolítva az értesítési listáról.',
'editcommentsaved'        => 'Aktualizált megjegyzés mentve.',
'commentdeletedmsg'       => 'Megjegyzés törölve.',
'gotonewtask'             => 'Menjen az új hibajegyhez amit létrehozott',
'projectcreated'          => 'Az Ön új projektje létrehozva.  Most már testreszabhatja a projektet a Projekt Kezelőben.',
'customiseproject'        => 'Projekt testreszabása',
'projectupdated'          => 'Projekt tulajdonságok aktualizálva',
'emptytitle'              => 'A projekt nevét nem töltötte ki. Menjen vissza és töltse ki.',
'loginbelow'              => 'Most megpróbálhat belépni.',
'attachmentdeletedmsg'    => 'A csatolás törölve.',
'reminderaddedmsg'        => 'Az emlékeztetője hozzáadva.',
'reminderdeletedmsg'      => 'A kiválaszott emlékeztető törölve.',
'flyspraytask'            => 'hibajegy',
'fieldsmissing'           => 'Egyes mező nem tartalmaz adatot, vagy érvénytelen adatot tartalmaz.',
'relatedinvalid'          => 'Itt nincs ilyen hibajegy.',
'relatedproject'          => 'Ez a hibajegy más projekthez van csatolva. Mindenképpen létre akarja hozni a kapcsolatot?',
'addanyway'               => 'Mindenképpen hozzáad',
'cancel'                  => 'Mégse',
'alreadyedited'           => 'Ezt a hibajegyet valaki módosította mielőtt Ön ezt mentette volna. Így is menteni akarja?',
'saveanyway'              => 'Mentés mindenképpen',
'nouserselected'          => 'Nincs felhasználó kiválasztva.  Válasszon ki legalább egyet, majd próbálja újra.',
'groupswitchupdated'      => 'Felhasználói csoport sikeresen módosítva.',
'takenownershipmsg'       => 'Ez a hibajegy Önhöz rendelt.',
'adminrequestmade'        => 'A kérését elküldtök a projekt kezelőjének.',
'newdepnotify'            => 'Új függőség hozzáadva a következő hibajegyhez:',
'dependadded'             => 'Hibajegy függősége hozzáadva',
'dependaddfailed'         => 'Hiba történt a függőség hozzáadásakor. Ellenőrizze le hogy lézetik-e még a hibajegy vagy nincs-e zárolva.',
'depremovedmsg'           => 'Hibajegy függőség eltávolítva',
'newdepis'                => 'Az új függőség',
'magicurlsent'            => 'Az üzenet elküldve az értesítési címre. Az üzenet tartalmaz egy hivatkozást, amit megnyitva a teljes hibajegyről informálódhat.',
'changefspass'            => 'Jelszó változtatása',
'magicurlmessage'         => 'Kérem kövesse a lenti hivatkozást a jelszó megváltoztatásához:',
'erroronform'             => 'Hiba történt az űrlap elküldésekor',
'addressused'             => 'Ez a címet használva regisztrált. Ha nem tudja miért kapta ezt az üzenetet, törölje nyugodtan és ne foglalkozzon vele. Kattintson a hivatkozásra a regisztráció befejezéséhez:',
'confirmcodeis'           => 'A megerősítő kódja:',
'codesent'                => 'A megerősítő kódot emailben elküldtük. Kövesse az utasításokat az üzenetben.',
'codenotsent'             => 'Nem lehet elküldeni a kódot, kérem próálja később.',
'taskmadeprivatemsg'      => 'Ez a hibajegy már privát',
'taskmadepublicmsg'       => 'Ez a hibajegy ismét publikus',
'realandnotify'           => 'A teljes név kitöltése kötelező. Töltse ki szintén az Email cím vagy a Jabber Azonosító mező valamelyikét is.',
'pmreqdeniedmsg'          => 'Projekt Kezelő kérés megtagadva',
'massopsuccess'           => 'Tömeges művelet sikeres (ahol a jogosultságok megfelelő volt)',
'usernotexist'            => 'Ez a felhasználó nem szerepel az adatbázisban.',
'commentattachperms'      => 'Nem törölheti ezt a megjegyzést, mert jogosultsága törölni a csatolást',
'voterecorded'            => 'A szavazatát rögzítettük',
'votefailed'              => 'A szavazata nem rögzíthető jelenleg.',
'createnewgroup'          => 'Új csoport létrehozása',
'requiredfields'          => 'A szükséges mezők megvannak jelölve ',
'addthisgroup'            => 'Csoport létrehozása',
'createnewproject'        => 'Új projekt létrehozása',
'addnewproject'           => 'Új projekt hozzáadása',
'htmlallowed'             => 'HTML kód engedélyezett',
'createthisproject'       => 'A projekt létrehozása',
'inlineimages'            => 'Mutassa a képeket beágyazva',
'createnewtask'           => 'Új hibajegy létrehozása a projektben:',
'addanother'              => 'További hibajegyet adjon hozzá ezután',
'addthistask'             => 'A hibajegy hozzáadása',
'notifyme'                => 'Értesítsen ha ez a hibajegy megváltozik',
'newtask'                 => 'Új hibajegy',
'attachafile'             => 'Fájl csatolása',
'registernewuser'         => 'Új felhasználó regisztálása',
'none'                    => 'Nincs',
'registeraccount'         => 'A hozzáférés regisztrálása',
'both'                    => 'Mindkettő',
'notifyfrom'              => 'Értesítés ',
'donotreply'              => 'EZ EGY AUTOMATA ÜZENET, KÉREM NE VÁLASZOLJON RÁ.',
'disclaimer'              => 'Ezt az értesítést azért kapta, mert regisztrált felhasználója a rendszernek, és ezt kérte a rendszertől korábban. Ha nem tudja miért kapta ezt az üzenetet, és nem kíván a jövőben ilyen üzenetet kapni, beállíthatja az értesítési paramétereket ha ellátogat a fenti hivatkozásra, ahol tesztreszabhatja az értesítési üzenetek szabályát.',
'userwho'                 => 'Felhasználók akik ezt tették',
'moreinfo'                => 'További információ található a következő hivatkozásra kattinva:',
'newtaskopened'           => 'Egy új hibajegy lett megnyitva.  Részletek lejjebb.',
'notify.taskclosed'       => 'A következő hibajegy már lezárva:',
'notify.taskreopened'     => 'A következő hibajegy újra megnyitva:',
'newdep'                  => 'A következő hibajegynek új függőségei vannak:',
'notify.depremoved'       => 'A következő hibajegy függőségei eltávolítva:',
'olddepwas'               => 'A régi függőség',
'notify.commentadded'     => 'A következő hibajegy új megjegyzést kapott:',
'commentis'               => 'A megjegyzés szövege az alábbi.',
'newattachment'           => 'Új fájl lett hozzácsatolva a következő hibajegyhez:',
'detailsbelow'            => 'A részletek lejjebb.',
'notify.relatedadded'     => 'Egy új kapcsolódó hibajegy lett hozzáadva a következő hibajegyhez:',
'relatedis'               => 'A kapcsolódó hibajegy',
'assignedtoyou'           => 'Ön az alábbi hibajegyhez lett hozzárendelve:',
'takenownership'          => 'átvette a tulajdonjogot a hibajegyen:',
'requiresaction'          => 'A következő hibajegy beavatkozást igényel a Projekt Kezelőben:',
'requiresactionnotify'    => 'A hibajegy beavatkozást igényel a Projekt Kezelőben.',
'pmdeny'                  => 'A Projekt Kezelő megtagadta a függőben lévőségi kérést a következő hibajegyhez:',
'pmdenynotify'            => 'A Projekt Kezelő megtagadta a kérést',
'fileaddedtoo'            => 'Egy vagy több fájl csatolva.',
'taskwatching'            => 'A következő hibajegyet figyelteti',
'isdepfor'                => 'egy új függőség ehhez',
'denialreason'            => 'A megtagadás oka',
'taskchanged'             => 'A következő hibajegy megváltoztatva.  A változások listája lejjebb látható.  A változtatás teljes információjához kövesse a hivatkozást és válassza a Történet fület.',
'useraddedtoassignees'    => 'Egy felhasználó hozzáadta saját magát a hozzárendelt felhasználók listájához ebben a hibajegyben.',
'removeddepis'            => 'Az eltávolított függőség',
'isnodepfor'              => 'már nem függőség többé',
'usergroups'              => 'Felhasználói csoportok',
'pmtoolbox'               => 'Projekt Kezelő',
'groupmanage'             => 'Csoport Menedzsment',
'pendingrequests'         => 'Függőben lévő kérések',
'reasongiven'             => 'Az ok',
'nopendingreq'            => 'Nincs függőben lévő Projekt Kezelő kérés.',
'givereason'              => 'Adjon meg egy okot',
'catlisted'               => 'Kategórialista szerkesztő',
'oslisted'                => 'Rendszerlista szerkesztő',
'verlisted'               => 'Változatlista szerkesztő',
'tasktypeed'              => 'Hibajegytípus szerkesztő',
'resed'                   => 'Megoldáslista szerkesztő',
'deny'                    => 'Megtagad',
'notifiedwhen'            => 'Értesítsen ha',
'onlynewtasks'            => 'Új hibajegy nyitva',
'allevents'               => 'Bármilyen esemény bekövetkezése bármelyik hibajegyben',
'feeds'                   => 'Lekérés',
'feeddescription'         => 'Lekérés leírása',
'feedimgurl'              => 'Kép hivatkozás lekérése (hagyja üresen ha nem akar képet)',
'notifysubject'           => 'Az értesítés tárgya',
'notifysubjectinfo'       => '(%p = projekt címe, %s = hibajegy összesítése, %t = hibajegy azonosító, %a = művelet, %u = felhasználó)',
'priority6'               => 'Azonnal',
'priority5'               => 'Gyorsan',
'priority4'               => 'Fontos',
'priority3'               => 'Magas',
'priority2'               => 'Normál',
'priority1'               => 'Alacsony',
'sendcode'                => 'Kód küldése!',
'entercode'               => 'Adja meg az ellenőrző kódot amit az értesítő üzenetben kapott. Az érintett fiók jelszavát is adja meg.',
'confirmationcode'        => 'Ellenőrző kód',
'registererror'           => 'Bizonyosodjon meg arról, hogy kitöltötte az összes szükséges mezőt, és hogy a helyes részleteket adta meg az értesítés típusához.',
'validusername'           => '(csak alfanumerikus betűk és a  - _ . engedélyezett)',
'emailtaken'              => 'Ez az email cím vagy Jabber azonosító már használatban van. Kérem válasszon másikat.',
'note'                    => '<strong>Megjegyzés:</strong>  Egy ellenőrző kódot fog kapni mielőtt a fiók elkészül. A kód kézhezvételének módját Ön határozta meg. Javasolt, hogy ténylegesen érvényes elérhetőséget kapjon meg, ennek hiányában sajnos nem tudjuk eljuttatni ezt Önhöz.',
'changelog'               => 'Változások listája',
'changeloggen'            => 'Változások listájának generátora',
'listfrom'                => 'Változási lista bejegyzései a ',
'to'                      => '-',
'oldestfirst'             => 'Régebiek előre',
'recentfirst'             => 'Legfrissebbek előre',
'severityrep'             => 'Súlyossági riport',
'totalopen'               => 'Összes nyitott hibajegy',
'age'                     => 'Kor',
'agerep'                  => 'Kor riport',
'eventsrep'               => 'Esemény riport',
'events'                  => 'Esemény',
'Tasks'                   => 'Hibajegyek',
'opened'                  => 'Nyitva',
'edited'                  => 'Szerkesztve',
'assigned'                => 'Hozzárendelve',
'within'                  => 'Ebben',
'pastday'                 => 'Tegnap',
'pastweek'                => 'Múlt héten',
'pastmonth'               => 'Múlt hónapban',
'pastyear'                => 'Tavaly',
'nolimit'                 => 'Nincs határ',
'from'                    => 'Dátum',
'duein'                   => 'Due in',
'selectfromdate'          => 'Dátumtól',
'selecttodate'            => 'Dátumig',
'showvoters'              => 'Megjelenít/elrejt szavazók',
'roadmap'                 => 'Roadmap',
'roadmapfor'              => 'Roadmap a változathoz',
'tasks'                   => 'Hibajegyek',
'completed'               => 'kész:',
'opentasks'               => 'nyitott hibajegyek',
'of'                      => '% ',
'severity5'               => 'kritikus',
'severity4'               => 'magas',
'severity3'               => 'közepes',
'severity2'               => 'alacsony',
'severity1'               => 'nagyon alacsony',
'Redirect'                => 'Átirányít',
'redirectmsg'             => 'Ha a böngészője nem támogat átirányítást kérem kattintson ide az átirányításhoz: %sHERE%s',
'allowclosedcomments'     => 'Megjegyzés engedélyezése lezárt hibajegyeken',
'comment'                 => 'Megjegyzés',
'editowncomments'         => 'Saját megjegyzés szerkesztése',
'reopened'                => 'Újranyitva',
'loading'                 => 'Betöltés...',
'notifyown'               => 'Értesít saját módosításokkor',
'youremail'               => 'Az Ön email címe',
'thankyouforbug'          => 'Köszönöm hogy jelentette a problémát. Láthatja a hibajegyet és figyelheti a megoldás folyamatát bármikor itt:',
'anonuser'                => 'Névtelen felhasználó',
'conflict'                => 'Konfliktus',
'file'                    => 'Fájl',
'KiB'                     => 'kilobájt',
'MiB'                     => 'megabájt',
'size'                    => 'Méret',
'projectgroup'            => 'Projekt csoport',
'profile'                 => 'Profil:',
'viewprofile'             => 'Profile megtekintése',
'regdate'                 => 'Regisztrált ekkor:',
'tasksopened'             => 'Hibajegy megnyitva',
'replyto'                 => 'Feladó email cím',
'notifytypes'             => 'Értesítési típusok',
'pm.taskchanged'          => 'Hibajegy megváltozott',
'pm.taskreopened'         => 'Hibajegy újranyitva',
'pm.depadded'             => 'Függőség hozzáadva',
'pm.depremoved'           => 'Függőség eltávolítva',
'pmrequest'               => 'Projekt Kezelő kérés',
'pmrequestdenied'         => 'Projekt Kezelő kérés megtagadva',
'newassignee'             => 'Új hozzárendelt',
'revdepadded'             => 'Fordított függőség hozzáadva',
'revdepaddedremoved'      => 'Fordított függőség eltávolítva',
'assigneeadded'           => 'Hozzárendelt hozzáadva',
'addusergroup'            => 'Felhasználó hozzáadása csoporthoz',
'groupmembers'            => 'Csoport tagok',
'deleteuser'              => 'Felhasználó törlése',
'userdeleted'             => 'Felhasználó törölve',
'autoassign'              => 'Hibajegy automatikus hozzárendelése a kategória tulajdonosához',
'ssl'                     => 'SSL',
'updatewrong'             => 'Ön a frissítés-értesítést engedélyezte, de nem sikerült a frissítő-szerverrel a kapcsolatfelvétel.
                             Lehetéges hogy a kiszolgáló szerver nem tud külső kapcsolatot létesíteni, vagy hálózati probléma lépett fel.
                             Kérem keresse fel a szerver karbantartóját ha a hiba tartósan fellép.',
'deleteproject'           => 'A projekt törlése és a tartalmak mozgatása ide',
'projectdeleted'          => 'Projekt sikeresen törölve',
'feedforall'              => 'Feliratkozás az összes projektre',
'usercreated'             => 'Felhasználó létrehozva',
'userdeleted'             => 'Felhasználó törölve',
'created'                 => 'Létrehozva',
'deleted'                 => 'Törölve',
'userid'                  => 'Felhasználó azonosító szám',
'editassignments'         => 'Hozzárendelések szerkesztése',
'preview'                 => 'Előnézet',
'anyprogress'             => 'Bármilyem előrehaladás',
'tasksrelated'            => 'Hibajegyek amik kapcsolódnak ehhez a hibajegyhez',
'duplicatetasks'          => 'Hibajegy lemásolása',
'databasemodfailed'       => 'Adatbázis módosítás sikertelen. Lehetséges okok: elégtelen jogosults.',
'frequency'               => 'Gyakoriság',
'newuserregistered'       => 'Új felhasználó regisztrált a rendszerhez. A felhasználó adatai:',
'newuserregisterednotify' => 'Új felhasználó regisztrált',
'notify_registration'     => 'Adminisztrátorok értesítése új felhasználó regisztrálása esetén',
'textversion'             => 'Szöveges változat',
'onlyprimary'             => 'Hibajegyek, melyek nem blokkolnak más hibajegyeket',
'switch'                  => 'Átvált',
'max'                     => 'max.',
'dates'                   => 'Dátumok',
'selectduedatefrom'       => 'Esedékesség',
'selectduedateto'         => '-',
'selectsincedatefrom'     => 'Változtatva',
'selectsincedateto'       => '-',
'selectdate'              => 'Select Date',
'selectopenedfrom'        => 'Megnyitva',
'selectopenedto'          => '-',
'selectclosedfrom'        => 'Lezárva',
'selectclosedto'          => '-',
'startat'                 => 'Kezdeti időpont',
'hasattachment'           => 'Van csatolása',
'private'                 => 'Privát',
'watching'                => 'Figyelt',
'alreadyvotedthistask'    => 'Ön szavazott erre a hibajegyre',
'alreadyvotedthisday'     => 'már szavazott ma',
'visibility'              => 'Láthatóság',
'public'                  => 'Publikus',
'leaveemptyauto'          => 'Hagyja a jelszó mezőt üresen ha automatikusan generált jelszót szeretne.',
'novalidemail'            => 'Nem adott meg érvényes email címet.',
'novalidjabber'           => 'Nem adott meg érvényes Jabber azonosítót.',
'missingrequired'         => 'Nem töltötte ki az összes szükséges mezőt.',
'entervalidusername'      => 'Kérem adjon meg valós felhasználói és teljes nevet.',
'couldnotaddusernotif'    => 'A felhasználó felvétele az értesítési listába sikertelen.',
'defaulttask'             => 'Alapértelmezett hibajegy leírás',
'all'                     => 'összes',
'events.useraddedtoassignees' => 'Felhasználó hozzáadva a hozzárendeltekhez',
'vote(s)'                 => 'szavazat(ok)',
'eventlog'                => 'Eseménynapló',
'assignmentchanged'       => 'Hozzárendelés megváltoztatva',
'detailedinfo'            => 'Részletes információ',
'All'                     => 'Összes',
'tasksireported'          => 'Hibajegyek amiket én jelentettem',
'recentlyopened'          => 'Nemrég megnyitott',
'stats'                   => 'Statisztika',
'totaltasks'              => 'összes hibajegy',
'mostwanted'              => 'Leggyakrabban keresett hibajegyek',
'defaultentry'            => 'Az alapértelmezett belépés utáni oldal',
'toplevel'                => 'Felső szintű nézet',
'overview'                => 'Áttekintés',
'error#'                  => 'Hiba #',
'error1'                  => 'Nincs elegendő jogosultsága megnyitni a csatolást.',
'error3'                  => 'Ismétlődő művelet. Átirányítás a főoldalra.',
'error4'                  => 'Nincs adminisztratív joga.',
'error5'                  => 'Ez a felhasználó nem létezik a rendszerben.',
'error6'                  => 'Érvénytelen adminisztrátoti terület.',
'error7'                  => 'Sikertelen belépés (rossz felhasználói név vagy jelszó)!',
'error71'                 => 'Fiók zárolva %d percig a többszöri sikertelen belépés miatt!',
'error8'                  => 'Nem adta meg a felhasználói nevet és a jelszót.',
'error9'                  => 'A hibajegy nem létezik vagy nincs jogosultsága megnézni azt.',
'error10'                 => 'Ez a hibajegy nem létezik.',
'error101'                => 'Nincs jogosultága megnézni ezt a hibajegyet.',
'error102'                => 'Nincs jogosultsága megnézni ezt a hibajegyet, ha belép, lehet hogy sikerül.',
'error11'                 => 'Nincs jogosultság a szerkeszteni a megjegyzést.',
'error12'                 => 'Nincs érvényes kulcs. Biztos benne, hogy Ön ezt kapta az értesítési üzenetben?',
'error13'                 => 'Névtelen felhasználóknak nincs profiljuk.',
'error14'                 => 'Nincs elegendő jogosultsága új csoport létrehozására.',
'error15'                 => 'Nincs elegentő jogosultsága új hibajegy létrehozására.',
'error16'                 => 'Ön nem projekt kezelő.',
'error17'                 => 'Érvénytelen projekt kezelő terület.',
'error18'                 => 'Érvénytelen hivatkozás.',
'error19'                 => 'Ez a felhasználó nem létezik a rendszerben.',
'error20'                 => 'Érvénytlen adatbázis módosítás.',
'error21'                 => 'Egy vagy több email nem küldhető el. Ellenőrizze a konfigurációt.',
'error22'                 => 'Felhasználó regisztrációja nem megendegett.',
'error23'                 => 'A felhasználó vagy csoportja nem léphet be.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Roadmap csak bizonyos projektekhez áll rendelkezésre.',
'done'                    => 'kész',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'A projekt nem törölhető.',
'GMT'                     => 'GMT',
'timezone'                => 'Időzóna',
'accept'                  => 'Elfogad',
'reasonfordeinal'         => 'A megtagadás oka',
'pruneclosedlinks'        => 'Lezárt hivatkozások vágása',
'pruneclosedtasks'        => 'Lezárt hibajegyek vágása',
'pagegenerated'           => 'Oldal és kép generálva %d másodperc alatt.',
'pruninglevel'            => 'Vágási szint',
'lastuser'                => 'Az utolsó felhasználó nem törölhető.',
'allprivate'              => 'Az összes projekt privát.',
'deletegroup'             => 'Csoport törlése és a tagok mozgatása ide',
'parent'                  => 'Szülő',
'ordertip'                => 'Az elemek sorrendje ebben a listában fog szerepelni',
'showtip'                 => 'A bejegyzés megjelenítése ebben a listában',
'deletetip'               => 'A bejegyzés törlése a listából',
'del'                     => 'töröl',
'request1'                => 'A hibajegy lezárás kérvényezve.',
'request2'                => 'A hibajegy újranyitásának kérelme megtörtént.',
'allpriorities'           => 'Összes prioritás',
'noroadmap'               => 'Nincs roadmap (nincs jövőbeni projekt definiálva).',
'expand'                  => 'Kinyit',
'collapse'                => 'Összecsuk',
'expandall'               => 'Az össestet kinyitja',
'collapseall'             => 'Az összeset összecsuk',
'minpwsize'               => 'A jelszó minimális hossza 5 karakter',
'passwordtoosmall'        => 'Jelszó hossza túl rövid.',
'accountwaslocked'        => 'A hozzáférése zárolva túl sok sikertelen belépés miatt.',
'failedattempts'          => '%d sikertelen belépés történt.',
'groupnotexist'           => 'Kiválasztott csoport nem létezik ebben a projektben.',
'searchindetails'         => 'Keresés a részletes leírásban',

'is_admin'		=> 'Adminisztrátor',
'manage_project'	=> 'Projekt kezelő',
'view_tasks'		=> 'Hibajegyek megtekintése',
'edit_own_comments'	=> 'Saját megjegyzés szerkesztése',
'open_new_tasks'	=> 'Új hibajegyek felvitele',
'modify_own_tasks'	=> 'Saját hibajegyek módosítása',
'modify_all_tasks'	=> 'Minden hibajegy módosítása',
'view_comments'		=> 'Megjegyzések megtekintése',
'add_comments'		=> 'Megjegyzés hozzáadása',
'edit_comments'		=> 'Megjegyzés szerkesztése',
'edit_assignments'	=> 'Hozzárendelések szerkesztése',
'delete_comments'	=> 'Megjegyzések törlése',
'create_attachments'	=> 'Csatolások hozzáadása',
'delete_attachments'	=> 'Csatolások törlése',
'view_history'		=> 'Történek megtekintése',
'close_own_tasks'	=> 'Saját hibajegyek lezárása',
'close_other_tasks'	=> 'Mások hibajegyeinek lezárása',
'assign_to_self'	=> 'Önmagamhoz rendelés',
'assign_others_to_self'	=> 'Mások hozzárendelése',
'view_reports'		=> 'Riportok megtekintése',
'add_votes'		=> 'Szavazat leadása',
'showasassignees'         => 'Hozzárendelhető személy',
'find'		=> 'Keresés'
);

?>
