<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Endre bruker',
'accountenabled'          => 'Konto aktivert',
'editallusers'            => 'Vis alle brukere',
'username'                => 'Brukernavn',
'usersupdated'            => 'Brukere ble oppdatert',
'realname'                => 'Virkelig navn',
'emailaddress'            => 'Epostadresse',
'jabberid'                => 'Jabber ID',
'profileimage'            => 'Profilbilde',
'notifytype'              => 'Varslingstype',
'group'                   => 'Gruppe',
'enableaccounts'          => 'Aktiver kontoer',
'disableaccounts'         => 'Deaktiver kontoer',
'deleteaccounts'          => 'Slett kontoer',
'updatedetails'           => 'Oppdater innhold',
'setglobally'             => 'Denne preferansen er satt til alle brukere.',
'usergroupmanage'         => 'Bruker- og gruppeinnstillinger',
'newuser'                 => 'Registrer ny bruker',
'newuserbulk'             => 'Registrer flere nye brukere',
'bulkuserstoadd'          => 'Liste på nye brukere',
'optionsforallusers'      => 'Valg for alle nye brukere',
'newgroup'                => 'Opprett ny gruppe',
'yes'                     => 'Ja',
'no'                      => 'Nei',
'editgroup'               => 'Endre gruppe',
'groupname'               => 'Gruppenavn',
'description'             => 'Beskrivelse',
'admin'                   => 'Administratorgruppe',
'opennewtasks'            => 'Ny oppgave',
'modifytasks'             => 'Endre eksisterende oppgave',
'addcomments'             => 'Legg til kommentarer',
'attachfiles'             => 'Legg til filer',
'vote'                    => 'Stemme',
'groupenabled'            => 'Medlemmer kan logge inn',
'groupopen'               => 'Medlemmer kan logge inn',
'tasktypelist'            => 'Oppgavetyper',
'categorylist'            => 'Kategorier',
'oslist'                  => 'Operativsystemer',
'resolutionlist'          => 'Løsningstyper',
'versionlist'             => 'Versjoner',
'severitylist'            => 'Påvirkninger',
'listnote'                => 'NB: Dersom "Vis" tas bort kan det være at noen oppgaver endres eller ikke vises slik de skal. Endring av verdiene i feltene vil også endre verdiene i de oppgavene som allerede har de feltene. Grunnen til at noen felter ikke kan slettes kan være beskyttet eller allerede brukt i oppgaver.',
'name'                    => 'Navn',
'order'                   => 'Rekkefølge',
'back'                    => 'Tilbake',
'text'                    => 'Tekst',
'highlight'               => 'Fremheving',
'show'                    => 'Vis',
'owner'                   => 'Eier',
'selectowner'             => 'Valgt eier',
'update'                  => 'Oppdater',
'addnew'                  => 'Legg til',
'flysprayprefs'           => 'Preferanser for Endringsportal',
'projecttitle'            => 'Applikasjonstittel',
'baseurl'                 => 'Base URL for denne installasjonen',
'replyaddress'            => 'Svar e-postadresse for varsling',
'themestyle'              => 'Stil',
'language'                => 'Språk',
'anonview'                => 'Tillate anonyme brukere å vise oppgaver',
'allowanon'               => 'Tillat anonyme brukere til å åpne nye oppgaver',
'never'                   => 'Aldri',
'anonymously'             => 'Anonymt',
'afterregister'           => 'Kun etter registrering',
'spamproof'               => 'Aktiver bekreftelseskode for nye brukerregistreringer',
'anongroup'               => 'Gruppe for nye registrerte brukere',
'groupassigned'           => 'Medlemmer i denne gruppen kan tildeles oppgaver',
'forcenotify'             => 'Tving oppgave varslinger som',
'neversend'               => 'Aldri send',
'userchoose'              => 'La hver bruker velge',
'email'                   => 'Epost',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Standard kategorieier',
'noone'                   => 'Ingen',
'jabbernotify'            => 'Jabber Påminnelser',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Konto brukernavn',
'jabberpass'              => 'Kontopassord',
'saveoptions'             => 'Lagre',
'editcomment'             => 'Endre kommentar',
'commentby'               => 'Kommentert av',
'saveeditedcomment'       => 'Lagre endret kommentar',
'projectprefs'            => 'Applikasjonspreferanser',
'pagetitle'               => 'Sidetittel',
'defaultproject'          => 'Standard applikasjon',
'projectlists'            => 'Applikasjonsliste',
'showlogo'                => 'Vis tittel logo bilde',
'showgravatars'           => 'Vis avatars',
'emailNoHTML'             => 'Ingen HTML i e-post',
'intromessage'            => 'Innledende melding',
'isactive'                => 'Applikasjonen er aktiv',
'createproject'           => 'Ny applikasjon',
'nopermission'            => 'Du har ikke tilgang til å se denne siden.',
'listordertip'            => 'Sorteringsrekkefølge i listen',
'listshowtip'             => 'Vis denne i listen',
'categoryownertip'        => "Denne personen vil motta varslinger når en oppgave i denne kategorien er åpnet\n",
'categoryparenttip'       => 'Overkategori som denne skal ligge under',
'notsubcategory'          => 'Hovedkategori',
'showinlineimages'        => 'Vis bilde vedlegg in felt',
'dateformat'              => 'Datoformat',
'dateformat_extended'     => 'Datoformat på innhold',
'cache_feeds'             => 'Buffre feeden',
'no_cache'                => 'Ingen buffer',
'cache_disk'              => 'Buffer på disk',
'cache_db'                => 'Buffer i DB',
'subcategoryof'           => 'Underkategori av',
'visiblecolumns'          => 'Kolonner som vises i oppgavelisten',
'visiblefields'           => 'Felt når legge til / endre / vis oppgave',
'tense'                   => 'Spent',
'listtensetip'            => 'Fortid, nåtid eller fremtid',
'past'                    => 'Fortid',
'present'                 => 'Nåtid',
'future'                  => 'Fremtid',
'oldpass'                 => 'Gammelt passord',
'nooldpass'               => 'Gammelt passord ble ikke tastet inn',
'oldpasswrong'            => 'Gammelt passord var feil',
'changepass'              => 'Endre passord',
'confirmpass'             => 'Bekreft passord',
'projectmanager'          => 'Applikasjonsansvarlig',
'viewtasks'               => 'Vis oppgaver',
'modifyowntasks'          => 'Endre egne oppgaver',
'modifyalltasks'          => 'Endre oppgaver som ikke er brukerens egen',
'viewcomments'            => 'Vis kommentarer',
'editcomments'            => 'Endre kommentarer',
'deletecomments'          => 'Slett kommentarer',
'viewattachments'         => 'Vis vedlegg',
'createattachments'       => 'Sett inn vedlegg',
'deleteattachments'       => 'Slett vedlegg',
'viewhistory'             => 'Se historikk',
'closeowntasks'           => 'Stenge egne oppgaver',
'closeothertasks'         => 'Lukk oppgaver som ikke er brukerens egen',
'assigntoself'            => 'Tildele oppgaver til seg selv hvis det ikke allerede er tildelt',
'assignotherstoself'      => 'Tildele andres oppgaver til seg selv',
'viewreports'             => 'Vis aktivitetslogg',
'othersview'              => 'Tillat alle å se dette prosjektet',
'usersandgroups'          => 'Brukere og grupper',
'globalgroup'             => 'Global gruppe',
'globalgroups'            => 'Globale grupper',
'defaultglobalgroup'      => 'Standard global gruppe for nye brukere',
'addtogroup'              => 'Legg til i gruppe',
'moveuserstogroup'        => 'Flytt brukere til gruppe',
'nogroup'                 => 'Ingen Group - Fjern fra prosjektet',
'eventdesc'               => 'Aktivitetsbeskrivelse',
'requestedby'             => 'Spurt av',
'daterequested'           => 'Dato Spurt',
'closetask'               => 'Steng oppgaven',
'reopentask'              => 'Re-åpne oppgave',
'applymember'             => 'Søk om Prosjekt medlemskap',
'forcurrentproj'          => 'For aktuelt prosjekt',
'lostpw'                  => 'Mistet passord gjen oppreting',
'lostpwexplain'           => "Skriv inn ditt brukernavn, for å sende en link for å endre passordet ditt. Dette vil bli sendt til varsling adresse i profilen din.\n",
'sendlink'                => 'Send lenke',
'savenewpass'             => 'Lagre nytt passord',
'anonreg'                 => 'Tillat registrering for nye brukere',
'allowanonopentask'       => 'Tillat at anonyme brukere oppretter oppgaver',
'editglobalgroup'         => 'Endre globale grupper',
'editgroupforproj'        => 'Rediger gruppe for Prosjekt',
'notshownforadmin'        => "Tillatelser er ikke vist for admin-gruppen. Du trenger ikke å redigere dem.\n",
'general'                 => 'Generelt',
'userregistration'        => 'Brukerregistrering',
'notifications'           => 'Varslinger',
'resetoptions'            => 'Tilbakestill',
'preferences'             => 'Preferanser',
'tasktypes'               => 'Oppgavetyper',
'resolutions'             => 'Løsningstyper',
'categories'              => 'Kategorier',
'operatingsystems'        => 'Operativsystemer',
'versions'                => 'Versjoner',
'admintoolboxlong'        => 'Adminverktøy',
'newproject'              => 'Ny applikasjon',
'delete'                  => 'Slett',
'link'                    => 'Lenke',
'referencelinks'          => 'Referanselink',
'listdeletetip'           => 'Slett denne fra listen',
'lookandfeel'             => 'Utseende',
'globaltheme'             => 'Globalt tema',
'emailnotify'             => 'Epostvarslinger',
'fromaddress'             => 'Fra adresse',
'smtpserver'              => 'SMTP-server',
'smtpuser'                => 'SMTP Brukernavn',
'smtppass'                => 'SMTP Passord',
'addrewrite'              => 'Bruk adressen omskriving',
'usereminderdaemon'       => 'Aktiver bakgrunns påminnelse daemon',
'tasksperpage'            => 'Oppgaver pr. side på oppgavelisten',
'addtoassignees'          => 'Legg selv til følgere',
'taskstatuses'            => 'Oppgavestatuser',
'canvote'                 => 'Kan gi stemmer',
'loginsuccessful'         => 'Innlogging vellykket',
'youareloggedout'         => 'Du har blitt logget ut.',
'waitwhiletransfer'       => 'Vennligst vent mens du blir overført ...',
'clicknowait'             => 'Klikk her hvis du ikke ønsker å vente.',
'accountdisabled'         => 'Din konto er deaktivert. Kontakt administrator.',
'task'                    => 'Oppgave',
'edittask'                => 'Endre oppgaven',
'openedby'                => 'Innmeldt av',
'editedby'                => 'Sist endret av',
'tasktype'                => 'Type',
'category'                => 'Kategori',
'status'                  => 'Status',
'assignedto'              => 'Tildelt til',
'operatingsystem'         => 'Operativsystem',
'severity'                => 'Påvirkning',
'reportedversion'         => 'Rapportert versjon',
'dueinversion'            => 'Frist i versjon',
'defaultdueinversion'     => 'Standard utløp i versjon for nye oppgaver',
'undecided'               => 'Ubestemt',
'percentcomplete'         => 'Prosent ferdig',
'details'                 => 'Innhold',
'savedetails'             => 'Lagre',
'canceledit'              => 'Avbryt',
'anonymous'               => 'Anonym Innsender',
'complete'                => 'Løst',
'closedby'                => 'Stengt av',
'reasonforclosing'        => 'Årsak til stenging:',
'reopenthistask'          => 'Gjenåpne denne oppgaven',
'comments'                => 'Kommentarer',
'attachments'             => 'Vedlegg',
'relatedtasks'            => 'Relaterte oppgaver',
'edit'                    => 'Endre',
'addcomment'              => 'Send inn kommentar',
'fileuploadedby'          => 'Filer lastet opp av',
'uploadafile'             => 'Legg ved en fil',
'addalink'                => 'Relater til en oppgave',
'addanotherlink'          => 'Legg til enda en relasjon',
'uploadnow'               => 'Last opp nå',
'thesearerelated'         => 'Disse oppgavene er relatert til denne oppgaven',
'remove'                  => 'Slett',
'addnewrelated'           => 'Relater oppgave #',
'add'                     => 'Legg til',
'otherrelated'            => 'Andre oppgaver som denne oppgaven er knyttet til',
'receivenotify'           => "Disse brukerne vil motta detaljvarsler når denne oppgaven endres.\n",
'addusertolist'           => 'Legg til bruker i denne listen',
'addtolist'               => 'Legg til i listen',
'addmyself'               => 'Legg meg til denne listen',
'removemyself'            => 'Fjern meg fra denne listen',
'theseusersnotify'        => "Disse brukerne vil motta detaljerte varsler når denne oppgaven endres.\n",
'attachedtoproject'       => 'Tiknyttet applikasjon',
'reminders'               => 'Påminnelser',
'system'                  => 'System',
'remindthisuser'          => 'Påminn denne brukeren',
'thisoften'               => 'så ofte',
'startafter'              => 'Vent før du starter påminnelser',
'hour'                    => 'time',
'hours'                   => 'timer',
'day'                     => 'dag',
'days'                    => 'dager',
'week'                    => 'uke',
'weeks'                   => 'uker',
'addreminder'             => 'Legg til påminnelse',
'defaultreminder'         => 'Dette er en påminnelse om å se på følgende oppgave:',
'message'                 => 'Beskjed',
'closed'                  => 'Stengt',
'filename'                => 'Filnavn:',
'date'                    => 'Dato',
'filesize'                => 'Filstørrelse:',
'closurecomment'          => 'Ekstra kommentarer om lukking:',
'history'                 => 'Historikk',
'nohistory'               => 'Ingen historikk tilgjengelig.',
'eventdate'               => 'Dato',
'user'                    => 'Bruker',
'event'                   => 'Aktivitet',
'fieldchanged'            => 'Felt endret',
'taskopened'              => 'Oppgave åpnet',
'taskreopened'            => 'Oppgave gjenåpnet',
'taskclosed'              => 'Oppgave stengt',
'commentadded'            => 'Kommentar lagret',
'commentedited'           => 'Kommentar endret',
'commentdeleted'          => 'Kommentar slettet',
'attachmentadded'         => 'Vedlegg lagt til',
'attachmentdeleted'       => 'Vedlegg slettet',
'taskedited'              => 'Oppgaveinnhold endret',
'notificationadded'       => 'Bruker lagt til varslingsliste',
'notificationdeleted'     => 'Bruker fjernet fra varslingsliste',
'relatedadded'            => 'Relatert oppgave lagret',
'relateddeleted'          => 'Relatert oppgave slettet',
'taskassigned'            => 'Oppgave tildelt til',
'taskreassigned'          => 'Oppgave tildelt på nytt til',
'assignmentremoved'       => 'Tildeling fjernet',
'summary'                 => 'Tittel',
'addedasrelated'          => 'Oppgave lagt til den relaterte listen',
'deletedasrelated'        => 'Oppgave fjernet fra den aktuelle listen',
'reminderadded'           => 'Påminnelse lagt til',
'reminderdeleted'         => 'Påminnelse fjernet',
'priority'                => 'Prioritet',
'previousvalue'           => 'Forrige verdi',
'newvalue'                => 'Ny verdi',
'selectareason'           => 'Velg årsak',
'assigntome'              => 'Tildel oppgaven til meg',
'reopenrequest'           => 'Be om gjenåpning',
'requestclose'            => 'Be om stenging',
'ownershiptaken'          => 'Bruker tok eierskap',
'closerequestmade'        => 'Forespurte oppgaven lukkes',
'reopenrequestmade'       => 'Bedt om oppgaven som skal gjenåpnes',
'taskdependson'           => 'Denne oppgaven er avhengig av',
'taskblocks'              => 'Denne oppgaven blokkerer disse fra stenging',
'depadded'                => 'Avhengighet lagt til',
'depaddedother'           => 'Denne oppgaven lagt til som avhengighet',
'depremoved'              => 'Avhengighet fjernet',
'depremovedother'         => 'Denne oppgaven fjernet fra annen oppgave avhengighet liste',
'showdetailserror'        => 'At oppgaven ikke finnes, eller du har ikke tillatelse til å vise det.',
'makeprivate'             => 'Gjør personlig',
'makepublic'              => 'offentliggjøre',
'taskmadeprivate'         => 'Oppgaven gjort personlig',
'taskmadepublic'          => 'Personvern fjernet - oppgave offentliggjort',
'confirmdeletecomment'    => 'Vil du slette kommentar?',
'attachementswilldeleted' => 'Alle vedlegg vil også bli slettet!',
'confirmdeleteattach'     => 'Er du sikker på at du vil slette dette vedlegget?',
'selectedhistory'         => 'Viser valgte historie detaljer',
'showallhistory'          => 'Vis full historikk tab igjen',
'hidethis'                => 'Skjule dette området igjen',
'mark100'                 => 'Marker oppgave som 100% fullført',
'watchtask'               => 'overvåk oppgave',
'stopwatching'            => 'Stopp overvåking',
'commentlink'             => 'Lenke til denne kommentaren',
'submitreq'               => 'Send forespørsel',
'reasonforreq'            => 'Årsak til forespørsel',
'pmreqdenied'             => 'Prosjektleder nektet forespørsel',
'taskpendingreq'          => "Prosjektleder handling venter. Se fanen Historikk for detaljer.\n",
'previoustask'            => 'Forrige oppgave',
'nexttask'                => 'Neste oppgave',
'duedate'                 => 'Frist',
'attachnoperms'           => "Det er vedlegg med denne kommentarer, men du har ingen tillatelse til å vise dem.\n",
'linknoperms'             => "Det er linker med denne kommentarer, men du har ingen tillatelse til å vise dem.\n",
'open'                    => 'Åpen',
'depgraph'                => 'Vis avhengigheter',
'reset'                   => 'Tilbakestill',
'selectusers'             => 'Valgte brukere...',
'addmetoassignees'        => 'Legg meg også i listen "Tildelt til"',
'addedtoassignees'        => 'Bruker lagt til agent liste',
'dependencygraph'         => 'Avhengigheter',
'attachanotherfile'       => 'Legg ved en fil til',
'OK'                      => 'OK',
'addvote'                 => 'Legg inn stemme',
'disable_lostpw'          => 'Deaktiver tapte passord henting',
'disable_changepw'        => 'Deaktiver opprette / redigere passord',
'notifyfromfs'            => 'Varsel fra Endringsportal',
'autogenerated'           => 'Dette er en automatisk melding, vennligst ikke svar.',
'forward'                 => 'Forover',
'previous'                => 'Forrige',
'next'                    => 'Neste',
'first'                   => 'Første',
'last'                    => 'Siste',
'page'                    => 'Side %d av %d',
'search'                  => 'Søk',
'alltasktypes'            => 'Alle typer oppgaver',
'allseverities'           => 'Alle alvorlighetsgrader',
'alldevelopers'           => 'Alle utviklere',
'notyetassigned'          => 'Ennå ikke tildelt',
'allcategories'           => 'Alle kategorier',
'allstatuses'             => 'Alle statuser',
'allopentasks'            => 'Alle åpne oppgaver',
'sortthiscolumn'          => 'Sorter etter denne kolonnen',
'id'                      => 'ID#',
'project'                 => 'Applikasjon',
'dateopened'              => 'Åpnet',
'progress'                => 'Fremdrift',
'searchthisproject'       => 'Søk i applikasjon',
'dueanyversion'           => 'Ferdig i vilken versjon',
'anyversion'              => 'Rapportert i noen versjon',
'dueversion'              => 'Frist i versjon',
'lastedit'                => 'Siste endret',
'os'                      => 'Operativsystem',
'reportedin'              => 'Rapportert I',
'taskrange'               => 'Viser oppgaver %d - %d av %d',
'noresults'               => 'Ingen funnet.',
'takeaction'              => 'Gjer tiltak',
'watchtasks'              => 'Overvåk valgte oppgaver',
'stopwatchingtasks'       => 'Ikke overvåk valgte oppgaver',
'assigntaskstome'         => 'Tildel valgte oppgaver til meg',
'dueby'                   => 'Ferdig av ',
'dueanytime'              => 'Ferdig kortid ',
'selectduedate'           => 'Velg frist',
'toggleselected'          => 'Toggle Valgt',
'due'                     => 'Frist',
'assignedtome'            => 'Tildelt til meg',
'tasklist'                => 'Oppgaveliste',
'dateclosed'              => 'Dato stengt',
'advanced'                => 'Avansert',
'searchcomments'          => 'Søk i kommentarer',
'searchforall'            => 'Søk etter alle ord',
'anonusers'               => 'Anonyme brukere',
'miscellaneous'           => 'Diverse',
'users'                   => 'Brukere',
'taskproperties'          => 'Oppgaveegenskaper',
'selectsincedate'         => 'Velg Endret siden',
'changedsince'            => 'Endret siden',
'updatefs'                => 'Vennligst oppdater flyspray.',
'currentversion'          => 'Din nåværende versjon er',
'latestversion'           => 'og den siste versjonen er',
'hidemessage'             => '(Minn meg på det senere)',
'saveas'                  => 'Lagre søk som',
'nosearches'              => 'Ingen lagrede søk',
'saving'                  => 'Lagrer ...',
'votes'                   => 'Stemmer',
'tovote'                  => 'Stem',
'allclosedtasks'          => 'Alle stengte oppgaver',
'password'                => 'Passord',
'login'                   => 'Logg inn',
'rememberme'              => 'Husk meg',
'lostpassword'            => 'Mistet passord?',
'lostpwforfs'             => 'Mistet passord for flyspray',
'lostpwmsg1'              => "Hei\n\nJeg har mistet passordet mitt for flyspray på _\n",
'lostpwmsg2'              => "Vennligst gi meg med et nytt passord.\n\nBrukernavn: _",
'regards'                 => "\n\nHilsen,",
'yourusername'            => '_ ditt brukernavn _',
'locale'                  => 'no-NO',
'filenotexist'            => "Filen ikke finnes, eller du har ikke tillatelse til å få tilgang til det.\n",
'showtask'                => 'Vis oppgave',
'now'                     => 'Nå',
'go'                      => 'Gå!',
'opentaskanon'            => 'Ny oppgave anonymt',
'register'                => 'Registrer',
'addnewtask'              => 'Ny oppgave',
'reports'                 => 'Aktivitetslogg',
'editmydetails'           => 'Redigere mine opplysninger',
'logout'                  => 'Logg ut',
'disabledaccount'         => "Din konto har blitt deaktivert! <br /> Umiddelbart logger deg ut ...\n",
'poweredby'               => 'Powered by flyspray',
'sponsoredby'             => ' ',
'projects'                => 'Applikasjoner',
'allprojects'             => 'Alle applikasjoner',
'selectproject'           => 'for applikasjon:',
'tasksall'                => 'Alle oppgaver',
'tasksassigned'           => 'Oppgaver tildelt meg',
'tasksreported'           => 'Oppgaver jeg har innmeldt',
'taskswatched'            => 'Oppgaver jeg overvåker',
'mysearch'                => 'Mine søk',
'admintoolbox'            => 'Admin',
'manageproject'           => 'Applikasjonsinnstillinger',
'permissions'             => 'Se Tillatelser',
'hide'                    => 'Skjul',
'pendingreq'              => 'PM ber om venting',
'errorpage'               => "Flyspray kan ikke gi den siden du ba om.\nKanskje du har bedt om en oppgave som ikke finnes, eller du\nhar ikke tillatelse til å vise den siden du ønsket. <br /> <br />\nDu har kanskje prøvd å bruke en slem URL til å samhandle med databasen\nbackend bruker SQL-injeksjon. Hvis dette er sant, kan du gå til hjørnet og tror\nom dine handlinger. Når du kommer tilbake, må du ikke gjøre det igjen!",
'permissionsforproject'   => 'Tillatelser for ',
'switchto'                => 'Bytte til',
'lastsearch'              => 'Siste søk',
'modify'                  => 'Endre',
'noticefrom'              => 'Varsel fra',
'hasopened'               => 'har åpnet en ny flyspray oppgave, og tildelt den til deg:',
'moreinfonew'             => 'Du kan finne mer informasjon om denne feilen på flyspray side:',
'newtaskcategory'         => 'En ny flyspray oppgave har blitt åpnet i denne kategorien',
'categoryowner'           => 'Du mottar dette fordi du er oppført som kategori eieren.',
'tasksummary'             => 'Oppgavesammendrag:',
'newtaskadded'            => 'Din nye oppgaven er lagt til.',
'summaryanddetails'       => 'Du må fylle inn både sammendraget og detaljene.',
'goback'                  => 'Gå tilbake.',
'messagefrom'             => 'Dette er en melding fra flyspray bug tracking system på _',
'hasjustmodified'         => 'har nettopp endret følgende oppgave.',
'changedfields'           => 'Endrede felt er prefikset med stjerner (**)',
'moreinfomodify'          => "Du kan få mer informasjon om denne oppgaven på følgende nettadresse:\n",
'nolongerassigned'        => "Følgende oppgave er ikke lenger tildelt deg. Det er nå tildelt\n",
'hasassigned'             => 'har tildelt deg følgende flyspray oppgave:',
'taskupdated'             => 'Oppgaven er oppdatert',
'tasksupdated'            => 'Oppgaver har blitt oppdatert.',
'hasclosedassigned'       => "har stengt følgende flyspray oppgaven du ble tildelt:\n",
'unassigned'              => 'Ikke tildelt',
'hasclosed'               => 'har stengt følgende oppgave.',
'youonnotify'             => "Du mottar dette fordi du er på varslingslisten.\n",
'taskclosedmsg'           => 'Oppgaven har blitt stengt',
'returntotask'            => 'Tilbake til detaljer om oppgaven',
'backtoindex'             => 'Gå tilbake til oppgavelisten',
'noclosereason'           => 'Du har ikke valgt en grunn for å stenge denne oppgaven.',
'hasreopened'             => 'har gjenåpnet følgende Flyspray oppgave som du lukket:',
'taskreopenedmsg'         => 'Oppgaven har blitt gjenåpnet.',
'backtotask'              => 'Gå tilbake til oppgaven.',
'commentaddedmsg'         => 'Kommentar har blitt lagt til.',
'commenttoassigned'       => 'har lagt til en kommentar til en oppgave du har fått tildelt:',
'commenttotask'           => 'har lagt følgende kommentar til denne oppgaven.',
'nocommententered'        => "Du bør legge inn en kommentar før du klikker på send-knappen.\n",
'fillinfields'            => 'Du gjorde ikke fylle inn alle feltene.',
'notcurrentpass'          => 'Det er ikke ditt riktige passord!',
'passchanged'             => 'Ditt passord er endret.',
'closewindow'             => 'Nå kan du lukke dette vinduet.',
'passnomatch'             => 'Dine nye passord var ikke det samme!',
'usernametaken'           => "Dette brukernavnet er allerede i bruk. Du må velge en annen.\n",
'usernametakenbulk'       => 'Brukernavn er allerede tatt',
'newusercreated'          => 'Ny brukerkonto er opprettet',
'accountcreated'          => 'Din brukerkonto er opprettet',
'newuserwarning'          => "Legg merke til at de globale preferanser kan kreve kontoen din for å bli godkjent av en administrator. Hvis du ikke kan logge inn, dette er nok derfor.\n",
'nomatchpass'             => 'Passordene er ulike.',
'confirmwrong'            => 'Bekreftelseskoden er feil!',
'formnotcomplete'         => 'Skjemaet ble ikke ferdig utfylt.',
'formnotnumeric'          => 'Satt inn data var ikke numerisk!',
'groupnametaken'          => 'De gruppenavnet er allerede tatt.',
'newgroupadded'           => 'Ny gruppe opprettet.',
'optionssaved'            => 'Endringer lagret.',
'hasuploaded'             => "har lastet opp en fil, vedlegg til en oppgave som har blitt tildelt til:\n",
'hasattached'             => 'har festet en fil til følgende oppgave.',
'fileuploaded'            => 'Filen er lastet opp.',
'fileerror'               => "Det oppstod en feil ved opplasting av filen. Kanskje tillatelsene på <i> vedlegg / </ i> katalogen er feil.\n",
'contactadmin'            => 'Kontakt ansvarlig for denne applikasjonen',
'selectfileerror'         => 'Du har ikke valgt en fil.',
'userupdated'             => 'Bruker detaljer har blitt oppdatert',
'realandemail'            => "Du fylte ikke inn både virkelig navn og e-postadresse feltene.\n",
'groupupdated'            => 'Gruppe definisjon oppdatert.',
'groupanddesc'            => 'Du fylte ikke inn gruppenavnet.',
'fillallfields'           => 'Vennligst fyll ut alle feltene.',
'listPmustN'              => '"Order" må være numerisk.',
'listupdated'             => 'Listen er oppdatert.',
'listitemadded'           => 'Ny liste element lagt.',
'relatedaddedmsg'         => 'Relatert oppgave lagt til listen.',
'relatederror'            => 'At oppgaven er allerede på dette relatert oppgaveliste.',
'relatedremoved'          => 'Relatert oppgave fjernet fra listen.',
'notifyadded'             => 'Bruker lagt til varslingsliste.',
'notifyerror'             => 'At brukeren er allerede på varslingsliste for denne oppgaven.',
'notifyremoved'           => 'Bruker fjernet fra varslingsliste.',
'editcommentsaved'        => 'Oppdatert kommentar er lagret.',
'commentdeletedmsg'       => 'Kommentar er slettet.',
'gotonewtask'             => 'Gå til oppgaven du opprettet',
'projectcreated'          => "Din nye prosjektet er opprettet. Du kan nå tilpasse prosjektet i prosjektledelse området.\n",
'customiseproject'        => 'Tilpass dette prosjektet',
'projectupdated'          => 'Preferanser prosjekt oppdatert',
'emptytitle'              => 'Du forlot Prosjekttittel-feltet stå tomt. Gå tilbake og rette den.',
'loginbelow'              => 'Du kan nå prøve å logge inn!',
'attachmentdeletedmsg'    => 'Vedlegget er slettet',
'reminderaddedmsg'        => 'Din påminnelse er lagt til.',
'reminderdeletedmsg'      => 'Den valgte påminnelse har blitt slettet.',
'flyspraytask'            => 'Flyspray oppgave',
'fieldsmissing'           => 'Noen felt inneholdt ingen eller ugyldige data.',
'relatedinvalid'          => 'Oppgaven finnes ikke.',
'relatedproject'          => "Denne oppgaven er festet til et annet prosjekt. Legg til forhold likevel?\n",
'addanyway'               => 'Legg til likevel',
'cancel'                  => 'Avbryt',
'alreadyedited'           => "Denne oppgaven ble redigert av noen andre før du lagret. Har du fortsatt ønsker å lagre endringene?\n",
'saveanyway'              => 'Lagre endringene mine uansett',
'nouserselected'          => "Ingen bruker valgt. Velg minst en bruker før du prøver igjen.\n",
'groupswitchupdated'      => 'Brukergrupper endret vellykket.',
'takenownershipmsg'       => 'Denne oppgaven er nå tildelt deg.',
'adminrequestmade'        => 'Din forespørsel er sendt til Applikasjonsansvarlig',
'newdepnotify'            => 'Ny avhengighet er lagt inn for følgende oppgave:',
'dependadded'             => 'Oppgaveavhengighet er lagt til',
'dependaddfailed'         => "Det oppsto en feil når du legger til avhengighet. Kontroller at oppgaven finnes, og det er ingen gjensidig blokken.\n",
'depremovedmsg'           => 'Oppgaveavhengighet er fjernet',
'newdepis'                => 'Den nye avhengighet er',
'magicurlsent'            => "En melding har blitt sendt til din varsling adresse. Den inneholder en link som tar deg til en side for å fullføre denne oppgaven.\n",
'changefspass'            => 'Endre flyspray passord',
'magicurlmessage'         => "Følg linken nedenfor for å endre flyspray passord:\n",
'erroronform'             => 'Det var et problem med innsending av skjemaet',
'addressused'             => "Denne adressen har blitt brukt til å registrere et flyspray konto. Hvis du ikke var ventet denne meldingen, kan ignorere og slette den. Gå til følgende URL for å fullføre registreringen:\n",
'confirmcodeis'           => 'Din bekreftelseskode er:',
'codesent'                => "Din bekreftelseskode har blitt sendt. Følg instruksjonene i meldingen.\n",
'codenotsent'             => 'Kan ikke sende koden din, vennligst prøv igjen senere.',
'taskmadeprivatemsg'      => 'Denne oppgaven er gjort personlig',
'taskmadepublicmsg'       => 'Denne oppgaven har blitt gjort offentlig igjen',
'realandnotify'           => "Du må fylle ut ditt virklige Name-feltet, og enten e-postadresse eller Jabber ID-feltet.\n",
'pmreqdeniedmsg'          => 'Forespørsel Prosjektleder nektet',
'massopsuccess'           => 'Mass operasjoner vellykkede - hvor tillatelser tillatt',
'usernotexist'            => 'Dennebrukeren finnes ikke på denne flyspray installasjon',
'commentattachperms'      => "Du kan ikke slette denne kommentaren - ingen tillatelse til å slette vedlegg\n",
'voterecorded'            => 'Din stemme er registrert',
'votefailed'              => 'Din stemme kan ikke registreres',
'createnewgroup'          => 'Opprett ny gruppe',
'requiredfields'          => 'Obligatoriske felt er merket med en',
'addthisgroup'            => 'Legg til denne gruppen',
'createnewproject'        => 'Opprett ny applikasjon',
'addnewproject'           => 'Opprett ny Applikasjon',
'htmlallowed'             => 'HTML-kode er tillatt',
'createthisproject'       => 'Opprett applikasjon',
'inlineimages'            => 'Vis bilde vedlegg inline',
'createnewtask'           => 'Opprett en ny oppgave i prosjektet:',
'addanother'              => 'Legg til en annen oppgave etter dette',
'addthistask'             => 'Opprett oppgaven',
'notifyme'                => 'Varsle meg ved endringer av denne oppgaven',
'newtask'                 => 'Ny oppgave',
'attachafile'             => 'Legg til en fil',
'registernewuser'         => 'Registrer ny bruker',
'none'                    => 'Ingen',
'registeraccount'         => 'Registrer denne kontoen',
'registerbulkaccount'     => 'Registrere kontoer',
'both'                    => 'Begge',
'notifyfrom'              => 'Melding fra _',
'donotreply'              => 'Dette er en automatisk melding, vennligst ikke svar.',
'disclaimer'              => "Du mottar denne meldingen fordi du har bedt om det fra flyspray bugtracking system. Hvis du ikke forvente denne meldingen eller ikke ønsker å motta post i fremtiden, kan du endre varslingsinnstillingene på nettadressen vist ovenfor.\n",
'userwho'                 => 'Brukeren som gjorde dette',
'moreinfo'                => 'Mer informasjon finner du på følgende nettadresse:',
'newtaskopened'           => 'En ny flyspray oppgave er blitt åpnet. Detaljer er nedenfor.',
'notify.taskclosed'       => 'Følgende oppgave er nå stengt:',
'notify.taskreopened'     => 'Følgende oppgave har blitt gjenåpnet:',
'newdep'                  => 'Følgende oppgave har en ny avhengighet:',
'notify.depremoved'       => 'Følgende oppgave har hatt en avhengighet fjernet:',
'olddepwas'               => 'Den gamle avhengighet var',
'notify.commentadded'     => 'Følgende oppgave har en ny kommentar til:',
'commentis'               => 'Kommentar tekst er nedenfor.',
'newattachment'           => 'En ny fil er knyttet til følgende oppgave:',
'detailsbelow'            => 'Detaljene er under.',
'notify.relatedadded'     => 'En ny beslektet oppgave er lagt til følgende oppgave:',
'relatedis'               => 'Den relatert oppgave er',
'assignedtoyou'           => 'Du er tildelt følgende oppgave',
'takenownership'          => 'har tatt eierskap for følgende oppgave:',
'requiresaction'          => 'Følgende oppgave krever handling av en prosjektleder:',
'requiresactionnotify'    => 'Oppgaven krever handling av en prosjektleder',
'pmdeny'                  => "En prosjektleder har avslått forespørselen påvente for følgende oppgave:\n",
'pmdenynotify'            => 'En prosjektleder har avslått forespørselen',
'fileaddedtoo'            => 'En eller flere filer har blitt festet.',
'taskwatching'            => 'Du overvåker følgende oppgaver',
'isdepfor'                => 'er en ny avhengighet for',
'denialreason'            => 'Grunn for avvisning',
'taskchanged'             => "Følgende oppgave er endret. Endringene er listet opp nedenfor. For full informasjon om hva som er endret, kan du gå til URL og klikk på fanen History.\n",
'useraddedtoassignees'    => "En bruker har lagt seg selv til i listen over brukere som er tildelt denne oppgaven.\n",
'removeddepis'            => 'Den fjernet avhengigheten er',
'isnodepfor'              => 'er ingen avhengighet lenger for',
'usergroups'              => 'Brukergrupper',
'pmtoolbox'               => 'Applikasjonsansvarligs verktøykasse',
'groupmanage'             => 'Gruppeinnstillinger',
'pendingrequests'         => 'Avventende forespørsler',
'reasongiven'             => 'Grunn',
'nopendingreq'            => 'Det er ingen avventende forespørsler fra Applikasjonsansvarlig',
'givereason'              => 'Gi en grunn',
'catlisted'               => 'Kategorier',
'oslisted'                => 'Operativsystemer',
'verlisted'               => 'Versjoner',
'tasktypeed'              => 'Oppgavetyper',
'resed'                   => 'Løsningstyper',
'deny'                    => 'Avvis',
'notifiedwhen'            => 'Varslet når',
'onlynewtasks'            => 'Nye oppgaver er åpnet',
'allevents'               => 'Enhver hendelse skjer i enhver oppgave',
'feeds'                   => 'Feeds',
'feeddescription'         => 'Feed beskrivelse',
'feedimgurl'              => 'Feed bilde URL (la stå tom for ingen bilde)',
'notifysubject'           => 'Varslingsnavn',
'notifysubjectinfo'       => '(%p = prosjekttittel, %s = oppgave Oppsummert, %t = oppgave id, %a = action, %u = user)',
'priority6'               => 'Veldig høy',
'priority5'               => 'Høy',
'priority4'               => 'Medium',
'priority3'               => 'Lav',
'priority2'               => 'Veldig lav',
'priority1'               => 'Utsatt',
'sendcode'                => 'Send kode!',
'entercode'               => "Skriv inn bekreftelseskoden du mottok på varselmelding. Skriv også ønsket konto passord.\n",
'confirmationcode'        => 'Bekreftelseskode',
'registererror'           => "Sørg for at du har fylt ut alle obligatoriske felter, og at du har lagt inn riktige opplysninger for ønsket varslingstype.\n",
'validusername'           => '(bare alfanumeriske tegn og -. _ er tillatt)',
'validemail'              => '(bruk ; for å skille flere epost-adresser)',
'emailtakenbulk'          => 'Epostadresse er allerede i bruk',
'emailtaken'              => "Den e-postadressen eller Jabber-ID er allerede tatt. Du må velge en annen.\n",
'note'                    => '<strong>NB:</strong> Du vil motta en bekreftelseskode før kontoen blir opprettet. Koden sendes dit du valgte som varslingsmåte ovenfor.<br />Hvis du legger inne feil informasjon vil du <strong>ikke</strong> motta bekreftelseskoden.',
'changelog'               => 'Endringslogg',
'changeloggen'            => 'Changelog Generator',
'listfrom'                => 'Liste changelog-oppføringer fra',
'to'                      => 'til',
'oldestfirst'             => 'Eldste først',
'recentfirst'             => 'Nyeste først',
'severityrep'             => 'Påvirkningsrapport',
'totalopen'               => 'Totalt åpne oppgaver',
'age'                     => 'Alder',
'agerep'                  => 'Alder Rapport',
'eventsrep'               => 'Aktivitetsrapport',
'events'                  => 'Aktiviteter',
'Tasks'                   => 'Oppgaver',
'opened'                  => 'Åpnet',
'edited'                  => 'Endret',
'assigned'                => 'Tildelt',
'within'                  => 'Innen',
'pastday'                 => 'Den siste dagen',
'pastweek'                => 'Den siste uken',
'pastmonth'               => 'Den siste måneden',
'pastyear'                => 'Det siste året',
'nolimit'                 => 'Ingen grense',
'from'                    => 'Fra',
'duein'                   => 'Frist innen',
'selectfromdate'          => 'Velg fra dato',
'selecttodate'            => 'Velg til dato',
'showvoters'              => 'Vis/skjul stemmere',
'roadmap'                 => 'Veikart',
'roadmapfor'              => 'Veikart for versjon',
'tasks'                   => 'oppgaver',
'completed'               => 'fullført.',
'opentasks'               => 'åpne oppgaver',
'of'                      => '% av',
'severity5'               => 'Kritisk',
'severity4'               => 'Høy',
'severity3'               => 'Medium',
'severity2'               => 'Lav',
'severity1'               => 'Veldig lav',
'Redirect'                => 'Omdirigere',
'redirectmsg'             => "Hvis nettleseren ikke støtter meta omdirigering vennligst klikk %sHERE%s for å bli omdirigert\n",
'allowclosedcomments'     => 'Tillat kommentarer til lukkede oppgaver',
'comment'                 => 'Kommentar',
'editowncomments'         => 'Endre egne kommentarer',
'reopened'                => 'Gjenåpnet',
'loading'                 => 'Laster...',
'notifyown'               => 'Varsel for egne endringer',
'youremail'               => 'Din epostadresse',
'thankyouforbug'          => "Takk for rapportering av problemet. Du kan se oppgaven og observere dens fremgang som helst ved hjelp av følgende URL:\n",
'anonuser'                => 'Anonym bruker',
'conflict'                => 'Konflikt',
'file'                    => 'Fil',
'KiB'                     => 'Kb',
'MiB'                     => 'Mb',
'size'                    => 'Størrelse',
'projectgroup'            => 'Applikasjonsgruppe',
'profile'                 => 'Profil:',
'viewprofile'             => 'Vis profil',
'regdate'                 => 'Registrert siden',
'tasksopened'             => 'Oppgave åpnet',
'replyto'                 => 'Svar til',
'notifytypes'             => 'Varslingstyper',
'pm.taskchanged'          => 'Oppgave endret',
'pm.taskreopened'         => 'Oppgave gjenåpnet',
'pm.depadded'             => 'Avhengighet lagt til',
'pm.depremoved'           => 'Avhengighet fjernet',
'pmrequest'               => 'PM forespørsel',
'pmrequestdenied'         => 'PM forespørsel avvist',
'newassignee'             => 'New oppdragstakeren',
'revdepadded'             => 'Omvendt avhengighet lagt',
'revdepaddedremoved'      => 'Omvendt avhengighet fjernet',
'assigneeadded'           => 'Oppdragstakeren lagt',
'addusergroup'            => 'Legg til bruker i denne gruppen',
'groupmembers'            => 'Gruppemedlemmer',
'deleteuser'              => 'Slett denne brukeren',
'userdeleted'             => 'Bruker slettet',
'autoassign'              => 'Autotildel sak til kategorieier',
'ssl'                     => 'SSL',
'updatewrong'             => "Du har oppdateringen kontrollfunksjonen er aktivert, men en feil oppstod under forsøk\nå kontakte oppdateringsserveren, enten verten tillater ikke utgående tilkoblinger\neller feilen ble forårsaket av et nettverksproblem.\nVennligst besøk flyspray nettsted for å sikre at du kjører den nyeste versjonen.\n",
'deleteproject'           => 'Slett dette prosjektet og flytte innholdet til',
'projectdeleted'          => 'Applikasjonen er slettet',
'feedforall'              => 'Feed for alle prosjekter',
'usercreated'             => 'Bruker opprettet',
'created'                 => 'Opprettet',
'deleted'                 => 'Slettet',
'userid'                  => 'Bruker ID',
'editassignments'         => 'Rediger oppdrag',
'preview'                 => 'Forhåndsvisning',
'anyprogress'             => 'Enhver Progress',
'tasksrelated'            => 'Oppgaver relatert til denne oppgaven',
'duplicatetasks'          => 'Kopier av denne oppgaven',
'databasemodfailed'       => "Database modifisering mislyktes. Mulige årsaker er tilstrekkelige tillatelser.\n",
'frequency'               => 'Frekvens',
'newuserregistered'       => "En ny bruker har registrert på din flyspray installasjon. Bruker detaljene er som følger:\n\n",
'newuserregisterednotify' => 'En ny bruker er registrert',
'notify_registration'     => 'Varsle administratorer om ny bruker',
'textversion'             => 'Vis i tekstformat',
'onlyprimary'             => 'Oppgaver ikke blokkere andre oppgaver',
'switch'                  => 'Switch',
'max'                     => 'maks.',
'dates'                   => 'Datoer',
'selectduedatefrom'       => 'Frist fra',
'selectduedateto'         => 'til',
'selectsincedatefrom'     => 'Endret fra',
'selectsincedateto'       => 'til',
'selectdate'              => 'Velg dato',
'selectopenedfrom'        => 'Åpnet fra',
'selectopenedto'          => 'til',
'selectclosedfrom'        => 'Stengt fra',
'selectclosedto'          => 'til',
'startat'                 => 'Start ved',
'hasattachment'           => 'Har vedlegg',
'private'                 => 'Personlig',
'watching'                => 'Overvåking',
'alreadyvotedthistask'    => 'du stemte for denne oppgaven',
'alreadyvotedthisday'     => 'har stemt i dag',
'visibility'              => 'Sikt',
'public'                  => 'Offentlig',
'leaveemptyauto'          => "La passordfeltene tomt hvis du vil at passordet skal genereres automatisk.\n",
'novalidemail'            => 'Du har ikke skrevet inn en gyldig e-postadresse.',
'novalidjabber'           => 'Du har ikke skrevet inn en gyldig Jabber adresse.',
'missingrequired'         => 'Du gjorde ikke fylle ut alle obligatoriske felter.',
'entervalidusername'      => 'Vennligst skriv inn et gyldig brukernavn og virkelige navn.',
'couldnotaddusernotif'    => 'Kunne ikke legge brukeren til varslingsliste.',
'defaulttask'             => 'Standard oppgavebeskrivelse',
'all'                     => 'alle',
'events.useraddedtoassignees'=> 'Bruker lagt til agenter ',
'eventlog'                => 'Aktivitetslogg',
'assignmentchanged'       => 'Oppdraget endret',
'detailedinfo'            => 'Detaljert informasjon',
'All'                     => 'Alle',
'tasksireported'          => 'Oppgaver jeg har innmeldt',
'recentlyopened'          => 'Åpnet nylig',
'stats'                   => 'Status',
'totaltasks'              => 'oppgaver totalt',
'mostwanted'              => 'Mest ettersøkte oppgaver',
'defaultentry'            => 'Standard oppføring side',
'toplevel'                => 'Toppnivå visning',
'overview'                => 'Oversikt',
'error#'                  => 'Feil #',
'error1'                  => "Du har ikke tilstrekkelige tillatelser til å vise dette vedlegget.\n",
'error3'                  => 'Gjentok handlingen, omdirigere til hovedsiden.',
'error4'                  => 'Du har ikke adminrettigheter.',
'error5'                  => 'At brukeren finnes ikke på denne flyspray installasjon.',
'error6'                  => 'Ugyldig adminområde.',
'error7'                  => 'Feil passord!',
'error71'                 => "Kontoen er låst for %d minutter på grunn av for mange mislykkede innloggingsforsøk!\n",
'error8'                  => 'Du skrev ikke inn brukernavn og passord.',
'error9'                  => 'Oppgaven finnes ikke eller ingen rettigheter til å vise denne oppgaven.',
'error10'                 => 'Denne oppgaven finnes ikke.',
'error101'                => 'Du har ingen tillatelse til å vise denne oppgaven.',
'error102'                => "Du har ingen tillatelse til å vise denne oppgaven, logge inn kan hjelpe.\n",
'error11'                 => 'Ingen tilgang til å endre denne kommentaren',
'error12'                 => "Ingen gyldig magiske nøkkelen! Er du sikker på at du fikk den frå meldingen?\n",
'error13'                 => 'Anonyme brukere har ikkje en profil.',
'error14'                 => 'Du har ikkje tilstrekkelige tillatelser til å opprette en ny gruppe.',
'error15'                 => 'Du har ikkje tilstrekkelige tillatelser til å åpne en oppgave.',
'error16'                 => 'Du er ikke en prosjektleder.',
'error17'                 => 'Ugyldig PM området.',
'error18'                 => 'Ugyldig magi URL.',
'error19'                 => 'Den brukeren finnes ikke på denne flyspray installasjon.',
'error20'                 => 'Ugyldig database modifikasjon.',
'error21'                 => 'En eller flere e-poster ble ikke sendt. Sjekk din config.',
'error22'                 => 'Ingen nye brukerregistrering tillatt.',
'error23'                 => 'Bruker eller gruppe ikke aktivert for innlogging.',
'error24'                 => "Verken dot kjørbar eller ein offentlig dot-server er blitt satt.\n",
'error25'                 => 'Veikart bare tilgjengelig for et bestemt prosjekt.',
'error26'                 => 'Uegnet OAuth leverandør.',
'error27'                 => 'Kan ikkje logge inn. Gje oss tillatelse til å vise e-postadressen din.',
'error28'                 => 'Du har ingen tilgang til dette området.',
'done'                    => 'gjort',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Prosjektet kunne ikke bli sletta.',
'GMT'                     => 'GMT',
'timezone'                => 'Tidssone',
'accept'                  => 'Aksepter',
'reasonfordeinal'         => 'Grunnen til fornektelse',
'pruneclosedlinks'        => 'Fjern Stengte relasjoner',
'pruneclosedtasks'        => 'Fjern Stengte oppgaver',
'pagegenerated'           => 'Side og bilde generert i %d sekunder.',
'pruninglevel'            => 'Reduksjonsnivå',
'lastuser'                => 'Den siste brukeren kan ikkje slettes.',
'allprivate'              => 'Alle applikasjon er personlige',
'deletegroup'             => 'Slett denne gruppen og flytte brukere til',
'parent'                  => 'Overordnet oppgave',
'ordertip'                => 'Rekkefølgen disse elementene vil vises i listen',
'showtip'                 => 'Vis element i listen',
'deletetip'               => 'Slett dette elementet fra listen',
'del'                     => 'del',
'request1'                => 'En oppgave nedleggelse har blitt forespurt.',
'request2'                => 'En forespørsel om å re-åpne oppgaven har blitt gjort.',
'allpriorities'           => 'Alle prioriteter',
'noroadmap'               => 'Veikart eksisterer ikke (den finnes ingen "fremtidsversjoner" for denne applikasjonen).',
'expand'                  => 'Utvid',
'collapse'                => 'Kollaps',
'expandall'               => 'Utvid alle',
'collapseall'             => 'Skjul alle',
'minpwsize'               => 'Minimum passord størrelse er 5 tegn',
'passwordtoosmall'        => 'Passordet er for kort.',
'accountwaslocked'        => "Kontoen hadde blitt låst på grunn av for mange mislykkede innloggingsforsøk.\n",
'failedattempts'          => 'Det var %d mislykkede innloggingsforsøk.',
'groupnotexist'           => 'Valgte gruppen finnes ikke i dette prosjektet.',
'searchindetails'         => 'Søke detaljer',
'showasassignees'         => 'Vis som agenter',
'find'                    => 'Finn',
'tls'                     => 'TLS',
'isadmin'                 => 'er admin',
'addvotes'                => 'Legg til stemmer',
'removevote'              => 'Fjern stemme',
'voteremoved'             => 'Din stemme er fjernet',
'voteremovefailed'        => 'Din stemme kan ikke fjernes.',
'connectedtasks'          => 'Tilknyttede oppgaver:',
'taskdependencies'        => 'Oppgaveavhengigheter',
'viewgraph'               => 'Vis graf',
'notaskdependencies'      => 'Denne oppgaven er ikke avhengig av andre oppgaver',
'dependson'               => 'Er avhengig av',
'blocks'                  => 'Blokkerer',
'newdependency'           => 'Ny avhengighet:',
'nouserstoadd'            => "Ingen brukere å legge til. Vennligst sikre navn, brukernavn og e-post er definert for hver bruker.\n",
'dispintro'               => 'Vise hoved innledende melding',
'mainmessage'             => 'Hoved innledende melding',
'setsupertask'            => 'Still Super-Task ID:',
'supertaskmodified'       => 'Super-Task ID er endret',
'set'                     => 'Sett',
'supertask'               => 'Super-Task',
'setparent'               => 'Legg inn ID# for overordnet oppgave',
'selfsupertasknotallowed' => 'Super-Task ID kan ikke være det samme som selv Oppgåve ID',
'quickaction'             => 'Hurtigvalg',
'updateselectedtasks'     => 'Oppdater valgte oppgaver',
'notspecified'            => 'Ikke spesifisert',
'editselectedtasks'       => 'Endre valgte oppgaver',
'information'             => 'Informasjon',
'taskclosedisabled'       => "Lukk Task er deaktivert som følgende avhengige oppgaver er fortsatt åpen: -\n",
'daysleft'                => 'dager igjen',
'dayoverdue'              => 'dager over fristen',
'duetoday'                => 'Frist i dag.',
'daysbeforealert'         => 'Dager før varsel',
'associatedsubtask'       => 'Tilknyttet deloppgave #',
'associatesubtask'        => 'Knytt deloppgave ID# med denne oppgaven',
'subtaskid'               => 'Deloppgave ID#',
'subtaskalreadyhasparent' => "Sub oppgaven du skrev allerede har en overordnet oppgave, må du fjerne dette før assosiere.\n",
'subtaskisparent'         => "Sub oppgaven du skrev inn er den overordnede oppgaven med denne oppgaven. Sub oppgave ikke forbundet.\n",
'subtasknotexist'         => 'Sub oppgaven du har angitt finnes ikke.',
'subtaskremovedmsg'       => 'Under oppgave har fulført fjernet',
'subtaskadded'            => 'Sub oppgave lagt',
'subtaskremoved'          => 'Sub oppgave fjernet',
'addnewsubtask'           => 'Opprett ny deloppgave',
'hidesubtasks'            => 'Skjul deloppgaver',
'voteforthistask'         => 'Stem på denne oppgaven',
'watchthistask'           => 'Se denne oppgaven',
'privatethistask'         => 'Gjør denne oppgaven personlig',
'adddependenttask'        => 'Knytt avhengig oppgave',
'associatetaskid'         => 'Sub oppgave id',
'parenttaskid'            => 'Overordnet ID#',
'invalidsupertaskid'      => 'Overordnede oppgave id er ikke gyldig.',
'supertaskadded'          => 'Supertask lagt',
'supertaskremoved'        => 'Supertask fjernet',
'effort'                  => 'Innsats',
'efforttracking'          => 'Innsatsovervåking',
'useeffort'               => 'Prosjektet benytter innsats sporing',
'estimatedeffort'         => 'Beregnet innsats',
'totalestimatedeffort'    => 'Totalt beregnet innsats',
'currenteffortdone'       => 'Innsats utført hittil',
'starteffort'             => 'Start overvåking',
'endeffort'               => 'Stopp overvåking',
'cleareffort'             => 'Fjern overvåking',
'addeffort'               => 'Legg til innsats',
'manualeffort'            => 'Manuelt Legg til innsats (H: M)',
'efforttrackingstarted'   => 'Innsats Sporing Startet for denne oppgaven.',
'efforttrackingnotstarted'=> "Kan ikke begynne å spore på en sak som allerede spores\n",
'efforttrackingstopped'   => 'Innsats Sporing Endte for denne oppgaven.',
'efforttrackingcancelled' => 'Innsats Sporing Avlyst for denne oppgaven.',
'efforttrackingadded'     => 'Manuell innsats registrert for oppgaven.',
'trackinginprogress'      => 'Sporing i Progress',
'viewestimatedeffort'     => 'Kan sjå innsats sporing.',
'viewcurrenteffortdone'   => 'Kan sjå nåværende innsats gjort',
'trackeffort'             => 'Kan spore innsats',
'invalideffort'           => 'Innsatsen er ugyldig. Må være et tall',
'showpass'                => 'Vis passord',
'chooseafile'             => 'Velg en fil!',
'incorrectfiletype'       => 'Feil filtype. Tillatt: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Ingen passord for å be. Du registrert gjennom %s',
'addmultipletasks'        => 'Importer oppgaveliste',
'pendingnewuserrequest'   => 'Avventende nye innmeldte forespørsler',
'adminrequestswaiting'    => 'Adminforespørsler venter',
'clicktoedit'             => 'Klikk på hvert felt for å raskt redigere',
'confirmedit'             => 'OK',
'regapprovedbyadmin'      => 'Registrering godkjent av admin (deaktiver bekreftelseskode)',
'activity'                => 'Aktivitet',
'myactivity'              => 'Min aktivitet',
'emailverificationwrong'  => 'Bekreftelsen stemmer ikke overens med den gitte e-postadresse',
'verifyemailaddress'      => 'Bekreft epost',
'hideemails'              => 'Skjul brukeres e-postadresser',
'hidemyemail'             => 'Skjule min e-postadresse',
'exporttasklist'          => 'Eksporter liste',
'onedecimal'              => 'ein desimal',
'manday'                  => 'man-dag',
'mandays'                 => 'man-dager',
'mandayabbrev'            => 'dag',
'hourspermanday'          => 'Timer per ein day (HH: mm)',
'itemexists'              => 'Sak %s finnes allerede i databasen.',
'categoryitemexists'      => 'Sak %s eksisterer allerede i kategorien %s i databasen.',
'pageswelcomemsg'         => 'Sider for å vise hoved intro melding',
'pagesintromsg'           => 'Sider for å vise intro melding',
'activeoauths'            => 'Aktive OAuth tilbydere',
'onlyoauthreg'            => 'Bare tillate Oauths registreringer',
'estimatedeffortformat'   => 'Estimert innsats visningsformat',
'currenteffortdoneformat' => 'Nåværende innsats gjort visningsformat',
'minute'                  => 'minutt',
'minutes'                 => 'minutter',
'minuteplural'            => 'minutter',
'minutesingular'          => 'minutt',
'minuteabbrev'            => 'min',
'hourplural'              => 'timer',
'hoursingular'            => 'time',
'hourabbrev'              => 't',
'estimatedeffortopen'     => 'Estimert innsats for åpne oppgaver',
'currenteffortdoneopen'   => 'Nåværende innsats brukt i åpne oppgaver',
'signinwith'              => 'Logg på med %s',
'canviewroadmap'          => 'Kan se veikart',
'enableavatars'           => 'Aktiver avatarer',
'maxavatarsize'           => 'Maksimal avatarstørrelse i piksler',
'taskhassubtask'          => 'Denne oppgaven har følgende sub-oppgave',
'taskhassubtasks'         => 'Denne oppgaven har følgende deloppgaver',
'translations'            => 'Oversettelser',
'translate'               => 'Oversett',
'taskdescription'         => 'Oppgavebeskrivelse',
'notaskdescription'       => 'ingen oppgavebeskrivelse',
'pleaseselect'            => 'Velg',
'closeselectedtasks'      => 'Steng valgte oppgaver',
'closetasks'              => 'Steng oppgaver',
'hintforbulkimport'       => "<b>Tips for bulk import:</b>\n<ol>\n<li>Kopier og lim inn fra et excel-ark eller CSV ved å lime den inn som en hel kolonne.</li>\n<li>Du kan bare lime inn tittel og detaljer.</li>\n</ol>",
'taskissubtaskof'         => 'Denne oppgaven er en under oppgave',
'applyfirstline'          => 'På før første linje',
'addmorerows'             => 'Legg til flere rader',
'addtasks'                => 'Legg til oppgaver',
'massopsdisabled'         => "Beklager, masseredigering for øyeblikket deaktivert for flyspray 1.0. Vi planlegger å fullføre gjennomføringen for en senere utgave av flyspray. Du kan aktivere dem i kildekoden på nytt på egen risiko, men leste kommentarene der før du gjør det.\n",
'viewroadmap'             => 'Kan se veikart',
'nosuicide'               => "Kjære bruker, ikke mitt program ikke tillate deg å ødelegge din tilgang til flyspray ved å deaktivere din egen konto eller bytter din egen gruppe. Den empatiske bror av HAL9000\n",
'movingtodifferentproject'=> "Flytte en oppgave som enten har en forelder eller deloppgaver til et annet prosjekt er ikke tillatt. Du må bryte forbindelsen mellom dem først.\n",
'musthavesameproject'     => 'Forelder og deloppgave må tilhøre samme prosjekt.',
'defaultorderby'          => 'Ordne tasklisten som standard av',
'viewowntasks'            => 'Vis mine oppgaver',
'viewgroupstasks'         => 'Vis gruppens oppgaver',
'urlrewriting'            => 'Url omskriving',
'enablehtaccess'          => "Vennligst aktiver .htaccess fil i flyspray root før du slår url omskriving på\n",
'nomodrewrite'            => "Mod omskriving ser ikke ut til å være tilgjengelig på denne serveren, beklager, men jeg kan ikke slå url omskriving på\n",
'on'                      => 'På',
'off'                     => 'Av',
'defaultorderbydirection' => 'Standard rekkefølge av retning',
'ascending'               => 'Stigende',
'descending'              => 'Synkende',
'myassignedtasks'         => 'Mine tildelte saker',
'commentedon'             => 'kommenterte',
);

?>
