<?php

/**
* Esta tradución es actualmente mantenida por
*  Cristian Rodriguez.
* Envia un mail con tus correcciones a judas.iscariote@flyspray.org
*
* Asegurate de usar un editor que guarde y lea este archivo en utf-8 asi
* como que utilize finales de linea UNIX..ahh.. y NO USES entidades html ¡¡
*
* Añadidas más traducciones por Armando Camarero arcepi@arcepi.net
* Agregadas más correcciones por Pablo Lezaeta prflr88@gmail.com
*
*/
$translation = array(
'edituser'                => 'Editar usuario',
'username'                => 'Nombre de usuario',
'realname'                => 'Nombre real',
'emailaddress'            => 'Direccion de correo',
'jabberid'                => 'Id de Jabber',
'notifytype'              => 'Tipo de notificacion',
'group'                   => 'Grupo',
'accountenabled'          => 'Cuenta habilitada',
'updatedetails'           => 'Actualizar detalles',
'setglobally'             => 'Estas preferencias fueron configuradas globalmente.',
'usergroupmanage'         => 'Administrar de Usuarios y Grupos',
'newuser'                 => 'Registrar nuevo usuario',
'newgroup'                => 'Crear un grupo nuevo',
'yes'                     => 'Sí',
'no'                      => 'No',
'editgroup'               => 'Editar grupo',
'groupname'               => 'Nombre del grupo',
'description'             => 'Descripción',
'admin'                   => 'Grupo administrador',
'opennewtasks'            => 'Abrir nuevas tareas',
'modifytasks'             => 'Modificar tareas existentes',
'addcomments'             => 'Agregar comentarios',
'attachfiles'             => 'Adjuntar archivos',
'vote'                    => 'Votar',
'groupenabled'            => 'Los miembros pueden identificarse',
'groupopen'               => 'Los miembros pueden identificarse',
'tasktypelist'            => 'Lista de tipos de tarea',
'categorylist'            => 'Lista de categorías',
'oslist'                  => 'Lista de sistemas operativos',
'resolutionlist'          => 'Lista de resoluciones',
'versionlist'             => 'Lista de versiones',
'severitylist'            => 'Lista de importancias',
'listnote'                => 'Nota: Desmarcando el recuadro «Mostrar» puede alterar algunas tareas en modo edición. Si modifica el campo «Nombre» el sistema cambiará todas las tareas con ese nombre.',
'name'                    => 'Nombre',
'order'                   => 'Orden',
'back'                    => 'Atras',
'text'                    => 'Texto',
'highlight'               => 'Resaltar',
'show'                    => 'Mostrar',
'owner'                   => 'Propietario',
'selectowner'             => 'Elija Propietario',
'update'                  => 'Actualizar',
'addnew'                  => 'Agregar nuevo',
'flysprayprefs'           => 'Preferencias de Flyspray',
'projecttitle'            => 'Titulo del proyecto',
'baseurl'                 => 'URL base para esta instalacion',
'replyaddress'            => 'Direccion de correo de respuesta para notificaciones',
'themestyle'              => 'Tema / Estilo',
'language'                => 'Lenguaje',
'anonview'                => 'Los usuarios anónimos pueden ver las tareas',
'allowanon'               => 'Los usuarios anónimos pueden abrir nuevas tareas',
'never'                   => 'Nunca',
'anonymously'             => 'Anonimamente',
'afterregister'           => 'Solamente después de registrarse',
'spamproof'               => 'Habilitar Código de confirmación para el registro de nuevos usuarios',
'anongroup'               => 'Grupo para los nuevos usuarios registrados',
'groupassigned'           => 'A los miembros de estos grupos se les puede asignar tareas',
'forcenotify'             => 'Forzar notificacion como',
'neversend'               => 'Nunca enviar',
'userchoose'              => 'Dejar decidir al usuario',
'email'                   => 'Correo electrónico',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Dueño de la categoría por omición',
'noone'                   => 'Nadie',
'jabbernotify'            => 'Notificaciones Jabber',
'jabberserver'            => 'Servidor',
'jabberport'              => 'Puerto',
'jabberuser'              => 'Usuario',
'jabberpass'              => 'Contraseña',
'saveoptions'             => 'Grabar opciones',
'editcomment'             => 'Modificar comentario',
'commentby'               => 'Comentario por',
'saveeditedcomment'       => 'Guardar comentario modificado',
'projectprefs'            => 'Preferencias del proyecto',
'pagetitle'               => 'Título',
'defaultproject'          => 'Proyecto por omición',
'projectlists'            => 'Lista de proyectos',
'showlogo'                => 'Mostrar la imagen con el logo',
'intromessage'            => 'Mensaje introductorio',
'isactive'                => 'Proyecto activo',
'createproject'           => 'Crear un nuevo proyecto',
'nopermission'            => 'No tiene permisos para usar esta página.',
'listordertip'            => 'El orden en que los elementos aparecerán listados',
'listshowtip'             => 'Mostrar este elemento en la lista',
'categoryownertip'        => 'Esta persona recibirá notificaciones cuando una tarea se abra dentro de esta categoría',
'categoryparenttip'       => 'La categoría padre de esta categoría',
'notsubcategory'          => 'Ninguna - es una categoría de nivel superior',
'showinlineimages'        => 'Mostrar las imágenes adjuntas',
'dateformat'              => 'Formato de la fecha',
'dateformat_extended'     => 'Formato detallado de la fecha',
'cache_feeds'             => 'Caché para RSS',
'no_cache'                => 'Sin caché',
'cache_disk'              => 'Caché en disco',
'cache_db'                => 'Caché en la base de datos',
'subcategoryof'           => 'Subcategoría de',
'visiblecolumns'          => 'Columnas visibles en la lista de tareas',
'tense'                   => 'Tiempo',
'listtensetip'            => 'Pasado, presente o futuro',
'past'                    => 'Pasado',
'present'                 => 'Presente',
'future'                  => 'Futuro',
'oldpass'                 => 'Contraseña antigua',
'nooldpass'               => 'No hay contraseñas antiguas',
'oldpasswrong'            => 'La contraseña antigua es incorrecta',
'changepass'              => 'Cambiar Contraseña',
'confirmpass'             => 'Confirme Contraseña',
'projectmanager'          => 'Administración del proyecto',
'viewtasks'               => 'Ver tareas',
'modifyowntasks'          => 'Modificar tareas propias',
'modifyalltasks'          => 'Modificar tareas de terceros',
'viewcomments'            => 'Ver comentarios',
'editcomments'            => 'Editar comentarios',
'deletecomments'          => 'Borrar comentarios',
'viewattachments'         => 'Ver adjuntos',
'createattachments'       => 'Crear adjuntos',
'deleteattachments'       => 'Borrar adjuntos',
'viewhistory'             => 'Ver historial',
'closeowntasks'           => 'Cerrar tareas propias',
'closeothertasks'         => 'Cerrar tareas de terceros',
'assigntoself'            => 'Asignarse tareas disponibles',
'assignotherstoself'      => 'Asignarse tareas de terceros',
'viewreports'             => 'Ver reportes',
'othersview'              => 'Permitir que cualquiera observe este proyecto',
'usersandgroups'          => 'Usuarios y grupos',
'globalgroup'             => 'Grupo Global',
'globalgroups'            => 'Grupos Globales',
'defaultglobalgroup'      => 'Grupo Global por defecto para nuevos usuarios',
'addtogroup'              => 'Agregar al grupo',
'moveuserstogroup'        => 'Mover usuarios al grupo',
'nogroup'                 => 'Sin grupo - Eliminar del proyecto',
'eventdesc'               => 'Descripción del evento',
'requestedby'             => 'Pedido por',
'daterequested'           => 'Fecha del pedido',
'closetask'               => 'Cerrar tarea',
'reopentask'              => 'Reabrir tarea',
'applymember'             => 'Aplicar para ser miembro del proyecto',
'forcurrentproj'          => 'Para el actual poyecto',
'lostpw'                  => 'Recuperar contraseña perdida',
'lostpwexplain'           => 'Ingrese su nombre de usuario para enviarle un enlace y poder cambiar su contraseña. Este enlace se le enviará a la dirección de notificación que consta en su pefil.',
'sendlink'                => 'Enviar enlace',
'savenewpass'             => 'Grabar nueva contraseña',
'anonreg'                 => 'Permitir el registro de nuevos usuarios',
'allowanonopentask'       => 'Permitir abrir tareas a usuarios anónimos',
'editglobalgroup'         => 'Editar el grupo global',
'editgroupforproj'        => 'Editar el grupo para el proyecto',
'notshownforadmin'        => 'Los permisos no se muestran para el grupo administrador, no necesita de ellos.',
'general'                 => 'General',
'userregistration'        => 'Registro de usuario',
'notifications'           => 'Notificaciones',
'resetoptions'            => 'Reiniciar opciones',
'preferences'             => 'Preferencias',
'tasktypes'               => 'Tipos de tarea',
'resolutions'             => 'Resoluciones',
'categories'              => 'Categorías',
'operatingsystems'        => 'Sistemas operativos',
'versions'                => 'Versiones',
'admintoolboxlong'        => 'Herramientas de administración',
'newproject'              => 'Nuevo Proyecto',
'delete'                  => 'Eliminar',
'listdeletetip'           => 'Eliminar este elemento de la lista',
'lookandfeel'             => 'Apariencia',
'globaltheme'             => 'Tema Global',
'emailnotify'             => 'Notificaciones a través del correo',
'fromaddress'             => 'Direccion del remitente',
'smtpserver'              => 'Servidor SMTP ',
'smtpuser'                => 'Usuario SMTP',
'smtppass'                => 'Contraseña SMTP ',
'addrewrite'              => 'Usar rescritura de dirección (address rewriting)',
'usereminderdaemon'       => 'Habilitar en 2do. plano el «demonio de recordatorios»',
'tasksperpage'            => 'Tareas por página',
'addtoassignees'          => 'Añadirme a los encargados ',
'taskstatuses'            => 'Estados de las tareas',
'canvote'                 => 'Puede votar en las tareas',
'loginsuccessful'         => 'Ingreso satisfactorio.',
'youareloggedout'         => 'Ha sido desconectado',
'waitwhiletransfer'       => 'Por favor, espere mientras es transferido...',
'clicknowait'             => 'Pulse aquí si no quiere esperar.',
'accountdisabled'         => 'Su cuenta está deshabilitada. Contacte a un administrador.',
'task'                    => 'Tarea',
'edittask'                => 'Editar tarea',
'openedby'                => 'Abierta por',
'editedby'                => 'Ultima edición por',
'tasktype'                => 'Tipo de Tarea',
'category'                => 'Categoría',
'status'                  => 'Estado',
'assignedto'              => 'Asignada a',
'operatingsystem'         => 'Sistema operativo',
'severity'                => 'Importancia',
'reportedversion'         => 'Version reportada',
'dueinversion'            => 'Agendada para la versión',
'undecided'               => 'Sin decidir',
'percentcomplete'         => 'Porcentaje completo:',
'details'                 => 'Detalles',
'savedetails'             => 'Guardar detalles',
'anonymous'               => 'Envío anónimo',
'complete'                => 'Completa',
'closedby'                => 'Cerrada por',
'reasonforclosing'        => 'La razon de cierre es:',
'reopenthistask'          => 'Reabrir esta tarea',
'comments'                => 'Comentarios',
'attachments'             => 'Adjuntos',
'relatedtasks'            => 'Tareas relacionadas',
'edit'                    => 'Editar',
'addcomment'              => 'Agregar comentario',
'fileuploadedby'          => 'Archivo subido por',
'uploadafile'             => 'Subir archivo adjunto',
'uploadnow'               => 'Subir ahora!',
'thesearerelated'         => 'Estas tareas están relacionadas con la tarea actual',
'remove'                  => 'Borrar',
'addnewrelated'           => 'Agregar nueva tarea relacionada',
'add'                     => 'Agregar',
'otherrelated'            => 'Otras tareas relacionadas a esta tarea',
'receivenotify'           => 'Estos usuarios recibirán notificaciones detalladas cuando esta tarea cambie',
'addusertolist'           => 'Sumar usuario a la lista',
'addtolist'               => 'Sumar a la lista',
'addmyself'               => 'Sumarme a la lista',
'removemyself'            => 'Removerme de la lista',
'theseusersnotify'        => 'Estos usuarios recibiran notificaciones detalladas cuando esta tarea cambie',
'attachedtoproject'       => 'Pertenece al proyecto',
'reminders'               => 'Recordatorios',
'system'                  => 'Sistema',
'remindthisuser'          => 'Recordar a este usuario',
'thisoften'               => 'Con esta continuidad',
'startafter'              => 'Esperar antes de comenzar los recordatorios',
'hours'                   => 'Hora(s)',
'days'                    => 'Día(s)',
'weeks'                   => 'Semana(s)',
'addreminder'             => 'Sumar recordatorio',
'defaultreminder'         => 'Este recordatorio es para que mire la siguiente tarea en Flyspray:',
'message'                 => 'Mensaje',
'closed'                  => 'Cerradas',
'filename'                => 'Archivo:',
'date'                    => 'Fecha',
'filesize'                => 'Tamaño:',
'closurecomment'          => 'Comentarios adicionales sobre el cierre:',
'history'                 => 'Historial',
'nohistory'               => 'No hay historial disponible.',
'eventdate'               => 'Fecha',
'user'                    => 'Usuario',
'event'                   => 'Evento',
'fieldchanged'            => 'Campo modificado',
'taskopened'              => 'Tarea abierta',
'taskreopened'            => 'La siguiente tarea fue reabiera:',
'taskclosed'              => 'La siguiente tarea ahora se encuentra cerrada:',
'commentadded'            => 'La siguiente tarea tiene un nuevo comentario:',
'commentedited'           => 'Comentario editado',
'commentdeleted'          => 'Se eliminó el comentario.',
'attachmentadded'         => 'Un nuevo archivo se adjunto a la siguiente tarea:',
'attachmentdeleted'       => 'El archivo adjunto fue eliminado',
'taskedited'              => 'Detalle de la Tarea editado',
'notificationadded'       => 'Usuario sumado a la lista de notificaciones',
'notificationdeleted'     => 'Usuario borrado de la lista de notificaciones',
'relatedadded'            => 'Se agregó una tarea relacionada a la siguiente tarea:',
'relateddeleted'          => 'Tarea relacionada borrada',
'taskassigned'            => 'Tarea asignada a',
'taskreassigned'          => 'Tarea reasignada a',
'assignmentremoved'       => 'Asignacion removida',
'summary'                 => 'Resumen',
'addedasrelated'          => 'Tarea sumada a la lista de relacionadas de',
'deletedasrelated'        => 'Tarea removida de la lista de relacionadas de',
'reminderadded'           => 'Se agregó su Recordatorio.',
'reminderdeleted'         => 'Se eliminó el recordatorio seleccionado.',
'priority'                => 'Prioridad',
'previousvalue'           => 'Valor previo',
'newvalue'                => 'Nuevo valor',
'selectareason'           => 'Seleccione una razon',
'assigntome'              => 'Asígnarme las tareas seleccionadas',
'reopenrequest'           => 'Requerir reapertura',
'requestclose'            => 'Requerir cierre',
'ownershiptaken'          => 'Usuario tomó propiedad',
'closerequestmade'        => 'Requerido el cierre de la tarea',
'reopenrequestmade'       => 'Requerida la reapertura de la tarea',
'taskdependson'           => 'Esta tarea depende de',
'taskblocks'              => 'Esta tarea bloquea el cierre de las siguientes tareas',
'depadded'                => 'La siguiente tarea tiene una nueva dependencia',
'depaddedother'           => 'Esta tarea se agregó como dependencia',
'depremoved'              => 'A la siguiente tarea se le removió una dependencia',
'depremovedother'         => 'Esta tarea fue removida de las dependencias de otras tareas',
'showdetailserror'        => 'Esa tarea no existe, o no tiene permiso para verla.',
'makeprivate'             => 'Hacerla Privada',
'makepublic'              => 'Hacerla Pública',
'taskmadeprivate'         => 'La tarea se hizo privada',
'taskmadepublic'          => 'La tarea se hizo pública nuevamente',
'confirmdeletecomment'    => '¿Seguro de que elimina este comentario? %s',
'confirmdeleteattach'     => '¿Seguro de que elimina este adjunto?',
'selectedhistory'         => 'Observando detalles del historial seleccionado',
'showallhistory'          => 'Mostrar nuevamente la pestaña completa del historial',
'hidethis'                => 'Ocultar nuevamente esta area',
'mark100'                 => 'Marcar la tarea como 100 % completada',
'watchtask'               => 'Observar esta tarea',
'stopwatching'            => 'No monitorear',
'commentlink'             => 'Enlace a este comentario',
'submitreq'               => 'Enviar pedido',
'reasonforreq'            => 'Razón de esta petición',
'pmreqdenied'             => 'El pedido al administrador del proyecto fue rechazado',
'taskpendingreq'          => 'Acción pendiente del administrador del proyecto.  Mire la solapa del historial para más detalles.',
'previoustask'            => 'Tarea previa',
'nexttask'                => 'Tarea proxima',
'duedate'                 => 'Fecha de vencimiento',
'attachnoperms'           => 'Existen adjuntos en este comentario, pero no tiene permisos para verlos.',
'open'                    => 'Abiertas',
'depgraph'                => 'Ver grafico de dependencia',
'reset'                   => 'Reajustar',
'selectusers'             => 'Seleccione usuarios...',
'addmetoassignees'        => 'Agrégarme a los encargados',
'addedtoassignees'        => 'Usuario agregado a la lista de encargados',
'dependencygraph'         => 'Gráfico de dependencias',
'attachanotherfile'       => 'Adjuntar otro archivo',
'OK'                      => 'Aceptar',
'addvote'                 => 'Agregar voto',
'notifyfromfs'            => 'Notificación de Flyspray',
'autogenerated'           => 'ESTE ES UN MENSAJE GENERADO AUTOMÁTICAMENTE. NO LO RESPONDA.',
'forward'                 => 'Adelante',
'previous'                => 'Previa',
'next'                    => 'Próxima',
'first'                   => 'Primero',
'last'                    => 'Último',
'page'                    => 'Página %d de %d',
'search'                  => 'Buscar',
'alltasktypes'            => 'Todos los tipos de tareas',
'allseverities'           => 'Todas las importancias',
'alldevelopers'           => 'Todos los desarrolladores',
'notyetassigned'          => 'Sin asignar',
'allcategories'           => 'Todas las categorías',
'allstatuses'             => 'Todos los estados',
'allopentasks'            => 'Todas las tareas abiertas',
'sortthiscolumn'          => 'Ordenar por esta columna',
'id'                      => 'Id',
'project'                 => 'Proyecto:',
'dateopened'              => 'Abierta',
'progress'                => 'Progreso',
'searchthisproject'       => 'Buscar en este proyecto',
'dueanyversion'           => 'Agendada para cualquier versión',
'anyversion'              => 'Reportado en todas las versiones',
'dueversion'              => 'Agendada para',
'lastedit'                => 'Última edicion',
'os'                      => 'Sistema operativo',
'reportedin'              => 'Reportada en',
'taskrange'               => 'Viendo tareas %d - %d de %d',
'noresults'               => 'No se encontraron resultados.',
'takeaction'              => 'Accion a tomar',
'watchtasks'              => 'Observar tareas seleccionadas',
'stopwatchingtasks'       => 'No continuar observando las siguientes tareas',
'assigntaskstome'         => 'Asignarme las siguientes tareas ',
'dueby'                   => 'Vencen por',
'dueanytime'              => 'Vencen en cualquier momento',
'selectduedate'           => 'Elija la fecha de vencimiento',
'toggleselected'          => 'Invertir selección',
'due'                     => 'Vence',
'assignedtome'            => 'Asignado a mí',
'tasklist'                => 'Lista de tareas',
'dateclosed'              => 'Fecha de cierre',
'advanced'                => 'Avanzado',
'searchcomments'          => 'Buscar en comentarios',
'searchforall'            => 'Buscar por todas las palabras',
'anonusers'               => 'Usuarios anónimos',
'miscellaneous'           => 'Misceláneos',
'users'                   => 'Usuarios',
'taskproperties'          => 'Propiedades de la tarea',
'selectsincedate'         => 'Seleccionar cambiado desde',
'changedsince'            => 'Cambiado desde',
'updatefs'                => 'Por favor, actualize su versión de Flyspray.',
'currentversion'          => 'Su version es',
'latestversion'           => 'Y la última versión es',
'hidemessage'             => '(recordarme más tarde)',
'saveas'                  => 'Guardar búsqueda como',
'nosearches'              => 'No hay búsquedas guardadas',
'saving'                  => 'Guardando...',
'votes'                   => 'Votos',
'allclosedtasks'          => 'Todas las tareas cerradas',
'password'                => 'Contraseña',
'login'                   => 'Ingresar',
'rememberme'              => 'Recordarme',
'lostpassword'            => '¿Olvidó su contraseña?',
'lostpwforfs'             => 'Contraseñas perdidas para Flyspray',
'lostpwmsg1'              => 'Hola. He perdido mi contraseña para Flyspray en ',
'lostpwmsg2'              => ', por favor, asígneme una nueva contraseña. Usuario: ',
'regards'                 => 'Disculpe las molestias,',
'yourusername'            => ' su usuario ',
'locale'                  => 'es',
'filenotexist'            => 'El archivo no existe. Contacte al administrador de Flyspray de este proyecto.',
'showtask'                => 'Mostrar tarea',
'now'                     => 'Ahora',
'go'                      => 'Ir',
'opentaskanon'            => 'Abrir anónimanete una nueva tarea',
'register'                => 'Registrar nuevo usuario',
'addnewtask'              => 'Nueva tarea',
'reports'                 => 'Reportes',
'editmydetails'           => 'Mi perfil',
'logout'                  => 'Salir',
'disabledaccount'         => 'Su cuenta ha sido deshabilitada. La sesion finalizará de inmediato...',
'poweredby'               => 'Impulsado por Flyspray',
'projects'                => 'Proyectos',
'allprojects'             => 'Todos los proyectos',
'selectproject'           => 'para el proyecto:',
'tasksall'                => 'Todas las tareas',
'tasksassigned'           => 'Tareas asignadas a mí',
'tasksreported'           => 'Tareas reportadas por mí',
'taskswatched'            => 'Tareas que observo',
'mysearch'                => 'Mis búsquedas',
'admintoolbox'            => 'Herramientas de administrador',
'manageproject'           => 'Editar proyecto',
'permissions'             => 'Ver permisos',
'hide'                    => 'Ocultar',
'pendingreq'              => 'Pedidos pendientes',
'errorpage'               => "Flyspray no puede mostrarle la página solicitada.\n                                 Tal vez ha pedido una tarea que no existe,\n                                 o no tiene permisos para ver la página solicitada.<br /><br />\n                                 Tal vez haya intentado ingresar con una URL maliciosa para interactuar con la base de datos\n                                 tratando de utilizar una inyección de SQL.  Si esto es así, vaya hasta un rincón\n                                 y medite sobre sus acciones.  Al volver, por favor no lo intente nuevamente!",
'permissionsforproject'   => 'Permisos para',
'switchto'                => 'Cambiar a',
'lastsearch'              => 'Última búsqueda',
'modify'                  => 'Modificar',
'noticefrom'              => 'Aviso de',
'hasopened'               => 'Ha abierto una nueva tarea en Flyspray y se la ha asignado a si mismo.:',
'moreinfonew'             => 'Puede encontrar más información sobre esta tarea en la página:',
'newtaskcategory'         => 'Una nueva tarea en Flyspray se ha abierto en esta categoría',
'categoryowner'           => 'Esta recibiendo este mensaje por ser el propietario de la categoría.',
'tasksummary'             => 'Detalle de la Tarea:',
'newtaskadded'            => 'Se agregó su nueva tarea.',
'summaryanddetails'       => 'Debe llenar el campo de resumen y detalle.',
'goback'                  => 'Regresar.',
'messagefrom'             => 'Este es un mensaje generado por Flyspray en',
'hasjustmodified'         => 'Ha modificado la siguiente tarea.',
'changedfields'           => 'Los campos modificados tienen de prefijo de dos asteriscos (**)',
'moreinfomodify'          => 'Podrá obtener más información de esta tarea en la siguiente URL:',
'nolongerassigned'        => 'La siguiente tarea ya no está asignada a usted:',
'hasassigned'             => 'Le han asignado la siguiente tarea en Flyspray:',
'taskupdated'             => 'Se actualizó la tarea.',
'hasclosedassigned'       => 'Cerró la siguiente tarea en Flyspray que tenía asignada:',
'unassigned'              => 'Sin asignar',
'hasclosed'               => 'Cerro la siguiente tarea.',
'youonnotify'             => 'Está recibiendo este mensaje porque se encuentra en la lista de notificaciones.',
'taskclosedmsg'           => 'La tarea ha sido cerrada.',
'returntotask'            => 'Regresar a los detalles de la tarea',
'backtoindex'             => 'Regresar a la lista de tareas',
'noclosereason'           => 'No ha seleccionado una razón de cierre de esta tarea.',
'hasreopened'             => 'Ha reabierto la siguiente tarea que ya había cerrado:',
'taskreopenedmsg'         => 'La tarea ha sido reabierta.',
'backtotask'              => 'Regresar a la tarea.',
'commentaddedmsg'         => 'Se ha añadido un comentario.',
'commenttoassigned'       => 'Agregó un comentario a una tarea asignada a usted:',
'commenttotask'           => 'Agregó el siguiente comentario a esta tarea.',
'nocommententered'        => 'Se debe ingresar un comentario antes de hacer clic en el botón de envío.',
'fillinfields'            => 'No llenó todos los campos.',
'notcurrentpass'          => 'No es su contraseña actual',
'passchanged'             => 'Su contraseña ha cambiado.',
'closewindow'             => 'Ahora puede cerrar esta ventana...',
'passnomatch'             => 'Sus nuevas contraseñas no coinciden',
'usernametaken'           => 'Ese nombre de usuario ya esta utilizado. Deberá ingresar un nuevo nombre de usuario.',
'newusercreated'          => 'Se creó una nueva cuenta de usuario.',
'accountcreated'          => 'Se creó su cuenta.',
'newuserwarning'          => 'Note que las preferencias globales pueden requerir que su cuenta sea aprobada por un administrador. Si no puede ingresar al sistema, esa debe ser la razón.',
'nomatchpass'             => 'Las contaseñas no coincidieron.',
'confirmwrong'            => 'El código de confirmación es incorrecto',
'formnotcomplete'         => 'El formulario no se lleno completamente.',
'formnotnumeric'          => 'Los datos ingresados no son numéricos',
'groupnametaken'          => 'Ese nombre de grupo ya existe en la actualidad.',
'newgroupadded'           => 'Se agregó el nuevo grupo.',
'optionssaved'            => 'Opciones de Flyspray guardadas.',
'hasuploaded'             => 'Subió un archivo adjunto a una tarea asignada:',
'hasattached'             => 'adjuntó un archivo a la siguiente tarea.',
'fileuploaded'            => 'Se subió el archivo correctamente.',
'fileerror'               => 'Hubo un error subiendo su archivo. Tal vez los permisos en el directorio <i>adjunto/</i> no son correctos.',
'contactadmin'            => 'Contacte al administrador de este proyecto.',
'selectfileerror'         => 'No seleccionó un archivo.',
'userupdated'             => 'Se actualizaron los detalles del usuario',
'realandemail'            => 'No llenó los campos nombre real y correo.',
'groupupdated'            => 'La definicion del grupo fue actualizada.',
'groupanddesc'            => 'No completó el nombre del grupo y la descripción.',
'fillallfields'           => 'Complete todos los campos, por favor.',
'listPmustN'              => 'El «orden» de la entrada de ser numérico.',
'listupdated'             => 'Se actualizó el Listado.',
'listitemadded'           => 'Se agregó un elemento al listado.',
'relatedaddedmsg'         => 'Se agregaron tareas relacionadast.',
'relatederror'            => 'Esa tarea se encuentra actualmente en el listado de tareas relacionadas.',
'relatedremoved'          => 'Se removió del listado la tarea relacionada.',
'notifyadded'             => 'Se agregó usuario a la lista de notificaciones.',
'notifyerror'             => 'Ese usuario ya se encuentra en la lista de notificaciones.',
'notifyremoved'           => 'Se removió al usuario de la lista de notificaciones.',
'editcommentsaved'        => 'Se guardó el comentario actualizado.',
'commentdeletedmsg'       => 'El comentario ha sido eliminado.',
'gotonewtask'             => 'Ir a la tarea recien creada',
'projectcreated'          => 'Se creó el nuevo proyecto. Siga el enlace de abajo para poner a punto las categorías, sistemas operativos y el listado de versiones',
'customiseproject'        => 'Personalizar este proyecto',
'projectupdated'          => 'Se actualizó las preferencias del proyecto',
'emptytitle'              => 'Dejó en blanco el título del proyecto. Regrese para solucionarlo.',
'loginbelow'              => 'Ahora puede ingresar al sistema utilzando el formulario de abajo.',
'attachmentdeletedmsg'    => 'El adjunto ha sido eliminado.',
'reminderaddedmsg'        => 'Se ha añadido el recordatorio.',
'reminderdeletedmsg'      => 'El recordatorio seleccionado se ha eliminado.',
'flyspraytask'            => 'Tarea de Flyspray',
'fieldsmissing'           => 'Algunos campos estaban en blanco o contenian información no válida.',
'relatedinvalid'          => 'Esa tarea no existe.',
'relatedproject'          => 'La tarea pertenece a un proyecto diferente.',
'addanyway'               => 'Agregar de todas formas',
'cancel'                  => 'Cancelar',
'alreadyedited'           => 'Esta tarea ha sido modificada por otra persona antes de que fuera guardada.',
'saveanyway'              => 'Guardar mis cambios de todas formas',
'nouserselected'          => 'No se seleccionó un usuario. Seleccione al menos uno antes de intentar nuevamente.',
'groupswitchupdated'      => 'Se modificaron satisfactoriamente los grupos de usuario.',
'takenownershipmsg'       => 'Esta tarea ahora esta asignada a ti.',
'adminrequestmade'        => 'Su pedido fue enviado a un administrador del proyecto.',
'newdepnotify'            => 'Se agregó una nueva dependencia a la siguiente tarea:',
'dependadded'             => 'Se agregó la dependencia de la tarea',
'dependaddfailed'         => 'Ahora no puede agregar esa tarea como dependencia',
'depremovedmsg'           => 'Se ha eliminado la dependencia de la tarea',
'newdepis'                => 'La nueva dependencia es',
'magicurlsent'            => 'Se envió un mensaje a su dirección de notificación. Contiene un enlace que lo llevará a una página para completar esta tarea.',
'changefspass'            => 'Cambiar la contraseña',
'magicurlmessage'         => 'Por favor, siga el siguiente enlace de abajo para cambiar su contraseña en Flyspray:',
'erroronform'             => 'Ocurrió un problema con el envío del formulario',
'addressused'             => 'Esta direccion ha sido utilizada para registrar una cuenta de Flyspray. Si no estaba esperando este mensaje, simplemente ignórelo y elimínelo. Su código de confirmación es: ',
'confirmcodeis'           => 'Su código de confirmación es:',
'codesent'                => 'Se envió el código de confirmación. Por favor, siga las instrucciones contenidas en el mensaje.',
'codenotsent'             => 'No fue posible enviar el código, intente más tarde.',
'taskmadeprivatemsg'      => 'Esta tarea se ha hecho privada',
'taskmadepublicmsg'       => 'Esta tarea se ha hecho pública de nuevo',
'realandnotify'           => 'Necesita rellenar los campos nombre real y alguno de los campos de correo o Id de Jabber.',
'pmreqdeniedmsg'          => 'Solicitud de administración del proyecto denegada.',
'massopsuccess'           => 'Las operaciones múltiples fueron satisfactorias',
'usernotexist'            => 'Ese nombre de usuario no existe en esta instalación de lyspray',
'commentattachperms'      => 'No puede eliminar ese comentario - No tiene permisos para eliminar adjuntos',
'voterecorded'            => 'Su voto ha sido almacenado',
'votefailed'              => 'Su voto no pudo ser almacenado en este momento.',
'createnewgroup'          => 'Crear nuevo grupo',
'requiredfields'          => 'Los campos requeridos están marcados con',
'addthisgroup'            => 'Agregar este grupo',
'createnewproject'        => 'Crear nuevo Proyecto',
'addnewproject'           => 'Agregar nuevo Proyecto',
'htmlallowed'             => 'Permitir código HTML',
'createthisproject'       => 'Crear este proyecto',
'inlineimages'            => 'Mostrar las imágenes adjuntas',
'createnewtask'           => 'Crear una nueva tarea en el proyecto:',
'addanother'              => 'Agregar otra tarea después de esta',
'addthistask'             => 'Agregar esta tarea',
'notifyme'                => 'Notificarme cuando esta tarea cambie',
'newtask'                 => 'Nueva tarea',
'attachafile'             => 'Adjuntar un archivo',
'registernewuser'         => 'Registrar nuevo usuario',
'none'                    => 'Ninguna',
'registeraccount'         => 'Registrar esta cuenta',
'both'                    => 'Ambos',
'notifyfrom'              => 'Notificacion de ',
'donotreply'              => 'ESTE ES UN MENSAJE AUTOMÁTICO, NO LO RESPONDA.',
'disclaimer'              => 'Ha recibido este mensaje porque lo han requerido desde el sistema de seguimiento de errores de Flyspray.  Puede ser removido de futuras notificaciones visitando la URL mostrada arriba.',
'userwho'                 => 'Usuario que lo hizo:',
'moreinfo'                => 'Encontrará más informacion en la URL:',
'newtaskopened'           => 'Se abrió una nueva tarea en Flyspray. Los detalles son los siguientes',
'notify.taskclosed'       => 'La siguiente tarea ahora está cerrada:',
'notify.taskreopened'     => 'La siguiente tarea ha sido reabierta:',
'newdep'                  => 'La siguiente tarea tiene una nueva dependencia:',
'notify.depremoved'       => 'Se ha eliminado una dependencia de la siguiente tarea:',
'olddepwas'               => 'La antigua dependencia era',
'notify.commentadded'     => 'La siguiente tarea tiene un comentario nuevo:',
'commentis'               => 'El texto del comentario está abajo.',
'newattachment'           => 'Se ha adjuntado un nuevo fichero a la siguiente tarea:',
'detailsbelow'            => 'Los detalles se muestran aquí abajo.',
'notify.relatedadded'     => 'Se ha añadido una nueva tarea relacionada a la siguiente tarea:',
'relatedis'               => 'La tarea relacionada es',
'assignedtoyou'           => 'Se le asignó la siguiente tarea:',
'takenownership'          => 'Se asignó la siguiente tarea:',
'requiresaction'          => 'La siguiente tarea requiere intervención de un Manager de proyecto:',
'requiresactionnotify'    => 'La tarea requiere intervención de un Manager de proyecto',
'pmdeny'                  => 'Un administrador del proyecto ha denegado el pedido pendiente para esta tarea:',
'pmdenynotify'            => 'Un administrador del proyecto ha denegado la petición',
'fileaddedtoo'            => 'Había uno o más ficheros adjuntos a este comentario.',
'taskwatching'            => 'La siguiente tarea que estás vigilando',
'isdepfor'                => 'Es una nueva dependencia de',
'denialreason'            => 'Razón de la denegación',
'taskchanged'             => 'La siguiente tarea ha cambiado.  Los nuevos detalles son los mostrados más abajo.  Para conocer la información completa de lo que ha cambiado, visite la URL y haga clic en la pestaña del historial.',
'useraddedtoassignees'    => 'Un usuario se ha añadido a si mismo a la lista de usuarios asignados a esta tarea.',
'removeddepis'            => 'La dependencia eliminada es',
'isnodepfor'              => 'ha dejado de ser una dependencia de',
'usergroups'              => 'Grupos de usuario',
'pmtoolbox'               => 'Barra de herramientas del administrador del proyecto',
'groupmanage'             => 'Manejo de grupos',
'pendingrequests'         => 'Pedidos pendientes de administración',
'reasongiven'             => 'Razon dada',
'nopendingreq'            => 'No existen pedidos pendientes para el administrador del proyecto.',
'givereason'              => 'Ingrese una razón',
'catlisted'               => 'Editor de lista de categorías',
'oslisted'                => 'Editor de lista de sistemas operativos',
'verlisted'               => 'Editor de lista de versiones',
'tasktypeed'              => 'Editor de lista de tipos de tarea',
'resed'                   => 'Editor de lista de resoluciones',
'deny'                    => 'Denegar',
'notifiedwhen'            => 'Notificarme cuando',
'onlynewtasks'            => 'Se abren nuevas tareas',
'allevents'               => 'Ocurre algun evento en las tareas',
'feeds'                   => 'RSS',
'feeddescription'         => 'Descripción del RSS',
'feedimgurl'              => 'Imagen del RSS (dejar en blanco para ninguna)',
'notifysubject'           => 'Asunto para las notificaciones',
'notifysubjectinfo'       => '(%p = título del proyecto, %s = sumario de la tarea, %t = id de la tarea, %a = acción, %u = nombre de usuario)',
'priority6'               => 'Al instante',
'priority5'               => 'Inmediata',
'priority4'               => 'Urgente',
'priority3'               => 'Alta',
'priority2'               => 'Normal',
'priority1'               => 'Baja',
'sendcode'                => 'Enviar código',
'entercode'               => 'Ingrese el código de confirmacion tal cual lo recibió. Además ingrese una contraseña de su agrado.',
'confirmationcode'        => 'Código de confirmación',
'registererror'           => 'Asegúrese de haber rellenado todos los campos requeridos y de haber ingresado correctamente el tipo de notificación deseada.',
'validusername'           => '(solamente están permitidos caracteres alfanuméricos y «-», «_», «.»)',
'emailtaken'              => 'Esa dirección de correo electrónico o Id de Jabber ya están en uso. Necesita elegir otro.',
'note'                    => '<b>Nota:</b>  Se le enviará un código de confirmación antes de crear su cuenta. El código se le enviará usando el metodo de notificacion seleccionado.<br />SI INGRESA INFORMACIÓN FALSA, NUNCA RECIBIRÁ SU CÓDIGO.',
'changelog'               => 'Registro de cambios',
'changeloggen'            => 'Generador de registro de cambios',
'listfrom'                => 'Listar ingresos al registro decambios desde',
'to'                      => 'Hasta',
'oldestfirst'             => 'Viejos primero',
'recentfirst'             => 'Recientes primero',
'severityrep'             => 'Reporte de Importancia',
'totalopen'               => 'Total de tareas abiertas',
'age'                     => 'Edad',
'agerep'                  => 'Reporte de edad',
'eventsrep'               => 'Reporte de eventos',
'events'                  => 'Eventos',
'Tasks'                   => 'Tareas',
'opened'                  => 'Abiertas',
'edited'                  => 'Modificadas',
'assigned'                => 'Asignadas',
'within'                  => 'Dentro de',
'pastday'                 => 'El último dia',
'pastweek'                => 'La última semana',
'pastmonth'               => 'El mes pasado',
'pastyear'                => 'El año pasado',
'nolimit'                 => 'Sin límite',
'from'                    => 'De',
'duein'                   => 'Vence en',
'selectfromdate'          => 'Seleccionar por fecha',
'selecttodate'            => 'Seleccionar hasta fecha',
'showvoters'              => 'Mostrar/ocultar votantes',
'roadmap'                 => 'Mapa de ruta',
'roadmapfor'              => 'Mapa de ruta para la versión',
'tasks'                   => 'Tareas',
'completed'               => 'Completada.',
'opentasks'               => 'Tareas abiertas',
'of'                      => '% de',
'severity5'               => 'Crítica',
'severity4'               => 'Alta',
'severity3'               => 'Media',
'severity2'               => 'Baja',
'severity1'               => 'Mínima',
'Redirect'                => 'Redirigiendo',
'redirectmsg'             => 'Si su navegador no soporta redirección haga clic  %sAQUÍ%s para ser redirigido',
'allowclosedcomments'     => 'Permitir comentarios en tareas cerradas',
'comment'                 => 'Comentar',
'editowncomments'         => 'Editar los comentarios propios',
'reopened'                => 'Reabierta',
'loading'                 => 'Cargando...',
'notifyown'               => 'Notificar los cambios propios',
'youremail'               => 'Su dirección de correo',
'thankyouforbug'          => 'Gracias por informar del problema. Puede ver las tareas y seguir su desarrollo en cualquier momento usando la URL:',
'anonuser'                => 'Usuario anónimo',
'conflict'                => 'Conflicto',
'file'                    => 'Archivo',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Tamaño',
'projectgroup'            => 'Grupo de proyecto',
'profile'                 => 'Perfil:',
'viewprofile'             => 'Ver perfil',
'regdate'                 => 'Registrado desde',
'tasksopened'             => 'Tareas abiertas',
'replyto'                 => 'Responder a',
'notifytypes'             => 'Tipos de notificación',
'pm.taskchanged'          => 'Tarea modificada',
'pm.taskreopened'         => 'Tarea reabierta',
'pm.depadded'             => 'Dependecia añadida',
'pm.depremoved'           => 'Dependencia eliminada',
'pmrequest'               => 'Solicitud de MP',
'pmrequestdenied'         => 'Solicitud de MP denegada',
'newassignee'             => 'Nuevo asignado',
'revdepadded'             => 'Dependencia inversa añadida',
'revdepaddedremoved'      => 'Dependencia inversa eliminada',
'assigneeadded'           => 'Asignado añadido',
'addusergroup'            => 'Añadir usuario a este grupo',
'groupmembers'            => 'Miembros del grupo',
'deleteuser'              => 'Eliminar este usuario',
'userdeleted'             => 'Usuario eliminado',
'autoassign'              => 'Autoasignar tarea al propietario de la categoría',
'ssl'                     => 'SSL',
'updatewrong'             => "Tiene habilitada la verificacion de nuevas versiones, pero ha acurrido un error \n                             contactandose con el servidor de actualizaciones. Es probable que su servidor no \n                             permita conexiones hacia el exterior o que haya ocurrido un problema de red.\n                             Por favor visite el sitio web de flyspray para asegurarse que esta utilizando la \n                             version mas reciente",
'deleteproject'           => 'Eliminar este proyecto y mover sus contenidos a',
'projectdeleted'          => 'Proyecto eliminado satisfactoriamente',
'feedforall'              => 'Origen de todos los proyectos',
'usercreated'             => 'Usuario creado',
'created'                 => 'Creado',
'deleted'                 => 'Eliminado',
'userid'                  => 'Id de usuario',
'editassignments'         => 'Editar asignaciones',
'preview'                 => 'Vista previa',
'anyprogress'             => 'Cualquier progreso',
'tasksrelated'            => 'Tareas relacionadas con esta',
'duplicatetasks'          => 'Tareas duplicadas de esta',
'databasemodfailed'       => 'Modificación de la base de datos fallida. Posible motivo, la falta de permisos.',
'frequency'               => 'Frecuencia',
'newuserregistered'       => 'Se ha registrado un nuevo usuario en su instalación de Flyspray. Los detalles del usuario son:',
'newuserregisterednotify' => 'Se ha registrado un nuevo usuario',
'notify_registration'     => 'Notificar a los administradores de los nuevos registros de usuario',
'textversion'             => 'Versión texto',
'onlyprimary'             => 'Tareas que no bloquean otras tareas',
'switch'                  => 'Cambiar',
'max'                     => 'Máx.',
'dates'                   => 'Fechas',
'selectduedatefrom'       => 'A completar para',
'selectduedateto'         => 'A',
'selectsincedatefrom'     => 'Cambiado desde',
'selectsincedateto'       => 'A',
'selectdate'              => 'Seleccionar fecha',
'selectopenedfrom'        => 'Abierta desde',
'selectopenedto'          => 'A',
'selectclosedfrom'        => 'Cerrada desde',
'selectclosedto'          => 'A',
'startat'                 => 'Comenzada a',
'hasattachment'           => 'Tiene adjuntos',
'private'                 => 'Privada',
'watching'                => 'Monitoreando',
'alreadyvotedthistask'    => 'Votó por esta tarea',
'alreadyvotedthisday'     => 'Ya ha votado hoy',
'visibility'              => 'Visibilidad',
'public'                  => 'Pública',
'leaveemptyauto'          => 'Deja los campos de contraseña en blanco si desea que se genere una automáticamente.',
'novalidemail'            => 'No escribió una dirección de correo válida.',
'novalidjabber'           => 'No escribió una dirección de Jabber válida.',
'missingrequired'         => 'No rellenó todos los campos requeridos.',
'entervalidusername'      => 'Por favor, introduzca un nombre de usuario y nombre real válidos.',
'couldnotaddusernotif'    => 'No se pudo añadir a este usuario a la lista de notificación.',
'defaulttask'             => 'Descripción por defecto de la tarea',
'all'                     => 'Todos',
'events.useraddedtoassignees'=> 'Usuario añadido a los asignados',
'vote(s)'                 => 'Voto(s)',
'eventlog'                => 'Registro de eventos',
'assignmentchanged'       => 'Asignación cambiada',
'detailedinfo'            => 'Información detallada',
'All'                     => 'Todos',
'tasksireported'          => 'Tareas de las que yo he informado',
'recentlyopened'          => 'Abierta recientemente',
'stats'                   => 'Estadística',
'totaltasks'              => 'Tareas totales',
'mostwanted'              => 'Tareas más buscadas',
'defaultentry'            => 'Página inicial por defecto',
'toplevel'                => 'Vista de más alto nivel',
'overview'                => 'Vista general',
'error#'                  => 'Número de error',
'error1'                  => 'No tiene suficientes permisos para ver este adjunto.',
'error3'                  => 'Acción repetida, redireccionando a la página principal.',
'error4'                  => 'No tiene permisos de administrador.',
'error5'                  => 'Ese usuario no existe en esta instalación.',
'error6'                  => 'Area de administracíon no válida.',
'error7'                  => 'Ingreso fallido (usuario o contraseña incorrecta)',
'error8'                  => 'No escribió el nombre de usuario y la contraseña.',
'error9'                  => 'La tarea no existe o no tiene permisos para verla.',
'error10'                 => 'La tarea no existe o no tiene permisos para verla.',
'error11'                 => 'No tiene permisos para editar este comentario.',
'error12'                 => '¡No es una clave mágica válida! ¿Está seguro de que la recibió con el mensaje de notificación?',
'error13'                 => 'Los usuarios anónimos no tienen perfil.',
'error14'                 => 'No tienes permisos suficientes para crear un grupo.',
'error15'                 => 'No tienes permisos suficientes para abrir una tarea.',
'error16'                 => 'No eres manager de proyecto.',
'error17'                 => 'Área MP no válida.',
'error18'                 => 'URL mágica no válida.',
'error19'                 => 'Ese usuario no existe en esta instalación de Flyspray.',
'error20'                 => 'Modificación a la base de datos no válida.',
'error21'                 => 'No se pudieron enviar uno o más correos. Verifique su configuración.',
'error22'                 => 'No está permitido el registro de nuevos usuarios.',
'error23'                 => 'Usuario o grupo deshabilitado para iniciar sesión.',
'error24'                 => 'No se ha configurado ni el ejecutable dot ni un servidor público de dot.',
'error25'                 => 'El mapa de ruta solamente está disponible para un proyecto específico.',
'error26'                 => 'Proveedor de código «oauth».',
'error27'                 => 'No se pudo ingresar. Debe autorizarnos para ver su dirección de correo.', 
'error28'                 => 'No tiene permisos para acceder a esta área.',
'done'                    => 'hecho',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'El proyecto no ha podido borrarse.',
'GMT'                     => 'GMT',
'timezone'                => 'Zona Horaria',
'accept'                  => 'Aceptar',
'reasonfordeinal'         => 'Razón de la denegación',
'pruneclosedlinks'        => 'Limpiar enlaces cerrados',
'pruneclosedtasks'        => 'Limpiar tareas cerradas',
'pagegenerated'           => 'Página e imagen generadas en %d segundos.',
'pruninglevel'            => 'Nivel de limpieza',
'lastuser'                => 'No se puede eliminar el último usuario.',
'allprivate'              => 'Todos los proyectos son privados.',
'deletegroup'             => 'Elimina este grupo y mueve sus usuarios a',
'parent'                  => 'Padre',
'ordertip'                => 'El orden en que estos elementos aparecerán en la lista',
'showtip'                 => 'Muestra este elemento en la lista',
'deletetip'               => 'Elimina este elemento de la lista',
'del'                     => 'Eliminar',
'allpriorities'           => 'Todas las Prioridades',
'request1'                => 'Se ha solicitado cerrar una tarea.',
'request2'                => 'Una solicitud para reabrir una tarea ha sido efectuada',
'expand'                  => 'Expandir',
'collapse'                => 'Contraer',
'expandall'               => 'Expandir todo',
'collapseall'             => 'Contraer todo',
'noroadmap'               => 'El mapa de ruta no está disponible (no existen versiones «futuras» específicas en este proyecto).',
'minpwsize'               => 'La longitud mínima de la contraseña es de 5 carácteres',
'passwordtoosmall'        => 'La contraseña es muy pequeña.',
'accountwaslocked'        => 'Su cuenta ha sido bloqueada debido a reitarados intentos de ingreso.',
'failedattempts'          => 'Han habido %d intentos fallidos de ingreso.',
'groupnotexist'           => 'El grupo seleccionado no existe en proyecto.',
'searchindetails'         => 'Detalles de búsqueda',
'showasassignees'         => 'Mostrar asignados',
'find'                    => 'Buscar',
'tls'                     => 'TLS',
'isadmin'                 => 'Es administrador',
'addvotes'                => 'Añadir voto',
'removevote'              => 'Eliminar voto',
'voteremoved'             => 'Su voto ha sido eliminado.',
'voteremovefailed'        => 'Su voto no puede ser eliminado en este momento.',
'novotes'                 => 'No tiene votos en esta tarea.',
'connectedtasks'          => 'Tareas conectadas:',
'taskdependencies'        => 'Tareas dependientes',
'viewgraph'               => 'ver gráfica',
'notaskdependencies'      => 'Esta tarea no depende de otras tareas.',
'dependson'               => 'Depende de',
'blocks'                  => 'Bloquea',
'newdependency'           => 'Nueva dependencia:',
'nouserstoadd'            => 'Sin usuario a agregar. Asegúrese de definir un nombre real, nombre de usuario y correo para cada uno.',
'dispintro'               => 'Mostrar mensage introductorio principal',
/* note only the English version for 'dispintro' is supported
 * other languages should also be taken cared of in the future*/

'setsupertask'            => 'Ajustar el Id de la supertarea:',
'supertaskmodified'       => 'El Id de la supertarea ha sido modificado',
'set'                     => 'Ajustar',
'supertask'               => 'Supertarea',
'setparent'               => 'Ajustar el Id de la tarea padre para esta tarea',
'selfsupertasknotallowed' => 'El Id de la supertarea no puede ser el mismo que el de la misma tarea',
'quickaction'             => 'Acciones rápidas',
'updateselectedtasks'     => 'Actualizar tareas seleccionadas',
'notspecified'            => 'No especificado',
'editselectedtasks'       => 'Editar tareas seleccionadas',
'information'             => 'Información',
'taskclosedisabled'       => 'El cerre de la tarea ha sido deshabilitado debido a que hay tareas dependientes aún están abiertas:-',
'daysleft'                => 'días restantes',
'dayoverdue'              => 'días de entrega',
'duetoday'                => 'Se entrega hoy.',
'daysbeforealert'         => 'Días antes de la alerta',
'associatedsubtask'       => 'Éxito al enlazar la tarea #FS',
'associatesubtask'        => 'Asociar el Id de la subtarea a esta tarea',
'subtaskid'               => 'Id de la subtarea',
'subtaskalreadyhasparent' => 'La subtarea que ingreso ya tiene una tarea padre, por favor, limpie los datos de esta antes de asociar.',
'subtaskisparent'         => 'La subtarea que ingresó es la tarea padre de esta misma tarea. Subtarea no asociada.',
'subtasknotexist'         => 'La subtarea ingresada no existe.',
'subtaskremovedmsg'       => 'La subtarea ha sido eliminada',
'subtaskadded'            => 'Subtarea añadida',
'subtaskremoved'          => 'Subtarea eliminada',
'addnewsubtask'           => 'Agregar nueva subtarea',
'hidesubtasks'            => 'Ocultar subtareas',
'voteforthistask'         => 'Votar por esta tarea',
'watchthistask'           => 'Vigilar esta tarea',
'privatethistask'         => 'Hacer esta tarea privada',
'adddependenttask'        => 'Asociar tarea dependiente',
'associatetaskid'         => 'Id de la subtarea',
'parenttaskid'            => 'Id de la tarea padre',
'invalidsupertaskid'      => 'Id de la tarea padre no válido.',
'supertaskadded'          => 'Añadir subtarea',
'supertaskremoved'        => 'Eliminar subtarea',
'effort'                  => 'Esfuerzo',
'efforttracking'          => 'Seguimiento de esfuerzo',
'useeffort'               => 'Proyectos usando el seguimiento de esfuerzo',
'estimatedeffort'         => 'Esfuerzo estimado',
'totalestimatedeffort'    => 'Esfuerzo total estimado',
'currenteffortdone'       => 'Esfuerzo actual finalizado',
'starteffort'             => 'Iniciar seguimiento',
'endeffort'               => 'Finalizar seguimiento',
'cleareffort'             => 'Limpiar seguimiento',
'addeffort'               => 'Añadir esfuerzo',
'manualeffort'            => 'Añadir esfuero manualmente (H:M)',
'efforttrackingstarted'   => 'Seguimiento de esfuerzo concedido a esta tarea.',
'efforttrackingnotstarted'=> 'No se puede iniciar el seguimiento a una tarea ya en seguimiento',
'efforttrackingstopped'   => 'El seguimiento de esfuerzo fue finalizado para esta tarea.',
'efforttrackingcancelled' => 'El seguimiento de esfuerzo fue cancelado para esta tarea.',
'efforttrackingadded'     => 'Esfuerzo manual guardado para esta tarea.',
'trackinginprogress'      => 'Seguimiento en progreso',
'viewestimatedeffort'     => 'Puede ver el seguimiento de esfuerzo',
'viewcurrenteffortdone'   => 'Puede ver el seguimiento actual de esfuerzo',
'trackeffort'             => 'Puede seguir el esfuerzo',
'invalideffort'           => 'El esfuerzo ingresado no es válido, Debe ser un número',
'showpass'                => 'Mostrar contraseña',
'chooseafile'             => '¡Seleccione un archivo!',
'incorrectfiletype'       => 'Tipo de archivo incorrecto. Admitidos: .jpg, .jpeg, .gif, .png.',
'oauthreqpass'            => 'Sin contraseña a pedir. Se registró a travez de %s',
'addmultipletasks'        => 'Añadir múltiples tareas',
'pendingnewuserrequest'   => 'Hay peticiones de Nuevos usuarios pendientes',
'adminrequestswaiting'    => 'Hay peticiones de administrador pendientes',
'clicktoedit'             => 'Haga clic en cada campo para una edición rápida',
'confirmedit'             => 'confirmar',
'canceledit'              => 'cancelar',
'regapprovedbyadmin'      => 'Registración aprobadas por administradores (deshabilitar código de confirmación)',
'activity'                => 'Actividad',
'myactivity'              => 'Mi actividad',
'emailverificationwrong'  => 'El correo de confirmación no tiene la misma dirección que el correo registrado',
'verifyemailaddress'      => 'Confirmar la dirrecipon de correo',
'hideemails'              => 'Ocultar la dirección de correo',
'hidemyemail'             => 'Ocultar midirección de correo',
'exporttasklist'          => 'Exportar lista de tareas',
'onedecimal'              => 'un decimal',
'manday'                  => 'hombres-día',
'mandays'                 => 'hombres-días',
'mandayabbrev'            => 'h/d',
'hourspermanday'          => 'Horas por hombres-día (HH:mm)',
'itemexists'              => 'El objeto %s ya existe en la base de datos.',
'categoryitemexists'      => 'El objeto %s ya existe en la categoría %s ien la base de datos.',
'pageswelcomemsg'         => 'Pages where to show main intro message',
'pagesintromsg'           => 'Pages where to show intro message',
'activeoauths'            => 'Activar proveedores de Oauth',
'onlyoauthreg'            => 'Only allow Oauths registrations',
'estimatedeffortformat'   => 'Estimated effort display format',
'currenteffortdoneformat' => 'Current effort done display format',
'minute'                  => 'minuto',
'minutes'                 => 'minutos',
'minuteplural'            => 'minutos',
'minutesingular'          => 'minuto',
'minuteabbrev'            => 'min',
'hourplural'              => 'horas',
'hoursingular'            => 'hora',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'Estimación de esfuerzo en tareas abiertas',
'currenteffortdoneopen'   => 'Esfuerzo actual en tareas Abiertas',
'signinwith'              => 'Acceder con %s',
'canviewroadmap'          => 'Puede ver roadmap',
'enableavatars'           => 'Activar avatares',
'maxavatarsize'           => 'Tamaño máximo de avatar en píxeles',
'taskhassubtask'          => 'La tarea tiene la siguiente subterea',
'taskhassubtasks'         => 'La tarea tiene las siguientes subtereas',
'translations'            => 'Traducciones',
'translate'               => 'Traducir',
'taskdescription'         => 'Descripción de la tarea',
'notaskdescription'       => 'tarea sin descripción',
'pleaseselect'            => 'Please select',
'closeselectedtasks'      => 'Cerrar tareas seleccionadas',
'closetasks'              => 'Cerrar tareas',
'hintforbulkimport'       => '<b>Trucos para importación masiva:</b>
  <ol>
  <li>Copy and paste from an excel spreadsheet or CSV by pasting one entire column.</li>
  <li>Currently you can only paste Summary and Details.</li>
  <li>There are suggestions when you assign to someone, and to no-one if there is no matched name.</li>
  </ol>',
'taskissubtaskof'         => 'Esta tarea es subtarea de',
'applyfirstline'          => 'Aplicar primera línea',
'addmorerows'             => 'Añadir más filas',
'addtasks'                => 'Añadir tareas',
'massopsdisabled'         => 'Sorry, bulk editing is currently disabled for Flyspray 1.0. We plan to finish implementation for a later release of Flyspray. You can enable them in source code again at your own risk, but read the comments there before doing it.',
'viewroadmap'             => 'No se puede ver el roadmap',
'nosuicide'               => 'Dear user, my program doesn\'t allow you to destroy your access to Flyspray by disabling your own account or switching your own group. The empathic brother of HAL9000',
'movingtodifferentproject' => 'Moving a task that has either a parent or subtasks to a different project is not allowed. You must break the connection between them first.',
'musthavesameproject'     => 'Tarea Padre y subtarea deben pertenecer al mismo proyecto.',
'defaultorderby'          => 'Order tasklist by default by',
'defaultorderby2'         => 'entonces por',
'viewowntasks'            => 'Ver Mis Tareas',
'viewgroupstasks'         => 'View groups tasks',
'urlrewriting'            => 'Reescritura de urls (url amigables)',
'enablehtaccess'          => 'Por favor, habilita el uso de .htaccess en la carpeta de Flyspray antes de activar la reescritura de urls',
'nomodrewrite'            => 'Parece que mod-rewrite no esta habilitado en el servidor de Flyspray. Debe estar activarlo para activar urls amigables',
'on'                      => 'habilitado',
'off'                     => 'deshabilitado',
'defaultorderbydirection' => 'Default order by direction',
'ascending'               => 'Ascendiente',
'descending'              => 'Descendiente',
'myassignedtasks'         => 'Mis tareas',
'commentedon'             => 'commented on',
'maxvoteperday'           => 'Votos Máximos por día',
'votesperproject'         => 'User\'s limit of votes per project',
'votelimitreached'        => 'You reached your vote limit for this project. See your profile page for which tasks you currently vote. There you can also take back vote. So we can see what tasks are most important for you. Solved tasks get your vote back into your available voting limit.',
'myvotes'                 => 'Mis Votos',
'tag'                     => 'Etiqueta',
'tags'                    => 'Etiquetas',
'tagsinfo'                => 'Free tagging/labeling of tasks in Flyspray: Separate tags by ; They aren\'t used yet for searching, sorting or filtering.',
'novalues'                => 'sin entradas',
'youhaveregistered'       => 'Te has registrado en Flyspray. Tus datos son los siguientes:',
'youhaveregisterednotify' => 'Tu registro en Flyspray ha sido aceptado por los Administradores.',
'usedintasks'             => 'Uso',
'freetagging'             => 'Permitir tags definidos por usuario',
'keyboardshortcuts'       => 'Atajos de teclado',
'testmailsettings'        => 'Probar ajustes de correo',
'test'                    => 'Prueba',
'testmailsettingsnotice'  => 'Y además comprueba si has recibido un correo de prueba en la cuenta de correo del usuario actual. (ver \'myprofile\'-page)',
'invalidinput'            => 'Vaya, hay enviadas algunas propiedades incompatibles o falta alguna.',
'invalidprogress'         => 'Por favor indique un valor de progreso válido.',
'invalidpriority'         => 'Por favor indique un valor de prioridad válido.',
'invalidseverity'         => 'Por favor indique un valor de gravedad válido.',
'invalidstatus'           => 'Por favor seleccione un estado de tarea válido.',
'invalidcategory'         => 'Por favor elija una categoría válida.',
'invalidreportedversion'  => 'Please choose a valid report version.',
'invaliddueversion'       => 'Please choose a valid due version.',
'invalidos'               => 'Por favor escoja un Sistema Operativo válido.',
'invalidtags'             => 'Por favor seleccione tags permitidos.',
'invalidassignees'        => 'Por favor seleccione Asignados permitidos.',
'customize'               => 'personalizar',
'hidesubs'                => 'ocultar subtareas',
'hideprivate'             => 'ocultar tareas privadas',
'hideclosed'              => 'ocultar tareas cerradas',
'currentproject'          => 'proyecto actual',
'targetproject'           => 'Proyecto de destino',
'availablekeybshortcuts'  => 'Atajos de teclado disponibles',
'logindialoglogout'       => 'Login Dialog / Logout',
'focustaskidsearch'       => 'focus taskid search',
'openselectedtask'        => 'abrir tarea seleccionada',
'movecursorup'            => 'move cursor up',
'movecursordown'          => 'move cursor down',
'taskdetails'             => 'Detalle de la tarea',
'taskediting'             => 'Edición de Tarea',
'savetask'                => 'Guardar tarea',
'generalintegration'      => 'General Integration Strings',
'generalintegrationdesc'  => 'This content is put by default theme inside the body-tag, below main content and before footer tag. Where it really appears on screen depends on CSS. Use a custom_*.css for that.',
'footerintegration'       => 'Footer Integration Strings',
'footerintegrationdesc'   => 'This content is put by default theme into the logical footer area by default. Where it really appears on screen depends on CSS. Use a custom_*.css for that.',
'editorbold'              => 'B',
'editorboldhint'          => 'negrita',
'editoritalic'            => 'I',
'editoritalichint'        => 'cursiva',
'editorunderline'         => 'U',
'editorunderlinehint'     => 'subrayado',
'editorstrikethrough'     => 'S',
'editorstrikethroughhint' => 'tachado',

);
?>
