<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Backend' => $baseDir . '/includes/class.backend.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'ContentSecurityPolicy' => $baseDir . '/includes/class.csp.php',
    'Cookie' => $baseDir . '/includes/class.gpc.php',
    'Database' => $baseDir . '/includes/class.database.php',
    'FSTpl' => $baseDir . '/includes/class.tpl.php',
    'Filters' => $baseDir . '/includes/class.gpc.php',
    'FlySprayI18N' => $baseDir . '/includes/i18n.inc.php',
    'Flyspray' => $baseDir . '/includes/class.flyspray.php',
    'Get' => $baseDir . '/includes/class.gpc.php',
    'GithubProvider' => $baseDir . '/includes/GithubProvider.php',
    'Jabber' => $baseDir . '/includes/class.jabber2.php',
    'Notifications' => $baseDir . '/includes/class.notify.php',
    'Post' => $baseDir . '/includes/class.gpc.php',
    'Project' => $baseDir . '/includes/class.project.php',
    'Req' => $baseDir . '/includes/class.gpc.php',
    'Securimage' => $vendorDir . '/dapphp/securimage/securimage.php',
    'Securimage_Color' => $vendorDir . '/dapphp/securimage/securimage.php',
    'TextFormatter' => $baseDir . '/includes/class.tpl.php',
    'Tpl' => $baseDir . '/includes/class.tpl.php',
    'Url' => $baseDir . '/includes/class.tpl.php',
    'User' => $baseDir . '/includes/class.user.php',
    'effort' => $baseDir . '/includes/class.effort.php',
    'recaptcha' => $baseDir . '/includes/class.recaptcha.php',
);
