<?php

$translation = array(
'edituser'                => 'ユーザ情報の変更',
'username'                => 'ユーザ名',
'realname'                => '氏名',
'emailaddress'            => 'E-mailアドレス',
'jabberid'                => 'Jabber ID',
'notifytype'              => '通知方法',
'group'                   => 'グループ',
'accountenabled'          => '有効なアカウント',
'updatedetails'           => '詳細更新',
'setglobally'             => 'この設定はグローバルに設定されています。',
'usergroupmanage'         => 'ユーザとグループの管理',
'newuser'                 => '新規ユーザの登録',
'newgroup'                => '新規グループの登録',
'yes'                     => 'はい',
'no'                      => 'いいえ',
'editgroup'               => 'グループ情報の変更',
'groupname'               => 'グループ名',
'description'             => '説明',
'admin'                   => 'Admin group',
'opennewtasks'            => '新規タスクを登録',
'modifytasks'             => '既存タスクを修正',
'addcomments'             => 'コメントを追加',
'attachfiles'             => 'ファイル添付',
'vote'                    => '投票',
'groupenabled'            => 'メンバのログイン',
'tasktypelist'            => 'タスク種別一覧',
'categorylist'            => 'カテゴリ一覧',
'oslist'                  => 'OS一覧',
'resolutionlist'          => 'クローズ理由一覧',
'versionlist'             => 'バージョン一覧',
'severitylist'            => '重大度一覧',
'listnote'                => '注意: 「表示」チェックボックスを解除すると、その設定値を持ったタスクの修正画面でその値を変更してしまうかもしれません。「名称」欄を変更すると、その名称の設定値だったすべてのタスクを変更することになります。動作に必要な項目やタスクに使用されている項目は削除できません。',
'name'                    => '名称',
'order'                   => '順番',
'back'                    => 'Back',
'text'                    => 'Text',
'highlight'               => 'Highlight',
'show'                    => '表示',
'owner'                   => '所有者',
'selectowner'             => '所有者を選択',
'update'                  => '更新',
'addnew'                  => '追加',
'flysprayprefs'           => 'Flyspray preferences',
'projecttitle'            => 'プロジェクト名',
'baseurl'                 => 'Base URL for this installation',
'replyaddress'            => 'Reply email address for notifications',
'themestyle'              => 'テーマ/スタイル',
'language'                => '言語',
'anonview'                => '未ログインユーザにタスクの参照を許可',
'allowanon'               => '未ログインユーザにタスクの登録を許可',
'never'                   => 'Never',
'anonymously'             => 'Anonymously',
'afterregister'           => 'Only after registering',
'spamproof'               => '新規ユーザ登録で確認コードを使用',
'anongroup'               => 'Group for new user registrations',
'groupassigned'           => 'タスクの担当者となれるユーザのグループ',
'forcenotify'             => 'タスク通知方法を固定',
'neversend'               => '送信しない',
'userchoose'              => 'ユーザが選択',
'email'                   => 'E-mail',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'デフォルトのカテゴリ所有者',
'noone'                   => '不在',
'jabbernotify'            => 'Jabber通知',
'jabberserver'            => 'サーバ',
'jabberport'              => 'ポート',
'jabberuser'              => 'アカウントユーザ名',
'jabberpass'              => 'アカウントパスワード',
'saveoptions'             => '設定保存',
'editcomment'             => 'コメント修正',
'commentby'               => 'コメント記述者',
'saveeditedcomment'       => 'コメント保存',
'projectprefs'            => 'Project Preferences',
'pagetitle'               => 'ページタイトル',
'defaultproject'          => 'デフォルトプロジェクト',
'projectlists'            => 'プロジェクト一覧',
'showlogo'                => 'Show title logo image',
'intromessage'            => '紹介文',
'isactive'                => 'プロジェクトはアクティブ',
'createproject'           => 'プロジェクト作成',
'nopermission'            => 'You don\'t have permission to use this page.',
'listordertip'            => 'この項目を一覧に表示するときの順番',
'listshowtip'             => 'この項目を一覧に表示',
'categoryownertip'        => 'このカテゴリのタスクがオープンされたときに通知するユーザ',
'categoryparenttip'       => 'この新しいカテゴリの親となるカテゴリ',
'notsubcategory'          => '無し (最上位カテゴリ)',
'showinlineimages'        => '添付画像をインラインで表示',
'dateformat'              => '日付形式',
'dateformat_extended'     => '詳細日付形式',
'cache_feeds'             => 'フィードのキャッシュ',
'no_cache'                => 'キャッシュしない',
'cache_disk'              => 'ディスクにキャッシュ',
'cache_db'                => 'データベースにキャッシュ',
'subcategoryof'           => 'Sub-category of',
'visiblecolumns'          => 'タスク一覧に表示する欄',
'tense'                   => '時期',
'listtensetip'            => '過去・現在・未来',
'past'                    => '過去',
'present'                 => '現在',
'future'                  => '未来',
'oldpass'                 => '旧パスワード',
'nooldpass'               => '旧パスワードが設定されていません。',
'oldpasswrong'            => '旧パスワードに誤りがあります。',
'changepass'              => 'パスワード',
'confirmpass'             => 'パスワード(確認)',
'projectmanager'          => 'プロジェクトの管理者',
'viewtasks'               => 'タスクを表示',
'modifyowntasks'          => '自分のタスクを修正',
'modifyalltasks'          => '自分以外のタスクを修正',
'viewcomments'            => 'コメントを表示',
'editcomments'            => 'コメントを修正',
'deletecomments'          => 'コメントを削除',
'viewattachments'         => '添付ファイルを表示',
'createattachments'       => '添付ファイルを作成',
'deleteattachments'       => '添付ファイルを削除',
'viewhistory'             => '履歴を表示',
'closeowntasks'           => '自分のタスクをクローズ',
'closeothertasks'         => '自分以外のタスクをクローズ',
'assigntoself'            => '未割り当てのタスクを自分に割り当て',
'assignotherstoself'      => '他人のタスクを自分に割り当て',
'viewreports'             => 'イベントログを表示',
'othersview'              => '誰でもこのプロジェクトを参照可能',
'usersandgroups'          => 'ユーザとグループ',
'globalgroup'             => 'グローバルグループ',
'globalgroups'            => 'グローバルグループ',
'defaultglobalgroup'      => '新規ユーザのデフォルトグローバルグループ',
'addtogroup'              => 'グループに追加',
'moveuserstogroup'        => 'ユーザを他のグループに移動',
'nogroup'                 => 'グループ無し - プロジェクトから削除',
'eventdesc'               => '要望事項',
'requestedby'             => '要望者',
'daterequested'           => '要望日',
'closetask'               => 'タスクをクローズ',
'reopentask'              => 'タスクを再オープン',
'applymember'             => 'プロジェクトメンバに応募',
'forcurrentproj'          => 'For current project',
'lostpw'                  => '忘れたパスワードの復旧',
'lostpwexplain'           => 'あなたのユーザ名を入力してください。あなたのプロフィールに登録された通知アドレスに、パスワード変更画面へのリンクを送信します。',
'sendlink'                => 'リンク送信',
'savenewpass'             => '新パスワードを保存',
'anonreg'                 => '新規ユーザ登録を許可',
'allowanonopentask'       => '未ログインユーザにタスクの登録を許可',
'editglobalgroup'         => 'Edit Global Group',
'editgroupforproj'        => 'Edit group for Project',
'notshownforadmin'        => '管理者グループに対する許可設定は変更する必要がないため表示されません。',
'general'                 => '一般',
'userregistration'        => 'ユーザ登録',
'notifications'           => '通知',
'resetoptions'            => '設定リセット',
'preferences'             => '設定',
'tasktypes'               => 'タスク種別',
'resolutions'             => 'クローズ理由',
'categories'              => 'カテゴリ',
'operatingsystems'        => 'OS',
'versions'                => 'バージョン',
'admintoolboxlong'        => '運用管理',
'newproject'              => '新規プロジェクト',
'delete'                  => '削除',
'listdeletetip'           => 'この項目を削除',
'lookandfeel'             => '外観',
'globaltheme'             => 'グローバルテーマ',
'emailnotify'             => 'E-mail通知',
'fromaddress'             => 'Fromアドレス',
'smtpserver'              => 'SMTPサーバ',
'smtpuser'                => 'SMTPユーザ名',
'smtppass'                => 'SMTPパスワード',
'addrewrite'              => 'Use address rewriting',
'usereminderdaemon'       => 'Enable background reminder daemon',
'tasksperpage'            => 'タスク一覧でのページ毎タスク数',
'addtoassignees'          => '自分を担当者に追加',
'taskstatuses'            => 'タスク状態',
'canvote'                 => 'タスクに投票',
'loginsuccessful'         => 'ログイン成功.',
'youareloggedout'         => 'ログアウトしました。',
'waitwhiletransfer'       => '転送中お待ちください...',
'clicknowait'             => 'Click here if you do not wish to wait.',
'accountdisabled'         => 'Your account is disabled.  Contact a full admin.',
'task'                    => 'タスク',
'edittask'                => 'タスクを修正',
'openedby'                => 'オープン者',
'editedby'                => '最終修正者',
'tasktype'                => 'タスク種別',
'category'                => 'カテゴリ',
'status'                  => '状態',
'assignedto'              => '担当者',
'operatingsystem'         => 'OS',
'severity'                => '重大度',
'reportedversion'         => '報告バージョン',
'dueinversion'            => '対応予定バージョン',
'undecided'               => '未決定',
'percentcomplete'         => '進捗',
'details'                 => '詳細',
'savedetails'             => '設定保存',
'canceledit'              => 'Cancel Edit',
'anonymous'               => '匿名登録者',
'complete'                => '完了',
'closedby'                => 'クローズ者',
'reasonforclosing'        => 'クローズの理由:',
'reopenthistask'          => 'タスクを再オープン',
'comments'                => 'コメント',
'attachments'             => '添付ファイル',
'relatedtasks'            => '関連タスク',
'edit'                    => '変更',
'addcomment'              => 'コメント追加',
'fileuploadedby'          => 'ファイルアップロード者',
'uploadafile'             => 'ファイルを添付',
'uploadnow'               => 'Upload now!',
'thesearerelated'         => 'These tasks are related to this task',
'remove'                  => '削除',
'addnewrelated'           => '関連タスクを追加',
'add'                     => '追加',
'otherrelated'            => 'このタスクに関連する他のタスク',
'receivenotify'           => 'These users will receive detailed notifications when this task changes.',
'addusertolist'           => 'ユーザをこの一覧に追加',
'addtolist'               => '一覧に追加',
'addmyself'               => '自分をこの一覧に追加',
'removemyself'            => '自分をこの一覧から削除',
'theseusersnotify'        => 'これらのユーザはこのタスクが変更されたときに詳細情報の通知を受け取ります。',
'attachedtoproject'       => '割り当てられたプロジェクト',
'reminders'               => '催促',
'system'                  => 'System',
'remindthisuser'          => '催促するユーザ',
'thisoften'               => '通知間隔',
'startafter'              => '最初の催促までの待ち',
'hours'                   => '時間',
'days'                    => '日',
'weeks'                   => '週間',
'addreminder'             => '催促登録',
'defaultreminder'         => 'これは以下のFlysprayタスクに対する催促です:',
'message'                 => 'メッセージ',
'closed'                  => 'クローズ',
'filename'                => 'ファイル名:',
'date'                    => '日付',
'filesize'                => 'ファイルサイズ:',
'closurecomment'          => 'クローズに対する追加コメント:',
'history'                 => '履歴',
'nohistory'               => '履歴はありません。',
'eventdate'               => '日付',
'user'                    => 'ユーザ',
'event'                   => 'イベント',
'fieldchanged'            => 'フィールド変更',
'taskopened'              => 'タスクオープン',
'taskreopened'            => 'タスク再オープン',
'taskclosed'              => 'タスククローズ',
'commentadded'            => 'コメント追加',
'commentedited'           => 'コメント修正',
'commentdeleted'          => 'コメント削除',
'attachmentadded'         => '添付ファイル追加',
'attachmentdeleted'       => '添付ファイル削除',
'taskedited'              => 'タスク詳細修正',
'notificationadded'       => '通知一覧にユーザ追加',
'notificationdeleted'     => '通知一覧からユーザ削除',
'relatedadded'            => '関連タスク追加',
'relateddeleted'          => '関連タスク削除',
'taskassigned'            => 'タスク割り当て',
'taskreassigned'          => 'タスク再割り当て',
'assignmentremoved'       => 'タスク割り当て解除',
'summary'                 => '要約',
'addedasrelated'          => '関連タスクとして追加',
'deletedasrelated'        => '関連タスクから削除',
'reminderadded'           => '通知追加',
'reminderdeleted'         => '通知削除',
'priority'                => '優先度',
'previousvalue'           => '以前の値',
'newvalue'                => '新しい値',
'selectareason'           => '理由を選択',
'assigntome'              => '自分に割り当て',
'reopenrequest'           => '再オープンを要望',
'requestclose'            => 'クローズを要望',
'ownershiptaken'          => '担当者割り当て',
'closerequestmade'        => 'タスククローズ要望',
'reopenrequestmade'       => 'タスク再オープン要望',
'taskdependson'           => 'このタスクが依存しているタスク',
'taskblocks'              => 'このタスクがクローズの妨げとなっているタスク',
'depadded'                => '依存に追加',
'depaddedother'           => '他のタスクの依存として追加',
'depremoved'              => '依存から削除',
'depremovedother'         => '他のタスクの依存から削除',
'showdetailserror'        => 'そのタスクは存在しないか、そのタスクを参照する許可がありません。',
'makeprivate'             => '非公開に変更',
'makepublic'              => '公開に変更',
'taskmadeprivate'         => '非公開に変更',
'taskmadepublic'          => 'プライバシーの除去 - 公開に変更',
'confirmdeletecomment'    => '本当にこのコメントを削除してもいいですか？%s',
'confirmdeleteattach'     => '本当にこの添付ファイルを削除してもいいですか？',
'selectedhistory'         => 'Showing selected history details',
'showallhistory'          => 'Show full history tab again',
'hidethis'                => 'Hide this area again',
'mark100'                 => 'タスクを 100% 完了にする',
'watchtask'               => '監視',
'stopwatching'            => '監視を解除',
'commentlink'             => 'このコメントへのリンク',
'submitreq'               => '要望を送信',
'reasonforreq'            => '要望の理由',
'pmreqdenied'             => 'プロジェクト管理者が要望を拒否',
'taskpendingreq'          => 'プロジェクト管理者による処理待ちです。詳細は履歴タブを見てください。',
'previoustask'            => '前のタスク',
'nexttask'                => '次のタスク',
'duedate'                 => '対応予定日',
'attachnoperms'           => 'このコメントには添付ファイルがありますが、添付ファイルを参照する権限がありません。',
'open'                    => 'オープン',
'depgraph'                => '依存関係グラフを表示',
'reset'                   => 'リセット',
'selectusers'             => 'ユーザを選択',
'addmetoassignees'        => '自分を担当者に追加',
'addedtoassignees'        => 'ユーザを担当者に追加',
'dependencygraph'         => '依存関係グラフ',
'attachanotherfile'       => 'もう1つファイルを添付',
'OK'                      => 'OK',
'addvote'                 => '投票',
'notifyfromfs'            => 'Flysprayからの通知',
'autogenerated'           => 'THIS IS AN AUTOMATICALLY GENERATED MESSAGE, DO NOT REPLY',
'forward'                 => '次',
'previous'                => '前',
'next'                    => '次',
'first'                   => '最初',
'last'                    => '最後',
'page'                    => '表示中ページ %d / %d',
'search'                  => 'Search',
'alltasktypes'            => '全タスク種別',
'allseverities'           => '全重大度',
'alldevelopers'           => '全開発者',
'notyetassigned'          => '未割り当て',
'allcategories'           => '全カテゴリ',
'allstatuses'             => '全状態',
'allopentasks'            => '全オープンタスク',
'sortthiscolumn'          => 'この欄でソート',
'id'                      => 'ID',
'project'                 => 'プロジェクト',
'dateopened'              => 'オープン日',
'progress'                => '進捗',
'searchthisproject'       => 'このプロジェクトを検索',
'dueanyversion'           => '全対応予定バージョン',
'anyversion'              => '全報告バージョン',
'dueversion'              => '対応予定バージョン',
'lastedit'                => '最終更新日',
'os'                      => 'OS',
'reportedin'              => '報告バージョン',
'taskrange'               => '表示中タスク %d - %d / %d',
'noresults'               => '検索条件に何も該当しませんでした',
'takeaction'              => '実行',
'watchtasks'              => '選択したタスクを監視',
'stopwatchingtasks'       => '選択したタスクの監視を解除',
'assigntaskstome'         => '選択したタスクを自分に割り当て',
'dueby'                   => 'Due by',
'dueanytime'              => 'Due anytime',
'selectduedate'           => '対応予定日を選択',
'toggleselected'          => '選択状態を反転',
'due'                     => '対応予定日',
'assignedtome'            => '自分に割り当てられたタスク',
'tasklist'                => 'タスク一覧',
'dateclosed'              => 'クローズ日',
'advanced'                => '詳細',
'searchcomments'          => 'コメント内も検索',
'searchforall'            => 'すべての単語でAND検索',
'anonusers'               => '未ログインユーザ',
'miscellaneous'           => '検索範囲',
'users'                   => 'ユーザ',
'taskproperties'          => 'タスク属性',
'selectsincedate'         => '最終更新日を選択',
'changedsince'            => '最終更新日',
'updatefs'                => 'Flysprayを更新してください。',
'currentversion'          => '現在のバージョンは',
'latestversion'           => '、最新のバージョンは',
'hidemessage'             => '(remind me later)',
'saveas'                  => '検索条件に名前を付けて保存',
'nosearches'              => '保存された検索条件はありません',
'saving'                   => '保存中...',
'votes'                   => '投票',
'allclosedtasks'          => '全クローズタスク',
'password'                => 'パスワード',
'login'                   => 'ログイン!',
'rememberme'              => '記憶する',
'lostpassword'            => 'パスワードを忘れましたか?',
'lostpwforfs'             => 'Lost password for Flyspray',
'lostpwmsg1'              => 'Hi.

I have lost my password for Flyspray on ',
'lostpwmsg2'              => ', please provide me with a new password.

Username: ',
'regards'                 => '

Regards,',
'yourusername'            => ' your username ',
'locale'                  => 'ja',
'filenotexist'            => 'File does not exist, or you do not have permission to access it.',
'showtask'                => 'タスク表示',
'now'                     => 'Now',
'go'                      => 'Go!',
'opentaskanon'            => '匿名でタスク登録',
'register'                => 'ユーザ登録',
'addnewtask'              => '新規タスク登録',
'reports'                 => 'イベントログ',
'editmydetails'           => 'プロフィールの変更',
'logout'                  => 'ログアウト',
'disabledaccount'         => 'あなたのアカウントは無効になりました。<br />ログアウトします。',
'poweredby'               => 'Powered by Flyspray',
'projects'                => 'プロジェクト',
'allprojects'             => '全プロジェクト',
'selectproject'           => 'for Project:',
'tasksall'                => '全タスク',
'tasksassigned'           => '自分に割り当てられたタスク',
'tasksreported'           => '自分が報告したタスク',
'taskswatched'            => '監視しているタスク',
'mysearch'                => 'お好み検索',
'admintoolbox'            => '運用管理',
'manageproject'           => 'プロジェクト管理',
'permissions'             => 'View Permissions',
'hide'                    => 'Hide',
'pendingreq'              => '個の要望がプロジェクト管理者待ち',
'errorpage'               => '要求されたページを提供することができません。<br />
                                 おそらく、要求されたタスクが存在しないか、要求されたページを参照する権限があなたにありません。<br /><br />
                                 You may have tried to use a naughty URL to interact with the database
                                 backend using SQL injection.  If this is true, go to the corner and think
                                 about your actions.  When you return, please do not do it again!',
'permissionsforproject'   => '許可 for ',
'switchto'                => 'プロジェクト切り替え',
'lastsearch'              => '一番最後に行った検索',
'modify'                  => 'Modify',
'noticefrom'              => '通知 from',
'hasopened'               => 'has OPENED A NEW Flyspray task, and assigned it to you:',
'moreinfonew'             => 'You can find more information about this bug at the Flyspray page:',
'newtaskcategory'         => 'A new Flyspray task has been opened in this category',
'categoryowner'           => 'You are receiving this because you are listed as the category owner.',
'tasksummary'             => 'Task summary:',
'newtaskadded'            => '新しいタスクが登録されました。',
'summaryanddetails'       => '要約と詳細の両方を埋める必要があります。',
'goback'                  => 'Go back.',
'messagefrom'             => 'Flyspray障害管理システムからのメッセージです。 ',
'hasjustmodified'         => 'has just modified the following task.',
'changedfields'           => 'Changed fields are prefixed with asterisks (**)',
'moreinfomodify'          => 'You can get more information about this task at the following URL:',
'nolongerassigned'        => 'The following task is no longer assigned to you.  It is now assigned to',
'hasassigned'             => 'has assigned to you the following Flyspray task:',
'taskupdated'             => 'タスクが更新されました。',
'hasclosedassigned'       => 'has closed the following Flyspray task that you were assigned:',
'unassigned'              => '未決定',
'hasclosed'               => 'has closed the following task.',
'youonnotify'             => 'You are receiving this because you are on the notification list.',
'taskclosedmsg'           => 'タスクがクローズされました。',
'returntotask'            => 'Return to the task details',
'backtoindex'             => 'Go back to the task list',
'noclosereason'           => 'タスクのクローズ理由が選択されていません。',
'hasreopened'             => 'has re-opened the following Flyspray task that you closed:',
'taskreopenedmsg'         => 'タスクが再オープンされました。',
'backtotask'              => 'Go back to the task.',
'commentaddedmsg'         => 'コメントが追加されました。',
'commenttoassigned'       => 'has added a comment to a task that you have been assigned:',
'commenttotask'           => 'has added the following comment to this task.',
'nocommententered'        => 'コメントを入力してください。',
'fillinfields'            => 'You didn\'t fill in all the fields.',
'notcurrentpass'          => 'That\'s not your current password!',
'passchanged'             => 'パスワードが変更されました。',
'closewindow'             => 'You can now close this window.',
'passnomatch'             => '新パスワードが同じではありません。',
'usernametaken'           => 'そのユーザ名はすでに取得されています。違うものを指定してください。',
'newusercreated'          => '新しいユーザが登録されました。',
'accountcreated'          => 'アカウントが登録されました。',
'newuserwarning'          => '新しいアカウントには管理者による承認を必要とする運用設定になっているかもしれません。ログインできない場合は、おそらくそれが原因です。',
'nomatchpass'             => 'パスワードが一致しません。',
'confirmwrong'            => '確認コードが間違っています!',
'formnotcomplete'         => 'フォームが完全に埋められていません。',
'formnotnumeric'          => '入力されたデータが数字ではありません。',
'groupnametaken'          => 'そのグループ名はすでに取得されています。',
'newgroupadded'           => '新しいグループが登録されました。',
'optionssaved'            => 'Flyspray設定が保存されました。',
'hasuploaded'             => 'has uploaded a file attachment to a task that have been assigned:',
'hasattached'             => 'has attached a file to the following task.',
'fileuploaded'            => 'File has been uploaded.',
'fileerror'               => 'There was an error uploading your file.  Perhaps the permissions on the <i>attachments/</i> directory are incorrect.',
'contactadmin'            => 'Contact the Administrator for this project.',
'selectfileerror'         => 'You didn\'t select a file.',
'userupdated'             => 'ユーザ情報が更新されました。',
'realandemail'            => 'You didn\'t fill in both the Real Name and Email Address fields.',
'groupupdated'            => 'グループ情報が更新されました。',
'groupanddesc'            => 'グループ名が埋められていません。',
'fillallfields'           => 'すべての入力欄を埋めてください。',
'listPmustN'              => '「順番」欄は数字である必要があります。',
'listupdated'             => '一覧が更新されました。',
'listitemadded'           => '新しい一覧項目が追加されました。',
'relatedaddedmsg'         => '関連タスクが一覧に追加されました。',
'relatederror'            => 'そのタスクはすでにこの関連タスク一覧に設定されています。',
'relatedremoved'          => '関連タスクが一覧から削除されました。',
'notifyadded'             => 'ユーザが通知一覧に追加されました。',
'notifyerror'             => 'That user is already on the notification list for that task.',
'notifyremoved'           => 'ユーザが通知一覧から削除されました。',
'editcommentsaved'        => '更新コメントが保存されました。',
'commentdeletedmsg'       => 'コメントが削除されました。',
'gotonewtask'             => 'Go to the new task you just created',
'projectcreated'          => '新しいプロジェクトが作成されました。プロジェクト管理領域で設定を行うことができます。',
'customiseproject'        => 'Customise this project',
'projectupdated'          => 'プロジェクトの設定が更新されました。',
'emptytitle'              => 'プロジェクト名が空欄です。戻って修正してください。',
'loginbelow'              => 'ログインの準備ができました。',
'attachmentdeletedmsg'    => 'The attachment has been deleted',
'reminderaddedmsg'        => '催促が追加されました。',
'reminderdeletedmsg'      => '選択された催促が削除されました。',
'flyspraytask'            => 'Flyspray task',
'fieldsmissing'           => '入力されていないまたは無効な入力欄があります。',
'relatedinvalid'          => 'そのようなタスクはありません。',
'relatedproject'          => 'このタスクは別のプロジェクトに割り当てられています。関連タスクとして追加しますか？',
'addanyway'               => 'Add anyway',
'cancel'                  => 'Cancel',
'alreadyedited'           => 'このタスクはあなたが保存する前に別のユーザによって変更されています。変更を保存しますか？',
'saveanyway'              => 'Save my changes anyway',
'nouserselected'          => 'No user selected.  Select at least one user before trying again.',
'groupswitchupdated'      => 'ユーザのグループを変更しました。',
'takenownershipmsg'       => 'このタスクがあなたに割り当てられました。',
'adminrequestmade'        => 'プロジェクト管理者に要望が送信されました。',
'newdepnotify'            => 'A new dependency has been added to the following task:',
'dependadded'             => 'タスクの依存が追加されました。',
'dependaddfailed'         => '依存の追加に失敗しました。そのタスクが存在するか、そのタスクから逆に依存されていないか確認してください。',
'depremovedmsg'           => 'タスクの依存が削除されました。',
'newdepis'                => '新しい依存は',
'magicurlsent'            => 'あなたの通知アドレスにメッセージを送信しました。その中に目的を完了するためのページへのリンクが含まれています。',
'changefspass'            => 'Flysprayのパスワードを変更',
'magicurlmessage'         => 'Flysprayのパスワードを変更するには以下のURLに行ってください。',
'erroronform'             => 'フォームの送信に問題があります。',
'addressused'             => 'このアドレスはFlysprayのアカウントを登録するために使用されました。
もしこのメッセージを予期していなかったのであれば、無視して削除してください。
あなたのアカウントの登録を完了するには、以下のURLに行ってください。',
'confirmcodeis'           => '確認コード:',
'codesent'                => '確認コードが送信されました。そのメッセージに書かれた手順にしたがってください。',
'codenotsent'             => '確認コードを送信できませんでした。しばらくしてからもう一度試してみてください。',
'taskmadeprivatemsg'      => 'タスクが非公開になりました。',
'taskmadepublicmsg'       => 'タスクが公開になりました。',
'realandnotify'           => '氏名と、E-mailアドレスまたはJabber IDの入力欄を埋めてください。',
'pmreqdeniedmsg'          => 'プロジェクト管理者が要望を拒否しました',
'massopsuccess'           => 'Mass operations successful - where permissions allowed',
'usernotexist'            => 'そのユーザはこのFlyspray上に存在しません。',
'commentattachperms'      => 'コメントを削除できません。- 添付ファイルを削除する権限がありません。',
'voterecorded'            => '投票が記録されました。',
'votefailed'              => '投票できませんでした。',
'createnewgroup'          => '新規グループの登録',
'requiredfields'          => '入力必須欄:',
'addthisgroup'            => 'このグループを登録',
'createnewproject'        => '新規プロジェクトの作成',
'addnewproject'           => '新規プロジェクトを登録',
'htmlallowed'             => 'HTML code is allowed',
'createthisproject'       => 'このプロジェクトを登録',
'inlineimages'            => '添付画像をインラインで表示',
'createnewtask'           => 'Create a new task in project:',
'addanother'              => 'Add another task after this one',
'addthistask'             => 'タスク登録',
'notifyme'                => 'このタスクが変更されたら自分に通知する',
'newtask'                 => '新規タスク',
'attachafile'             => 'Attach a file',
'registernewuser'         => '新規ユーザの登録',
'none'                    => '無し',
'registeraccount'         => 'このアカウントを登録',
'both'                    => '両方',
'notifyfrom'              => '通知 from ',
'donotreply'              => 'これは自動的に送信されたメッセージです。返信しないでください。',
'disclaimer'              => 'あなたがこのメッセージを受信したのは、Flyspray障害管理システム上であなたが要求したためです。このメッセージを予期していなかったか、今後受信したくない場合は、上記URLであなたの通知設定を変更することができます。',
'userwho'                 => '操作ユーザ',
'moreinfo'                => '詳細は以下のURLから参照できます。',
'newtaskopened'           => 'Flysprayに新しいタスクが登録されました。詳細は以下の通りです。',
'notify.taskclosed'       => '以下のタスクがクローズされました。',
'notify.taskreopened'     => '以下のタスクが再オープンされました。',
'newdep'                  => '以下のタスクに新しい依存が追加されました。',
'notify.depremoved'       => '以下のタスクから依存が削除されました。',
'olddepwas'               => 'The old dependency was',
'notify.commentadded'     => '以下のタスクに新しいコメントが登録されました。',
'commentis'               => 'コメント文は以下です。',
'newattachment'           => '以下のタスクに新しい添付ファイルが追加されました。',
'detailsbelow'            => '詳細は以下の通りです。',
'notify.relatedadded'     => '以下のタスクに新しい関連タスクが登録されました。',
'relatedis'               => '関連タスクは以下です。',
'assignedtoyou'           => '以下のタスクがあなたに割り当てられました。',
'takenownership'          => 'に以下のタスクが割り当てられました。',
'requiresaction'          => '以下のタスクはプロジェクト管理者による処理が必要です。',
'requiresactionnotify'    => 'Task requires action by a Project Manager',
'pmdeny'                  => 'プロジェクト管理者が以下のタスクに対する要望を拒否しました。',
'pmdenynotify'            => 'A Project Manager has denied the request',
'fileaddedtoo'            => 'このコメントには1つ以上の添付ファイルがあります。',
'taskwatching'            => 'あなたは以下のタスクを監視しています。',
'isdepfor'                => 'このタスクは以下のタスクから依存されています。',
'denialreason'            => '拒否の理由',
'taskchanged'             => '以下のタスクは修正されました。修正内容は以下の一覧の通りです。修正内容の詳細情報を見るには、下記のURLに行き履歴タブをクリックしてください。',
'useraddedtoassignees'    => 'ユーザが以下のタスクの担当者一覧に自分自身を追加しました。',
'removeddepis'            => '削除された依存',
'isnodepfor'              => 'このタスクはもはや以下のタスクの依存ではありません。',
'usergroups'              => 'ユーザとグループ',
'pmtoolbox'               => 'プロジェクト管理',
'groupmanage'             => 'グループ管理',
'pendingrequests'         => '未解決要望',
'reasongiven'             => '理由',
'nopendingreq'            => '未解決の要望はありません。',
'givereason'              => 'Give a reason',
'catlisted'               => 'カテゴリ一覧',
'oslisted'                => 'OS一覧',
'verlisted'               => 'バージョン一覧',
'tasktypeed'              => 'タスク種別一覧',
'resed'                   => 'クローズ理由一覧',
'deny'                    => '拒否',
'notifiedwhen'            => 'Notified when',
'onlynewtasks'            => 'New tasks are opened',
'allevents'               => 'Any event occurs in any task',
'feeds'                   => 'フィード',
'feeddescription'         => 'フィードの説明',
'feedimgurl'              => 'フィードの画像URL (画像無しは空欄)',
'notifysubject'           => '通知の題名',
'notifysubjectinfo'       => '(%p = プロジェクト名, %s = タスク要約, %t = タスクID, %a = イベント内容, %u = ユーザ名)',
'priority6'               => '即刻',
'priority5'               => '大至急',
'priority4'               => '至急',
'priority3'               => '高',
'priority2'               => '通常',
'priority1'               => '低',
'sendcode'                => 'コード送信!',
'entercode'               => '通知メッセージの中に記載された確認コードを入力してください。また希望するアカウントのパスワードを入力してください。',
'confirmationcode'        => '確認コード',
'registererror'           => '必須の入力欄がすべて埋まっているか、希望する通知形式用の入力欄が正しく入力されているか、確認してください。',
'validusername'           => '(アルファベット・数字と - _ . が使用可能)',
'emailtaken'              => 'そのE-mailアドレスまたはJabber IDはすでに取得されています。違うものを指定してください。',
'note'                    => '<strong>注意:</strong>  アカウントを作成する前に、あなた宛に確認コードが送信されます。この確認コードは上記の希望する通知方法で送信されます。<br />入力に間違いがあった場合、<strong>あなたは確認コードを受信できません。</strong>',
'changelog'               => '変更履歴',
'changeloggen'            => '変更履歴生成',
'listfrom'                => 'List changelog entries from',
'to'                      => '終了日',
'oldestfirst'             => 'Oldest first',
'recentfirst'             => 'Most recent first',
'severityrep'             => 'Severity Report',
'totalopen'               => 'Total open tasks',
'age'                     => 'Age',
'agerep'                  => 'Age Report',
'eventsrep'               => 'Events Report',
'events'                  => 'イベント',
'Tasks'                   => 'タスク',
'opened'                  => 'オープン',
'edited'                  => '修正',
'assigned'                => '割り当て',
'within'                  => '最近',
'pastday'                 => '過去1日',
'pastweek'                => '過去1週間',
'pastmonth'               => '過去1ヶ月間',
'pastyear'                => '過去1年間',
'nolimit'                 => '無制限',
'from'                    => '開始日',
'duein'                   => '対応予定',
'selectfromdate'          => '開始日を選択',
'selecttodate'            => '終了日を選択',
'showvoters'              => '投票者の表示/非表示',
'roadmap'                 => 'ロードマップ',
'roadmapfor'              => 'ロードマップ for バージョン',
'tasks'                   => 'タスク',
'completed'               => 'が完了。',
'opentasks'               => 'オープンタスク',
'of'                      => '% of',
'severity5'               => '重大',
'severity4'               => '高',
'severity3'               => '普通',
'severity2'               => '低',
'severity1'               => '極低',
'Redirect'                => '転送',
'redirectmsg'             => 'If your browser does not support meta redirection please click %sHERE%s to be redirected',
'allowclosedcomments'     => 'クローズされたタスクにコメントを許可',
'comment'                 => 'コメント',
'editowncomments'         => '自分のコメントを修正',
'reopened'                => '再オープン',
'loading'                 => '読み込み中...',
'notifyown'               => '自分自身による変更を通知する',
'youremail'               => 'あなたのE-mailアドレス',
'thankyouforbug'          => '問題の指摘をありがとうございます。以下のURLからいつでもこのタスクを参照しその進捗を監視することができます。',
'anonuser'                => '未ログインユーザ',
'conflict'                => 'Conflict',
'file'                    => 'ファイル',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'サイズ',
'projectgroup'            => 'プロジェクトグループ',
'profile'                 => 'プロフィール:',
'viewprofile'             => 'プロフィールの参照',
'regdate'                 => '登録日',
'tasksopened'             => 'オープンしたタスク',
'replyto'                 => 'Reply-To',
'notifytypes'             => '通知するイベント',
'pm.taskchanged'          => 'タスク修正',
'pm.taskreopened'         => 'タスク再オープン',
'pm.depadded'             => '依存追加',
'pm.depremoved'           => '依存削除',
'pmrequest'               => 'プロジェクト管理者への要望',
'pmrequestdenied'         => 'プロジェクト管理者への要望の拒否',
'newassignee'             => '新しい担当者',
'revdepadded'             => '逆依存追加',
'revdepaddedremoved'      => '逆依存削除',
'assigneeadded'           => '担当者追加',
'addusergroup'            => '指定ユーザをこのグループに追加',
'groupmembers'            => 'グループメンバ',
'deleteuser'              => 'このユーザを削除',
'userdeleted'             => 'ユーザが削除されました。',
'autoassign'              => 'カテゴリ所有者にタスクを自動割り当て',
'ssl'                     => 'SSL',
'updatewrong'             => '更新確認機能が有効に設定されていますが、更新サーバに接続中にエラーが発生しました。
あなたのホストが外への接続を許可していないか、ネットワークの問題によるエラーです。
FlysprayのWebサイトに行き、現在稼働しているのが最新バージョンかどうか確認してください。',
'deleteproject'           => 'このプロジェクトを削除して内容を指定プロジェクトに移動',
'projectdeleted'          => 'プロジェクトが削除されました。',
'feedforall'              => '全プロジェクトに対するフィード',
'usercreated'             => 'ユーザを登録',
'userdeleted'             => 'ユーザを削除',
'created'                 => '登録',
'deleted'                 => '削除',
'userid'                  => 'ユーザID',
'editassignments'         => '割り当てを変更',
'preview'                 => 'プレビュー',
'anyprogress'             => '全進捗',
'tasksrelated'            => 'このタスクに関連しているタスク',
'duplicatetasks'          => 'このタスクと重複しているタスク',
'databasemodfailed'       => 'データベースの更新に失敗しました。権限がないからかもしれません。',
'frequency'               => '頻度',
'newuserregistered'       => '新規ユーザがFlysprayに登録されました。登録されたユーザの詳細は以下の通りです。',
'newuserregisterednotify' => '新規ユーザが登録されました',
'notify_registration'     => '新規ユーザ登録を管理者に通知',
'textversion'             => 'テキスト版',
'onlyprimary'             => '依存されていないタスク',
'switch'                  => '切り替え',
'max'                     => '最大',
'dates'                   => '日付',
'selectduedatefrom'       => '対応予定日',
'selectduedateto'         => 'から',
'selectsincedatefrom'     => '更新日',
'selectsincedateto'       => 'から',
'selectdate'              => '日付選択',
'selectopenedfrom'        => 'オープン日',
'selectopenedto'          => 'から',
'selectclosedfrom'        => 'クローズ日',
'selectclosedto'          => 'から',
'startat'                 => '開始日',
'hasattachment'           => '添付ファイルがあるタスク',
'private'                 => '非公開',
'watching'                => '監視中',
'alreadyvotedthistask'    => '投票済み',
'alreadyvotedthisday'     => '本日投票済み',
'visibility'              => '公開/非公開',
'public'                  => '公開',
'leaveemptyauto'          => 'パスワードを自動生成する場合は空欄にしてください。',
'novalidemail'            => '有効なE-mailアドレスが入力されていません。',
'novalidjabber'           => '有効なJabber IDが入力されていません。',
'missingrequired'         => '入力されていない必須入力欄があります。',
'entervalidusername'      => '有効なユーザ名と氏名を入力してください。',
'couldnotaddusernotif'    => 'ユーザを通知一覧に追加できませんでした。',
'defaulttask'             => 'デフォルトのタスク詳細',
'all'                     => 'すべて',
'events.useraddedtoassignees' => '担当者追加',
'vote(s)'                 => '票',
'eventlog'                => 'イベントログ',
'assignmentchanged'       => '担当者変更',
'detailedinfo'            => '詳細情報',
'All'                     => 'すべて',
'tasksireported'          => '自分が報告したタスク',
'recentlyopened'          => '最近登録されたタスク',
'stats'                   => '統計',
'totaltasks'              => '全タスク',
'mostwanted'              => '最要望タスク',
'defaultentry'            => '初期表示画面',
'toplevel'                => '概要',
'overview'                => '概要',
'error#'                  => 'エラー番号',
'error1'                  => '添付ファイルを参照する権限がありません。',
'error3'                  => '繰り返し操作です。メインページに転送します。',
'error4'                  => '管理する権限がありません。',
'error5'                  => 'そのユーザはこのFlyspray上に存在しません。',
'error6'                  => '無効な運用管理領域です.',
'error7'                  => 'ログインに失敗しました。ユーザ名またはパスワードが間違っています。',
'error71'                 => '繰り返しログインに失敗したので、アカウントは %d 分間ロックされます。',
'error8'                  => 'ユーザ名またはパスワードが入力されていません。',
'error9'                  => 'タスクが存在しないか、そのタスクを参照する権限がありません。',
'error10'                 => 'タスクが存在しません。',
'error101'                => 'タスクを参照する権限がありません。',
'error102'                => 'タスクを参照する権限がありません。ログインすれば参照できるかもしれません。',
'error11'                 => 'このコメントを修正する権限がありません。',
'error12'                 => 'マジックキーが正しくありません。通知メッセージに書かれた内容を確認してください。',
'error13'                 => '未ログインユーザにプロフィールはありません。',
'error14'                 => '新規グループを登録する権限がありません。',
'error15'                 => '新規タスクを登録する権限がありません。',
'error16'                 => 'あなたはプロジェクト管理者ではありません。',
'error17'                 => '無効なプロジェクト管理領域です。',
'error18'                 => '無効なマジックURLです。',
'error19'                 => 'そのユーザはこのFlyspray上に存在しません。',
'error20'                 => '無効なデータベース変更です。',
'error21'                 => '1通もしくは複数のE-mailが送信できませんでした。設定を確認してください。',
'error22'                 => 'ユーザ登録が許可されていません。',
'error23'                 => 'ユーザまたはグループにログイン許可がありません。',
'error24'                 => 'dot 実行環境も dot 公開サーバも設定されていません。',
'error25'                 => 'ロードマップは特定のプロジェクトに対してだけ存在します。',
'done'                    => '完了',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'プロジェクトを削除できません。',
'GMT'                     => 'GMT',
'timezone'                => '時間帯',
'accept'                  => '承諾',
'reasonfordeinal'         => '拒否の理由',
'pruneclosedlinks'        => '切れたリンクを除去',
'pruneclosedtasks'        => 'クローズタスクを除去',
'pagegenerated'           => 'ページと画像の生成に %d 秒かかりました。',
'pruninglevel'            => '除去レベル',
'lastuser'                => '最後のユーザは削除できません。',
'allprivate'              => 'すべてのプロジェクトが非公開になっています。',
'deletegroup'             => 'このグループを削除してユーザを指定グループに移動',
'parent'                  => '親カテゴリ',
'ordertip'                => 'この項目を一覧に表示するときの順番',
'showtip'                 => 'この項目を一覧に表示',
'deletetip'               => 'この項目を削除',
'del'                     => '削除',
'request1'                => 'タスクのクローズの要望が出されています。',
'request2'                => 'タスクの再オープンの要望が出されています。',
'allpriorities'           => '全優先度',
'noroadmap'               => 'ロードマップはありません(「未来」と設定されたバージョンがプロジェクトにありません)。',
'expand'                  => '詳細を開く',
'collapse'                => '詳細を閉じる',
'expandall'               => 'すべての詳細を開く',
'collapseall'             => 'すべての詳細を閉じる',
'minpwsize'               => 'パスワードは5文字以上です。',
'passwordtoosmall'        => 'パスワードが短すぎます。',
'accountwaslocked'        => '繰り返しログインに失敗したので、このアカウントはロックされていました。',
'failedattempts'          => '%d 回のログイン失敗がありました。',
'groupnotexist'           => '選択されたグループはこのプロジェクトに存在しません。',
'searchindetails'         => '詳細内も検索',
'showasassignees'         => '担当者欄に表示',
'find'                    => '検索',
);

?>
