<?php

$translation = array(
'edituser'		=>'Уреди корисника',
'username'		=>'Корисничко име',
'realname'		=>'Стварно име',
'emailaddress'		=>'Емајл адреса',
'jabberid'		=>'Jabber адреса',
'notifytype'		=>'Тип обавештења',
'group'			=>'Група',
'accountenabled'	=>'Пријава дозвољена',
'updatedetails'		=>'Ажурирај детаље',
'setglobally'		=>'Ова повластица постављена је глобално.',
'usergroupmanage'	=>'Управљање корисницима и групама',
'newuser'		=>'Регистровање новог корисника',
'newgroup'		=>'Креирање нове групе',
'yes'			=>'Да',
'no'			=>'Не',
'editgroup'		=>'Уреди групу',
'groupname'		=>'Назив групе',
'description'		=>'Опис',
'admin'			=>'Админ група',
'opennewtasks'		=>'Креирај нови задатак',
'modifytasks'		=>'Измени постојећи задатак',
'addcomments'		=>'Додај коментар',
'attachfiles'		=>'Придружи фајл',
'vote'			=>'Гласај',
'groupenabled'		=>'Чланови се могу пријављивати',
'groupopen'		    =>'Чланови се могу пријављивати',
'tasktypelist'		=>'Листа типова задатака',
'categorylist'		=>'Листа категорија',
'oslist'		=>'Листа оперативних система',
'resolutionlist'	=>'Ресолутионс лист',
'versionlist'		=>'Листа верзија',
'severitylist'		=>'Листа важности',
'listnote'		=>'Напомена:  Дечекирање колоне "Приказ" може изменити неке задатке када су у режиму измене.  Промена поља у колони "Име" ће се односити на све задатке, где се помиње промена. Слогови који се не могу обрисати заштићени су јер су потребни за исправно функционисање задатака.',
'name'			=>'Име',
'order'			=>'Редослед',
'back'			=>'Назад',
'text'			=>'Текст',
'highlight'		=>'Нагласи',
'show'			=>'Приказ',
'owner'			=>'Власник',
'selectowner'		=>'Избор власника',
'update'		=>'Ажурирај',
'addnew'		=>'Додај нови',
'flysprayprefs'		=>'Flyspray повластице',
'projecttitle'		=>'Наслов пројекта',
'baseurl'		=>'Базни URL за ову инсталацију',
'replyaddress'		=>'Обавештења реплицирај на емајл адресу',
'themestyle'		=>'Тема / стил',
'language'		=>'Језик',
'anonview'		=>'Дозволи непријављеним корисницима да гледају задатке',
'allowanon'		=>'Дозволи непријављеним корисницима да креирају задатке',
'never'			=>'Никад',
'anonymously'		=>'Анонимно',
'afterregister'		=>'Само након регистровања',
'spamproof'		=>'Омогући потврдни коод за регистрацију нових корисника',
'anongroup'		=>'Група за ново-регистрованог корисника',
'groupassigned'		=>'Чланови ове групе могу додељивати задатке',
'forcenotify'		=>'Наложи обавештења о задацима',
'neversend'		=>'да се никад не шаљу',
'userchoose'		=>'да сваки корисник може изабрати',
'email'			=>'Емајл',
'jabber'		=>'Jabber адреса',
'defaultcatowner'	=>'Подразумевани власник категорије',
'noone'			=>'Ниједан',
'jabbernotify'		=>'Jabber обавештења',
'jabberserver'		=>'Сервер',
'jabberport'		=>'Порт',
'jabberuser'		=>'Корисничко име',
'jabberpass'		=>'Корисничка лозинка',
'saveoptions'		=>'Сачувај',
'editcomment'		=>'Уреди коментар',
'commentby'		=>'Коментарисао',
'saveeditedcomment'	=>'Сними измењени коментар',
'projectprefs'		=>'Могућности над пројектима',
'pagetitle'		=>'Наслов стране',
'defaultproject'	=>'Подразумевани пројекат',
'projectlists'		=>'Листа пројеката',
'showlogo'		=>'Прикажи наслов лого-а',
'intromessage'		=>'Уводна порука',
'isactive'		=>'Пројекат је активан',
'createproject'		=>'Креирај нови пројекат',
'nopermission'		=>'Немате дозволу да користите ову страну!',
'listordertip'		=>'Редослед ће бити приказан у листи',
'listshowtip'		=>'Прикажи ову ставку у листи',
'categoryownertip'	=>'Ово лице ће примати обавештења када се отвори задатак у овој категорији',
'categoryparenttip'	=>'Тhe parent category this new one  will fall under',
'notsubcategory'	=>'Ниједна (врховна категорија!)',
'showinlineimages'	=>'Прикажи слику прикључка у линији',
'dateformat'		=>'Формат датума (%d, %m, %y, или %Y)',
'dateformat_extended'	=>'Детаљни формат датума',
'cache_feeds'		=>'Кеширање података',
'no_cache'		=>'Нема кеширања',
'cache_disk'		=>'Кеширање на диску',
'cache_db'		=>'Кеширање у ДБ',
'subcategoryof'		=>'Подкатегорија категорије',
'visiblecolumns'	=>'Колоне заглавља приказане у таск листи',
'tense'			=>'Верзија',
'listtensetip'		=>'Прошла, садашња, или будућа',
'past'			=>'Прошла',
'present'		=>'Садашња',
'future'		=>'Будућа',
'oldpass'		=>'Стара лозинка',
'nooldpass'		=>'Стара лозинка није подешена',
'oldpasswrong'		=>'Стара лозинка је погрешна',
'changepass'		=>'Нова лозинка',
'confirmpass'		=>'Потврди нову лозинку',
'projectmanager'	=>'Руководилац пројеката',
'viewtasks'		=>'Увид задатака',
'modifyowntasks'	=>'Измена сопствених задатака',
'modifyalltasks'	=>'Измена задатака који нису у власништву',
'viewcomments'		=>'Увид коментара',
'editcomments'		=>'Измена коментара',
'deletecomments'	=>'Брисање коментара',
'viewattachments'	=>'Увид прикључка',
'createattachments'	=>'Направи прикључење',
'deleteattachments'	=>'Обриши прикључке',
'viewhistory'		=>'Увид промена',
'closeowntasks'		=>'Затвори сопствене задатке',
'closeothertasks'	=>'Затвори задатке који нису у власништву',
'assigntoself'		=>'Додели задатак себи, ако није већ додељен',
'assignotherstoself'	=>'Додели друге задатке себи',
'viewreports'		=>'Увид дневника догађаја',
'othersview'		=>'Дозволи сваком да гледа овај пројекат',
'usersandgroups'	=>'Корисници и групе',
'globalgroup'		=>'Општа група',
'globalgroups'		=>'Опште групе',
'defaultglobalgroup'	=>'Подразумевана општа група за нове кориснике',
'addtogroup'		=>'Додај у групу',
'moveuserstogroup'	=>'Премести корисника у групу',
'nogroup'		=>'Нема група - Избачене из пројекта',
'eventdesc'		=>'Опис догађаја',
'requestedby'		=>'Тражен од',
'daterequested'		=>'Датум захтева',
'closetask'		=>'Затвор задатак',
'reopentask'		=>'Поново отовори задатак',
'applymember'		=>'Примени за чланове пројекта',
'forcurrentproj'	=>'За текући пројекат',
'lostpw'		=>'Проналажење изгубљене лозинке',
'lostpwexplain'		=>'Унесите Ваше корисничко име за слање линка за промену лозинке.  Ово ће бити сачувано у Ваш профил обавештења.',
'sendlink'		=>'Пошаљи линк',
'savenewpass'		=>'Сачувај нову лозинку',
'anonreg'		=>'Дозволи регистрацију нових корисника',
'allowanonopentask'	=>'Дозволи непријављеним корисницима да отварају задатке',
'editglobalgroup'	=>'Измени општу групу',
'editgroupforproj'	=>'Измени пројектну групу',
'notshownforadmin'	=>'Дозволе нису приказане за администраторску групу. Непотребно их је мењати.',
'general'		=>'Опште',
'userregistration'	=>'Корисничка регистрација',
'notifications'		=>'Обавештења',
'resetoptions'		=>'Поништи опције',
'preferences'		=>'Општа подешавања',
'tasktypes'		=>'Типови задатака',
'resolutions'		=>'Разрешења',
'categories'		=>'Категорије',
'operatingsystems'	=>'Оперативни системи',
'versions'		=>'Верзије',
'admintoolboxlong'	=>'Администраторске алатке',
'newproject'		=>'Нови пројекат',
'delete'		=>'Обриши',
'listdeletetip'		=>'Обриши ову ставку из листе',
'lookandfeel'		=>'Изглед и осећај',
'globaltheme'		=>'Општа тема',
'emailnotify'		=>'Емаjл обавештења',
'fromaddress'		=>'Шаље са адресе',
'smtpserver'		=>'SMTP сервер',
'smtpuser'		=>'SMTP корисничко име',
'smtppass'		=>'SMTP лозинка',
'addrewrite'		=>'Користи замену адресе',
'usereminderdaemon'	=>'Омогући позадинску услугу (deamon) за подсетник',
'tasksperpage'		=>'Задатака по страни листе задатака',
'addtoassignees'	=>'Додај се сам листи додељених',
'taskstatuses'		=>'Статуси задатака',
'canvote'		=>'Може гласати за задатак',
'loginsuccessful'	=>'Пријава успешна.',
'youareloggedout'	=>'Ви сте се одјавили.',
'waitwhiletransfer'	=>'Молим сачекајте пренос...',
'clicknowait'		=>'Кликни овде, ако не желиш да чекаш.',
'accountdisabled'	=>'Ваш налог је искључен. Контактирајте администратора система.',
'task'			=>'Задатак',
'edittask'		=>'Измени овај задатак',
'openedby'		=>'Отворен од',
'editedby'		=>'Последњи мењао',
'tasktype'		=>'Тип задатка',
'category'		=>'Категорија',
'status'		=>'Статус',
'assignedto'		=>'Додељен',
'operatingsystem'	=>'Оперативни систем',
'severity'		=>'Важност',
'reportedversion'	=>'Пријављена верзија',
'dueinversion'		=>'Очекује се у верзији',
'undecided'		=>'Неодређено',
'percentcomplete'	=>'% извршења',
'details'		=>'Детаљи',
'savedetails'		=>'Сачувај детаље',
'canceledit'		=>'Откажи измену',
'anonymous'		=>'Непознати пошиљалац',
'complete'		=>'завршено',
'closedby'		=>'Затворено од стране',
'reasonforclosing'	=>'Разлог затварања:',
'reopenthistask'	=>'Поново отовори овај задатак',
'comments'		=>'Коментари',
'attachments'		=>'Прикључци',
'relatedtasks'		=>'Повезани задаци',
'edit'			=>'Измени',
'addcomment'		=>'Додај коментар',
'fileuploadedby'	=>'Датотека послата од стране ',
'uploadafile'		=>'Прикључи датотеку',
'uploadnow'		=>'Пошаљи сада!',
'thesearerelated'	=>'Ови задаци су у вези са овим задатком',
'remove'		=>'Избаци',
'addnewrelated'		=>'Додај нови задатак који је с овим у вези',
'add'			=>'Додај!',
'otherrelated'		=>'Други задаци с којима је овај у вези',
'receivenotify'		=>'Ови корисници ће примати детаљна обавештења када се задатак измени.',
'addusertolist'		=>'Додај корисника овој листи',
'addtolist'		=>'Додај у листу',
'addmyself'		=>'Сам се додај овој листи',
'removemyself'		=>'Избаци се сам из ове листе',
'theseusersnotify'	=>'Ови корисници ће примати детаљна обавештења увек када се овај задатак измени.',
'attachedtoproject'	=>'Прикључен пројекту',
'reminders'		=>'Подсетник',
'system'		=>'Систем',
'remindthisuser'	=>'Подсети овог корисника',
'thisoften'		=>'То се често',
'startafter'		=>'Сачекајте пре покретања подсетника',
'hours'			=>'Сат(и)',
'days'			=>'Дан(а)',
'weeks'			=>'Недеља(е)',
'addreminder'		=>'Додај подсетник',
'defaultreminder'	=>'Ово је подсетник који ће пратити селедеће Flyspray задатке:',
'message'		=>'Порука',
'closed'		=>'Затворен',
'filename'		=>'Назив датотеке:',
'date'			=>'Датум',
'filesize'		=>'Величина датотеке:',
'closurecomment'	=>'Додатно појашњење о разлогу затварања:',
'history'		=>'Историја',
'nohistory'		=>'Историја није доступна.',
'eventdate'		=>'Датум',
'user'			=>'Корисник',
'event'			=>'Догађај',
'fieldchanged'		=>'Промењено је',
'taskopened'		=>'Задатак отворен',
'taskreopened'		=>'Задатак поново отворен',
'taskclosed'		=>'Задатак затворен',
'commentadded'		=>'Додат коментар',
'commentedited'		=>'Коментар измењен',
'commentdeleted'	=>'Коментар обрисан',
'attachmentadded'	=>'Прикључак додат',
'attachmentdeleted'	=>'Прикључак обрисан',
'taskedited'		=>'Детаљи задатка измењени',
'notificationadded'	=>'Корисник додат листи обавештења',
'notificationdeleted'	=>'Корисник избачен из листе обавештења',
'relatedadded'		=>'Повезани задатак додат',
'relateddeleted'	=>'Повезани задатак избачен',
'taskassigned'		=>'Задатак додељен',
'taskreassigned'	=>'Задатак преусмерен на',
'assignmentremoved'	=>'Додела избрисана',
'summary'		=>'Кратак опис',
'addedasrelated'	=>'Задатак додат листи повезаних',
'deletedasrelated'	=>'Задатак избачен из листе повезаних',
'reminderadded'		=>'Додат подсетник',
'reminderdeleted'	=>'Подсетник избачен',
'priority'		=>'Приоритет',
'previousvalue'		=>'Претходна вредност',
'newvalue'		=>'Нова вредност',
'selectareason'		=>'Избор разлога',
'assigntome'		=>'Додели мени',
'reopenrequest'		=>'Захтев за поновно отварање',
'requestclose'		=>'Захтев за затварање',
'ownershiptaken'	=>'Корисниково власништво',
'closerequestmade'	=>'Затражено затварање задатка',
'reopenrequestmade'	=>'Затражено поновно отварање задатка',
'taskdependson'		=>'Овај задатак зависи од:',
'taskblocks'		=>'Овај задатак блокира ове од затварања',
'depadded'		=>'Додата зависност',
'depaddedother'		=>'Овај задатак додаје као зависност',
'depremoved'		=>'Зависност уклоњена',
'depremovedother'	=>'Овај задатак је избачен из листе зависних задатака',
'showdetailserror'	=>'Овај задатак не постоји, или немате дозоволу да га погледате.',
'makeprivate'		=>'направи га приватним',
'makepublic'		=>'направи га јавним',
'taskmadeprivate'	=>'Задатак је сада приватан',
'taskmadepublic'	=>'Приватност уклоњена! Задатак је сада јаван',
'confirmdeletecomment'	=>'Сигурни сте да желите обрисати овај комнтар? %s',
'confirmdeleteattach'	=>'Сигурни сте да желите обрисати овај прикључак?',
'selectedhistory'	=>'Приказ изабраних детаља историје',
'showallhistory'	=>'Прикажи језичак пуне историје поново',
'hidethis'		=>'Сакриј ову зону поново',
'mark100'		=>'Означи задатак 100% завршеним',
'watchtask'		=>'прати промене',
'stopwatching'		=>'заустави праћење',
'commentlink'		=>'Линк ка коментару',
'submitreq'		=>'Пошаљи захтев',
'reasonforreq'		=>'Разлог забране',
'pmreqdenied'		=>'Руководилац пројектима је забранио захтев',
'taskpendingreq'	=>'Руководилац пројеката тренутно нешто ради. Видите на "Историја" језичку шта се догађа.',
'previoustask'		=>'Претходни задатак',
'nexttask'		=>'Наредни задатак',
'duedate'		=>'Рок',
'attachnoperms'		=>'Постоје прикључци за овај коментар, али Ви немате дозволу за њихов увид.',
'open'			=>'Отвори',
'depgraph'		=>'Увид графичког приказа зависности',
'reset'			=>'Ресет',
'selectusers'		=>'Избор корисника...',
'addmetoassignees'	=>'Додај ме листи додељених',
'addedtoassignees'	=>'Корисник додат листи додељених',
'dependencygraph'	=>'Графички приказ зависности',
'attachanotherfile'	=>'Прикачи још неку датотеку',
'OK'			=>'У реду',
'addvote'		=>'Дај глас',
'notifyfromfs'		=>'Обавештење од Flyspray система',
'autogenerated'		=>'ОВО ЈЕ АУТОМАТСКИ ГЕНЕРИСАНА ПОРУКА! НЕ ОДГОВАРАЈ!',
'forward'		=>'Напред',
'previous'		=>'Претходни',
'next'			=>'Следећи',
'first'			=>'Први',
'last'			=>'Последњи',
'page'			=>'Страна %d од %d',
'search'		=>'Тражи',
'alltasktypes'		=>'Сви типови задатака',
'allseverities'		=>'Све важности',
'alldevelopers'		=>'Сви програмери',
'notyetassigned'	=>'Није ипак додељен',
'allcategories'		=>'Све категорије',
'allstatuses'		=>'Сви статуси',
'allopentasks'		=>'Сви отоворени задаци',
'sortthiscolumn'	=>'Сорт по овој колони',
'id'			=>'Бр.',
'project'		=>'Пројекат',
'dateopened'		=>'Отворен',
'progress'		=>'Напредак у раду',
'searchthisproject'	=>'Претражи овај пројекат за',
'dueanyversion'		=>'Очекује се у ма којој верзији',
'anyversion'		=>'Пријављен у ма којој верзији',
'dueversion'		=>'Очекује се у верзији',
'lastedit'		=>'Поседње измењен',
'os'			=>'Оперативни систем',
'reportedin'		=>'Пријављен у',
'taskrange'		=>'Приказ задатака %d - %d од %d',
'noresults'		=>'Ваша претрага није дала резлтате.',
'takeaction'		=>'Примени изабрано',
'watchtasks'		=>'Праћење изабраних задатака',
'stopwatchingtasks'	=>'Прекини праћење изабраних задатака',
'assigntaskstome'	=>'Додели ми изабрани задатак',
'dueby'			=>'Доспева',
'dueanytime'		=>'Било када',
'selectduedate'		=>'Избор датума доспећа',
'toggleselected'	=>'Промена избора',
'due'			=>'Рок',
'assignedtome'		=>'Додељен мени',
'tasklist'		=>'Листа задатака',
'dateclosed'		=>'Датум затварања',
'advanced'		=>'Још услова за претрагу',
'searchcomments'	=>'Тражи у коментарима',
'searchforall'		=>'Тражи за све речи',
'anonusers'		=>'Непознати корисник',
'miscellaneous'		=>'Разно',
'users'			=>'Корисници',
'taskproperties'	=>'Својства задатка',
'selectsincedate'	=>'Изабери измене од',
'changedsince'		=>'Измене од',
'updatefs'		=>'Молимо ажурирајте Ваш Flyspray.',
'currentversion'	=>'Ваша транутна верзија је',
'latestversion'		=>', а последња верзија је',
'hidemessage'		=>'(подсети ме касније)',
'saveas'		=>'Сачувај претрагу као',
'nosearches'		=>'Нема сачуваних претрага',
'saving'		=>'Снимање...',
'votes'			=>'Гласова',
'allclosedtasks'	=>'Сви затворени задаци',
'password'		=>'Лозинка',
'login'			=>'Пријави се',
'rememberme'		=>'Подсети ме',
'lostpassword'		=>'Изгубили сте лозинку?',
'lostpwforfs'		=>'Изгубили стe лозинку за Flyspray',
'lostpwmsg1'		=>'Здраво!

Изгубио/ла сам моју лозинку за Flyspray на',
'lostpwmsg2'		=>', молим Вас пошаљите ми нову лозинку.

Корисничко име: ',
'regards'		=>'

Поздрав од ',
'yourusername'		=>' Ваше корисничко име ',
'locale'		=>'en-AU',
'filenotexist'		=>'Датотека не постоји, или немате доволу да јој приступите.',
'showtask'		=>'Прикажи задатак',
'now'			=>'Сада',
'go'			=>'Иди!',
'opentaskanon'		=>'Отвори нови задатак као непознат',
'register'		=>'Региструј се',
'addnewtask'		=>'Додај нови задатак',
'reports'		=>'Дневник догађаја',
'editmydetails'		=>'Измени моје детаље',
'logout'		=>'Одјави се',
'disabledaccount'	=>'Ваша пријава је онемогућена!<br />Одмах ћете бити одјављени...',
'poweredby'		=>'Powered by Flyspray',
'projects'		=>'Пројекти',
'allprojects'		=>'Сви пројекти',
'selectproject'		=>'за пројекат:',
'tasksall'		=>'Сви задаци',
'tasksassigned'		=>'Задаци додељени мени',
'tasksreported'		=>'Задаци које сам ја пријавио',
'taskswatched'		=>'Пратим задатак',
'mysearch'		=>'Моја претрага',
'admintoolbox'		=>'Администраторске алатке',
'manageproject'		=>'Управљање пројектима',
'permissions'		=>'Види дозволе',
'hide'			=>'Сакриј',
'pendingreq'		=>'Чека се за ПМ захтев',
'errorpage'		=>'Flyspray не може приказати ову страну.
Можда сте тражили задатак који не постоји, или немате
дозволу да видите страницу коју сте желели.<br /><br />
Можда сте покушали да користите погрешан линк у интеракцији са базом података.
Ако је то тачно размислите мало о својим поступцима и молимо Вас да то не чините поново.',
'permissionsforproject'	=>'Дозволе за ',
'switchto'		=>'Пређи на',
'lastsearch'		=>'Последња претрага',
'modify'		=>'Измени',
'noticefrom'		=>'Обавештење од',
'hasopened'		=>'имате ОТВОРЕН НОВИ Flyspray задатак и додељен је Вама:',
'moreinfonew'		=>'Можете наћи Више информација о овој грешки на  Flyspray страни:',
'newtaskcategory'	=>'Нови Flyspray задатак биће отоворен у овој категорији',
'categoryowner'		=>'Ви добијате ово јер сте наведени као власник категорије.',
'tasksummary'		=>'Резиме задатка:',
'newtaskadded'		=>'Ваш нови задатак је додат.',
'summaryanddetails'	=>'Потребно је поунити оба поља, "Кратак опис" и "Детаљи".',
'goback'		=>'Иди назад.',
'messagefrom'		=>'Ова порука је од Flyspray система за праћење грешака на ',
'hasjustmodified'	=>'сте изменили следећи задатак.',
'changedfields'		=>'Измењена поља имају префикс (**)',
'moreinfomodify'	=>'Можете имати више информација о овом задатку следећи овај линк:',
'nolongerassigned'	=>'Следећи задатак више није додељен Вама.  Сада је додељен',
'hasassigned'		=>'имате додељен следећи Flyspray задатак:',
'taskupdated'		=>'Задатак је измењен.',
'hasclosedassigned'	=>'је затворен следећи Flyspray задатак који Вам је додељен:',
'unassigned'		=>'Недодељен',
'hasclosed'		=>'је затворен следећи задатак.',
'youonnotify'		=>'Ви добијате ово јер сте на листи за обавештавање.',
'taskclosedmsg'		=>'Задатак је затворен.',
'returntotask'		=>'Повратак на детаље задатка',
'backtoindex'		=>'Повраћај на листу задатака',
'noclosereason'		=>'Нисте изабрали разлог за затварање тог задатка.',
'hasreopened'		=>'поново је отворен следећи Flyspray задатак који сте затворили:',
'taskreopenedmsg'	=>'Задатак је поново отворен.',
'backtotask'		=>'Врати се на задатак.',
'commentaddedmsg'	=>'Коментар је дат.',
'commenttoassigned'	=>'додат је следећи коментар задатку који Вам је додељен:',
'commenttotask'		=>'дат је следећи коментар овом задатку.',
'nocommententered'	=>'Ви заиста треба да унесете коментар пре наго што кликнете на дугме.',
'fillinfields'		=>'Нисте попунили сва поља.',
'notcurrentpass'	=>'То није Ваша тренутна лозинка!',
'passchanged'		=>'Ваша лозинка је промењена.',
'closewindow'		=>'Можете сада затворити овај прозор.',
'passnomatch'		=>'Ваша нова лозинка није иста',
'usernametaken'		=>'То корисничко име је ваћ заузето! Мораћете да унесете друго.',
'newusercreated'	=>'Нови корисникчки налог је креиран.',
'accountcreated'	=>'Ваш налог је креиран.',
'newuserwarning'	=>'Имајте у виду да Ваш налог треба да буде одобрен од стране админиистратора система. Ако не можете да се пријавите то је разлог зашто не можете.',
'nomatchpass'		=>'Лозинка не одговара.',
'confirmwrong'		=>'Потврдни коод је погрешан!',
'formnotcomplete'	=>'Форма није цела попуњена.',
'formnotnumeric'	=>'Унешени податак није нумерички!',
'groupnametaken'	=>'Име групе је већ заузето.',
'newgroupadded'		=>'Нова група додата.',
'optionssaved'		=>'Flyspray опције сачуване',
'hasuploaded'		=>'отпремили сте датотеку, као прикључак, задатку који је додељен:',
'hasattached'		=>'прикачена је датотека следећем задатку.',
'fileuploaded'		=>'Датотека је отпремљена.',
'fileerror'		=>'Дошло је до грешке у отпремању Ваше датотеке. Можда су дозволе над <i>прикљученим/</i> директоријумима погрешне.',
'contactadmin'		=>'Контактирајте администратора овог пројекта.',
'selectfileerror'	=>'Нисте изабрали датотеку.',
'userupdated'		=>'Подаци о кориснику су измењени',
'realandemail'		=>'Нисте попунили поља "Стварно име" и/или "Eмаjл адреса".',
'groupupdated'		=>'Дефиниција група измењна.',
'groupanddesc'		=>'Нисте унели име групе.',
'fillallfields'		=>'Молим попуните сва поља.',
'listPmustN'		=>'Поредак ће бити нумерички.',
'listupdated'		=>'Листа је ажурирана!',
'listitemadded'		=>'Додат нови слог у листи.',
'relatedaddedmsg'	=>'Повезани задатак је додат листи.',
'relatederror'		=>'Овај задатак је већ у вези са задацима из листе повезаних.',
'relatedremoved'	=>'Повезани задатак је избачен из листе.',
'notifyadded'		=>'Корисник је додат листи обавештавања.',
'notifyerror'		=>'Корисник је већ у листи обавештавања за овај задатак.',
'notifyremoved'		=>'Корисник је избачен из листе обавештавања.',
'editcommentsaved'	=>'Измењени коментар је сачуван.',
'commentdeletedmsg'	=>'Коментар је обрисан.',
'gotonewtask'		=>'Иди на новонаправљени задатак',
'projectcreated'	=>'Ваш нови пројекат је креиран. Можете га сада подесити у зони за управљање пројектима.',
'customiseproject'	=>'Подеси овај пројекат',
'projectupdated'	=>'Подешавања пројекта измењена',
'emptytitle'		=>'Поље за назив пројекта нисте унели!  Молимо унесите га.',
'loginbelow'		=>'Сада можете покушати да се пријавите.',
'attachmentdeletedmsg'	=>'Прикључак је обрисан',
'reminderaddedmsg'	=>'Ваш подсетник је додат.',
'reminderdeletedmsg'	=>'Ваш изабрани подсетик је обрисан.',
'flyspraytask'		=>'Flyspray задатак',
'fieldsmissing'		=>'Нека поља не садрже податке, или су подаци погрешни.',
'relatedinvalid'	=>'Не постоји такав задатак.',
'relatedproject'	=>'Овај задатак је прикључен другом пројекту. Додај везу у сваком случају',
'addanyway'		=>'Додај у сваком случају',
'cancel'		=>'Откажи',
'alreadyedited'		=>'Овај задатак је изменио неко други пре него што сте сачували промене. Да ли још желите да сачувате промене?',
'saveanyway'		=>'Сачувај моје промене у сваком случају',
'nouserselected'	=>'Корисник није изабран. Изаберите најмање једног корисника пре него што покушате поново.',
'groupswitchupdated'	=>'Корисничка група је измењена успешно.',
'takenownershipmsg'	=>'Овај задатак је сада додељен Вама.',
'adminrequestmade'	=>'Ваш захтев је сада послат руководиоцу пројекта.',
'newdepnotify'		=>'Нова зависност је додата следећем задатку:',
'dependadded'		=>'Зависност задатка додата',
'dependaddfailed'	=>'Дошло је до грешке при додавању зависности. Проверите да ли задатак постоји и да ли се можда узајамно не блокирају.',
'depremovedmsg'		=>'Зависност задатака је уклоњена',
'newdepis'		=>'Нова зависност је',
'magicurlsent'		=>'Порука је послата на Вашу адресу за обавештења. Она садржи адресу линка који ће Вас одвести на страницу где ћете довршити овај задатак.',
'changefspass'		=>'Промена Flyspray лозинке',
'magicurlmessage'	=>'Молимо следите следећи линк испод за промену Ваше Flyspray лозинке:',
'erroronform'		=>'Дошло је до проблема у слању Ваше форме',
'addressused'		=>'Ова адреса се користи да се региструје Flyspray налог. Ако не очекујете ову поруку, молимо игноришите је и обришите. Следите следећи link да довршите регистрацију:',
'confirmcodeis'		=>'Ваш потврдни коод је:',
'codesent'		=>'Ваш потврдни коод је послат. Молимо следите инструкције садржане у поруци.',
'codenotsent'		=>'Не може се послати Ваш коод, молимо покушајте касније.',
'taskmadeprivatemsg'	=>'Овај задатак је начињен приватним',
'taskmadepublicmsg'	=>'Овај задатак је начињен поново јавним',
'realandnotify'		=>'Потребно је попунити поља "Стварно име", "Емаjл адреса", или "Jabber адреса".',
'pmreqdeniedmsg'	=>'Захтев одбијен од стране рукуводиоца пројекта',
'massopsuccess'		=>'Масовно извођење операција успешно - дозволе су постављене',
'usernotexist'		=>'Корисник не постоји у овој Flyspray инсталацији',
'commentattachperms'	=>'Не можете обрисати коментар, јер немате дозволу за брисање приклучења',
'voterecorded'		=>'Ваш глас је упамћен',
'votefailed'		=>'Ваш глас неће бити додат овог пута.',
'createnewgroup'	=>'Креирај нову групу',
'requiredfields'	=>'Обавезна поља су означена са',
'addthisgroup'		=>'Додај ову групу',
'createnewproject'	=>'Креирај нови пројекат',
'addnewproject'		=>'Додај нови пројекат',
'htmlallowed'		=>'ХТМЛ коод је дозвољен',
'createthisproject'	=>'Креирај овај пројекат',
'inlineimages'		=>'Прикажи прикључену слику у линији',
'createnewtask'		=>'Креирање новог задатка у пројекту:',
'addanother'		=>'Додавање још једног задатка након овог',
'addthistask'		=>'Додај овај задатак',
'notifyme'		=>'Обавести ме о било каквој промени овог задатка',
'newtask'		=>'Нови задатак',
'attachafile'		=>'Прикачи датотеку',
'registernewuser'	=>'Регистровање новог кориснка',
'none'			=>'Ништа',
'registeraccount'	=>'Регистровање овог налога',
'both'			=>'Обадва',
'notifyfrom'		=>'Обавештење од ',
'donotreply'		=>'ОВО ЈЕ АУТОМАТСКА ПОРУКА, НЕ ОДГОВАРАЈТЕ НА ЊУ!',
'disclaimer'		=>'Примили сте ову поруку пошто је затражена од Flyspray система за праћење грешака. Ако не очекујете поруку, или не желите да примате пошту у будуће, можете променити подешавања у Вашем систему обавештавања на овом линку изнад.',
'userwho'		=>'Корисник који је то урадио',
'moreinfo'		=>'Више информација могу се наћи пратећи следећи линк:',
'newtaskopened'		=>'Нови Flyspray задатак је отворен.  Детаљи су видљиви испод.',
'notify.taskclosed'	=>'Следећи задатак је сада затворен:',
'notify.taskreopened'	=>'Следећи задатак је сада поново отворен:',
'newdep'		=>'Следећи задатак има нову зависност:',
'notify.depremoved'	=>'Следећи задатак има избачену зависност:',
'olddepwas'		=>'Стара зависност је',
'notify.commentadded'	=>'Следећи задатак има додат нови коментар:',
'commentis'		=>'Текст коментара је испод.',
'newattachment'		=>'Нова датотека је прикључена следећем задатку:',
'detailsbelow'		=>'Детаљи су испод.',
'notify.relatedadded'	=>'Новоповезани задатак је додат следећем задатку:',
'relatedis'		=>'Повезани задатак је',
'assignedtoyou'		=>'Додељен Вам је следећи задатак:',
'takenownership'	=>'је преузео власништво над следећим задатком:',
'requiresaction'	=>'Следећи задатак захтева акцију руководиоца пројекта:',
'requiresactionnotify'	=>'Задатак захтева акцију руководиоца пројекта',
'pmdeny'		=>'Руководилац пројеката је одбио захтев за следеће задатке:',
'pmdenynotify'		=>'Руководилац пројеката је одбио захтев.',
'fileaddedtoo'		=>'Једна, или више, датотека су прикључене.',
'taskwatching'		=>'Следећи задатак пратите',
'isdepfor'		=>'је нова зависност за',
'denialreason'		=>'Разлог забране',
'taskchanged'		=>'Следећи задатак је измењен. Измене су видљиве испод. За више информација о изменама види на линку, као и на језичку "Историја".',
'useraddedtoassignees'	=>'Корисник се сам додао листи корисника којима је додељен овај задатак.',
'removeddepis'		=>'Уклоњена зависност је',
'isnodepfor'		=>'није зависност више за',
'usergroups'		=>'Корисничке групе',
'pmtoolbox'		=>'Алати руководиоца пројеката',
'groupmanage'		=>'Управљање групама',
'pendingrequests'	=>'Не решени захтеви',
'reasongiven'		=>'Разлог наведен',
'nopendingreq'		=>'Нема не решених захтева за руководиоца пројекта.',
'givereason'		=>'Наведите разлог',
'catlisted'		=>'Уређивач листе категорија',
'oslisted'		=>'Уређивач листе опретаивних система',
'verlisted'		=>'Уређивач листе верзија',
'tasktypeed'		=>'Уређивач листе типова',
'resed'			=>'Уређивач листе разлучивања',
'deny'			=>'Одбиј',
'notifiedwhen'		=>'обавештен кад',
'onlynewtasks'		=>'Нови задтак отоворен',
'allevents'		=>'Нови догађај се појавио у задатку',
'feeds'			=>'FEED-ови',
'feeddescription'	=>'Опис FEED-а',
'feedimgurl'		=>'Линк слике за FEED (празно, ако нема слике)',
'notifysubject'		=>'Субјекат поруке обавештења',
'notifysubjectinfo'	=>'(%p = наслов пројекта, %s = задатак укратко, %t = број задатка, %a = акција, %u = корисник)',
'priority6'		=>'Тренутни',
'priority5'		=>'Скорији',
'priority4'		=>'Ургентни',
'priority3'		=>'Високи',
'priority2'		=>'Нормалан',
'priority1'		=>'Низак',
'sendcode'		=>'Пошаљи коод!',
'entercode'		=>'Унесите потврдни коод, који сте примили у Вашој поруци.  Такође унесите Вашу тражену лозинку.',
'confirmationcode'	=>'Потврдни коод',
'registererror'		=>'Проверите да ли сте попунили сва обавезна поља и након тога унестите исправне податке за Ваш жељени начин обавештења.',
'validusername'		=>'(само алфанумерички знаци и - _ . су дозвољени)',
'emailtaken'		=>'Емајл адреса, или Jabber адреса су већ наведени. Морате изабрати другу.',
'note'			=>'<strong>Напомена:</strong>  Биће Вам послат коод потврде, пре него што се Ваш налог креира.  Коод ће Вам бити послат коришћењем претходно изабране методе.<br />Ако унесете погрешне податке, <strong>нећете примити Ваш потврдни коод</strong>.',
'changelog'		=>'Дневник промена',
'changeloggen'		=>'Генератор дневника промена',
'listfrom'		=>'Листање ставки дневника од',
'to'			=>'до',
'oldestfirst'		=>'Старији прво',
'recentfirst'		=>'Најновији прво',
'severityrep'		=>'Извештај важности',
'totalopen'		=>'Укупно отоворених задатака',
'age'			=>'Датум',
'agerep'		=>'Датум извештаја',
'eventsrep'		=>'Извештај о одгађајима',
'events'		=>'Догађаји',
'Tasks'			=>'Задаци',
'opened'		=>'Отворени',
'edited'		=>'измењени',
'assigned'		=>'Додељени',
'within'		=>'Унутар',
'pastday'		=>'Јуче',
'pastweek'		=>'Прошле недеље',
'pastmonth'		=>'Прошлог месеца',
'pastyear'		=>'Прошле године',
'nolimit'		=>'Нема ограничења',
'from'			=>'Од',
'duein'			=>'Доспева у',
'selectfromdate'	=>'Избор од датума',
'selecttodate'		=>'Избод до датума',
'showvoters'		=>'Прикажи/сакриј гласаче',
'roadmap'		=>'План',
'roadmapfor'		=>'План за верзију',
'tasks'			=>'задатака',
'completed'		=>'завршено.',
'opentasks'		=>'отворених задатака',
'of'			=>'% од',
'severity5'		=>'Критична',
'severity4'		=>'Висока',
'severity3'		=>'Средња',
'severity2'		=>'Ниска',
'severity1'		=>'Веома ниска',
'Redirect'		=>'Преусмери',
'redirectmsg'		=>'Ако Ваш Интернет претраживач не подржава редирекцију кликните на %sHERE%s за редирекцију',
'allowclosedcomments'	=>'Дозволи коментаре над затвореним задацима',
'comment'		=>'Коментар',
'editowncomments'	=>'Измени свој коментар',
'reopened'		=>'Поново отворен',
'loading'		=>'Учитавање...',
'notifyown'		=>'Обавештења о сопственим променама',
'youremail'		=>'Ваша емајл адреса',
'thankyouforbug'	=>'Захваљујемо Вам се на пријави проблема. Можете видети задатке и пратити напредак над њима, било када, пратећи следећи линк:',
'anonuser'		=>'Непознати корисник',
'conflict'		=>'Конфликт',
'file'			=>'Датотека',
'KiB'			=>'кБ',
'MiB'			=>'МБ',
'size'			=>'Величина',
'projectgroup'		=>'Пројектна група',
'profile'		=>'Профил:',
'viewprofile'		=>'Увид профила',
'regdate'		=>'Регистрован од',
'tasksopened'		=>'Задатак отворен',
'replyto'		=>'Одоговори',
'notifytypes'		=>'Тип обавештења',
'pm.taskchanged'	=>'Задатак измењен',
'pm.taskreopened'	=>'Задатак поново отворен',
'pm.depadded'		=>'Завсност додата',
'pm.depremoved'		=>'Зависност уклоњена',
'pmrequest'		=>'ПМ захтев',
'pmrequestdenied'	=>'ПМ захтев одбачен',
'newassignee'		=>'Нови овлашћеник',
'revdepadded'		=>'Контра-зависност додата',
'revdepaddedremoved'	=>'Контра-зависност укллоњена',
'assigneeadded'		=>'Овалшћеник додат',
'addusergroup'		=>'Додај корисника овој групи',
'groupmembers'		=>'Чланови групе',
'deleteuser'		=>'Брисање корисника',
'userdeleted'		=>'Корисник обрисан',
'autoassign'		=>'Аутоматска додела задатка власнику категорије',
'ssl'			=>'SSL',
'updatewrong'		=>'Провера ажурирања је укључена и у том поступку се појавила грешка
приликом контактирања сервера. Или је проблем са спољашњим приступом овог хоста,
или је проблем са мрежом.
Молимо посетите Flyspray сајт, ради добављања најновије верзије!',
'deleteproject'		=>'Бриши овај пројекат и премести садржај у',
'projectdeleted'	=>'Пројекат је успешно обрисан',
'feedforall'		=>'FEED за све пројекте',
'usercreated'		=>'Корисник креиран',
'userdeleted'		=>'Корисник обрисан',
'created'		=>'Креиран',
'deleted'		=>'Обрисан',
'userid'		=>'Кориснички број',
'editassignments'	=>'Измени доделу',
'preview'		=>'Преглед',
'anyprogress'		=>'Ма који напредак',
'tasksrelated'		=>'Задаци који су у вези',
'duplicatetasks'	=>'Дуплих задатака',
'databasemodfailed'	=>'Промена базе података неуспешна. Могући разог је недостатак привилегија.',
'frequency'		=>'Учестало',
'newuserregistered'	=>'Нови корисник је регистрован у Вашој Flyspray инсталацији. Кориснички подаци су следећи:',
'newuserregisterednotify'=>'Нови корисник регистрован',
'notify_registration'	=>'Обавести администратора о новим регистрацијама',
'textversion'		=>'Текст верзија',
'onlyprimary'		=>'Задатак не блокира друге задатке',
'switch'		=>'Промени',
'max'			=>'макс.',
'dates'			=>'Датуми',
'selectduedatefrom'	=>'Очекује се од',
'selectduedateto'	=>'доспева до',
'selectsincedatefrom'	=>'Мењено од',
'selectsincedateto'	=>'до',
'selectdate'		=>'Изабери датум',
'selectopenedfrom'	=>'Отворено од',
'selectopenedto'	=>'до',
'selectclosedfrom'	=>'Затворено од',
'selectclosedto'	=>'до',
'startat'		=>'Почни на',
'hasattachment'		=>'Има прикључак (attachment)',
'private'		=>'Приватно',
'watching'		=>'Праћење промена',
'alreadyvotedthistask'	=>'гласали сте за овај задатак',
'alreadyvotedthisday'	=>'већ гласано данас',
'visibility'		=>'Видљивост',
'public'		=>'Јавно',
'leaveemptyauto'	=>'Немојте уноситити лозинку, ако желите да се она аутоматски генерише.',
'novalidemail'		=>'Нисте унели важећу емаjл адресу.',
'novalidjabber'		=>'Нисте унели важећу Jabber адресу.',
'missingrequired'	=>'Нисте попунили сва обавезна поља!',
'entervalidusername'	=>'Молимо унесите важеће корисничко и стварно име.',
'couldnotaddusernotif'	=>'Овај корисник неће бити додат листи обавештења.',
'defaulttask'		=>'Подразумевани опис задатка',
'all'			=>'све',
'events.useraddedtoassignees' =>'Корисник додат листи додељених',
'vote(s)'		=>'глас(ова)',
'eventlog'		=>'Дневник догађаја',
'assignmentchanged'	=>'Додела промењена',
'detailedinfo'		=>'Детаљне информације',
'All'			=>'Све',
'tasksireported'	=>'Задаци и извештаји',
'recentlyopened'	=>'Често отварани',
'stats'			=>'Статуси',
'totaltasks'		=>'укупно задатака',
'mostwanted'		=>'Најтраженији задаци',
'defaultentry'		=>'Подразумевана улазна страна',
'toplevel'		=>'Увид највишег нивоа',
'overview'		=>'Преглед',
'error#'		=>'Грешка број: ',
'error1'		=>'Немате довољно дозвола да видите овај прикључак!',
'error3'		=>'Поновљен поступак, враћање на главну страну!',
'error4'		=>'Немате администраторска права!',
'error5'		=>'Корисник није регистрован у овој Flyspray инсталацији!',
'error6'		=>'Погрешна администраторска зона.',
'error7'		=>'Пријава неуспела. Погрешна лозинка!',
'error71'		=>'Кориснички налог је закључан за наредних %d минута због превеликог броја покушаја пријаве!',
'error8'		=>'Нисте унели корисничко име и/или лозинку!',
'error9'		=>'Задатак не постоји, или немате дозволу за увид задатака!',
'error10'		=>'Овај задатак не постоји!',
'error101'		=>'Немате дозволу за увид овог задатка!',
'error102'		=>'Немате дозволу за увид овог задатка! Пријавите се, можда ће пријава помоћи.',
'error11'		=>'Немате дозволу за измену овог коментара!',
'error12'		=>'Неважећи магични кључ! Да ли сте сигурни да је ово Ваша порука обавештења?',
'error13'		=>'Анонимни корисник нема профил!',
'error14'		=>'Немате довољно дозвола да креирате нову групу!',
'error15'		=>'Немате довољно дозвола да отворите задатак!',
'error16'		=>'Ви нисте руководилац пројеката!',
'error17'		=>'Погрешна ПМ зона!',
'error18'		=>'Погрешан магични линк!',
'error19'		=>'Корисник не постоји у овој Flayspray инсталацији!',
'error20'		=>'Погрешна измена базе података!',
'error21'		=>'Једна, или више, електронских порука (емајл) није послата! Проверите Вашу конфигурацију.',
'error22'		=>'Забрањена регистрација новим корисницима!',
'error23'		=>'Кориснику, или његовој групи, је забрањена пријава!',
'error24'		=>'Neither the dot executable nor a public dot server has been set.',
'error25'		=>'План је расположив само за специфичне пројекте.',
'done'			=>'урађено',
'rss'			=>'RSS',
'atom'			=>'Атом',
'projectnotdeleted'	=>'Пројекат није обрисан!',
'GMT'			=>'GMT',
'timezone'		=>'Временска зона',
'accept'		=>'Прихвати',
'reasonfordeinal'	=>'Разлог за забрану',
'pruneclosedlinks'	=>'Одстрани затворене линкове',
'pruneclosedtasks'	=>'Одстрани затворене задатке',
'pagegenerated'		=>'Страна и слика генерисани у %d секунди.',
'pruninglevel'		=>'Одстрањивање нивоа',
'lastuser'		=>'Последњи корисник не може бити обрисан!',
'allprivate'		=>'Сви пројекти су приватни!',
'deletegroup'		=>'Обриши ову групу и премести корисњике у',
'parent'		=>'Надређен',
'ordertip'		=>'Редослед ставки биће приказан у листи',
'showtip'		=>'Прикажи ову ставку у листи',
'deletetip'		=>'Бриши ову ставку из листе',
'del'			=>'Бриши',
'request1'		=>'Затражено је затварање задатка.',
'request2'		=>'Поступак за поновно отварање задатка успешно окончан.',
'allpriorities'		=>'Сви приоритети',
'noroadmap'		=>'Ова опција није расположива у тренутној верзији.',
'expand'		=>'Рашири',
'collapse'		=>'Сажми',
'expandall'		=>'Рашири све',
'collapseall'		=>'Сажми све',
'minpwsize'		=>'Минимална дужина лозинке је 5 знакова',
'passwordtoosmall'	=>'Дужина лозинке је прекратка',
'accountwaslocked'	=>'Ваш кориснички налог је закључан због превеликог броја покушаја пријаве!',
'failedattempts'	=>'Укупно %d неуспешних покушаја пријаве!',
'groupnotexist'		=>'Изабрана група не постоји у овом пројекту!',
'searchindetails'	=>'Детаљи претраге',
'showasassignees'	=>'Прикажи као додељене',
'find'			=>'Нађи',
'tls'			=>'TLS',
'isadmin'		=>'Да ли је ово администратор?',
'addvotes'		=>'Гласај за',
);
