<?php

$translation = array(
'edituser'                => 'Modifica utilizator',
'accountenabled'          => 'Cont activat',
'editallusers'            => 'Vezi toti utilizatorii',
'username'                => 'Utilizator',
'usersupdated'            => 'Utilizatori modificati cu succes',
'realname'                => 'Nume real',
'emailaddress'            => 'Adresa email',
'jabberid'                => 'ID Jabber',
'profileimage'            => 'Imagine profil',
'notifytype'              => 'Tip notificare',
'group'                   => 'Grup',
'enableaccounts'          => 'Activeaza conturi',
'disableaccounts'         => 'Dezactiveaza conturi',
'deleteaccounts'          => 'Sterge conturi',
'updatedetails'           => 'Modifica detalii',
'setglobally'             => 'Aceasta preferinta a fost setata global.',
'usergroupmanage'         => 'Management utilizatori si grupuri de utilizatori',
'newuser'                 => 'Inregistrare utilizator nou',
'newuserbulk'             => 'Inregistrare utilizatori multipli',
'bulkuserstoadd'          => 'Lista utilizatorilor noi',
'optionsforallusers'      => 'Optiuni pentru toti utilizatorii',
'newgroup'                => 'Creare grup nou',
'yes'                     => 'Da',
'no'                      => 'Nu',
'editgroup'               => 'Modifica grup',
'groupname'               => 'Nume grup',
'description'             => 'Descriere',
'admin'                   => 'Grup administrator',
'opennewtasks'            => 'Deschide tichet nou',
'modifytasks'             => 'Modifica tichete existente',
'addcomments'             => 'Adauga comentarii',
'attachfiles'             => 'Ataseaza fisiere',
'vote'                    => 'Vot',
'groupenabled'            => 'Membrii se pot autentifica',
'groupopen'               => 'Membrii se pot autentifica',
'tasktypelist'            => 'Lista tipuri tichete',
'categorylist'            => 'Lista categorii',
'oslist'                  => 'Lista Sisteme de Operare',
'resolutionlist'          => 'Lista rezolvari',
'versionlist'             => 'Lista versiuni',
'severitylist'            => 'Lista severitati',
'listnote'                => 'Observatie: Debifand "arata" se pot altera anumite tichete in modul de editare. Schimband campul "Nume" va schimba toate tichetele cu acest nume. Cele care nu se pot sterge sunt fie protejate pentru o functionare corecta, fie sunt folosite deja in tichete.',
'name'                    => 'Nume',
'order'                   => 'Ordine',
'back'                    => 'Inapoi',
'text'                    => 'Text',
'highlight'               => 'Evidentiaza',
'show'                    => 'Afiseaza',
'owner'                   => 'Titular',
'selectowner'             => 'Selecteaza titular',
'update'                  => 'Actualizeaza',
'addnew'                  => 'Adaugare',
'flysprayprefs'           => 'Preferinte Flyspray',
'projecttitle'            => 'Titlu proiect',
'baseurl'                 => 'URL de baza pentru aceasta instalare',
'replyaddress'            => 'Adresa de email pentru notificari',
'themestyle'              => 'Tema / Stil',
'customstyle'             => 'personalizat',
'language'                => 'Limba',
'anonview'                => 'Permite utilizatorilor anonimi sa vizualizeze tichetele',
'allowanon'               => 'Permite utilizatorilor anonimi sa adauge tichete noi',
'never'                   => 'Niciodata',
'anonymously'             => 'Anonim',
'afterregister'           => 'Numai dupa inregistrare',
'spamproof'               => 'Activeaza codul de confirmare pentru inregistrarile noi',
'anongroup'               => 'Grup implicit pentru noile inregistrari de conturi',
'groupassigned'           => 'Membrilor din aceste grupuri li se pot atribui tichete',
'forcenotify'             => 'Forteaza notificarile ca si',
'neversend'               => 'Nu trimite niciodata',
'userchoose'              => 'Permite utilizatorului sa isi aleaga',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Titularul implicit pentru categorie',
'noone'                   => 'Nimeni',
'jabbernotify'            => 'Notificari Jabber',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Nume utilizator',
'jabberpass'              => 'Parola',
'saveoptions'             => 'Salveaza optiuni',
'editcomment'             => 'Modifica comentariu',
'commentby'               => 'Comentariu adaugat de',
'saveeditedcomment'       => 'Salveaza',
'projectprefs'            => 'Preferinte proiect',
'pagetitle'               => 'Titlu pagina',
'defaultproject'          => 'Proiect implicit',
'projectlists'            => 'Lista proiecte',
'showlogo'                => 'Afiseaza logo',
'showgravatars'           => 'Afiseaza Gravatar',
'emailNoHTML'             => 'Fara HTML in e-mailuri',
'intromessage'            => 'Mesaj introductiv',
'active'                  => 'activ',
'inactive'                => 'inactiv',
'isactive'                => 'Proiect activ',
'showinactive'            => 'Afiseaza proiecte inactive',
'hideinactive'            => 'Ascunde proiecte inactive',
'createproject'           => 'Creaza proiect nou',
'nopermission'            => 'Nu ai permisiunea sa folosesti aceasta pagina.',
'listordertip'            => 'Ordinea listarii',
'listshowtip'             => 'Afiseaza in lista',
'categoryownertip'        => 'Aceasta persoana va primi notificari cand un tichet va fi deschis in categoria aceasta',
'categoryparenttip'       => 'Va fi sub categoria',
'notsubcategory'          => 'Niciuna (categorie tip parinte)',
'showinlineimages'        => 'Afiiseaza fisierele atasate de tip imagine in linie',
'dateformat'              => 'Formatul datei',
'dateformat_extended'     => 'Formatul datei (detaliat)',
'cache_feeds'             => 'Feeduri cache',
'no_cache'                => 'Fara stocare',
'cache_disk'              => 'Stocare pe disc',
'cache_db'                => 'Stocare in DB',
'subcategoryof'           => 'Sub-categoria lui',
'visiblecolumns'          => 'Coloanele afisate in lista de tichete',
'visiblefields'           => 'Campuri la adaugarea, editarea si vizualizarea unui tichet',
'tense'                   => 'Timp',
'listtensetip'            => 'Trecut, prezent sau viitor',
'past'                    => 'Trecut',
'present'                 => 'Prezent',
'future'                  => 'Viitor',
'oldpass'                 => 'Parola veche',
'nooldpass'               => 'Nu a fost completata parola veche',
'oldpasswrong'            => 'Parola veche a fost scrisa gresit',
'changepass'              => 'Schimba parola',
'confirmpass'             => 'Confirma parola',
'projectmanager'          => 'Manager Proiect',
'viewtasks'               => 'Vizualizare tichete',
'modifyowntasks'          => 'Modifica tichetele proprii',
'modifyalltasks'          => 'Modifica tichetele altora',
'viewcomments'            => 'Vizualizare comentarii',
'editcomments'            => 'Modifica comentarii',
'deletecomments'          => 'Sterge comentarii',
'viewattachments'         => 'Vizualizeaza fisiere atasate',
'createattachments'       => 'Poate atasa fisiere',
'deleteattachments'       => 'Poate sterge fisiere',
'viewhistory'             => 'Vizualizare istoric',
'closeowntasks'           => 'Inchide tichetele proprii',
'closeothertasks'         => 'Inchide tichetele altora',
'assigntoself'            => 'Isi poate atribui tichetele, daca nu sunt deja atribuite cuiva',
'assignotherstoself'      => 'Isi poate atribui tichetele altora',
'viewreports'             => 'Poate vizualiza log-ul de evenimente',
'othersview'              => 'Permite oricui sa vizualizeze tichetele din acest proiect',
'othersviewroadmap'       => 'Permite oricui sa vizualizeze harta de parcurs a acestui proiect',
'usersandgroups'          => 'Utilizatori si grupuri de utilizatori',
'globalgroup'             => 'Grup Global',
'globalgroups'            => 'Grupuri Globale',
'defaultglobalgroup'      => 'Grup global implicit pentru utilizatorii noi',
'addtogroup'              => 'Adauga in grup',
'moveuserstogroup'        => 'Muta utilizatorii in grup',
'nogroup'                 => 'Fara grup - Elimina din proiect',
'eventdesc'               => 'Descriere eveniment',
'requestedby'             => 'Persoana',
'daterequested'           => 'Data',
'closetask'               => 'Inchide tichet',
'reopentask'              => 'Redeschide tichet',
'applymember'             => 'Cere sa fie membru al proiectului',
'forcurrentproj'          => 'Pentru proiectul curent',
'lostpw'                  => 'Recuperare parola',
'lostpwexplain'           => 'Completeaza numele de utilizator pentru trimiterea unui link in vederea schimbarii parolei. Acest link va fi trimis la adresa de email din profilul tau.',
'sendlink'                => 'Trimite link',
'savenewpass'             => 'Salveaza noua parola',
'anonreg'                 => 'Permite inregistrarea de utilizatori noi',
'allowanonopentask'       => 'Permite utilizatorilor anonimi sa adauge tichete noi',
'editglobalgroup'         => 'Modifica grup global',
'editgroupforproj'        => 'Modifica grup proiect',
'notshownforadmin'        => 'Permisiunile nu sunt afisate pentru grupul de administratori. Nu este necesar sa faceti modificari.',
'general'                 => 'General',
'userregistration'        => 'Inregistrare utilizatori noi',
'notifications'           => 'Notificari',
'resetoptions'            => 'Anuleaza modificari',
'preferences'             => 'Preferinte',
'tasktypes'               => 'Tipuri de tichete',
'resolutions'             => 'Rezolvari',
'categories'              => 'Categorii',
'operatingsystems'        => 'Sisteme de Operare',
'versions'                => 'Versiuni',
'admintoolboxlong'        => 'Panoul administratorului',
'newproject'              => 'Proiect nou',
'delete'                  => 'Sterse',
'link'                    => 'Link',
'referencelinks'          => 'Linkuri de referinta:',
'listdeletetip'           => 'Sterge din lista',
'lookandfeel'             => 'Aspect',
'globaltheme'             => 'Tema globala',
'emailnotify'             => 'Notificari email',
'fromaddress'             => 'De la adresa email',
'smtpserver'              => 'Server SMTP',
'smtpuser'                => 'Utilizator SMTP',
'smtppass'                => 'Parola SMTP',
'addrewrite'              => 'Rescrie adresele',
'usereminderdaemon'       => 'Porneste serviciul de tip reminder',
'tasksperpage'            => 'Nr. de tichete in lista de tichete',
'addtoassignees'          => 'Adauga la lista de persoane atribuite',
'taskstatuses'            => 'Statusuri tichete',
'canvote'                 => 'Poate vota in tichete',
'loginsuccessful'         => 'Autentificare reusita.',
'youareloggedout'         => 'Deautentificare reusita.',
'waitwhiletransfer'       => 'Te rog sa astepti cat timp esti transferat...',
'clicknowait'             => 'Click aici daca nu doresti sa astepti.',
'accountdisabled'         => 'Contul tau e dezactivat. Contacteaza un administrator de sistem.',
'task'                    => 'Tichet',
'edittask'                => 'Modifica tichet',
'openedby'                => 'Deschis de',
'editedby'                => 'Ultima modificare',
'tasktype'                => 'Tip tichet',
'category'                => 'Categorie',
'status'                  => 'Status',
'assignedto'              => 'Persoana atribuita',
'operatingsystem'         => 'Sistem Operare',
'severity'                => 'Severitate',
'reportedversion'         => 'Raportat in versiunea',
'dueinversion'            => 'De rezolvat pana in versiunea',
'defaultdueinversion'     => 'Versiunea implicita de rezolvat a noilor tichete',
'undecided'               => 'Nedecis',
'percentcomplete'         => 'Procentaj',
'details'                 => 'Descriere',
'savedetails'             => 'Salveaza',
'canceledit'              => 'Renunta la modificari',
'anonymous'               => 'Trimis de anonim',
'complete'                => 'complet',
'closedby'                => 'Inchis de',
'reasonforclosing'        => 'Motiv inchidere:',
'reopenthistask'          => 'Redeschide tichetul',
'comments'                => 'Comentarii',
'attachments'             => 'Fisiere atasate',
'relatedtasks'            => 'Tichete similare',
'edit'                    => 'Modifica',
'addcomment'              => 'Adauga raspuns',
'fileuploadedby'          => 'Fisier atasat de',
'uploadafile'             => 'Ataseaza fisier',
'addalink'                => 'Adauga un link',
'addanotherlink'          => 'Adauga alt link',
'uploadnow'               => 'Incarca',
'thesearerelated'         => 'Aceste tichete sunt inrudite cu acest tichet',
'remove'                  => 'Elimina',
'addnewrelated'           => 'Noteaza un tichet similar cu acesta sau un duplicat al acestuia',
'add'                     => 'Adauga',
'otherrelated'            => 'Alte tichete cu care acesta este inrudit',
'receivenotify'           => 'Acesti utilizatori vor primi notificari detaliate cand acest tichet sufera modificari.',
'addusertolist'           => 'Adauga persoana la lista de notificari',
'addtolist'               => 'Adauga in lista',
'addmyself'               => 'Adauga-ma in lista',
'removemyself'            => 'Elimina-ma din lista',
'theseusersnotify'        => 'Urmatoarele persoane vor primi informatii detaliate pe mail atunci cand apar noutati la acest tichet.',
'attachedtoproject'       => 'Postat in',
'reminders'               => 'Atentionari',
'system'                  => 'Sistem',
'systemvalues'            => 'Valori comune sistem',
'projectvalues'           => 'Valori specifice proiectului',
'remindthisuser'          => 'Reaminteste-i acestui utilizator',
'thisoften'               => 'Des',
'startafter'              => 'Timpul de asteptare inainte de a trimite atentionare',
'hour'                    => 'ora',
'hours'                   => 'ore',
'day'                     => 'zi',
'days'                    => 'zile',
'week'                    => 'saptamana',
'weeks'                   => 'saptamani',
'addreminder'             => 'Adauga atentionare',
'defaultreminder'         => 'Aceasta este o atentionare pentru a verifica urmatorul tichet:',
'message'                 => 'Mesaj',
'closed'                  => 'Inchis',
'filename'                => 'Fisier:',
'date'                    => 'Data',
'filesize'                => 'Marime fisier:',
'closurecomment'          => 'Comentarii aditionale cu privire la solutionare:',
'history'                 => 'Istoric',
'nohistory'               => 'Nu este disponibil istoricul.',
'eventdate'               => 'Data',
'user'                    => 'Utilizator',
'event'                   => 'Eveniment',
'fieldchanged'            => 'Camp modificat',
'taskopened'              => 'Tichet deschis',
'taskreopened'            => 'Tichet redeschis',
'taskclosed'              => 'Tichet inchis',
'commentadded'            => 'Comentariu adaugat',
'commentedited'           => 'Commentariu editat',
'commentdeleted'          => 'Comentariu sters',
'attachmentadded'         => 'Fisier atasat',
'attachmentdeleted'       => 'Fisier sters',
'taskedited'              => 'Detaliile tichetului au fost modificate',
'notificationadded'       => 'Persoana adaugata in lista de notificari',
'notificationdeleted'     => 'Persoana eliminata din lista de notificari',
'relatedadded'            => 'Tichet similar - dependenta adaugata',
'relateddeleted'          => 'Tichet similar - dependenta eliminata',
'taskassigned'            => 'Tichetul a fost alocat ',
'taskreassigned'          => 'Tichetul a fost realocat',
'assignmentremoved'       => 'Atribuirea a fost eliminata',
'summary'                 => 'Sumar',
'addedasrelated'          => 'Tichetul este similar cu',
'deletedasrelated'        => 'Tichetul este nu mai e similar cu',
'reminderadded'           => 'Atentionare adaugata',
'reminderdeleted'         => 'Atentionare eliminata',
'priority'                => 'Prioritate',
'previousvalue'           => 'Valoare anterioara',
'newvalue'                => 'Valoare noua',
'selectareason'           => 'Selectare motiv',
'assigntome'              => 'Atribuie-ma',
'reopenrequest'           => 'Redeschide tichet',
'requestclose'            => 'Inchide tichet',
'ownershiptaken'          => 'Tichetul este preluat de',
'closerequestmade'        => 'Cere inchidere tichet',
'reopenrequestmade'       => 'Cere redeschidere tichet',
'taskdependson'           => 'Tichetul are urmatoarele dependente',
'taskdependsontask'       => 'Tichetul are urmatoarele dependente',
'taskdependsontasks'      => 'Tichetul are urmatoarele dependente',
'taskblock'               => 'Acest tichet nu permite inchiderea urmatoarelor tichete:',
'taskblocks'              => 'Acest tichet nu permite inchiderea urmatoarelor tichete:',
'depadded'                => 'Dependenta adaugata',
'depaddedother'           => 'Tichetul a fost adaugat ca dependenta de tichetul',
'depremoved'              => 'Dependenta eliminata',
'depremovedother'         => 'Tichet eliminat din alta lista de tichete',
'showdetailserror'        => 'Acest tichet nu exista sau nu ai permisiunea de a il vizualiza.',
'makeprivate'             => 'fa privat',
'makepublic'              => 'fa public',
'taskmadeprivate'         => 'Tichet facut privat',
'taskmadepublic'          => 'Tichetul a fost facut public',
'confirmdeletecomment'    => 'Esti sigur ca doresti sa stergi acest comentariu? %s',
'attachementswilldeleted' => 'Toate fisierele atasate vor fi sterse!',
'confirmdeleteattach'     => 'Esti sigur ca doresti sa stergi fisierul atasat?',
'selectedhistory'         => 'Afiseaza detaliile istoricului',
'showallhistory'          => 'Afiseaza istoricul complet din nou',
'hidethis'                => 'Ascunde aceasta zona',
'mark100'                 => 'Marcheaza tichetul cu procentaj 100%',
'watchtask'               => 'urmareste tichet',
'stopwatching'            => 'Nu mai urmari',
'commentlink'             => 'Link catre comentariu',
'submitreq'               => 'Trimite',
'reasonforreq'            => 'Comentarii rezolvare',
'pmreqdenied'             => 'Nu s-a permis modificarea tichetului',
'taskpendingreq'          => 'Se asteapta o actiune din partea Managerului de Proiect. Vezi istoricul pentru detalii',
'previoustask'            => 'Tichetul anterior',
'nexttask'                => 'Tichetul urmator',
'duedate'                 => 'Pana la data',
'attachnoperms'           => 'Sunt fisiere atasate acestui comentariu, dar nu ai permisiunea de a le vizualiza.',
'linknoperms'             => 'Sunt linkuri in acest comentariu, dar nu ai permisiunea de a le vizualiza.',
'open'                    => 'Deschise',
'depgraph'                => 'Trasabilitate',
'reset'                   => 'Reseteaza',
'selectusers'             => 'Selecteaza persoane...',
'addmetoassignees'        => 'Atribuie-ma (+1)',
'addedtoassignees'        => 'Persoana a preluat tichetul',
'dependencygraph'         => 'Grafic dependente',
'attachanotherfile'       => 'Ataseaza alt fisier',
'OK'                      => 'OK',
'addvote'                 => 'Adauga vot',
'disable_lostpw'          => 'Dezactiveaza formularul de recuperare parola',
'disable_changepw'        => 'Dezactiveaza posibilitatea de a crea sau edita o parola',
'notifyfromfs'            => 'Notificare de la FlySpray',
'autogenerated'           => 'ACESTA ESTE UN MESAJ GENERAT AUTOMAT DE SISTEM. VA RUGAM SA NU RASPUNDETI.',
'forward'                 => 'Inainte',
'previous'                => 'Anterior',
'next'                    => 'Urmator',
'first'                   => 'Primul',
'last'                    => 'Ultimul',
'page'                    => 'Pagina %d din %d',
'search'                  => 'Cauta',
'alltasktypes'            => 'Toate',
'allseverities'           => 'Toate severitatile',
'alldevelopers'           => 'Toti dezvoltatorii',
'notyetassigned'          => 'Fara atribuire',
'allcategories'           => 'Toate categoriile',
'allstatuses'             => 'Toate statusurile',
'allopentasks'            => 'Toate tichetele deschise',
'sortthiscolumn'          => 'Sorteaza dupa aceasta coloana',
'id'                      => 'ID',
'project'                 => 'Proiect',
'dateopened'              => 'Data deschidere',
'progress'                => 'Progres',
'searchthisproject'       => 'Cauta',
'dueanyversion'           => 'Pana in orice versiune',
'anyversion'              => 'Raportat in orice versiune',
'dueversion'              => 'Pana in versiunea',
'lastedit'                => 'Ultimul raspuns',
'os'                      => 'Sistem operare',
'reportedin'              => 'Raportat in',
'taskrange'               => 'Arata %d - %d din %d tichete.',
'noresults'               => 'Cautarea dvs. nu a returnat rezultate.',
'takeaction'              => 'Trimite',
'watchtasks'              => 'Urmareste tichetele selectate',
'stopwatchingtasks'       => 'Nu mai urmari tichetele selectate',
'assigntaskstome'         => 'Atribuie-mi tichetele selectate',
'dueby'                   => 'Pana la',
'dueanytime'              => 'Oricand',
'selectduedate'           => 'Selecteaza data de final',
'toggleselected'          => 'Mod selectie activat',
'due'                     => 'Pana',
'assignedtome'            => 'Atribuite mie',
'tasklist'                => 'Tichete',
'dateclosed'              => 'Data inchiderii',
'advanced'                => 'Cautare avansata',
'searchcomments'          => 'Cauta in comentarii',
'searchforall'            => 'Cauta dupa cuvinte',
'anonusers'               => 'Utilizatori anonimi',
'miscellaneous'           => 'Diverse',
'users'                   => 'Utilizatori',
'taskproperties'          => 'Proprietati tichet',
'selectsincedate'         => 'Selecteaza Schimbat de la',
'changedsince'            => 'Schimbat de la',
'updatefs'                => 'Te rugam sa actualizezi FlySpray.',
'currentversion'          => 'Versiunea folosita este',
'latestversion'           => 'iar cea mai recenta versiune este',
'hidemessage'             => '(aminteste-mi mai tarziu)',
'saveas'                  => 'Salveaza template cautare',
'nosearches'              => 'Nu exista template-uri',
'saving'                   => 'Salvez...',
'votes'                   => 'Voturi',
'tovote'                  => 'Voteaza',
'allclosedtasks'          => 'Toate tichetele inchise',
'password'                => 'Parola',
'login'                   => 'Autentificare',
'rememberme'              => 'Tine minte',
'lostpassword'            => 'Parola uitata?',
'lostpwforfs'             => 'Parola uitata pentru FlySprayLost password for Flyspray',
'lostpwmsg1'              => 'Salutare! Mi-am uitat parola.',
'lostpwmsg2'              => 'Te rog sa imi trimiti o noua parola pentu utilizatorul: ',
'regards'                 => 'Multumiri,',
'yourusername'            => ' numele tau de utilizator ',
'locale'                  => 'ro-RO',
'filenotexist'            => 'Fisierul nu exista sau nu ai permisiunea de a il accesa.',
'showtask'                => 'Vezi tichet',
'now'                     => 'Acum',
'go'                      => 'Du-te!',
'opentaskanon'            => 'Deschide un tichet nou in mod anonim',
'register'                => 'Inregistrare cont nou',
'addnewtask'              => 'Adauga tichet nou',
'reports'                 => 'Rapoarte',
'editmydetails'           => 'Modifica detalii',
'logout'                  => 'Deautentificare',
'disabledaccount'         => 'Contul tau a fost dezactivat!<br />Vi se face deautentificarea...',
'poweredby'               => 'Conceput de FlySpray',
'sponsoredby'             => 'Flyspray este sponsorizat de',
'projects'                => 'Proiecte',
'allprojects'             => 'Toate proiectele',
'selectproject'           => 'pentru proiectul:',
'tasksall'                => 'Toate tichetele',
'tasksassigned'           => 'Tichete atribuite mie',
'tasksreported'           => 'Tichete deschise de mine',
'taskswatched'            => 'Tichete urmarite',
'mysearch'                => 'Cautarile mele',
'admintoolbox'            => 'Panou administrare',
'manageproject'           => 'Panou administrare proiect',
'permissions'             => 'Permisiuni',
'hide'                    => 'Ascunde',
'pendingreq'              => 'tichet(e) care necesita atentia ta',
'errorpage'               => 'FlySpray nu poate afisa pagina ceruta.
                                 Este posibil ca tichetul sa nu existe sau nu ai
                                 permisiunea de a vizualiza pagina pe care ai cerut-o.<br /><br />
                                 Se poate sa fi incercat sa folosesti un URL pentru a interoga baza de date
                                 prin spate. Daca e adevarat, pune-te la colt cu mainile la spate si
                                 fa-ti o mustrare de constinta. Cand te intorci pe aici, sa nu mai faci asta!',
'permissionsforproject'   => 'Permisiuni pentru ',
'switchto'                => 'Schimba la',
'lastsearch'              => 'Ultima cautare',
'modify'                  => 'Modifica',
'noticefrom'              => 'Notificare de la',
'hasopened'               => 'a deschis un tichet nou si ti l-a atribuit tie:',
'moreinfonew'             => 'Poti gasi mai multe informatii la pagina:',
'newtaskcategory'         => 'Un nou tichet a fost deschis in aceasta categorie',
'categoryowner'           => 'Primesti acest mail deoarece figurezi ca titular de categorie.',
'tasksummary'             => 'Sumar tichet:',
'newtaskadded'            => 'Tichetul a fost adaugat.',
'summaryanddetails'       => 'Este necesar sa completezi atat sumarul problemei cat si niste detalii.',
'summaryrequired'         => 'Este necesar sa completezi campul Sumar.',
'goback'                  => 'Inapoi.',
'messagefrom'             => 'Acesta este un mesaj de la platforma Flyspray ',
'hasjustmodified'         => 'a modificat tichetul urmator',
'changedfields'           => 'Campurile modificate sunt completate cu (**) inainte',
'moreinfomodify'          => 'Poti primi mai multe informatii despre tichet dand click pe urmatorul link:',
'nolongerassigned'        => 'Tichetul urmator nu iti mai este atribuit. Acum este atribuit lui',
'hasassigned'             => 'ti-a atribuit urmatorul tichet:',
'taskupdated'             => 'Tichetul a fost actualizat.',
'tasksupdated'            => 'Tichetele au fost actualizate.',
'hasclosedassigned'       => 'a inchis tichetul la care ai fost atribuit:',
'unassigned'              => 'Neatribuit',
'hasclosed'               => 'a inchis tichetul.',
'youonnotify'             => 'Primesti acest mail deoarece esti in lista de notificari.',
'taskclosedmsg'           => 'Tichetul a fost inchis.',
'returntotask'            => 'Intoarce-te la detaliile tichetului',
'backtoindex'             => 'Intoarce-te la lista de tichete',
'noclosereason'           => 'Nu ai selectat un motiv pentru a inchide acest tichet.',
'hasreopened'             => 'a redeschis tichetul pe care l-ai inchis:',
'taskreopenedmsg'         => 'Tichetul a fost redeschis.',
'backtotask'              => 'Inapoi la tichet.',
'commentaddedmsg'         => 'Raspunsul a fost adaugat.',
'commenttoassigned'       => 'a adaugat un comentariu unui tichet la care esti atribuit:',
'commenttotask'           => 'a adaugat urmatorul comentariu la acest tichet.',
'nocommententered'        => 'Ar trebui sa scrii ceva in zona de comentarii inainte de a apasa butonul.',
'fillinfields'            => 'Nu ai completat toate campurile.',
'notcurrentpass'          => 'Aceasta nu este parola curenta!',
'passchanged'             => 'Parola a fost schimbata.',
'closewindow'             => 'Poti inchide aceasta fereastra.',
'passnomatch'             => 'Parolele noi nu sunt aceleasi!',
'usernametaken'           => 'Acest nume de utilizator exista. Va trebui sa iti alegi altul',
'usernametakenbulk'       => 'Numele de utilizator exista deja',
'newusercreated'          => 'Contul a fost creat.',
'accountcreated'          => 'Contul tau a fost creat.',
'newuserwarning'          => 'Este posibil ca acest cont sa fie aprobat de catre administrator. Daca nu te poti conecta, se poate ca acesta sa fie motivul.',
'nomatchpass'             => 'Parolele nu sunt aceleasi.',
'confirmwrong'            => 'Codul de confirmare nu este corect!',
'formnotcomplete'         => 'Formularul nu a fost completat in intregime.',
'formnotnumeric'          => 'Datele inserate nu sunt de tip numeric!',
'groupnametaken'          => 'Acest grup exista deja.',
'newgroupadded'           => 'Grup nou adaugat.',
'optionssaved'            => 'Optiunile Flyspray salvate.',
'hasuploaded'             => 'a atasat un fisier la un tichet la care esti atribuit:',
'hasattached'             => 'a atasat un fisier urmatorului tichet.',
'fileuploaded'            => 'Fisierul a fost atasat.',
'fileerror'               => 'A fost o eroare la atasarea fisierului. E posibil ca drepturile de scriere pentru directorul <i>attachments/</i> nu sunt corecte.',
'contactadmin'            => 'Contacteaza administratorul pentru acest proiect.',
'selectfileerror'         => 'Nu ai selectat un fisier.',
'userupdated'             => 'Detaliile utilizatorului au fost actualizate',
'realandemail'            => 'Nu ai completat Numele Real si Adresa Email',
'groupupdated'            => 'Definitiile de grup au fost actualizate.',
'groupanddesc'            => 'Nu ai completat numele grupului.',
'fillallfields'           => 'Completeaza toate campurile.',
'listPmustN'              => '"Ordine" trebuie sa fie de tip numeric.',
'listupdated'             => 'Lista a fost modificata.',
'listitemadded'           => 'S-a adaugat elementul nou.',
'relatedaddedmsg'         => 'Tichetul inrudit a fost adaugat.',
'relatederror'            => 'Acest tichet exista deja in lista tichetelor inrudite.',
'relatedremoved'          => 'Tichetul inrudit a fost eliminat din lista.',
'notifyadded'             => 'Adaugare persoana la lista de notificari',
'notifyerror'             => 'Persoana este deja in lista de notificari pentru acest tichet.',
'notifyremoved'           => 'Persoana eliminata din lista de notificari',
'editcommentsaved'        => 'Salvarile comentariului s-au facut.',
'commentdeletedmsg'       => 'Comentariul a fost sters.',
'gotonewtask'             => 'Du-te la tichetul pe care tocmai l-ai deschis',
'projectcreated'          => 'Proiectul a fost creat. Poti face acum personalizarile dorite.',
'customiseproject'        => 'Personalizeaza acest proiect',
'projectupdated'          => 'Preferintele proiecfului au fost actualizate',
'emptytitle'              => 'Nu ai completat titlul proiectului!',
'loginbelow'              => 'Poti incerca sa te autentifici.',
'attachmentdeletedmsg'    => 'Fisierul atasat a fost sters',
'reminderaddedmsg'        => 'Atentionarea a fost adaugata.',
'reminderdeletedmsg'      => 'Atentionarea selectata a fost stearsa.',
'flyspraytask'            => 'Tichet Flyspray',
'fieldsmissing'           => 'Unele campuri nu au fost completate sau au fost completate gresit.',
'relatedinvalid'          => 'Nu exista acest tichet.',
'relatedproject'          => 'Acest tichet este atasat altui proiect. Doresti sa faci faci o legatura intre ele?',
'addanyway'               => 'Adauga oricum',
'cancel'                  => 'Renunta',
'alreadyedited'           => 'Acest tichet a suferit modificari inainte ca tu sa salvezi modificarile. Inca doresti sa salvezi modificarile facute doar de tine?',
'saveanyway'              => 'Salveaza modificarile mele',
'nouserselected'          => 'Niciun utilizator selectat. Selecteaza macar un utilizatori inainte sa incerci din nou.',
'groupswitchupdated'      => 'Grupurile de utilizatori au fost modificate cu succes.',
'takenownershipmsg'       => 'Tichetul a fost atribuit.',
'adminrequestmade'        => 'Cererea ta a fost trimisa unui Manager de Proiect.',
'newdepnotify'            => 'O dependenta a fost adaugata tichetului urmator:',
'dependadded'             => 'Dependenta de tichet a fost adaugata',
'dependaddfailed'         => 'A fost o problema la adaugarea acestei dependente. Verifica daca respectivul tichet exista sau daca nu cumva se blocheaza reciproc.',
'depremovedmsg'           => 'Dependenta a fost eliminata',
'newdepis'                => 'Noua dependenta este',
'magicurlsent'            => 'Un mesaj a fost trimis la adresa de notificare. Acest mesaj contine un link care te va trimite catre pagina in care exista respectivul tichet.',
'changefspass'            => 'Schimba parola',
'magicurlmessage'         => 'Te rugam sa dai click pe linkul de mai jos pentru a iti schimba parola:',
'erroronform'             => 'A fost o problema la trimiterea formularului',
'addressused'             => 'Aceasta adrea a fost folosita pentru crearea unui cont de utilizator FlySpray. Daca nu asteptai acest mail, ignora-l si sterge-l. Da click pe urmatorul link pentru a finaliza procesul de inregistrare:',
'confirmcodeis'           => 'Codul de confirmare este:',
'codesent'                => 'Codul de confirmare a fost trimis. Te rugam sa urmezi instructiunile din mailul trimis.',
'codenotsent'             => 'Nu putem trimite codul. Incearca mai tarziu.',
'taskmadeprivatemsg'      => 'Tichetul a fost facut privat',
'taskmadepublicmsg'       => 'Tichetul a fost facut public din nou',
'realandnotify'           => 'Trebuie sa completezi campul Nume Real si fie Adresa Email, fie ID Jabber.',
'pmreqdeniedmsg'          => 'Cererea catre Managerul de Proiect a fost refuzata',
'massopsuccess'           => 'Operatiuni in masa cu succes - acolo unde exista permisiuni',
'usernotexist'            => 'Utilizatorul completat in formularul de conectare nu exista in baza noastra de date. Va rugam sa verificati daca ati introdus numele de utilizator corect.',
'commentattachperms'      => 'Nu pot sterge acel comentariu - nu ai permisiunea de a sterge fisiere atasate.',
'voterecorded'            => 'Votul tau a fost inregistrat',
'votefailed'              => 'Votul tau nu a putut fi inregistrat in acest moment.',
'createnewgroup'          => 'Creaza grup nou',
'requiredfields'          => 'Campurile obligatorii sunt marcate cu',
'addthisgroup'            => 'Adauga acest grup',
'createnewproject'        => 'Creaza un nou proiect',
'addnewproject'           => 'Adauga proiect nou',
'htmlallowed'             => 'Cod HTML permis',
'createthisproject'       => 'Creaza acest proiect',
'inlineimages'            => 'Afiseaza imaginile atasate in linie',
'createnewtask'           => 'Creaza un nou tichet in proiect:',
'addanother'              => 'Adauga alt tichet dupa acesta',
'addthistask'             => 'Adauga tichet',
'notifyme'                => 'Anunta-ma pe mail cand acest tichet are modificari',
'newtask'                 => 'Tichet nou',
'attachafile'             => 'Ataseaza fisier',
'registernewuser'         => 'Inregistreaza utilizator nou',
'none'                    => 'Nimic',
'registeraccount'         => 'Inregistreaza acest cont',
'registerbulkaccount'     => 'Inregistreaza conturi',
'both'                    => 'Ambele',
'notifyfrom'              => 'Notificare de la ',
'donotreply'              => 'MESAJ GENERAT AUTOMAT DE SISTEM, VA RUGAM SA NU RASPUNDETI LA EL!',
'disclaimer'              => 'Acest mesaj il primiti pentru a fi la curent cu modificarile aduse la tichetul pe care l-ati postat.',
'userwho'                 => 'Utilizatorul / utilizatorii',
'moreinfo'                => 'Pentru a vizualiza tichetul, apasati pe linkul de mai jos:',
'newtaskopened'           => 'Pe platforma CLB-Request a fost deschis un nou tichet. Detaliile acestuia sunt urmatoarele:',
'notify.taskclosed'       => 'Tichetul de mai jos a fost inchis:',
'notify.taskreopened'     => 'Tichetul de mai jos a fost redeschis:',
'newdep'                  => 'Tichetul de mai jos are un alt tichet marcat ca duplicat:',
'notify.depremoved'       => 'Tichetul de mai jos nu mai este marcat ca duplicat:',
'olddepwas'               => 'Vechea dependenta era',
'notify.commentadded'     => 'Tichetului urmator i s-a adaugat un nou comentariu:',
'commentis'               => 'Continutul comentariului este mai jos.',
'newattachment'           => 'Un fisier a fost atasat urmatorului tichet:',
'detailsbelow'            => 'Detaliile sunt mai jos.',
'notify.relatedadded'     => 'Un tichet similar celui de mai jos a fost postat:',
'relatedis'               => 'Tichetul similar este',
'assignedtoyou'           => 'Ai fost atribuit urmatorului tichet:',
'takenownership'          => 'a luat conducerea urmatorului tichet:',
'requiresaction'          => 'Urmatorul tichet necesita interventia unui Manager de Proiect:',
'requiresactionnotify'    => 'Tichetul necesita interventia unui Manager de Proiect',
'pmdeny'                  => 'Managerul de proiect a refuzat cererea aflata in asteptare la urmatorul tichet:',
'pmdenynotify'            => 'Managerul de proiect a refuzat cererea',
'fileaddedtoo'            => 'Unul sau mai multe fisiere au fost atasate.',
'taskwatching'            => 'Tichetul urmator este urmarit de tine',
'isdepfor'                => 'este dependenta de',
'denialreason'            => 'Motivul respingerii',
'taskchanged'             => 'Tichetul dvs. a fost modificat. Pentru un scurt raport cu privire la acest tichet, accesati linkul de mai jos si apasati pe butonul Raport tichet.',
'useraddedtoassignees'    => 'Un utilizator a fost atribuit urmatorului tichet.',
'removeddepis'            => 'Dependenta eliminata este',
'isnodepfor'              => 'nu mai este dependenta pentru',
'usergroups'              => 'Grupuri de utilizatori',
'pmtoolbox'               => 'Panou administrare Man. Proiect',
'groupmanage'             => 'Administrare grup',
'pendingrequests'         => 'Asteapta interventii',
'reasongiven'             => 'Motiv?',
'nopendingreq'            => 'Nu este nimic care sa necesite interventia ta.',
'givereason'              => 'Ofera un motiv',
'catlisted'               => 'Modificare lista categorii',
'oslisted'                => 'Modificare lista Sisteme Operare',
'verlisted'               => 'Modificare lista versiuni',
'tasktypeed'              => 'Modificare lista tipuri tichete',
'resed'                   => 'Modificare lista rezolvari',
'deny'                    => 'Respinge',
'notifiedwhen'            => 'Notificare cand',
'onlynewtasks'            => 'Noi tichete sunt deschise',
'allevents'               => 'Orice eveniment care apare in orice tichet',
'feeds'                   => 'Feeduri',
'feeddescription'         => 'Descriere feed',
'feedimgurl'              => 'URL imagine feed (lasa necompletat daca nu doresti imagine)',
'notifysubject'           => 'Subiect notificari',
'notifysubjectinfo'       => '(%p = nume proiect, %s = sumar tichet, %t = id tichet, %a = actiune, %u = utilizator)',
'priority6'               => 'Urgent',
'priority5'               => 'Foarte mare',
'priority4'               => 'Medie',
'priority3'               => 'Mica',
'priority2'               => 'Foarte mica',
'priority1'               => 'Fara prioritizare',
'sendcode'                => 'Trimite cod!',
'entercode'               => 'Introdu codul primit in mesajul de notificare. Dealtfel, introdu si parola dorita.',
'confirmationcode'        => 'Cod confirmare',
'registererror'           => 'Asigura-te ca ai completat toate campurile obligatorii si ca ai introdus detaliile necesare pentru tipul de notificare dorit.',
'validusername'           => '(numai caracterele alfanumerice si - _ . sunt permise)',
'validemail'              => '(foloseste ; pentru a diferentia adresele de mail)',
'emailtakenbulk'          => 'Adresa de email este deja folosita',
'emailtaken'              => 'Aceasta adresa de email sau ID-Jabber este deja folosita. Trebuie sa folosesti alta.',
'note'                    => '<strong>Observatie:</strong> Vei primi un cod de confirmare inainte ca contul de utilizator sa fie creat. Codul va fi trimis folosind tipul de notificare ales mai sus.<br />Daca nu introduci detaliile corecte, <strong>nu vei primi codul</strong>.',
'changelog'               => 'Log modificari',
'changeloggen'            => 'Generator log modificari',
'listfrom'                => 'Afiseaza logul de modificari de la',
'to'                      => 'pana la',
'oldestfirst'             => 'Cel mai vechi primul',
'recentfirst'             => 'Cel mai recent primul',
'severityrep'             => 'Raport severitate',
'totalopen'               => 'Total tichete deschise',
'age'                     => 'Varsta',
'agerep'                  => 'Raport varsta',
'eventsrep'               => 'Raport evenimente',
'events'                  => 'Evenimente',
'Tasks'                   => 'Tichete',
'opened'                  => 'Deschise',
'edited'                  => 'Editate',
'assigned'                => 'Atribuite',
'within'                  => 'Pana in',
'pastday'                 => 'Ziua anterioara',
'pastweek'                => 'Saptamana anterioara',
'pastmonth'               => 'Luna anterioara',
'pastyear'                => 'Anul anterior',
'nolimit'                 => 'Fara limite',
'from'                    => 'De la',
'duein'                   => 'Pana in',
'selectfromdate'          => 'Selecteaza de la data',
'selecttodate'            => 'Selecteaza pana la data',
'showvoters'              => 'Arata/ascunde voturi',
'roadmap'                 => 'Harta',
'roadmapfor'              => 'Harta pentru versiunea',
'tasks'                   => 'tichete',
'completed'               => 'completate.',
'opentasks'               => 'tichete deschise',
'of'                      => '% din',
'severity5'               => 'Critica',
'severity4'               => 'Mare',
'severity3'               => 'Normala',
'severity2'               => 'Mica',
'severity1'               => 'Foarte mica',
'Redirect'                => 'Redirectare',
'redirectmsg'             => 'Daca browserul nu permite redirectionarile, apasa %sAICI%s sa fii redirectionat',
'allowclosedcomments'     => 'Permite comentarii noi la un tichet inchis',
'comment'                 => 'Comentariu',
'editowncomments'         => 'Modifica propriile comentarii',
'reopened'                => 'Redeschis',
'loading'                 => 'Incarcare...',
'notifyown'               => 'Notifica pentru schimbarile proprii',
'youremail'               => 'Adresa ta de e-mail',
'thankyouforbug'          => 'Multumim pentru ca ati raportat problema. Puteti vizualiza situatia tichetului si progresul acestuia oricand dand click pe urmatorul link:',
'anonuser'                => 'Utilizator anonim',
'conflict'                => 'Conflict',
'file'                    => 'Fisier',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => 'Marime',
'projectgroup'            => 'Grup proiect',
'profile'                 => 'Profil:',
'viewprofile'             => 'Vezi profil',
'regdate'                 => 'Inregistrat din',
'tasksopened'             => 'Tichete deschise',
'replyto'                 => 'Raspunde lui',
'notifytypes'             => 'Tip notificari',
'pm.taskchanged'          => 'Tichet modificat',
'pm.taskreopened'         => 'Tichet redeschis',
'pm.depadded'             => 'Dependenta adaugata',
'pm.depremoved'           => 'Dependenta eliminata',
'pmrequest'               => 'Cerere Manager Proiect',
'pmrequestdenied'         => 'Cerere Manager Proiect respinsa',
'newassignee'             => 'Persoana noua atribuita',
'revdepadded'             => 'Dependenta in oglinda adaugata',
'revdepaddedremoved'      => 'Dependenta in oglinda eliminata',
'assigneeadded'           => 'Persoana atribuita',
'addusergroup'            => 'Adauga utilizator la acest grup',
'groupmembers'            => 'Membrii grupului',
'deleteuser'              => 'Sterge acest utilizator',
'userdeleted'             => 'Utilizator sters',
'autoassign'              => 'Atribuie automat un tichet la titularul de categorie',
'ssl'                     => 'SSL',
'updatewrong'             => 'Ai optiunea de verificare daca exista update-uri, insa o eroare a aparut in incercarea
                             de a contacta serverul de update, hostul tau nu permite conectarile catre alte surse externe
                             sau eroarea a fost cauzata de o problema de retea.
                             Te rugam sa accesezi site-ul FlySpray pentru a fi sigur ca folosesti ultima versiune aparuta.',
'deleteproject'           => 'Sterge acest proiect si muta continutul in',
'projectdeleted'          => 'Proiectul a fost sters cu succes',
'feedforall'              => 'Feed pentru toate proiectele',
'usercreated'             => 'Utilizator creat',
'userdeleted'             => 'Utilizator sters',
'created'                 => 'Creat',
'deleted'                 => 'Sters',
'userid'                  => 'ID utilizator',
'editassignments'         => 'Modifica atribuirile',
'preview'                 => 'Previzualizare',
'anyprogress'             => 'Orice progres',
'tasksrelated'            => 'Tichetele asemanatoare',
'duplicatetasks'          => 'Tichetele duplicate',
'databasemodfailed'       => 'Modificarea bazei de date a esuat. Posibil sa nu existe suficiente permisiuni.',
'frequency'               => 'Frecventa',
'newuserregistered'       => 'Un utilizator nou s-a inregistrat. Detaliile sunt urmatoarele:',
'newuserregisterednotify' => 'Un nou utilizator s-a inregistrat',
'notify_registration'     => 'Notifica administratorii cand apare o noua inregistrare de utilizator',
'textversion'             => 'Versiune Text',
'onlyprimary'             => 'Tichete care nu blocheaza alte tichete',
'onlyblocker'             => 'Tichete care blocheaza alte tichete',
'blockerornoblocker'      => 'Blocheaza sau nu, selectare ambelor optiuni de filtrare nu au niciun sens.',
'switch'                  => 'Schimba',
'max'                     => 'max.',
'dates'                   => 'Data',
'selectduedatefrom'       => 'De la',
'selectduedateto'         => 'pana la',
'selectsincedatefrom'     => 'Schimbate de la',
'selectsincedateto'       => 'pana la',
'selectdate'              => 'Selecteaza data',
'selectopenedfrom'        => 'Deschise de la',
'selectopenedto'          => 'pana la',
'selectclosedfrom'        => 'Inchise de la',
'selectclosedto'          => 'pana la',
'startat'                 => 'Incepe de la',
'hasattachment'           => 'Are fisier atasat',
'private'                 => 'Privat',
'watching'                => 'Urmarire',
'alreadyvotedthistask'    => 'ai votat pentru acest tichet',
'alreadyvotedthisday'     => 'ai votat deja astazi',
'visibility'              => 'Vizibilitate',
'public'                  => 'Public',
'leaveemptyauto'          => 'Lasa parolele necompletate, daca doresti o parola generata automat.',
'novalidemail'            => 'Nu s-a introdus o adresa de email valida.',
'novalidjabber'           => 'Nu s-a introdus o adresa Jabber valida.',
'missingrequired'         => 'Nu s-au completat toate campurile obligatorii.',
'entervalidusername'      => 'Introdu un utilizator valid si un nume real.',
'couldnotaddusernotif'    => 'Nu s-a putut adauga acest utilizator la lista de notificari.',
'defaulttask'             => 'Descrierea tichetului implicita',
'all'                     => 'toate',
'events.useraddedtoassignees' => 'Persoana atribuita',
'eventlog'                => 'Log - Rapoarte',
'assignmentchanged'       => 'Atribuire',
'detailedinfo'            => 'Informatii detaliate',
'All'                     => 'Toate',
'tasksireported'          => 'Tichete deschise de mine',
'recentlyopened'          => 'Deschise recent',
'stats'                   => 'Statistici',
'totaltasks'              => 'tichete totale',
'mostwanted'              => 'Cele mai dorite tichete',
'defaultentry'            => 'Pagina implicita',
'toplevel'                => 'Vizualizare de sus',
'overview'                => 'Ansamblu',
'error#'                  => 'Eroare #',
'error1'                  => 'Nu ai permisiuni de a vizualiza acest fisier atasat.',
'error3'                  => 'Actiune repetata, redirectionare la pagina principala.',
'error4'                  => 'Nu ai drepturi administrative.',
'error5'                  => 'Acel utilizator nu exista in baza de date.',
'error6'                  => 'Zona de administrare invalida.',
'error7'                  => 'Autentificare esuata, parola incorecta!',
'error71'                 => 'Contul blocat pentru %d minute din cauza prea multor incercari esuate de autentificare!',
'error8'                  => 'Nu ai introdus numele de utilizator si parola.',
'error9'                  => 'Tichetul nu exista sau nu exista permisiuni pentru a il vizualiza.',
'error10'                 => 'Tichetul nu exista.',
'error101'                => 'Nu ai permisiunea de a vizualiza acest tichet.',
'error102'                => 'Nu ai permisiunea de a vizualiza tichetul. Incearca sa te autentifici pe site.',
'error11'                 => 'Nu ai permisiunea de a modifica acest comentariu.',
'error12'                 => 'Cheia nu este valida. Esti sigur ca ai primit-o prin mesajele de notificare?',
'error13'                 => 'Utilizatorii anonimi nu au profil.',
'error14'                 => 'Nu ai destule drepturi sa concepi un grup nou.',
'error15'                 => 'Nu ai destule drepturi pentru a deschide un tichet.',
'error16'                 => 'Nu esti Manager de Proiect.',
'error17'                 => 'Zona de administrare proiect invalida.',
'error18'                 => 'Link URL invalid.',
'error19'                 => 'Acest utilizator nu exista in baza de date.',
'error20'                 => 'Modificare a bazei de date invalida.',
'error21'                 => 'Unul sau mai multe mailuri nu au putut fi trimise. Verifica configurarile.',
'error22'                 => 'Nu sunt permise inregistrarile noi de utilizatori.',
'error23'                 => 'Grupul sau utilizatorul nu au dreptul de a se autentifica.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Roadmap only available for a specific project.',
'error26'                 => 'Unsupported oauth provider.',
'error27'                 => 'Unable to login in. Authorize us to view your email address.',
'error28'                 => 'You have no permission to access this area.',
'done'                    => 'finalizat',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Proiectul nu a putut fi sters.',
'GMT'                     => 'GMT',
'timezone'                => 'Zona locala',
'accept'                  => 'Accept',
'reasonfordeinal'         => 'Motivul pentru refuz',
'pruneclosedlinks'        => 'Sterge linkurile inchise',
'pruneclosedtasks'        => 'Sterge tichetele inchise',
'pagegenerated'           => 'Pagina si imagine generata in %d secunde.',
'pruninglevel'            => 'Nivelul de stergere',
'lastuser'                => 'Ultimul utilizator nu a putut fi sters.',
'allprivate'              => 'Toate proiectele sunt private.',
'deletegroup'             => 'Sterge acest grup si muta utilizatorii in',
'parent'                  => 'Parinte',
'ordertip'                => 'Ordinea in care aceste elemente vor aparea in lista',
'showtip'                 => 'Afiseaza acest element in lista',
'deletetip'               => 'Sterge acest element din lista',
'del'                     => 'del',
'request1'                => 'Se cere inchiderea tichetului.',
'request2'                => 'Se cere redeschiderea tichetului.',
'allpriorities'           => 'Toate prioritatile',
'noroadmap'               => 'Fisa de parcurs nu este disponibila (se pare ca nu exista in plan "versiuni" ulterioare).',
'expand'                  => 'Extindere',
'collapse'                => 'Restrangere',
'expandall'               => 'Extinde tot',
'collapseall'             => 'Restrange tot',
'minpwsize'               => 'Parola trebuie sa contina minim 5 caractere',
'passwordtoosmall'        => 'Parola introdusa este prea scurta.',
'accountwaslocked'        => 'Contul tau a fost blocat din cauza prea multor incercari de autentificare esuate.',
'failedattempts'          => 'Au fost %d tentative de autentificare esuate.',
'groupnotexist'           => 'Grupul selectat nu exista in acest proiect.',
'searchindetails'         => 'Cauta detalii',
'showasassignees'         => 'Afiseaza ca atribuiti',
'find'                    => 'Atribuire',
'tls'                     => 'TLS',
'isadmin'                 => 'Este admin',
'addvotes'                => 'Adauga vot',
'removevote'              => 'Sterge vot',
'voteremoved'             => 'Votul tau a fost sters',
'voteremovefailed'        => 'Votul tau nu a putut fi sters la acest moment.',
'novotes'                 => 'In prezent nu ai niciun vot la niciun tichet.',
'connectedtasks'          => 'Tichete conectate:',
'taskdependencies'        => 'Tichete dependente',
'viewgraph'               => 'vezi grafic',
'notaskdependencies'      => 'Acest tichet nu depinde de un altul.',
'dependson'               => 'Depinde de',
'blocks'                  => 'Blocheaza',
'newdependency'           => 'Depinde de:',
'nouserstoadd'            => 'Nu sunt utilizatori de adaugat. Fii sigur ca Nume, Nume utilizator si Adresa de mail sunt definite pentru fiecare utilizator in parte.',
'dispintro'               => 'Afiseaza mesajul introductiv',
'mainmessage'             => 'Mesaj introductiv',
/* note only the English version for 'dispintro' is supported
 * other languages should also be taken cared of in the future*/

'setsupertask'            => 'Seteaza ID Super-Tichet ID:',
'supertaskmodified'       => 'ID Super-Tichet a fost modificat',
'set'                     => 'Seteaza',
'supertask'               => 'Super-Tichet',
'setparent'               => 'Seteaza acest tichet ca principal',
'selfsupertasknotallowed' => 'ID-ul Super-Tichetului nu poate fi acelasi cu ID-ul de tichet',
'quickaction'             => 'Optiuni tichet',
'updateselectedtasks'     => 'Actualizeaza tichetele selectate',
'notspecified'            => 'Nespecificat',
'editselectedtasks'       => 'Modifica tichetele selectate',
'information'             => 'Informatii',
'taskclosedisabled'       => 'Inchiderea tichetului nu este disponibila deoarece tichetele care depind de el inca sunt deschise:-',
'daysleft'                => 'zile ramase',
'dayoverdue'              => 'zile depasite',
'duetoday'                => 'pana azi',
'daysbeforealert'         => 'Zile inaintea alertei',
'associatedsubtask'       => 'S-a asociat cu succes tichetul',
'associatesubtask'        => 'Seteaza acest tichet ca duplicat',
'subtaskid'               => 'ID Sub-tichet',
'subtaskalreadyhasparent' => 'Sub-tichetul introdus are deja un tichet de tip parinte. Te rog sa elimini asocierea si sa incerci din nou.',
'subtaskisparent'         => 'Sub-tichetul introdus este parintele acestui tichet. Nu se poate face asocierea.',
'subtasknotexist'         => 'Sub-tichetul introdus nu exista.',
'subtaskremovedmsg'       => 'Sub-tichetul a fost eliminat cu succes',
'subtaskadded'            => 'Sub-tichet adaugat',
'subtaskremoved'          => 'Sub-tichet eliminat',
'addnewsubtask'           => 'Adauga tichet nou ca si completare',
'hidesubtasks'            => 'Ascunde subcategorie',
'voteforthistask'         => 'Voteaza pentru acest tichet',
'watchthistask'           => 'Urmareste acest tichet',
'privatethistask'         => 'Fa acest tichet privat',
'adddependenttask'        => 'Adauga dependenta de tichetul',
'associatetaskid'         => 'ID sub-tichet',
'parenttaskid'            => 'ID tichet parinte',
'invalidsupertaskid'      => 'ID parinte nu este valid.',
'supertaskadded'          => 'Tichet important adaugat',
'supertaskremoved'        => 'Tichet important sters',
'effort'                  => 'Efort',
'efforttracking'          => 'Cronometru efort',
'useeffort'               => 'Proiectul foloseste cronometrarea de efort',
'estimatedeffort'         => 'Durata de lucru estimata',
'totalestimatedeffort'    => 'Efortul total estimat',
'currenteffortdone'       => 'Durata de lucru efectuata',
'starteffort'             => 'Incepe cronometrarea',
'endeffort'               => 'Opreste cronometrarea',
'cleareffort'             => 'Sterge cronometrarea',
'addeffort'               => 'Adauga efort',
'manualeffort'            => 'Adauga efort manual (H:m)',
'efforttrackingstarted'   => 'Cronometrarea efortului la acest tichet a inceput.',
'efforttrackingnotstarted'=> 'Nu pot incepe cronometrarea la un tichet la care exista deja o cronometrare in curs.',
'efforttrackingstopped'   => 'Cronometrarea efortului la acest tichet a luat sfarsit.',
'efforttrackingcancelled' => 'S-a anulat cronometrarea de efort la acest tichet.',
'efforttrackingadded'     => 'Efortul manual pentru acest tichet a fost inregistrat.',
'trackinginprogress'      => 'Urmarirea progresului',
'viewestimatedeffort'     => 'Poate vizualiza efortul depus',
'viewcurrenteffortdone'   => 'Poate vizualiza timpul pentru dezvoltare curent',
'trackeffort'             => 'Poate cronometra efortul',
'invalideffort'           => 'Timpul oferit este invalid. Trebuie sa fie de tip numeric.',
'showpass'                => 'Afiseaza parola',
'chooseafile'             => 'Alege un fisier!',
'incorrectfiletype'       => 'Fisierul ales este incorect. Fisiere permise: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Nu este nevoie de parola. Esti inregistrat prin %s',
'addmultipletasks'        => 'Adauga mai multe tichete',
'pendingnewuserrequest'   => 'Utilizator nou in asteptare',
'adminrequestswaiting'    => 'Cerinte pentru administrator in asteptare',
'clicktoedit'             => 'Editeaza rapid tichetul apasand pe fiecare camp in parte',
'confirmedit'             => 'Modifica',
'canceledit'              => 'Renunta',
'regapprovedbyadmin'      => 'Inregistrarile sunt aprobate de cate administratori (se dezactiveaza codul de confirmare)',
'activity'                => 'Activitate',
'myactivity'              => 'Activitatea mea',
'emailverificationwrong'  => 'Adresa de confirmare nu corespunde cu adresa oferita initial',
'verifyemailaddress'      => 'Confirma adresa de email',
'hideemails'              => 'Ascunde adresele de email ale utilizatorilor',
'hidemyemail'             => 'Ascunde-mi adresa de email',
'exporttasklist'          => 'Exporta lista tichete',
'onedecimal'              => 'o singura zecimala',
'manday'                  => 'Munca persoanei pe zi',
'mandays'                 => 'Munca persoanei pe zile',
'mandayabbrev'            => 'mpz',
'hourspermanday'          => 'Ore de munca pe zi (HH:mm)',
'itemexists'              => 'Elementul %s exista deja in baza de date.',
'categoryitemexists'      => 'Elementul %s este deja in categoria %s.',
'pageswelcomemsg'         => 'Paginile in care sa se afiseze mesajul introductiv',
'pagesintromsg'           => 'Paginile in care sa se afiseze mesajul introductiv',
'activeoauths'            => 'Provideri Oauth activi',
'onlyoauthreg'            => 'Permite doar autentificarile Oauth',
'estimatedeffortformat'   => 'Formatul pentru estimarea efortului',
'currenteffortdoneformat' => 'Formatul curent pentru efortul depus',
'minute'                  => 'minut',
'minutes'                 => 'minute',
'minuteplural'            => 'minute',
'minutesingular'          => 'minut',
'minuteabbrev'            => 'min',
'hourplural'              => 'ore',
'hoursingular'            => 'ora',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'Efortul estimat pentru tichetele deschise',
'currenteffortdoneopen'   => 'Efortul curent depus in tichetele deschise',
'signinwith'              => 'Inregistreaza-te cu %s',
'canviewroadmap'          => 'Poate vizualiza fisa de parcurs',
'enableavatars'           => 'Activeza imagini profil',
'maxavatarsize'           => 'Dimensiune maxima a imaginii de profil (pixeli)',
'taskhassubtask'          => 'Acest tichet are urmatorul sub-tichet',
'taskhassubtasks'         => 'Acest tichet are urmatoarele sub-tichete',
'translations'            => 'Traduceri',
'translate'               => 'Tradu',
'taskdescription'         => 'DESCRIERE:',
'notaskdescription'       => 'nu exista o descriere a tichetului',
'pleaseselect'            => 'Selecteaza',
'closeselectedtasks'      => 'Inchide tichetele selectate',
'closetasks'              => 'inchide tichete',
'hintforbulkimport'       => '<b>Adauga mai multe tichete deodata</b>',
'taskissubtaskof'         => 'Acesta este un sub-tichet al',
'applyfirstline'          => 'Introdu prima linie',
'addmorerows'             => 'Adauga si alt tichet in lista',
'addtasks'                => 'Adauga toate tichetele',
'massopsdisabled'         => 'Momentan nu se pot modifica mai multe tichete in aceasta versiune (1.0). Incercam sa facem implementarea intr-o versiune ulterioara',
'viewroadmap'             => 'Poate vizualiza fisa de parcurs',
'nosuicide'               => 'Programul nu iti permite sa distrugi accesul la FlySpray prin dezactivarea propriului cont sau prin schimbarea propriului grup.',
'movingtodifferentproject' => 'Mutarea unui tichet care are fie un parinte sau sub-tichete intr-un alt proiect nu este permisa. Trebuie sa intrerupi conexiunile intre tichete inainte.',
'musthavesameproject'     => 'Tichetul tip parinte si sub-tichetul trebuie sa apartina aceluiasi proiect.',
'defaultorderby'          => 'Ordoneaza implicit lista de tichete dupa',
'defaultorderby2'         => 'apoi dupa',
'viewowntasks'            => 'Vizualizare propriile tichete',
'viewgroupstasks'         => 'Vizualizare tichetele de grup',
'urlrewriting'            => 'Rescriere URL',
'enablehtaccess'          => 'Activeaza scrierea pe fisierul .htaccess din calea in care este instalat FlySpray inainte de a activa rescrierea URL',
'nomodrewrite'            => 'Modul de rescriere pare sa nu fie disponibil pe acest server; imi pare rau dar nu pot activa rescrierea de URL',
'on'                      => 'Pornit',
'off'                     => 'Oprit',
'defaultorderbydirection' => 'Sortarea implicita dupa directie',
'ascending'               => 'Crescator',
'descending'              => 'Descrescator',
'myassignedtasks'         => 'Tichetele mele',
'commentedon'             => 'a raspuns pe',
'maxvoteperday'           => 'Voturi maxime pe zi',
'votesperproject'         => 'Limita utilizatorului de voturi per proiect',
'votelimitreached'        => 'S-a atins numarul maxim de voturi pentru acest proiect. Verifica profilul tau sa vezi la ce tichete ai votat in prezent. De acolo poti anula cateva voturi. Asa putem vedea care sunt tichetele cele mai importante pentru tine. Rezolvarea tichetelor iti reseteaza limita de voturi pe zi.',
'myvotes'                 => 'Voturile mele',
'tag'                     => 'Eticheta',
'tags'                    => 'Etichete',
'tagsinfo'                => 'Etichetare libera in FlySpray: separa etichetele cu ;. Nu se poate face o cautare dupa etichete inca. Nici filtrare si nici sortare.',
'novalues'                => 'fara intrari',
'youhaveregistered'       => 'Te-ai inregistrat la FlySpray. Detaliile de conectare sunt urmatoarele:',
'youhaveregisterednotify' => 'Inregistrarea la FlySpray a fost acceptata de administratori.',
'usedintasks'             => 'Folosire',
'freetagging'             => 'permite etichete definite de utilizatori',
'keyboardshortcuts'       => 'Taste rapide',
'testmailsettings'        => 'Verifica setarile de email active in prezent',
'test'                    => 'Testeaza',
'testmailsettingsnotice'  => 'Verifica daca ai primit emailul de test pe adresa de mail a utilizatorului in cauza (vezi \'profilulmeu\'-pagina)',
'invalidinput'            => 'Se pare ca sunt niste proprietati incompatibile ce trebuiesc rezolvate inainte de a muta tichetul in alt proiect.',
'invalidprogress'         => 'Selecteaza valoarea de progres valida.',
'invalidpriority'         => 'Selecteaza o valoare de prioritate valida.',
'invalidseverity'         => 'Selecteaza o valoare de severitate valida.',
'invalidstatus'           => 'Selecteaza un status de tichet valid in momentul cand muti acest tichet in alt proiect.',
'invalidcategory'         => 'Selecteaza o categorie valida in momentul cand muti acest tichet in alt proiect.',
'invalidreportedversion'  => 'Selecteaza o versiune valida cand muti acest tichet in al proiect.',
'invaliddueversion'       => 'Selecteaza o versiunea de implementat valida in momentul cand muti acest tichet in alt proiect.',
'invalidos'               => 'Selecteaza un Sistem de Operare valid in momentul cand muti acest tichet in alt proiect.',
'invalidtags'             => 'Selecteaza doar etichetele permise in momentul cand muti tichetul in alt proiect.',
'invalidassignees'        => 'Selecteaza doar persoanele permise sa li se atribuie tichete atunci cand muti tichetul in alt proiect.',
'customize'               => 'personalizeaza',
'hidesubs'                => 'ascunde sub-tichete',
'hideprivate'             => 'ascunde tichetele private',
'hideclosed'              => 'ascunde tichetele inchise',
'currentproject'          => 'proiect curent',
'targetproject'           => 'proiect tinta',
'availablekeybshortcuts'  => 'Shortcuturi prin tastatura disponibile',
'logindialoglogout'       => 'Fereastra autentificare / deautentificare',
'focustaskidsearch'       => 'concentreaza cautarea dupa ID tichet',
'openselectedtask'        => 'deschide tichetul selectat',
'movecursorup'            => 'urca cursorul',
'movecursordown'          => 'coboara cursorul',
'taskdetails'             => 'Detalii tichet',
'taskediting'             => 'Editare tichet',
'savetask'                => 'salveaza tichet'
);
?>
