<?php

$translation = array(
'edituser'                => '編輯用戶',
'accountenabled'          => '帳號啟用',
'editallusers'            => '查看所有用戶',
'username'                => '使用者',
'usersupdated'            => '使用者更新成功',
'realname'                => '真實姓名',
'emailaddress'            => '電子郵件',
'jabberid'                => 'Jabber ID',
'profileimage'            => '圖片',
'notifytype'              => '通知類型',
'group'                   => '群組',
'enableaccounts'          => '啟動帳號',
'disableaccounts'         => '關閉帳號',
'deleteaccounts'          => '移除帳號',
'updatedetails'           => '更新詳細資訊',
'setglobally'             => '這個一般設定已被設定為全域設定',
'usergroupmanage'         => '使用者與群組管理',
'newuser'                 => '註冊新使用者',
'newuserbulk'             => '註冊多個新的使用者',
'bulkuserstoadd'          => '新用戶列表',
'optionsforallusers'      => '所有新用戶選項',
'newgroup'                => '建立群組',
'yes'                     => '是',
'no'                      => '否',
'editgroup'               => '編輯群組',
'groupname'               => '群組名',
'description'             => '描述',
'admin'                   => '管理群組',
'opennewtasks'            => '打開新建任務',
'modifytasks'             => '修改任務',
'addcomments'             => '新增註解',
'attachfiles'             => '附件',
'vote'                    => '投票',
'groupopen'               => '成員可以登入',
'groupenabled'            => '成員可以登入',
'tasktypelist'            => '任務類型列表',
'categorylist'            => '模組列表',
'oslist'                  => '作業系統列表',
'resolutionlist'          => '解決方式列表',
'versionlist'             => '版本列表',
'severitylist'            => '問題嚴重性列表',
'listnote'                => '注意： 在編輯環境下，取消 "顯示" 複選框會改變一些任務。 修改"名稱"字串會用這個名稱修改全部任務。',
'name'                    => '名稱',
'order'                   => '順序',
'back'                    => '退後',
'text'                    => '文本',
'highlight'               => '高亮',
'show'                    => '顯示',
'owner'                   => '主管',
'selectowner'             => '選擇所有者',
'update'                  => '更新',
'addnew'                  => '增加',
'flysprayprefs'           => 'Flyspray 常用設定',
'projecttitle'            => '專案標題',
'baseurl'                 => 'Base URL for 這個安裝',
'replyaddress'            => '通知的回覆電子郵件地址',
'themestyle'              => '主題 / 樣式',
'language'                => '語言',
'customstyle'             => '自定義的樣式',
'anonview'                => '允許匿名用戶查看任務',
'allowanon'               => '允許匿名用戶打開新任務',
'never'                   => '從不',
'anonymously'             => '匿名',
'afterregister'           => '只有在註冊之後',
'spamproof'               => '啟用新用戶註冊確認碼',
'anongroup'               => '新用戶註冊的群組',
'groupassigned'           => '這些群組的成員能被指派任務',
'forcenotify'             => '任務通知方式',
'neversend'               => '不發送',
'userchoose'              => '讓用戶自己選擇',
'email'                   => '電子郵件',
'jabber'                  => 'Jabber',
'defaultcatowner'         => '預設的模組主管',
'noone'                   => '不要',
'jabbernotify'            => 'Jabber通知',
'jabberserver'            => '伺服器',
'jabberport'              => '連接埠',
'jabberuser'              => '帳號帳號',
'jabberpass'              => '帳號密碼',
'saveoptions'             => '儲存選項',
'editcomment'             => '編輯評論',
'commentby'               => '評論人',
'saveeditedcomment'       => '儲存評論',
'projectprefs'            => '專案常用設定',
'pagetitle'               => '頁面標題',
'defaultproject'          => '預設的專案',
'projectlists'            => '專案列表',
'showlogo'                => '顯示標題圖片',
'showgravatars'           => '顯示頭像',
'emailNoHTML'             => '沒有HTML電子郵件',
'intromessage'            => '介紹性訊息',
'active'                  => '啟動',
'inactive'                => '關閉',
'isactive'                => '專案是啟動的',
'createproject'           => '建立一個新專案',
'showinactive'            => '顯示關閉的專案',
'hideinactive'            => '隱藏關閉的專案',
'nopermission'            => '您沒有權限使用這個頁面.',
'listordertip'            => '這些條目的順序將顯示在列表裡',
'listshowtip'             => '在列表裡顯示這個條目 ',
'categoryownertip'        => '當這個模組中打開一個任務時，這個人將收到通知',
'categoryparenttip'       => '這個新模組的上級模組將會降級',
'notsubcategory'          => '無 (頂級模組)',
'showinlineimages'        => '嵌入顯示圖片附件',
'dateformat'              => '日期格式',
'dateformat_extended'     => '詳細日期格式',
'cache_feeds'             => '動態訊息暫存',
'no_cache'                => '不暫存',
'cache_disk'              => '暫存到磁碟',
'cache_db'                => '暫存到資料庫',
'subcategoryof'           => '子模組',
'visiblecolumns'          => '任務列表中顯示的列',
'visiblefields'           => '當新增/編輯/查看任務時',
'tense'                   => '時間',
'listtensetip'            => '過去的, 現在的或者將來的',
'past'                    => '過去的',
'present'                 => '現在的',
'future'                  => '將來的',
'oldpass'                 => '舊的密碼',
'nooldpass'               => '沒有設定舊的密碼',
'oldpasswrong'            => '舊的密碼是錯的',
'changepass'              => '修改密碼',
'confirmpass'             => '確認密碼',
'projectmanager'          => '專案經理',
'viewtasks'               => '查看任務',
'modifyowntasks'          => '修改自己主管的任務',
'modifyalltasks'          => '修改不屬於用戶主管的任務',
'viewcomments'            => '查看評論',
'editcomments'            => '編輯評論',
'deletecomments'          => '刪除評論',
'viewattachments'         => '查看附件',
'createattachments'       => '建立附件',
'deleteattachments'       => '刪除附件',
'viewhistory'             => '查看歷史',
'closeowntasks'           => '關閉主管任務',
'closeothertasks'         => '任務不是用戶主管的關閉',
'assigntoself'            => '如果沒有被指派，指派任務給自己',
'assignotherstoself'      => '指派其他人的任務到自己',
'viewreports'             => '查看事件日誌',
'othersview'              => '允許任何人查看這個專案的任務',
'othersviewroadmap'       => '允許任何人查看這個專案的視圖',
'usersandgroups'          => '用戶群組',
'globalgroup'             => '全域群組',
'globalgroups'            => '全域群組',
'defaultglobalgroup'      => '新用戶預設的全域群組',
'addtogroup'              => '增加到群組',
'moveuserstogroup'        => '移動用戶到群組',
'nogroup'                 => '無群組 - 從專案移除',
'eventdesc'               => '事件描述',
'requestedby'             => '申請人',
'daterequested'           => '申請日期',
'closetask'               => '關閉任務',
'reopentask'              => '重新打開任務',
'applymember'             => '申請專案成員資格',
'forcurrentproj'          => '當前的專案',
'lostpw'                  => '找回遺失的密碼',
'lostpwexplain'           => '請輸入您的帳號，我們會發送一個修改您密碼的連結到您的個人資料中填寫的通知郵件地址.',
'sendlink'                => '發送連結',
'savenewpass'             => '儲存新密碼',
'anonreg'                 => '允許新用戶註冊',
'allowanonopentask'       => '允許匿名用戶打開任務',
'editglobalgroup'         => '編輯全域群組',
'editgroupforproj'        => '編輯專案的群組',
'notshownforadmin'        => '管理群組的權限沒有顯示.您不需要編輯它們.',
'general'                 => '常用',
'userregistration'        => '用戶註冊',
'notifications'           => '通知',
'resetoptions'            => '重置選項',
'preferences'             => '常用設定',
'tasktypes'               => '任務類型',
'resolutions'             => '解決方式',
'categories'              => '模組定義',
'operatingsystems'        => '作業系統',
'versions'                => '版本定義',
'admintoolboxlong'        => '管理員工具箱',
'newproject'              => '新建專案',
'delete'                  => '刪除',
'link'                    => '連結',
'referencelinks'          => '參考連結',
'listdeletetip'           => '從列表中刪除這個條目',
'lookandfeel'             => '外觀',
'globaltheme'             => '全域主題',
'emailnotify'             => '電子郵件 通知',
'fromaddress'             => '發件地址',
'smtpserver'              => 'SMTP 伺服器',
'smtpuser'                => 'SMTP 帳號',
'smtppass'                => 'SMTP 密碼',
'addrewrite'              => '使用地址重寫',
'usereminderdaemon'       => '啟用後台提醒服務',
'tasksperpage'            => '每頁任務列表顯示的任務數',
'addtoassignees'          => '增加自己為被指派人',
'taskstatuses'            => '任務狀態',
'canvote'                 => '可以對任務投票',
'loginsuccessful'         => '登入成功.',
'youareloggedout'         => '您已經註銷了.',
'waitwhiletransfer'       => '請稍後...',
'clicknowait'             => '如果您不想等待，請點這裡.',
'accountdisabled'         => '您的帳號被禁用了. 請聯繫管理員.',
'task'                    => '任務',
'edittask'                => '編輯這個任務',
'openedby'                => '任務打開人：',
'editedby'                => '最後修改者：',
'tasktype'                => '任務類型',
'category'                => '模組',
'status'                  => '狀態',
'assignedto'              => '指派到',
'operatingsystem'         => '作業系統',
'severity'                => '嚴重性',
'reportedversion'         => '報告版本',
'dueinversion'            => '延期到版本',
'defaultdueinversion'     => '預設新任務延期到版本',
'undecided'               => '未決定',
'percentcomplete'         => '完成百分比',
'details'                 => '詳細訊息',
'savedetails'             => '儲存詳細訊息',
'canceledit'              => '取消編輯',
'anonymous'               => '匿名提交者',
'complete'                => '完成',
'closedby'                => '關閉，由',
'reasonforclosing'        => '關閉的理由:',
'reopenthistask'          => '重新打開這個任務',
'comments'                => '評論數量',
'attachments'             => '附件數量',
'relatedtasks'            => '關聯任務',
'edit'                    => '編輯',
'addcomment'              => '增加評論',
'fileuploadedby'          => '文件上傳，由',
'uploadafile'             => '附加一個文件',
'addalink'                => '新增一個連結',
'addanotherlink'          => '新增另一個連結',
'uploadnow'               => '現在上傳!',
'thesearerelated'         => '這些任務被關聯到這個任務了',
'remove'                  => '移除',
'addnewrelated'           => '增加一個新的關聯任務',
'add'                     => '增加!',
'otherrelated'            => '這個任務關聯的其他的任務',
'receivenotify'           => '當這個任務被修改時，下列用戶將收到詳細的通知.',
'addusertolist'           => '增加用戶到通知列表',
'addtolist'               => '增加到列表',
'addmyself'               => '把我加入到這個列表中',
'removemyself'            => '從這個列表中移除我自己',
'theseusersnotify'        => '當這個任務被修改時，下面的用戶將收到詳細的通知.',
'attachedtoproject'       => '屬於專案',
'reminders'               => '提醒',
'system'                  => '系統',
'systemvalues'            => '系統列表值範圍',
'projectvalues'           => '專案的具體列表值',
'remindthisuser'          => '提醒用戶',
'thisoften'               => '每隔',
'startafter'              => '啟動提醒前等待',
'hour'                    => '小時',
'hours'                   => '小時',
'day'                     => '天',
'days'                    => '天',
'week'                    => '星期',
'weeks'                   => '星期',
'addreminder'             => '增加提醒',
'defaultreminder'         => '下面是 Flyspray 的任務提醒:',
'message'                 => '消息',
'closed'                  => '已解決的',
'filename'                => '文件名稱:',
'date'                    => '日期',
'filesize'                => '文件大小:',
'closurecomment'          => '其它關於關閉的評論:',
'history'                 => '歷史',
'nohistory'               => '沒有歷史.',
'eventdate'               => '日期',
'user'                    => '用戶',
'event'                   => '事件',
'fieldchanged'            => '欄位發生變動',
'taskopened'              => '任務被打開了',
'taskreopened'            => '任務被重新打開了',
'taskclosed'              => '任務被關閉了',
'commentadded'            => '評論增加了',
'commentedited'           => '評論修改了',
'commentdeleted'          => '評論刪除了',
'attachmentadded'         => '附件增加了',
'attachmentdeleted'       => '附件刪除了',
'taskedited'              => '任務詳細訊息修改了',
'notificationadded'       => '用戶增加到通知列表了',
'notificationdeleted'     => '用戶從通知列表中移除了',
'relatedadded'            => '關聯任務增加了',
'relateddeleted'          => '關聯任務移除了',
'taskassigned'            => '任務被指派到',
'taskreassigned'          => '任務被重新指派到',
'assignmentremoved'       => '指派被移除了',
'summary'                 => '摘要',
'addedasrelated'          => '任務增加到其關聯列表了：',
'deletedasrelated'        => '任務從其關聯列表中移除了',
'reminderadded'           => '提醒增加了',
'reminderdeleted'         => '提醒刪除了',
'priority'                => '優先級',
'previousvalue'           => '前一個值',
'newvalue'                => '新值',
'selectareason'           => '選擇一個理由',
'assigntome'              => '指派到我',
'reopenrequest'           => '請求重新打開',
'requestclose'            => '請求關閉',
'ownershiptaken'          => '用戶成為主管',
'closerequestmade'        => '申請任務關閉',
'reopenrequestmade'       => '申請任務被重新打開',
'taskdependson'           => '這個任務依賴',
'taskdependsontask'       => '任務取決於',
'taskdependsontasks'      => '任務取決於',
'taskblock'               => '這個任務被阻止關閉',
'taskblocks'              => '這個任務被阻止關閉',
'depadded'                => '依賴增加的',
'depaddedother'           => '這個任務增加為依賴',
'depremoved'              => '依賴移除',
'depremovedother'         => '這個任務從其他的任務依賴列表中移除了',
'showdetailserror'        => '任務不存在, 或者您沒有查看它的權限。',
'makeprivate'             => '置為不公開',
'makepublic'              => '置為公開',
'taskmadeprivate'         => '任務成為不公開的了',
'taskmadepublic'          => '移除了私有屬性 - 任務成為公開的了',
'confirmdeletecomment'    => '真的刪除這個評論? %s',
'attachementswilldeleted' => '所有附件也將被刪除!',
'confirmdeleteattach'     => '真的刪除這個附件?',
'selectedhistory'         => '正在顯示選定的歷史詳細訊息',
'showallhistory'          => '重新顯示全部歷史標籤',
'hidethis'                => '重新隱藏這個區域',
'mark100'                 => '標記任務為100%完成',
'watchtask'               => '關注任務',
'stopwatching'            => '停止關注',
'commentlink'             => '連結到這個評論',
'submitreq'               => '提交請求',
'reasonforreq'            => '這個請求的理由',
'pmreqdenied'             => '專案經理拒絶了請求',
'taskpendingreq'          => '專案經理操作被掛起.  進一步詳細訊息請查看歷史頁.',
'previoustask'            => '前一個任務',
'nexttask'                => '下一個任務',
'duedate'                 => '延期到日期',
'attachnoperms'           => '這個評論有附件, 但是您沒有權限查看',
'linknoperms'             => '這個評論有連結, 但是您沒有權限查看',
'open'                    => '未解決的',
'depgraph'                => '查看依賴圖表',
'reset'                   => '重置',
'selectusers'             => '選擇用戶...',
'addmetoassignees'        => '把我加入被指派人',
'addedtoassignees'        => '用戶增加到被指派人列表',
'dependencygraph'         => '依賴圖表',
'attachanotherfile'       => '附加另一個 文件',
'OK'                      => '好',
'addvote'                 => '增加投票',
'disable_lostpw'          => '禁止遺失密碼檢索',
'disable_changepw'        => '禁止密碼建立/編輯',
'notifyfromfs'            => '來自Flyspray的通知',
'autogenerated'           => '這個是自動生成的消息,請勿回覆',
'forward'                 => '向前',
'previous'                => '前一個',
'next'                    => '下一個',
'first'                   => '第一個',
'last'                    => '最後一個',
'page'                    => '第 %d 頁，共 %d 頁',
'search'                  => '搜尋',
'alltasktypes'            => '全部任務類型',
'allseverities'           => '全部嚴重性級別',
'alldevelopers'           => '全部開發人員',
'notyetassigned'          => '尚未被指派',
'allcategories'           => '全部模組',
'allstatuses'             => '全部狀態',
'allopentasks'            => '全部打開的任務',
'sortthiscolumn'          => '以此列排序',
'id'                      => '編號',
'project'                 => '專案',
'dateopened'              => '打開的',
'progress'                => '進度',
'searchthisproject'       => '在專案中搜尋',
'dueanyversion'           => '延期到任何版本',
'anyversion'              => '任何版本中的報告',
'dueversion'              => '延期到版本',
'lastedit'                => '最近修改的',
'os'                      => '作業系統',
'reportedin'              => '報告',
'taskrange'               => '正在顯示 任務 %d - %d (共%d 個)',
'noresults'               => '您的搜尋沒有返回結果.',
'takeaction'              => '操作',
'watchtasks'              => '關注選定的任務',
'stopwatchingtasks'       => '停止關注選定的任務',
'assigntaskstome'         => '將選定的任務指派給我',
'dueby'                   => '延期，由',
'dueanytime'              => '延期任意事件',
'selectduedate'           => '選擇延期日期',
'toggleselected'          => '反選選定的',
'due'                     => '延期',
'assignedtome'            => '指派到我的',
'tasklist'                => '任務列表',
'dateclosed'              => '關閉的日期',
'advanced'                => '進階',
'searchcomments'          => '在評論中搜尋',
'searchforall'            => '搜尋全部詞',
'anonusers'               => '匿名用戶',
'miscellaneous'           => '雜項',
'users'                   => '用戶',
'taskproperties'          => '任務屬性',
'selectsincedate'         => '選擇發生變動自從',
'changedsince'            => '發生變動自從',
'updatefs'                => '請更新Flyspray.',
'currentversion'          => '您的當前的版本是',
'latestversion'           => '，最新的版本是',
'hidemessage'             => '(以後提醒我)',
'saveas'                  => '儲存搜尋為',
'nosearches'              => '沒有儲存的搜尋',
'saving'                  => '儲存...',
'votes'                   => '投票',
'tovote'                  => '投票',
'allclosedtasks'          => '全部關閉的任務',
'password'                => '密碼',
'login'                   => '登入!',
'rememberme'              => '記住我',
'lostpassword'            => '遺失了密碼',
'lostpwforfs'             => '遺失了Flyspray的密碼',
'lostpwmsg1'              => "您好。\n\n我遺失了 Flyspray 密碼 ",
'lostpwmsg2'              => ", 請提供我一個新密碼.\n\nUsername: ",
'regards'                 => "\n\n敬禮,",
'yourusername'            => ' 您的帳號 ',
'locale'                  => 'zh-TW',
'filenotexist'            => '文件不存在, 或者您沒有權限訪問它.',
'showtask'                => '顯示任務',
'now'                     => '現在',
'go'                      => '開始!',
'opentaskanon'            => '匿名打開一個新任務',
'register'                => '註冊',
'addnewtask'              => '增加新任務',
'reports'                 => '事件日誌',
'editmydetails'           => '編輯我的詳細訊息',
'logout'                  => '註銷',
'disabledaccount'         => '您的帳號被禁用了!<br>即刻將您註銷...',
'poweredby'               => '平台提供 FlySpray',
'sponsoredby'             => 'Flyspray 發起者',
'projects'                => '專案',
'allprojects'             => '全部專案',
'selectproject'           => '專案:',
'tasksall'                => '全部任務',
'tasksassigned'           => '被指派到我的任務',
'tasksreported'           => '我報告的任務',
'taskswatched'            => '我關注的 ',
'mysearch'                => '我的搜尋',
'admintoolbox'            => '管理員工具箱',
'manageproject'           => '管理專案',
'permissions'             => '查看權限',
'hide'                    => '隱藏',
'pendingreq'              => '專案經理請求正在等待',
'errorpage'               => "Flyspray 不能提供您申請的頁面 .\n       也許您申請的任務不存在, 或者您\n       沒有權限查看您想要的頁面.<br /><br />\n       您可能在試圖訪問資料庫.  果真如此, 想想您做的操作.  返回之後, 請不要再做了!",
'permissionsforproject'   => '權限：',
'switchto'                => '切換到',
'lastsearch'              => '上次搜尋',
'modify'                  => '修改',
'noticefrom'              => '提醒，來自：',
'hasopened'               => '打開了一個新的任務, 並把它指派給您:',
'moreinfonew'             => '您在下面頁面找到關於這個錯誤的更多訊息:',
'newtaskcategory'         => '這個模組中有一個新任務被打開了',
'categoryowner'           => '因為您是這個模組的主管，所以您能收到這個消息.',
'tasksummary'             => '任務摘要:',
'newtaskadded'            => '您有一個新任務.',
'summaryanddetails'       => '摘要和詳細訊息您都需要填寫.',
'summaryrequired'         => '你需要填寫一個簡短的任務總結',
'goback'                  => '返回.',
'messagefrom'             => '這個是一個來自Flyspray 錯誤跟蹤系統的消息',
'hasjustmodified'         => '剛剛修改了下面的任務.',
'changedfields'           => '發生了變動的欄位由星號(**)首碼',
'moreinfomodify'          => '您能在下面的URL得到更多關於這個任務的訊息:',
'nolongerassigned'        => '下面的任務不再被指派到您了,它現在被指派到',
'hasassigned'             => '已經指派給您下面的Flyspray 任務:',
'taskupdated'             => '任務被更新了.',
'tasksupdated'            => '任務已經更新了.',
'hasclosedassigned'       => '已經關閉了下面這些指派到您的任務:',
'unassigned'              => '未指派的',
'hasclosed'               => '已經關閉了下面這些任務.',
'youonnotify'             => '您正在接收這個，因為您在通知列表中.',
'taskclosedmsg'           => '任務已經被關閉了.',
'returntotask'            => '返回到任務詳細訊息',
'backtoindex'             => '回到任務列表',
'noclosereason'           => '您需要選擇一個理由來關閉這個任務.',
'hasreopened'             => '已經重新打開了下面這些被您關閉的Flyspray 任務:',
'taskreopenedmsg'         => '任務被重新打開了.',
'backtotask'              => '回到任務.',
'commentaddedmsg'         => '增加的評論.',
'commenttoassigned'       => '一個指派到您的任務增加了一個評論:',
'commenttotask'           => '已經給這個任務了增加了下面的評論',
'nocommententered'        => '在提交之前，您需要填寫評論內容',
'fillinfields'            => '您沒有填寫全部的訊息',
'notcurrentpass'          => '這不是您的當前的密碼!',
'passchanged'             => '您的密碼被修改了.',
'closewindow'             => '您現在可以關閉這個窗口.',
'passnomatch'             => '您的輸入的兩個新密碼不一致!',
'usernametaken'           => '這個帳號已經存在了.  您需要再選擇一個.',
'usernametakenbulk'       => '帳號已經被占用了.',
'newusercreated'          => '新用戶帳號被建立了.',
'accountcreated'          => '您的帳號被建立了',
'newuserwarning'          => '注意全域常用設定可能需要由管理員批准您的帳號. 如果您不能登入, 可能是因為這個原因.',
'nomatchpass'             => '密碼不匹配.',
'confirmwrong'            => '確認碼不正確!',
'formnotcomplete'         => '表單沒有完全填寫.',
'formnotnumeric'          => '插入的數據不是數字!',
'groupnametaken'          => '這個群組名稱已經被占用了.',
'newgroupadded'           => '增加了一個新群組.',
'optionssaved'            => 'Flyspray 的選項儲存了.',
'hasuploaded'             => '上傳了一個文件附件到被指派的任務:',
'hasattached'             => '附加了一個文件到下面的 任務.',
'fileuploaded'            => '上傳了一個文件.',
'fileerror'               => '上傳您的文件時發生錯誤. 也許<i>附件/</i>目錄的權限不正確.',
'contactadmin'            => '聯繫這個專案的管理員.',
'selectfileerror'         => '您沒有選擇文件.',
'userupdated'             => '用戶的詳細訊息已經被更新了',
'realandemail'            => '您沒有填寫真實名稱和電子郵件地址.',
'groupupdated'            => '群組定義更新了.',
'groupanddesc'            => '您沒有填寫群組名稱.',
'fillallfields'           => '請填寫全部訊息.',
'listPmustN'              => '"順序" 這裡只能填寫數字.',
'listupdated'             => '列表更新了.',
'listitemadded'           => '增加了一個新列表條目.',
'relatedaddedmsg'         => '關聯任務增加到列表中了.',
'relatederror'            => '這個任務已經在這個關聯任務列表裡了.',
'relatedremoved'          => '關聯任務從列表中移除了.',
'notifyadded'             => '用戶增加到通知列表了.',
'notifyerror'             => '這個用戶已經在任務的通知列表中了.',
'notifyremoved'           => '用戶從通知列表中移除了.',
'editcommentsaved'        => '更新的評論儲存了.',
'commentdeletedmsg'       => '評論已經被刪除了.',
'gotonewtask'             => '到您剛剛建立的新任務去',
'projectcreated'          => '您建立了新專案.  點擊下面連結設定模組, 作業系統和版本列表',
'customiseproject'        => '定製這個專案',
'projectupdated'          => '專案常用設定更新了',
'emptytitle'              => '您沒有輸入專案標題.',
'loginbelow'              => '您現在可以登入了.',
'attachmentdeletedmsg'    => '附件被刪除了',
'reminderaddedmsg'        => '增加了一個您的提醒.',
'reminderdeletedmsg'      => '選中的提醒被刪除了.',
'flyspraytask'            => 'Flyspray任務',
'fieldsmissing'           => '一些欄位沒有數據或者數據無效.',
'relatedinvalid'          => '沒有這個任務.',
'relatedproject'          => '這個任務屬於不同的專案. 還要增加關聯嗎?',
'addanyway'               => '增加',
'cancel'                  => '取消',
'alreadyedited'           => '這個任務在您儲存之前被其他人修改了.您還要繼續儲存嗎?',
'saveanyway'              => '繼續儲存',
'nouserselected'          => '沒有選擇用戶. 選擇只少一個用戶再試一次.',
'groupswitchupdated'      => '用戶群組 修改 成功地.',
'takenownershipmsg'       => '這個任務現在被指派給您了.',
'adminrequestmade'        => '您的請求被發送到專案經理了.',
'newdepnotify'            => '一個新的依賴被增加到下面的任務:',
'dependadded'             => '增加了一個任務依賴',
'dependaddfailed'         => '增加依賴時出現錯誤. 檢查任務是否存在，以及任務之間沒有相互阻止.',
'depremovedmsg'           => '任務依賴被移除了',
'newdepis'                => '新的依賴是',
'magicurlsent'            => '向您的通知地址發送了消息. 包含一個完成任務所需要的連結.',
'changefspass'            => '修改Flyspray密碼',
'magicurlmessage'         => '請進入下面地址以修改密碼:',
'erroronform'             => '提交表單時出現問題',
'addressused'             => '這個訊息是用於註冊Flyspray帳號.  如果這是您不需要的訊息，請刪除它. 進入下面的連結完成註冊:',
'confirmcodeis'           => '您的確認碼是:',
'codesent'                => '您的確認碼發出了.  請按照消息中的提示操作.',
'codenotsent'             => '無法發送確認碼, 請稍候重試.',
'taskmadeprivatemsg'      => '這個任務被置為不公開了',
'taskmadepublicmsg'       => '這個任務被重新置為公開了',
'realandnotify'           => '您需要填寫真實姓名欄位, 郵件地址和Jabber ID至少要填一項.',
'pmreqdeniedmsg'          => '專案經理請求被拒絶了',
'massopsuccess'           => '批次操作成功',
'usernotexist'            => '用戶不存在',
'commentattachperms'      => '您不能刪除這個評論- 沒有刪除附件的權限',
'voterecorded'            => '您的投票被記錄了',
'votefailed'              => '您的投票現在不能加入.',
'createnewgroup'          => '建立新的群組',
'requiredfields'          => '必填欄位後面標記了一個',
'addthisgroup'            => '增加這個群組',
'createnewproject'        => '建立一個新專案',
'addnewproject'           => '增加新的專案',
'htmlallowed'             => '可以使用HTML程式碼',
'createthisproject'       => '建立這個專案',
'inlineimages'            => '嵌入顯示圖片附件',
'createnewtask'           => '在專案中建立一個新的任務:',
'addanother'              => '在此之後，增加另一個任務',
'addthistask'             => '增加這個任務',
'notifyme'                => '當任務發生變化時通知我',
'newtask'                 => '新任務',
'attachafile'             => '附加一個文件',
'registernewuser'         => '註冊新用戶',
'none'                    => '無',
'registeraccount'         => '註冊這個帳號',
'registerbulkaccount'     => '註冊帳號',
'both'                    => '兩者都要',
'notifyfrom'              => 'FlySpray通知:來自',
'donotreply'              => '這是一個自動發送的消息，請勿回覆.',
'disclaimer'              => '根據您從Flyspray 錯誤跟蹤系統請求，我們發送了這個消息. 您可以進入下面連結取消此類消息的發送.',
'userwho'                 => '做此操作的用戶是',
'moreinfo'                => '從下面URL可以得到詳細訊息:',
'newtaskopened'           => '一個新的Flyspray任務被打開了.  詳情如下.',
'notify.taskclosed'       => '下面的任務現在被關閉了:',
'notify.taskreopened'     => '下面的任務已經被重新打開了:',
'newdep'                  => '下面的任務增加了一個新的依賴:',
'notify.depremoved'       => '下面的任務移除了一個依賴:',
'olddepwas'               => '原來的依賴是',
'notify.commentadded'     => '下面的任務增加了一個新的評論:',
'commentis'               => '評論內容如下.',
'newattachment'           => '一個新的文件被附加到下面的任務:',
'detailsbelow'            => '詳情如下.',
'notify.relatedadded'     => '一個新的關聯任務被增加到下面的任務:',
'relatedis'               => '關聯任務是',
'assignedtoyou'           => '您被指派到下面的任務:',
'takenownership'          => '成為了下面的任務的主管:',
'requiresaction'          => '下面的任務需要專案經理的操作:',
'requiresactionnotify'    => '任務需要專案經理的操作',
'pmdeny'                  => '專案經理拒絶了的下面任務的請求掛起:',
'pmdenynotify'            => '專案經理拒絶了請求',
'fileaddedtoo'            => '這個評論有文件附件.',
'taskwatching'            => '您正在關注下面的任務',
'isdepfor'                => '是一個新的依賴，對於',
'denialreason'            => '拒絶的理由',
'taskchanged'             => '下面的任務被變更了.變更列在下面.想得到詳細的變更訊息,請訪問下面連結，並點歷史頁.',
'useraddedtoassignees'    => '用戶把自己加入到這個任務的指派用戶了.',
'removeddepis'            => '被移除的依賴是',
'isnodepfor'              => '不再是依賴了，對於',
'usergroups'              => '用戶群組',
'pmtoolbox'               => '專案經理工具箱',
'groupmanage'             => '群組管理',
'pendingrequests'         => '掛起的請求',
'reasongiven'             => '給出的理由',
'nopendingreq'            => '沒有掛起的專案經理請求.',
'givereason'              => '給出一個理由',
'catlisted'               => '模組列表編輯',
'oslisted'                => '作業系統列表編輯',
'verlisted'               => '版本列表編輯',
'tasktypeed'              => '任務類型列表編輯',
'resed'                   => '解決方式列表編輯',
'deny'                    => '拒絶',
'notifiedwhen'            => '通知在',
'onlynewtasks'            => '新任務被打開了',
'allevents'               => '任何任務中的任何事件',
'feeds'                   => '動態訊息',
'feeddescription'         => '動態訊息訂閲',
'feedimgurl'              => '動態訊息圖片連結 (沒有請不要填)',
'notifysubject'           => '通知主題',
'notifysubjectinfo'       => '(%p =專案標題, %s = 任務摘要, %t = 任務ID, %a = 操作, %u = 使用者)',
'priority6'               => '必須馬上解決',
'priority5'               => '儘快解決',
'priority4'               => '緊急',
'priority3'               => '高',
'priority2'               => '普通',
'priority1'               => '低',
'sendcode'                => '發送確認碼!',
'entercode'               => '輸入您收到的確認碼. 並輸入您的帳號密碼.',
'confirmationcode'        => '確認碼',
'registererror'           => '填寫所有必填欄位,輸入正確的通知類型.',
'validusername'           => '(只可接受數字，英文字元和 - _ . )',
'validemail'              => '(使用 ; 分離多個電子郵件地址)',
'emailtakenbulk'          => '郵件地址已經被占用.',
'emailtaken'              => '郵件地址或Jabber ID被占用了. 您需要再選擇一個.',
'note'                    => '<strong>注意:</strong>  在您的帳號建立之前，我們將發送給您一個確認碼. 確認碼使用您上面選擇的通知方式.<br />如果您輸入的訊息是錯誤的,您將<strong>不會收到確認碼</strong>.',
'changelog'               => '變更日誌',
'changeloggen'            => '變更日誌生成',
'listfrom'                => '列出變更日誌項',
'to'                      => '到',
'oldestfirst'             => '舊的在前',
'recentfirst'             => '近期在前',
'severityrep'             => '嚴重性報告',
'totalopen'               => '全部打開的任務',
'age'                     => '壽命',
'agerep'                  => '壽命報告',
'eventsrep'               => '事件報告',
'events'                  => '事件',
'Tasks'                   => '任務',
'opened'                  => '未解決的',
'edited'                  => '已修改的',
'assigned'                => '指派的',
'within'                  => '居於',
'pastday'                 => '上一日',
'pastweek'                => '上一週',
'pastmonth'               => '上一月',
'pastyear'                => '上一年',
'nolimit'                 => '不限',
'from'                    => '從',
'duein'                   => '延期到',
'selectfromdate'          => '選擇開始日期',
'selecttodate'            => '選擇結束日期',
'showvoters'              => '顯示隱藏投票人',
'roadmap'                 => '路線圖',
'roadmapfor'              => '版本的路線圖',
'tasks'                   => '任務',
'completed'               => '完成了.',
'opentasks'               => '個打開的任務',
'of'                      => '% ,全部',
'severity5'               => '嚴重',
'severity4'               => '高',
'severity3'               => '中',
'severity2'               => '低',
'severity1'               => '很低',
'Redirect'                => '轉向',
'redirectmsg'             => '如果您的瀏覽器 不支持HTTP重定向請點這個%sHERE%s連結 ',
'allowclosedcomments'     => '允許對關閉的任務評論',
'comment'                 => '評論',
'editowncomments'         => '編輯自己的評論',
'reopened'                => '重新打開了',
'loading'                 => '載入...',
'notifyown'               => '主管的任務發生變更時也發送通知',
'youremail'               => '您的電子郵件地址',
'thankyouforbug'          => '感謝您報告您的問題. 您可以通過下面的連結看到這個任務並且隨時觀察它的進度:',
'anonuser'                => '匿名用戶',
'conflict'                => '衝突',
'file'                    => '文件',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => '大小',
'projectgroup'            => '專案群組',
'profile'                 => '個人資料:',
'viewprofile'             => '查看個人資料',
'regdate'                 => '註冊時間',
'tasksopened'             => '打開的任務',
'replyto'                 => '回覆到',
'notifytypes'             => '通知類型',
'pm.taskchanged'          => '任務變更了',
'pm.taskreopened'         => '任務重新打開了',
'pm.depadded'             => '依賴增加了',
'pm.depremoved'           => '依賴移除了',
'pmrequest'               => '專案經理請求',
'pmrequestdenied'         => '專案經理請求被拒絶了',
'newassignee'             => '新的被指派人',
'revdepadded'             => '反向依賴增加了',
'revdepaddedremoved'      => '反向依賴移除了',
'assigneeadded'           => '增加了被指派人',
'addusergroup'            => '向這個組增加用戶',
'groupmembers'            => '群組成員',
'deleteuser'              => '刪除這個用戶',
'userdeleted'             => '用戶刪除了',
'autoassign'              => '自動為模組主管分配一個任務',
'ssl'                     => 'SSL',
'updatewrong'             => "您選擇了自動更新功能,\n   但是在連結伺服器時出現問題, 也許您無法訪問因特網\n   或者由於網絡故障造成.\n   請訪問Flyspray 網站確認您運行的是最新版本的FlySpray.",
'deleteproject'           => '刪除這個專案並把內容移至',
'projectdeleted'          => '專案被成功地刪除了',
'feedforall'              => '所有專案的動態訊息',
'usercreated'             => '用戶建立了',
'created'                 => '建立了',
'deleted'                 => '刪除了',
'userid'                  => '用戶ID',
'editassignments'         => '編輯任務指派',
'preview'                 => '預覽',
'anyprogress'             => '任何進度',
'tasksrelated'            => '這個任務的關聯任務',
'duplicatetasks'          => '這個任務的重複任務',
'databasemodfailed'       => '修改資料庫失敗. 可能是沒有足夠的權限.',
'frequency'               => '頻率',
'newuserregistered'       => '一個新的用戶註冊了. 用戶的詳細情況如下所示:',
'newuserregisterednotify' => '一個新的用戶註冊了',
'notify_registration'     => '新用戶註冊時通知管理員',
'textversion'             => '純文字版本',
'onlyprimary'             => '任務沒有阻止其他任務',
'onlyblocker'             => '任務阻止其他任務',
'blockerornoblocker'      => '攔截器或非攔截器,選擇兩個過濾器選項沒有意義。',
'switch'                  => '進入',
'max'                     => '最大',
'dates'                   => '日期',
'selectduedatefrom'       => '延期的 從',
'selectduedateto'         => '到',
'selectsincedatefrom'     => '變更的 從',
'selectsincedateto'       => '到',
'selectdate'              => '選擇日期',
'selectopenedfrom'        => '打開的 從',
'selectopenedto'          => '到',
'selectclosedfrom'        => '關閉的從',
'selectclosedto'          => '到',
'startat'                 => '開始於',
'hasattachment'           => '有附件',
'private'                 => '不公開的',
'watching'                => '關注',
'alreadyvotedthistask'    => '您對這個任務投了票',
'alreadyvotedthisday'     => '今天已經投過票了',
'visibility'              => '可見',
'public'                  => '公開',
'leaveemptyauto'          => '如果您想要自動生成密碼，請不要填寫密碼欄位.',
'novalidemail'            => '您輸入的郵件地址不正確.',
'novalidjabber'           => '您輸入的Jabber ID不正確.',
'missingrequired'         => '您沒有填寫全部的必填欄位.',
'entervalidusername'      => '請輸入有效的帳號和真實姓名.',
'couldnotaddusernotif'    => '不能把用戶加入到通知列表.',
'defaulttask'             => '預設任務描述',
'all'                     => '全部',
'events.useraddedtoassignees'=> '用戶成為被指派人',
'eventlog'                => '事件日誌',
'assignmentchanged'       => '指派發生了變動',
'detailedinfo'            => '詳細訊息',
'All'                     => '全部',
'tasksireported'          => '我報告的',
'recentlyopened'          => '最近打開的',
'stats'                   => '狀態',
'totaltasks'              => '個全部的任務',
'mostwanted'              => '最想要的任務',
'defaultentry'            => '預設入口頁面',
'toplevel'                => '最上層查看',
'overview'                => '總覽',
'error#'                  => '錯誤 #',
'error1'                  => '您沒有查看這個附件所需的權限.',
'error3'                  => '重複的操作, 回到主頁.',
'error4'                  => '您沒有管理權限.',
'error5'                  => '這個用戶不存在.',
'error6'                  => '無效的管理員區域.',
'error7'                  => '登入失敗(帳號或者密碼錯誤)!',
'error71'                 => '帳戶被鎖定%d分鐘由於太多失敗的登入嘗試!',
'error8'                  => '您沒有帳號或者密碼.',
'error9'                  => '任務不存在或者沒有權限查看這個任務.',
'error10'                 => '任務不存在或者沒有權限查看這個任務.',
'error101'                => '您沒有權限查看此任務.',
'error102'                => '您沒有權限查看此任務,登入可能會有所幫助.',
'error11'                 => '沒有編輯這個評論的權限.',
'error12'                 => '無效的激活碼!請核實一下?',
'error13'                 => '匿名用戶沒有個人資料.',
'error14'                 => '您沒有足夠的權限建立一個新的群組.',
'error15'                 => '您沒有足夠的權限打開一個任務.',
'error16'                 => '您不是專案經理.',
'error17'                 => '無效的專案經理區域.',
'error18'                 => '無效的激活地址連結.',
'error19'                 => '用戶不存在.',
'error20'                 => '無效的資料庫修改.',
'error21'                 => '郵件發送失敗，請檢查配置.',
'error22'                 => '不允許新用戶註冊.',
'error23'                 => '用戶或群組不允許登入.',
'error24'                 => '被設定的既不是一個可執行文件也不是一個公共伺服器.',
'error25'                 => '只有在指定的專案中路線圖才可用.',
'error26'                 => '不支持認證提供者.',
'error27'                 => '無法登入。授權我們查看您的電子郵件區域.',
'error28'                 => '你沒有權限訪問該地區',
'done'                    => '完成',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => '專案不能被刪除.',
'GMT'                     => 'GMT',
'timezone'                => '時區',
'accept'                  => '接受',
'reasonfordeinal'         => '拒絶的理由',
'pruneclosedlinks'        => '刪除關閉的連結',
'pruneclosedtasks'        => '刪除關閉的任務',
'pagegenerated'           => '頁面和圖形在 %d 秒內生成.',
'pruninglevel'            => '正在刪除級別',
'lastuser'                => '最後的用戶不能被刪除.',
'allprivate'              => '所有的專案都是不公開的.',
'deletegroup'             => '刪除這個群組，把用戶移到',
'parent'                  => '上級',
'ordertip'                => '條目的順序會在列表中顯示',
'showtip'                 => '在列表中顯示這一條',
'deletetip'               => '從列表中刪除這一條',
'del'                     => '刪除',
'request1'                => '一個任務關閉請求.',
'request2'                => '請求重新打開任務.',
'allpriorities'           => '所有優先級',
'noroadmap'               => '沒有可用的路線圖(不存在專案特定的“未來”版本)。',
'expand'                  => '展開',
'collapse'                => '摺疊',
'expandall'               => '全部展開',
'collapseall'             => '全部摺疊',
'minpwsize'               => '最小密碼大小是5字元',
'passwordtoosmall'        => '密碼長度太小了。',
'accountwaslocked'        => '你的帳號被鎖,由於太多的失敗的登入嘗試.',
'failedattempts'          => '有%d失敗的登入嘗試.',
'groupnotexist'           => '在這個專案選擇組不存在.',
'searchindetails'         => '搜尋細節',
'showasassignees'         => '顯示為受託人',
'find'                    => '搜尋',
'tls'                     => 'TLS',
'isadmin'                 => '是管理者',
'addvotes'                => '新增投票',
'removevote'              => '刪除投票',
'voteremoved'             => '你的投票被刪除',
'voteremovefailed'        => '你的投票不能被刪除.',
'novotes'                 => '你現在沒有任何可投票.',
'connectedtasks'          => '連接的任務:',
'taskdependencies'        => '任務依賴關係',
'viewgraph'               => '查看圖表',
'notaskdependencies'      => '這個任務不依賴於任何其他任務.',
'dependson'               => '依賴於',
'blocks'                  => '塊',
'newdependency'           => '新的依賴關係:',
'nouserstoadd'            => '沒有用戶新增.請確保名稱,帳號和電子郵件是為每個用戶定義的.',
'dispintro'               => '顯示主介紹訊息',
'mainmessage'             => '主介紹訊息',
'setsupertask'            => '設定Super-Task ID:',
'supertaskmodified'       => 'Super-Task ID被修改',
'set'                     => '設定',
'supertask'               => 'Super-Task',
'setparent'               => '為本任務設定父任務ID',
'selfsupertasknotallowed' => 'Super-Task ID不能和任務ID相同',
'quickaction'             => ' 快速操作',
'updateselectedtasks'     => '更新所選任務',
'notspecified'            => '未指定',
'editselectedtasks'       => '編輯所選任務',
'information'             => '訊息',
'taskclosedisabled'       => '禁止關閉當前任務,因依賴任務尚未關閉:-',
'daysleft'                => '天還剩',
'dayoverdue'              => '天過期',
'duetoday'                => '今天到期',
'daysbeforealert'         => '天前提醒',
'associatedsubtask'       => '相關的子任務#FS',
'associatesubtask'        => '為本任務設定子任務ID',
'subtaskid'               => '子任務ID',
'subtaskalreadyhasparent' => '您輸入的子任務已經有一個父任務,請明確此關聯.',
'subtaskisparent'         => '您輸入的子任務是父任務的任務.子任務無關',
'subtasknotexist'         => '您輸入的子任務不存在.',
'subtaskremovedmsg'       => '子任務已經成功被移除',
'subtaskadded'            => '新增子任務',
'subtaskremoved'          => '刪除子任務',
'addnewsubtask'           => '新增新的子任務',
'hidesubtasks'            => '隱藏子任務',
'voteforthistask'         => '為本任務投票',
'watchthistask'           => '查看這個任務',
'privatethistask'         => '置為不公開任務',
'adddependenttask'        => '增加依賴任務',
'associatetaskid'         => '子任務id',
'parenttaskid'            => '父任務id',
'invalidsupertaskid'      => '父任務id無效.',
'supertaskadded'          => '新增超級任務',
'supertaskremoved'        => '刪除超級任務',
'effort'                  => '工作量',
'efforttracking'          => '工作量跟蹤',
'useeffort'               => '專案使用的工作量跟蹤',
'estimatedeffort'         => '估計工作量',
'totalestimatedeffort'    => '估計總工作量',
'currenteffortdone'       => '當前完成工作量',
'starteffort'             => '開始跟蹤',
'endeffort'               => '停止跟蹤',
'cleareffort'             => '清除跟蹤',
'addeffort'               => '新增跟蹤',
'manualeffort'            => '手動新增跟蹤(H:M)',
'efforttrackingstarted'   => '開始跟蹤這個任務的工作量',
'efforttrackingnotstarted'=> '無法開始跟蹤,這個問題已經被跟蹤',
'efforttrackingstopped'   => '這個任務的工作量跟蹤結束.',
'efforttrackingcancelled' => '這個任務的工作量跟蹤被取消.',
'efforttrackingadded'     => '手動記錄工作量的任務.',
'trackinginprogress'      => '跟蹤過程中',
'viewestimatedeffort'     => '可以查看工作量跟蹤',
'viewcurrenteffortdone'   => '可以查看當前工作量做了什麼',
'trackeffort'             => '可以跟蹤工作量',
'invalideffort'           => '輸入的是工作量無效的,必須是一個數字',
'showpass'                => '顯示密碼',
'chooseafile'             => '請選擇一個文件!',
'incorrectfiletype'       => '錯誤的文件類型.允許:jpg,jpeg,gif,png',
'oauthreqpass'            => '沒有密碼請求.你註冊通過%s',
'addmultipletasks'        => '新增多個任務',
'pendingnewuserrequest'   => '等待請求的新用戶',
'adminrequestswaiting'    => '等待管理員請求',
'clicktoedit'             => '點擊每個欄位快速編輯',
'confirmedit'             => '確認',
'regapprovedbyadmin'      => '由管理員註冊批准(禁用確認程式碼)',
'activity'                => '活動',
'myactivity'              => '我的活動',
'emailverificationwrong'  => '電子郵件不匹配給定的電子郵件地址',
'verifyemailaddress'      => '確認電子郵件地址',
'hideemails'              => '隱藏用戶電子郵件地址',
'hidemyemail'             => '隱藏我的電子郵件地址',
'exporttasklist'          => '匯出任務列表',
'onedecimal'              => '一個小數',
'manday'                  => '人工日',
'mandays'                 => '人工日',
'mandayabbrev'            => '簡寫的人工日',
'hourspermanday'          => '一個人工日的工作時 (HH:mm)',
'itemexists'              => '專案%s已經存在於資料庫中',
'categoryitemexists'      => '專案%s已經存在在%s資料庫類.',
'pageswelcomemsg'         => '頁面顯示主要介紹訊息',
'pagesintromsg'           => '頁面顯示介紹訊息',
'activeoauths'            => '活躍的認證提供者',
'onlyoauthreg'            => '只允許認證者註冊',
'estimatedeffortformat'   => '估計工作量顯示格式',
'currenteffortdoneformat' => '當前完成工作量顯示格式',
'minute'                  => '分鐘',
'minutes'                 => '分鐘',
'minuteplural'            => '分鐘',
'minutesingular'          => '分鐘',
'minuteabbrev'            => '最小值',
'hourplural'              => '小時',
'hoursingular'            => '小時',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => '估計開放任務工作量',
'currenteffortdoneopen'   => '當前開放任務耗費工作量',
'signinwith'              => '登入%s',
'canviewroadmap'          => '可以查看路線圖',
'enableavatars'           => '啟用頭像',
'maxavatarsize'           => '最大頭像像素值',
'taskhassubtask'          => '這個任務有以下子任務',
'taskhassubtasks'         => '這個任務有以下子任務',
'translations'            => '翻譯',
'translate'               => '翻譯',
'taskdescription'         => '任務描述',
'notaskdescription'       => '沒有任務描述',
'pleaseselect'            => '請選擇',
'closeselectedtasks'      => '關閉選擇任務',
'closetasks'              => '關閉任務',
'hintforbulkimport'       => "<b>批次導入的技巧:</b>\n<ol>\n<li>複製和貼上從excel電子表格或CSV貼上一個整列.</li>\n<li>目前你只能貼上彙總和細節.</li>\n<li>There are suggestions when you assign to someone, and to no-one if there is no matched name.</li>\n</ol>",
'taskissubtaskof'         => '本任務的父任務',
'applyfirstline'          => '應用第一行',
'addmorerows'             => '新增更多的行',
'addtasks'                => '新增任務',
'massopsdisabled'         => '對不起,批次編輯目前在Flyspray 1.0被禁止.我們計劃在後面的版本進行實現.You can enable them in source code again at your own risk, but read the comments there before doing it.',
'viewroadmap'             => '可以查看路線圖',
'nosuicide'               => '親愛的用戶，因為管理員已經禁用了您的帳戶，您不允許訪問網站或改變用戶組。',
'movingtodifferentproject'=> '移動一個父任務或子任務到另一個專案是不允許的.你首先必須打破他們之間的聯繫。',
'musthavesameproject'     => '父任務和子任務必須屬於同一個專案.',
'defaultorderby'          => '排序預設任務列表',
'defaultorderby2'         => '與',
'viewowntasks'            => '查看自己的任務',
'viewgroupstasks'         => '查看任務組',
'urlrewriting'            => '覆寫URL',
'enablehtaccess'          => '請在覆寫URL之前讓你的.htaccess文件在Flyspray根目錄',
'nomodrewrite'            => '重寫在這個服務上似乎不可用，不好意思，我不能覆寫URL在',
'on'                      => '打開',
'off'                     => '關閉',
'defaultorderbydirection' => '按預設方向',
'ascending'               => '升序',
'descending'              => '降序',
'myassignedtasks'         => '我分配的任務',
'commentedon'             => '評論',
'maxvoteperday'           => '每天最多選票',
'votesperproject'         => '在每個專案中用戶被限制的選票',
'votelimitreached'        => '你的投票限製為這個專案。在個人資料頁面查看哪些任務可以投票.你也可以收回的選票.我們可以看到哪些任務對你是最重要的.解決任務可以收回你的選票.',
'myvotes'                 => '我的選票',
'tag'                     => '標籤',
'tags'                    => '標籤',
'tagsinfo'                => '任務的自由標記/標籤:是單獨的標籤；它們還不能使用搜尋、排序或過濾.',
'novalues'                => '沒有條目',
'youhaveregistered'       => '你已經在Flyspray註冊,你的詳細資料如下:',
'youhaveregisterednotify' => '你在Flyspray上的註冊已經被管理員接受.',
'usedintasks'             => '用法',
'freetagging'             => '允許用戶定義標籤',
'keyboardshortcuts'       => '快速鍵',
'openselectedtask'        => '開啟選擇的任務',
'usedintasks'             => '使用量',
'testmailsettings'        => '測試目前的電子郵件伺服器設定',
'test'                    => '測試',
'testmailsettingsnotice'  => 'And also check if you received the test email in the mail account of the current user (see \'myprofile\'-page)',
'customize'               => '自訂',
'movecursorup'            => '游標向上',
'movecursordown'          => '游標向下',
'taskdetails'             => '詳細任務',
'taskediting'             => '編輯任務',
'savetask'                => '儲存任務',
'hidesubs'                => '隱藏非主要任務',
'hideprivate'             => '隱藏隱私任務',
'hideclosed'              => '隱藏關閉任務',
'currentproject'          => '目前任務',
'targetproject'           => '目標任務',
'availablekeybshortcuts'  => '可用的快速鍵',
'logindialoglogout'       => '登入登出紀錄',

);

?>
