<?php
$translation=array(
'available'          => 'verfügbar',
'missing'            => 'fehlt',
'needcomposer'       => 'Flyspray benötigt einige zusätzliche Programmbibliotheken, die mit Composer installiert werden können.',
'no'                 => 'nein',
'installcomposer'    => 'Starte Composer',
'performupgrade'     => 'Aktualisierung durchführen',
'precautions'        => 'Vorsichtsmaßnahmen',
'precautionbackup'   => 'Erstelle eine Sicherung deiner Datenbank und aller zu Flyspray gehörenden Dateien vor der Aktualisierung',
'preconditionchecks' => 'Voraussetzungen',
'proceedtodbsetup'   => 'weiter zu den Datenbankeinstellungen',
'recommended'        => 'empfohlen',
'supported'          => 'unterstützt',
'upgrade'            => 'Aktualisierung',
'upgradepossible'    => 'Eine Aktualisierung ist möglich.',
'versioncompare'     => 'Deine derzeitige Flysprayversion ist <strong>%s</strong> und es kann auf Version <strong>%s</strong> aktualisiert werden.',
'writeable'          => 'schreibbar',
'writeaccessconf'    => 'Um Flyspray zu aktualisieren muß Lese- und Schreibrecht für flyspray.conf.php existieren.',
'yes'                => 'ja',
);
?>
