<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Muokkaa käyttäjää',
'accountenabled'          => 'Käyttäjätili voimassa',
'editallusers'            => 'Näytä kaikki käyttäjät',
'username'                => 'Käyttäjätunnus',
'usersupdated'            => 'Käyttäjät päivitetty',
'realname'                => 'Nimi',
'emailaddress'            => 'Sähköpostiosoite',
'jabberid'                => 'Jabber ID',
'profileimage'            => 'Kuva',
'notifytype'              => 'Ilmoitustapa',
'group'                   => 'Ryhmä',
'enableaccounts'          => 'Ota käyttäjätilit käyttöön',
'disableaccounts'         => 'Poista käyttäjätilit käytöstä',
'deleteaccounts'          => 'Poista käyttäjätili',
'updatedetails'           => 'Päivitä tiedot',
'setglobally'             => 'Tämä on yleisasetus.',
'usergroupmanage'         => 'Käyttäjä- ja ryhmähallinta',
'newuser'                 => 'Uusi käyttäjä',
'newuserbulk'             => 'Useita uusia käyttäjiä',
'bulkuserstoadd'          => 'Uudet käyttäjät',
'optionsforallusers'      => 'Oletusasetukset uusille käyttäjille',
'newgroup'                => 'Uusi ryhmä',
'yes'                     => 'Kyllä',
'no'                      => 'Ei',
'editgroup'               => 'Muokkaa ryhmää',
'groupname'               => 'Ryhmän nimi',
'description'             => 'Kuvaus',
'admin'                   => 'Ylläpitäjä',
'opennewtasks'            => 'Avaa uusia tehtäviä',
'modifytasks'             => 'Muokkaa tehtäviä',
'addcomments'             => 'Lisää kommentteja',
'attachfiles'             => 'Liitä tiedostoja',
'vote'                    => 'Äänestä',
'groupenabled'            => 'Jäsenet voivat kirjautua',
'groupopen'               => 'Jäsenet voivat kirjautua',
'tasktypelist'            => 'Tehtävätyypit',
'categorylist'            => 'Luokitukset',
'oslist'                  => 'Käyttöjärjestelmät',
'resolutionlist'          => 'Päätökset',
'versionlist'             => 'Versiot',
'severitylist'            => 'Vakavuudet',
'listnote'                => 'Huom! Näytä-valintaruudun poisvalinta saattaa vaikuttaa tehtäviin muokkauksessa. Nimi-kentän muutos vaikuttaa kaikkiin samannimisiin tehtäviin. Kohteet, joiden poisto ei onnistu, ovat joko käytössä jossain tehtävässä tai niitä tarvitaan ohjelman oikein toimimiseksi.',
'name'                    => 'Nimi',
'order'                   => 'Järjestys',
'back'                    => 'Takaisin',
'text'                    => 'Teksti',
'highlight'               => 'Korosta',
'show'                    => 'Näytä',
'owner'                   => 'Omistaja',
'selectowner'             => 'Valitse omistaja',
'update'                  => 'Päivitä',
'addnew'                  => 'Lisää uusi',
'flysprayprefs'           => 'Flysprayn asetukset',
'projecttitle'            => 'Projektin otsikko',
'baseurl'                 => 'Asennuksen URL-osoite',
'replyaddress'            => 'Ilmoitusten vastausosoite',
'themestyle'              => 'Teema / Tyyli',
'customstyle'             => 'Kustomoitu',
'language'                => 'Kieli',
'anonview'                => 'Salli tuntemattomien käyttäjien nähdä tehtävät',
'allowanon'               => 'Salli tuntemattomien käyttäjien avata uusia tehtäviä',
'never'                   => 'Ei koskaan',
'anonymously'             => 'Anonyymisti',
'afterregister'           => 'Vasta rekisteröinnin jälkeen',
'spamproof'               => 'Vahvistuskoodi uusille käyttäjille',
'anongroup'               => 'Oletusryhmä uusille käyttäjille',
'groupassigned'           => 'Näiden ryhmien jäsenille voidaan osoittaa tehtäviä',
'forcenotify'             => 'Tehtäväilmoitusten pakotus',
'neversend'               => 'Älä lähetä koskaan',
'userchoose'              => 'Käyttäjän oma valinta',
'email'                   => 'Sähköposti',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Luokituksen oletusomistaja',
'noone'                   => 'Ei kukaan',
'jabbernotify'            => 'Jabber-ilmoitukset',
'jabberserver'            => 'Palvelin',
'jabberport'              => 'Portti',
'jabberuser'              => 'Käyttäjänimi',
'jabberpass'              => 'Salasana',
'saveoptions'             => 'Tallenna asetukset',
'editcomment'             => 'Muokkaa kommenttia',
'commentby'               => 'Kommentoija',
'saveeditedcomment'       => 'Tallenna kommentti',
'projectprefs'            => 'Projektin asetukset',
'pagetitle'               => 'Sivun otsikko',
'defaultproject'          => 'Oletusprojekti',
'projectlists'            => 'Projektilista',
'showlogo'                => 'Näytä logo',
'showgravatars'           => 'Näytä Gravatar (A Globally Recognized Avatar)',
'emailNoHTML'             => 'Sähköpostit tekstimuodossa',
'intromessage'            => 'Aloitusviesti',
'active'                  => 'aktiivinen',
'inactive'                => 'epäaktiivinen',
'isactive'                => 'Aktiivinen',
'showinactive'            => 'Näytä epäaktiiset projektit',
'hideinactive'            => 'Piilota epäaktiiviset projektit',
'createproject'           => 'Uusi projekti',
'nopermission'            => 'Oikeutesi eivät riitä sivun näyttämiseen.',
'listordertip'            => 'Listan esitysjärjestys',
'listshowtip'             => 'Näytä listassa',
'categoryownertip'        => 'Henkilö, jolle ilmoitetaan luokituksen uudesta tehtävästä',
'categoryparenttip'       => 'Uuden luokituksen isäntäluokitus',
'notsubcategory'          => 'Ei mikään (päätason luokitus)',
'showinlineimages'        => 'Näytä kuvaliitteet tekstin joukossa',
'dateformat'              => 'Päivämäärän muoto',
'dateformat_extended'     => 'Laajennettu päivämäärän muoto',
'cache_feeds'             => 'Syötteen välimuistikäyttö',
'no_cache'                => 'Ei välimuistia',
'cache_disk'              => 'Välimuisti levyllä',
'cache_db'                => 'Välimuisti tietokannassa',
'subcategoryof'           => 'Alaluokitus',
'visiblecolumns'          => 'Tehtävälistan sarakkeet',
'visiblefields'           => 'Tehtävän kentät',
'tense'                   => 'Aikamuoto',
'listtensetip'            => 'Menneisyys, nykyisyys tai tulevaisuus',
'past'                    => 'Menneisyys',
'present'                 => 'Nykyisyys',
'future'                  => 'Tulevaisuus',
'oldpass'                 => 'Aiempi salasana',
'nooldpass'               => 'Aiempaa salasanaa ei ollut asetettu',
'oldpasswrong'            => 'Aiempi salasana oli väärä',
'changepass'              => 'Vaihda salasana',
'confirmpass'             => 'Vahvista salasana',
'projectmanager'          => 'Projektin ylläpitäjä',
'viewtasks'               => 'Näytä tehtävät',
'modifyowntasks'          => 'Muokkaa tehtäviäsi',
'modifyalltasks'          => 'Muokkaa kaikkia tehtäviä',
'viewcomments'            => 'Näytä kommentit',
'editcomments'            => 'Muokkaa kommentteja',
'deletecomments'          => 'Poista kommentteja',
'viewattachments'         => 'Näytä liitteet',
'createattachments'       => 'Luo liitteitä',
'deleteattachments'       => 'Poista liitteitä',
'viewhistory'             => 'Näytä historia',
'closeowntasks'           => 'Sulje omat tehtäväni',
'closeothertasks'         => 'Sulje kaikki tehtävät',
'assigntoself'            => 'Osoita osoittamattomat tehtävät itsellesi',
'assignotherstoself'      => 'Osoita muille kuuluvia tehtäviä itsellesi',
'viewreports'             => 'Näytä tapahtumaloki',
'othersview'              => 'Salli kaikkien nähdä tämä projekti',
'othersviewroadmap'       => 'Salli kenen tahansa nähdä projektin etenemissuunnitelma',
'usersandgroups'          => 'Käyttäjät ja ryhmät',
'globalgroup'             => 'Yleisryhmä',
'globalgroups'            => 'Yleisryhmät',
'defaultglobalgroup'      => 'Oletusryhmä uusille käyttäjille',
'addtogroup'              => 'Lisää ryhmään',
'moveuserstogroup'        => 'Siirrä käyttäjät ryhmään',
'nogroup'                 => 'Ei ryhmää - poista projektista',
'eventdesc'               => 'Tapahtuman kuvaus',
'requestedby'             => 'Pyytänyt',
'daterequested'           => 'Pyydetty',
'closetask'               => 'Sulje tehtävä',
'reopentask'              => 'Avaa tehtävä uudelleen',
'applymember'             => 'Hae jäsenyyttä projektissa',
'forcurrentproj'          => 'Valitulle projektille',
'lostpw'                  => 'Uuden salasanan pyyntö',
'lostpwexplain'           => 'Anna käyttäjätunnuksesi salasanan muutoslinkkiä varten. Se lähetetään käyttäjäprofiilissasi olevaan sähköpostiosoitteeseen.',
'sendlink'                => 'Lähetä linkki',
'savenewpass'             => 'Tallenna uusi salasana',
'anonreg'                 => 'Salli uudet käyttäjät',
'allowanonopentask'       => 'Salli tuntemattomien käyttäjien avata tehtäviä',
'editglobalgroup'         => 'Muokkaa yleisryhmää',
'editgroupforproj'        => 'Muokkaa ryhmää projektissa',
'notshownforadmin'        => 'Ylläpitäjien ryhmän oikeuksia ei näytetä. Niitä ei tarvitse muokata.',
'general'                 => 'Yleinen',
'userregistration'        => 'Käyttäjäasetukset',
'notifications'           => 'Ilmoitukset',
'resetoptions'            => 'Palauta asetukset',
'preferences'             => 'Asetukset',
'tasktypes'               => 'Tehtävätyypit',
'resolutions'             => 'Päätökset',
'categories'              => 'Luokitukset',
'operatingsystems'        => 'Käyttöjärjestelmät',
'versions'                => 'Versiot',
'admintoolboxlong'        => 'Ylläpitotyökalut',
'newproject'              => 'Uusi projekti',
'delete'                  => 'Poista',
'link'                    => 'Linkki',
'referencelinks'          => 'Viitelinkit:',
'listdeletetip'           => 'Poista listasta',
'lookandfeel'             => 'Ulkoasu',
'globaltheme'             => 'Yleinen teema',
'emailnotify'             => 'Sähköposti-ilmoitukset',
'fromaddress'             => 'Lähettäjän osoite',
'smtpserver'              => 'SMTP-palvelin',
'smtpuser'                => 'SMTP-käyttäjätunnus',
'smtppass'                => 'SMTP-salasana',
'addrewrite'              => 'Käytä muokattuja URL-osoitteita.',
'usereminderdaemon'       => 'Käynnistä taustamuistutukset',
'tasksperpage'            => 'Tehtävälistan sivukohtainen tehtävämäärä',
'addtoassignees'          => 'Liitä minut tekijäksi',
'taskstatuses'            => 'Tehtävien tilat',
'canvote'                 => 'Äänioikeus tehtävissä',
'loginsuccessful'         => 'Sisäänkirjautuminen onnistui.',
'youareloggedout'         => 'Olet kirjautunut ulos.',
'waitwhiletransfer'       => 'Odota hetki, kun sinut siirretään...',
'clicknowait'             => 'Klikkaa tätä, jos et halua odottaa.',
'accountdisabled'         => 'Käyttäjätilisi on jäädytetty. Ota yhteyttä ylläpitoon.',
'task'                    => 'Tehtävä',
'edittask'                => 'Muokkaa tehtävää',
'openedby'                => 'Avannut',
'editedby'                => 'Viimeksi muokannut',
'tasktype'                => 'Tehtävätyyppi',
'category'                => 'Luokitus',
'status'                  => 'Tila',
'assignedto'              => 'Osoitettu',
'operatingsystem'         => 'Käyttöjärjestelmä',
'severity'                => 'Vakavuus',
'reportedversion'         => 'Raportointiversio',
'dueinversion'            => 'Valmis versiossa',
'defaultdueinversion'     => 'Oletus valmistumisversio uusille tehtäville',
'undecided'               => 'Ei päätetty',
'percentcomplete'         => 'Valmistumisaste',
'details'                 => 'Tiedot',
'savedetails'             => 'Tallenna tiedot',
'canceledit'              => 'peruuta',
'anonymous'               => 'Tuntematon ilmoittaja',
'complete'                => 'valmis',
'closedby'                => 'Sulkenut',
'reasonforclosing'        => 'Sulkemisen syy:',
'reopenthistask'          => 'Avaa tehtävä uudelleen',
'comments'                => 'Kommentit',
'attachments'             => 'Liitteet',
'relatedtasks'            => 'Liittyvät tehtävät',
'edit'                    => 'Muokkaa',
'addcomment'              => 'Uusi kommentti',
'fileuploadedby'          => 'Tiedoston lisääjä',
'uploadafile'             => 'Uusi liite',
'addalink'                => 'Uusi linkki',
'addanotherlink'          => 'Lisää uusi linkki',
'uploadnow'               => 'Vie tiedosto!',
'thesearerelated'         => 'Nämä tehtävät liittyvät tähän tehtävään',
'remove'                  => 'Poista',
'addnewrelated'           => 'Uusi liittyvä tehtävä',
'add'                     => 'Lisää',
'otherrelated'            => 'Muut tähän tehtävään liittyvät tehtävät',
'receivenotify'           => 'Tehtävän muutoksista ilmoitetaan näille käyttäjille.',
'addusertolist'           => 'Lisää käyttäjä tähän listaan',
'addtolist'               => 'Lisää listaan',
'addmyself'               => 'Lisää minut tähän listaan',
'removemyself'            => 'Poista minut tästä listasta',
'theseusersnotify'        => 'Näille käyttäjille ilmoitetaan aina kun tämä tehtävä muuttuu.',
'attachedtoproject'       => 'Liitetty projektiin',
'reminders'               => 'Muistutukset',
'system'                  => 'Järjestelmä',
'systemvalues'            => 'Järjestelmän yleiset arvot',
'projectvalues'           => 'Projektikohtaiset arvot',
'remindthisuser'          => 'Muistuta tätä käyttäjää',
'thisoften'               => 'Näin usein',
'startafter'              => 'Odota ennen muistutusten aloittamista',
'hour'                    => 'tunti',
'hours'                   => 'tuntia',
'day'                     => 'päivä',
'days'                    => 'päivää',
'week'                    => 'viikko',
'weeks'                   => 'viikkoa',
'addreminder'             => 'Lisää muistutus',
'defaultreminder'         => 'Tämä on muistutus. Katso Flyspray-tehtävä:',
'message'                 => 'Viesti',
'closed'                  => 'Suljettu',
'filename'                => 'Tiedoston nimi',
'date'                    => 'Päiväys',
'filesize'                => 'Tiedoston koko:',
'closurecomment'          => 'Muita huomautuksia sulkemisesta:',
'history'                 => 'Historia',
'nohistory'               => 'Historiaa ei ole saatavilla.',
'eventdate'               => 'Päiväys',
'user'                    => 'Käyttäjä',
'event'                   => 'Tapahtuma',
'fieldchanged'            => 'Muutettu kenttä',
'taskopened'              => 'Tehtävä avattu',
'taskreopened'            => 'Tehtävä avattu uudelleen',
'taskclosed'              => 'Tehtävä suljettu',
'commentadded'            => 'Kommentti lisätty',
'commentedited'           => 'Kommenttia muokattu',
'commentdeleted'          => 'Kommentti poistettu',
'attachmentadded'         => 'Liite lisätty',
'attachmentdeleted'       => 'Liite poistettu',
'taskedited'              => 'Tehtävän tietoja muokattu',
'notificationadded'       => 'Ilmoituslistaan lisätty',
'notificationdeleted'     => 'Poistettu ilmoituslistasta',
'relatedadded'            => 'Liittyvä tehtävä lisätty',
'relateddeleted'          => 'Liittyvä tehtävä poistettu',
'taskassigned'            => 'Tehtävä osoitettu',
'taskreassigned'          => 'Tehtävä uudelleenosoitettu',
'assignmentremoved'       => 'Tehtävän osoitus poistettu',
'summary'                 => 'Yhteenveto',
'addedasrelated'          => 'Tehtävä lisätty liitettyjen tehtävien listalle',
'deletedasrelated'        => 'Tehtävä poistettu liitettyjen tehtävien listalta',
'reminderadded'           => 'Muistutus lisätty',
'reminderdeleted'         => 'Muistutus poistettu',
'priority'                => 'Kiireellisyys',
'previousvalue'           => 'Aiempi arvo',
'newvalue'                => 'Uusi arvo',
'selectareason'           => 'Valitse syy',
'assigntome'              => 'Osoita minulle',
'reopenrequest'           => 'Pyydä uudelleen avaamista',
'requestclose'            => 'Pyydä sulkemista',
'ownershiptaken'          => 'Käyttäjä otti omistukseensa',
'closerequestmade'        => 'Tehtävän sulkemista pyydetty',
'reopenrequestmade'       => 'Tehtävän uudelleen avaamista pyydetty',
'taskdependson'           => 'Tämä tehtävä riippuu',
'taskdependsontask'       => 'Tehtävä riippuu tehtävästä',
'taskdependsontasks'      => 'Tehtävä riippuu tehtävistä',
'taskblock'               => 'Tehtävä estää seuraavan sulkemisen',
'taskblocks'              => 'Tämä tehtävä estää sulkemasta näitä',
'depadded'                => 'Riippuvuussuhde lisätty',
'depaddedother'           => 'Tämä tehtävä lisätty riippuvuussuhteena',
'depremoved'              => 'Riippuvuussuhde poistettu',
'depremovedother'         => 'Tämä tehtävä poistettu toisen tehtävän riippuvuussuhteista',
'showdetailserror'        => 'Tehtävää ei ole tai oikeutesi eivät riitä sen näkemiseen.',
'makeprivate'             => 'Tee yksityiseksi',
'makepublic'              => 'Julkaise',
'taskmadeprivate'         => 'Tehtävä on muutettu yksityiseksi',
'taskmadepublic'          => 'Tehtävä julkaistu',
'confirmdeletecomment'    => 'Oletko varma, että haluat poistaa tämän kommentin? %s',
'attachementswilldeleted' => 'Myös kaikki liitteet poistetaan!',
'confirmdeleteattach'     => 'Oletko varma, että haluat poistaa tämän liitteen?',
'selectedhistory'         => 'Näytetään valitut historiatiedot',
'showallhistory'          => 'Näytä historiavälilehti uudelleen',
'hidethis'                => 'Piilota uudestaan',
'mark100'                 => 'Merkitse tehtävä valmiiksi',
'watchtask'               => 'tarkkaile tehtävää',
'stopwatching'            => 'lakkaa tarkkailemasta',
'commentlink'             => 'Linkki kommenttiin',
'submitreq'               => 'Lähetä muutospyyntö',
'reasonforreq'            => 'Muutospyynnön syy',
'pmreqdenied'             => 'Projektin ylläpitäjä kieltäytyi muutospyynnöstä',
'taskpendingreq'          => 'Odottaa projektin ylläpitäjän toimenpiteitä. Katso historiavälilehdeltä yksityiskohtia.',
'previoustask'            => 'Edellinen tehtävä',
'nexttask'                => 'Seuraava tehtävä',
'duedate'                 => 'Valmistuu',
'attachnoperms'           => 'Kommenttiin sisältyy liitteitä, mutta oikeutesi eivät riitä niiden näkemiseen.',
'linknoperms'             => 'Kommenttiin sisältyy linkkejä, mutta oikeutesi eivät riitä niiden näkemiseen.',
'open'                    => 'Avoimet',
'depgraph'                => 'Näytä riippuvuusgraafi',
'reset'                   => 'Palauta',
'selectusers'             => 'Valitse käyttäjät...',
'addmetoassignees'        => 'Lisää minut tekijäksi',
'addedtoassignees'        => 'Käyttäjä lisätty tekijäksi',
'dependencygraph'         => 'Riippuvuusgraafi',
'attachanotherfile'       => 'Liitä toinen liite',
'OK'                      => 'OK',
'addvote'                 => 'Lisää ääni',
'disable_lostpw'          => 'Estä salasanan palautus',
'disable_changepw'        => 'Estä salasanan muokkaus',
'notifyfromfs'            => 'Ilmoitus Flyspraystä',
'autogenerated'           => 'TÄMÄ ON AUTOMAATTISESTI LUOTU VIESTI, ÄLÄ VASTAA SIIHEN',
'forward'                 => 'Eteenpäin',
'previous'                => 'Edellinen',
'next'                    => 'Seuraava',
'first'                   => 'Ensimmäinen',
'last'                    => 'Viimeinen',
'page'                    => 'Sivu %d/%d.',
'search'                  => 'Hae',
'alltasktypes'            => 'Kaikki',
'allseverities'           => 'Kaikki',
'alldevelopers'           => 'Kaikki',
'notyetassigned'          => 'Osoittamattomat',
'allcategories'           => 'Kaikki',
'allstatuses'             => 'Kaikki',
'allopentasks'            => 'Avoimet',
'sortthiscolumn'          => 'Lajittele tämän sarakkeen mukaan',
'id'                      => 'ID',
'project'                 => 'Projekti',
'dateopened'              => 'Avattu',
'progress'                => 'Edistyminen',
'searchthisproject'       => 'Hae tästä projektista',
'dueanyversion'           => 'Versioriippumaton',
'anyversion'              => 'Versioriippumaton',
'dueversion'              => 'Tavoiteversio',
'lastedit'                => 'Viimeksi muokattu',
'os'                      => 'Käyttöjärjestelmä',
'reportedin'              => 'Raportoitu',
'taskrange'               => 'Näytetään tehtävät %d - %d / %d',
'noresults'               => 'Hakusi ei tuottanut tuloksia.',
'takeaction'              => 'Toimenpide',
'watchtasks'              => 'Tarkkaile valittuja tehtäviä',
'stopwatchingtasks'       => 'Lakkaa tarkkailemasta valittuja tehtäviä',
'assigntaskstome'         => 'Osoita valitut tehtävät minulle',
'dueby'                   => 'Valmis',
'dueanytime'              => 'Ei valmistumisaikaa',
'selectduedate'           => 'Valitse valmistumisaika',
'toggleselected'          => 'Käännä valinta',
'due'                     => 'Valmis',
'assignedtome'            => 'Omat tehtäväni',
'tasklist'                => 'Tehtävälista',
'dateclosed'              => 'Suljettu',
'advanced'                => 'Laajennettu',
'searchcomments'          => 'Hae kommenteista',
'searchforall'            => 'Hae kaikkia sanoja',
'anonusers'               => 'Tuntemattomat käyttäjät',
'miscellaneous'           => 'Sekalaista',
'users'                   => 'Käyttäjät',
'taskproperties'          => 'Tehtävän ominaisuudet',
'selectsincedate'         => 'Valitse muuttunut jälkeen',
'changedsince'            => 'Muuttunut jälkeen',
'updatefs'                => 'Ole hyvä ja päivitä Flyspray.',
'currentversion'          => 'Nykyinen versiosi on',
'latestversion'           => 'ja viimeisin versio on',
'hidemessage'             => '(muistuta minua myöhemmin)',
'saveas'                  => 'Tallenna haku nimellä',
'nosearches'              => 'Ei tallennettuja hakuja',
'saving'                  => 'Tallennetaan...',
'votes'                   => 'Ääniä',
'tovote'                  => 'Äänestä',
'allclosedtasks'          => 'Kaikki suljetut',
'password'                => 'Salasana',
'login'                   => 'Kirjaudu',
'rememberme'              => 'Muista minut',
'lostpassword'            => 'Salasana hukkunut?',
'lostpwforfs'             => 'Flysprayn kadonnut salasana',
'lostpwmsg1'              => "Terve.\n\nOlen kadottanut salasanani Flysprayhyn ",
'lostpwmsg2'              => ", olkaa hyvä ja antakaa minulle uusi salasana.\n\nKäyttäjätunnus: ",
'regards'                 => "Terveisin,\n\n",
'yourusername'            => ' käyttäjätunnuksesi ',
'locale'                  => 'fi-FI',
'filenotexist'            => 'Tiedostoa ei ole olemassa, tai oikeutesi eivät riitä,',
'showtask'                => 'Näytä tehtävä',
'now'                     => 'Nyt',
'go'                      => 'Mene!',
'opentaskanon'            => 'Uusi tehtävä nimettömänä',
'register'                => 'Rekisteröi',
'addnewtask'              => 'Uusi tehtävä',
'reports'                 => 'Tapahtumaloki',
'editmydetails'           => 'Muokkaa tietojani',
'logout'                  => 'Kirjaudu ulos',
'disabledaccount'         => 'Käyttäjätilisi on jäädytetty!<br>Sinut kirjataan ulos välittömästi...',
'poweredby'               => 'Palvelun tarjoaa Flyspray',
'sponsoredby'             => 'Flysprayta sponsoroi',
'projects'                => 'Projektit',
'allprojects'             => 'Kaikki projektit',
'selectproject'           => 'Projektille:',
'tasksall'                => 'Kaikki tehtävät',
'tasksassigned'           => 'Tehtäväni',
'tasksreported'           => 'Raportoimani tehtävät',
'taskswatched'            => 'Tarkkailemani tehtävät',
'mysearch'                => 'Hakuni',
'admintoolbox'            => 'Ylläpitotyökalut',
'manageproject'           => 'Projektinhallinta',
'permissions'             => 'Käyttöoikeudet',
'hide'                    => 'Piilota',
'pendingreq'              => 'pyyntö projektin ylläpidolle',
'errorpage'               => 'Flyspray ei voi näyttää pyytämääsi sivua. Halusit ehkä nähdä tehtävän jota ei ole olemassa, tai sinulla ei ole oikeuksia nähdä haluamaasi sivua.<br/><br/>Olet saattanut myös yrittää tietomurtoa SQL-injektiota käyttämällä. Jos tämä pitää paikkansa, menee nurkkaan häpeämään ja miettimään toimintaasi. Älä yritä uudestaan palatessasi!',
'permissionsforproject'   => 'Käyttöoikeudet projektiin ',
'switchto'                => 'Vaihda',
'lastsearch'              => 'Viimeisin haku',
'modify'                  => 'Muokkaa',
'noticefrom'              => 'Ilmoitus ',
'hasopened'               => ' on avannut uuden sinulle osoitetun Flyspray-tehtävän:',
'moreinfonew'             => 'Lisätietoja tästä bugista Flysprayn sivulta:',
'newtaskcategory'         => 'Flysprayhyn on avattu uusi tehtävä luokituksessa',
'categoryowner'           => 'Saat tämän ilmoituksen luokituksen omistajana.',
'tasksummary'             => 'Tehtäväyhteenveto:',
'newtaskadded'            => 'Uusi tehtäväsi on lisätty.',
'summaryanddetails'       => 'Täytä sekä yhteenveto että yksityiskohtainen selostus.',
'summaryrequired'         => 'Kirjoita lyhyt yhteenveto tehtävästä',
'goback'                  => 'Palaa takaisin.',
'messagefrom'             => 'Tämä on automaattinen viesti Flyspraystä ',
'hasjustmodified'         => 'on juuri muokannut seuraavaa tehtävää.',
'changedfields'           => 'Muuttuneet kentät on merkitty **:lla.',
'moreinfomodify'          => 'Lisätietoja tehtävästä saat URL-osoitteesta:',
'nolongerassigned'        => 'Seuraava tehtävä ei ole enää osoitettu sinulle. Se on nyt osoitettu',
'hasassigned'             => 'osoitti sinulle seuraavan Flysprayn tehtävän:',
'taskupdated'             => 'Tehtävä päivitetty.',
'tasksupdated'            => 'Tehtävät päivitetty.',
'hasclosedassigned'       => 'sulki sinulle osoitetun Flyspray-tehtävän:',
'unassigned'              => 'Osoittamaton',
'hasclosed'               => 'sulki seuraavan tehtävän.',
'youonnotify'             => 'Tämä ilmoitus on lähetetty sinulle, koska olet ilmoituslistalla.',
'taskclosedmsg'           => 'Tehtävä on suljettu.',
'returntotask'            => 'Palaa tehtävän tietoihin',
'backtoindex'             => 'Palaa tehtävälistaan',
'noclosereason'           => 'Et valinnut tehtävän sulkemissyytä.',
'hasreopened'             => 'avasi uudelleen aiemmin sulkemasi tehtävän:',
'taskreopenedmsg'         => 'Tehtävä avattiin uudelleen.',
'backtotask'              => 'Palaa takaisin tehtävään.',
'commentaddedmsg'         => 'Kommentti lisätty.',
'commenttoassigned'       => 'lisäsi kommentin sinulle osoitettuun tehtävään.',
'commenttotask'           => 'lisäsi kommentin tähän tehtävään.',
'nocommententered'        => 'Sinun todellakin pitää kirjoittaa kommentti ennenkuin klikkaat \\"Lähetä\\".',
'fillinfields'            => 'Et täyttänyt kaikkia kenttiä.',
'notcurrentpass'          => 'Se ei ole nykyinen salasanasi!',
'passchanged'             => 'Salasanasi on muutettu.',
'closewindow'             => 'Voit nyt sulkea tämän ikkunan.',
'passnomatch'             => 'Salasanat eivät olleet samat!',
'usernametaken'           => 'Käyttäjätunnus on jo varattu. Sinun täytyy valita toinen.',
'usernametakenbulk'       => 'Käyttäjätunnus on jo varattu.',
'newusercreated'          => 'Uusi käyttäjätili on luotu.',
'accountcreated'          => 'Käyttäjätilisi on luotu.',
'newuserwarning'          => 'Huomioi, että ohjelman asetukset saattavat edellyttää käyttäjätilisi hyväksymistä ylläpitäjän taholta. Tämä voi olla syynä sisäänkirjautumisen epäonnistumiseen.',
'nomatchpass'             => 'Salasanat eivät täsmänneet keskenään.',
'confirmwrong'            => 'Vahvistuskoodi on virheellinen!',
'formnotcomplete'         => 'Lomaketta ei täytetty kokonaan.',
'formnotnumeric'          => 'Tieto ei ole numeerinen!',
'groupnametaken'          => 'Ryhmän nimi on jo varattu.',
'newgroupadded'           => 'Ryhmä lisätty.',
'optionssaved'            => 'Flysprayn asetukset tallennettu.',
'hasuploaded'             => 'on ladannut liitetiedoston tehtävään joka on osoitettu sinulle:',
'hasattached'             => 'on liittänyt tiedoston seuraavaan tehtävään.',
'fileuploaded'            => 'Tiedosto on ladattu',
'fileerror'               => 'Tiedoston tuonti epäonnistui. Tarkista <i>attachments/</i> hakemiston käyttöoikeudet.',
'contactadmin'            => 'Ota yhteyttä projektin ylläpitäjiin.',
'selectfileerror'         => 'Et valinnut tiedostoa.',
'userupdated'             => 'Käyttäjän tiedot on päivitetty',
'realandemail'            => 'Nimesi ja sähköpostiosoitteesi puuttuvat.',
'groupupdated'            => 'Ryhmän määrittely päivitetty.',
'groupanddesc'            => 'Ryhmän nimi puuttuu.',
'fillallfields'           => 'Ole hyvä ja täytä kaikki kentät.',
'listPmustN'              => 'Arvon "järjestys" tulee olla numero',
'listupdated'             => 'Lista on päivitetty.',
'listitemadded'           => 'Uusi rivi lisätty.',
'relatedaddedmsg'         => 'Uusi liittyvä tehtävä lisätty.',
'relatederror'            => 'Tämä tehtävä on jo liitettyjen tehtävien listalla.',
'relatedremoved'          => 'Liitetty tehtävä poistettu listalta.',
'notifyadded'             => 'Käyttäjä lisätty ilmoituslistaan.',
'notifyerror'             => 'Käyttäjä on jo tehtävän ilmoituslistalla.',
'notifyremoved'           => 'Käyttäjä poistettu ilmoituslistasta.',
'editcommentsaved'        => 'Kommentti päivitetty.',
'commentdeletedmsg'       => 'Kommentti poistettu.',
'gotonewtask'             => 'Siirry juuri luomaasi tehtävään',
'projectcreated'          => 'Uusi projektisi on luotu. Sen muokkaus onnistuu projektihallinnan avulla.',
'customiseproject'        => 'Muokkaa tätä projektia',
'projectupdated'          => 'Projektin asetukset päivitetty',
'emptytitle'              => 'Projektilla tulee olla nimi. Palaa korjaamaan puuttuva tieto.',
'loginbelow'              => 'Voit nyt yrittää kirjautua.',
'attachmentdeletedmsg'    => 'Liite on poistettu.',
'reminderaddedmsg'        => 'Muistutuksesi on lisätty.',
'reminderdeletedmsg'      => 'Valittu muistutus on poistettu.',
'flyspraytask'            => 'Flysprayn tehtävä',
'fieldsmissing'           => 'Jotkin kentät eivät sisältäneet tietoa tai tieto oli virheellistä.',
'relatedinvalid'          => 'Tehtävää ei ole olemassa.',
'relatedproject'          => 'Tehtävä on liitetty toiseen projektiin. Lisää liitos tästä huolimatta?',
'addanyway'               => 'Lisää joka tapauksessa',
'cancel'                  => 'Peruuta',
'alreadyedited'           => 'Tätä tehtävää muokkasi toinen käyttäjä ennen tallennusyritystäsi. Haluatko tästä huolimatta tallentaa omat muutoksesi ja menettää hänen tekemänsä muutokset?',
'saveanyway'              => 'Tallenna muutokseni joka tapauksessa',
'nouserselected'          => 'Ei valittua käyttäjää. Valitse vähintään yksi ennen uudelleen yrittämistä.',
'groupswitchupdated'      => 'Käyttäjäryhmät muokattu onnistuneesti,',
'takenownershipmsg'       => 'Tämä tehtävä on nyt osoitettu sinulle,',
'adminrequestmade'        => 'Pyyntösi on lähetetty projektin ylläpitäjille.',
'newdepnotify'            => 'Uusi riippuvuussuhde on lisätty tehtävään:',
'dependadded'             => 'Tehtävään on lisätty riippuvuussuhde',
'dependaddfailed'         => 'Riippuvuussuhteen lisäyksessä tapahtui virhe. Tarkista, että tehtävä on olemassa eikä ole jo olemassa keskinäistä liitosta.',
'depremovedmsg'           => 'Tehtävän riippuvuussuhde on poistettu',
'newdepis'                => 'Uusi riippuvuussuhde on',
'magicurlsent'            => 'Sähköpostiosoitteeseesi on lähetetty viesti. Se sisältää linkin sivulle, josta voit täydentää tämän tehtävän tiedot.',
'changefspass'            => 'Vaihda Flysprayn salasana',
'magicurlmessage'         => 'Ole hyvä ja käytä annettua linkkiä vaihtaaksesi Flysprayn salasanan:',
'erroronform'             => 'Tietojen tallentamisessa ilmeni ongelma',
'addressused'             => 'Tätä osoitetta on käytetty Flyspray tilin rekisteröitymiseen. Jos sinä et ollut odottamassa mitään viestiä meiltä, niin elä välitä ja tuhoa viesti samantien. Mene tähän osoitteeseen jotta saat viimeisteltyä rekisteröitymisesi:',
'confirmcodeis'           => 'Vahvistuskoodisi on:',
'codesent'                => 'Vahvistuskoodisi on lähetetty. Ole hyvä ja seuraa viestissä olevia ohjeita,',
'codenotsent'             => 'Vahvistuskoodiasi ei voida lähettää, ole hyvä ja yritä myöhemmin uudelleen.',
'taskmadeprivatemsg'      => 'Tämä tehtävä on muutettu yksityiseksi',
'taskmadepublicmsg'       => 'Tämä tehtävä on muutettu taas julkiseksi',
'realandnotify'           => 'Syötä koko nimesi sekä joko sähköpostiosoitteesi tai Jabber ID.',
'pmreqdeniedmsg'          => 'Pyyntö projektin ylläpitäjille evätty',
'massopsuccess'           => 'Massaoperaatiot suoritettiin onnistuneesti - missä käyttöoikeudet riittivät',
'usernotexist'            => 'Käyttäjää ei olemassa',
'commentattachperms'      => 'Et voi poistaa kommenttia - oikeutesi eivät salli liitteiden poistoa.',
'voterecorded'            => 'Äänesi on rekisteröity',
'votefailed'              => 'Ääntäsi ei voitu rekisteröidä juuri nyt.',
'createnewgroup'          => 'Uusi ryhmä',
'requiredfields'          => 'Pakolliset kentät ovat merkitty',
'addthisgroup'            => 'Lisää tämä ryhmä',
'createnewproject'        => 'Uusi projekti',
'addnewproject'           => 'Lisää projekti',
'htmlallowed'             => 'HTML-koodi sallittu',
'createthisproject'       => 'Luo tämä projekti',
'inlineimages'            => 'Näytä kuvaliitteet tekstin joukossa',
'createnewtask'           => 'Luo uusi tehtävä tähän projektiin:',
'addanother'              => 'Lisää uusi tehtävä tämän jälkeen',
'addthistask'             => 'Lisää tämä tehtävä',
'notifyme'                => 'Ilmoita tehtävässä tapahtuvista muutoksista',
'newtask'                 => 'Uusi tehtävä',
'attachafile'             => 'Liitä tiedosto',
'registernewuser'         => 'Rekisteröi uusi käyttäjä',
'none'                    => 'Ei mikään',
'registeraccount'         => 'Rekisteröi tämä käyttäjätili',
'registerbulkaccount'     => 'Rekisteröi käyttäjätilit',
'both'                    => 'Molemmat',
'notifyfrom'              => 'Ilmoitus ',
'donotreply'              => 'TÄMÄ ON AUTOMAATTINEN VIESTI, ÄLÄ VASTAA SIIHEN.',
'disclaimer'              => 'Sait tämän viestin koska sinut on merkitty vastaanottajaksi Flyspray vianseurantajärjestelmässä. Mikäli et osannut odottaa tätä viestiä tai et halua vastaanottaa sähköpostiviestejä jatkossa, niin voit muuttaa ilmoitusasetuksiasi yläpuolella mainitussa URL-osoitteessa.',
'userwho'                 => 'Tekijä',
'moreinfo'                => 'Lisätietoja löydät seuraavasta osoitteesta:',
'newtaskopened'           => 'Flysprayssa on avattu uusi tehtävä. Yksityiskohdat alempana.',
'notify.taskclosed'       => 'Suljettu tehtävä:',
'notify.taskreopened'     => 'Uudelleen avattu tehtävä:',
'newdep'                  => 'Uusi riippuvuussuhde on liitetty tehtävään:',
'notify.depremoved'       => 'Riippuvuussuhde on poistettu tehtävästä:',
'olddepwas'               => 'Vanha riippuvuussuhde oli',
'notify.commentadded'     => 'Uusi kommentti on lisätty tehtävään:',
'commentis'               => 'Kommentin teksti on alla',
'newattachment'           => 'Uusi tiedosto on liitetty tehtävään:',
'detailsbelow'            => 'Yksityiskohdat ovat alla.',
'notify.relatedadded'     => 'Uusi liittyvä tehtävä on lisätty tehtävään:',
'relatedis'               => 'Liittyvä tehtävä on',
'assignedtoyou'           => 'Sinulle on osoitettu seuraava tehtävä.',
'takenownership'          => 'on ottanut haltuunsa seuraavan tehtävän:',
'requiresaction'          => 'Seuraava tehtävä vaatii projektin ylläpitäjän toimenpidettä:',
'requiresactionnotify'    => 'Tehtävä vaatii projektin ylläpitäjän toimenpidettä',
'pmdeny'                  => 'Projektin ylläpitäjä on evännyt pyynnön seuraavaan tehtävään:',
'pmdenynotify'            => 'Projektin ylläpitäjä on evännyt pyynnön',
'fileaddedtoo'            => 'Yksi tai useampia tiedostoja on liitetty',
'taskwatching'            => 'Seuraavalla tarkkailemallasi tehtävällä',
'isdepfor'                => 'on uusi riippuvuussuhde',
'denialreason'            => 'Eväämisen syy',
'taskchanged'             => 'Seuraavaa tehtävää on muutettu. Muutokset on listattu alla. Tarkemmat tiedot muutoksista saat menemällä seuraavaan osoitteeseen ja siellä historiavälilehteä klikkaamalla.',
'useraddedtoassignees'    => 'Käyttäjä on lisännyt nämä tehtävälle osoitettujen tekijöiden listaan.',
'removeddepis'            => 'Poistettu riippuvuussuhde on',
'isnodepfor'              => 'ei ole enää riippuvuussuhteessa tehtävään',
'usergroups'              => 'Käyttäjäryhmät',
'pmtoolbox'               => 'Projektin ylläpitäjän työkalut',
'groupmanage'             => 'Ryhmien hallinta',
'pendingrequests'         => 'Odottavat pyynnöt',
'reasongiven'             => 'Annettu syy',
'nopendingreq'            => 'Projektin ylläpitäjille ei ole odottavia pyyntöjä.',
'givereason'              => 'Anna syy',
'catlisted'               => 'Luokituseditori',
'oslisted'                => 'Käyttöjärjestelmäeditori',
'verlisted'               => 'Versioeditori',
'tasktypeed'              => 'Tehtävätyyppieditori',
'resed'                   => 'Päätöseditori',
'deny'                    => 'Evää',
'notifiedwhen'            => 'Ilmoita, kun',
'onlynewtasks'            => 'Uusia tehtäviä avataan',
'allevents'               => 'Kaikki tapahtumat tehtävissä',
'feeds'                   => 'Syötteet',
'feeddescription'         => 'Syötteen kuvaus',
'feedimgurl'              => 'Syötteen kuvatiedoston URL (jätä tyhjäksi tarkoittaa ei kuvaa)',
'notifysubject'           => 'Ilmoitusten otsikko',
'notifysubjectinfo'       => '(%p = projektin nimi, %s = tehtävän yhteenveto, %t = tehtävän id, %a = toimenpide, %u = käyttäjä)',
'priority6'               => 'Erittäin korkea',
'priority5'               => 'Korkea',
'priority4'               => 'Keskinkertainen',
'priority3'               => 'Matala',
'priority2'               => 'Erittäin alhainen',
'priority1'               => 'Lykätty',
'sendcode'                => 'Lähetä vahvistuskoodi!',
'entercode'               => 'Syötä saamassasi viestissä ollut vahvistuskoodi. Syötä myös haluamasi salasana.',
'confirmationcode'        => 'Vahvistuskoodi',
'registererror'           => 'Varmista, että täytit kaikki tarvittavat tiedot sekä oikeat tiedot haluamaasi ilmoituskanavaan.',
'validusername'           => 'sallitut merkit ovat: alfanumeeriset merkit sekä -, _ ja .',
'validemail'              => 'Erota useat sähköpostiosoitteet toisistaan käyttämällä ;.',
'emailtakenbulk'          => 'Sähköpostiosoite on jo varattu.',
'emailtaken'              => 'Antamasi sähköpostiosoite tai Jabber-ID on jo käytössä. Ole hyvä, ja valitse toinen.',
'note'                    => '<strong>Huom!</strong> Sinulle lähetetään vahvistuskoodi haluamasi kanavan kts. yllä kautta ennen tilisi luontia.<br />Jos lähetät vääriä tietoja, <strong>et saa koodiasi</strong>.',
'changelog'               => 'Muutosloki',
'changeloggen'            => 'Muutoslokin luoja',
'listfrom'                => 'Näytä muutoslokia lähtien',
'to'                      => 'päättyen',
'oldestfirst'             => 'Vanhin ensin',
'recentfirst'             => 'Tuorein ensin',
'severityrep'             => 'Vakavuusraportti',
'totalopen'               => 'Avoimia tehtäviä yhteensä',
'age'                     => 'Ikä',
'agerep'                  => 'Ikäraportti',
'eventsrep'               => 'Tapahtumaraportti',
'events'                  => 'Tapahtumat',
'Tasks'                   => 'Tehtävät',
'opened'                  => 'Avattu',
'edited'                  => 'Muokattu',
'assigned'                => 'Osoitettu',
'within'                  => 'Arvojen välillä',
'pastday'                 => 'Viimeisin vuorokausi',
'pastweek'                => 'Viimeisin viikko',
'pastmonth'               => 'Viimeisin kuukausi',
'pastyear'                => 'Viimeisin vuosi',
'nolimit'                 => 'Ei rajaa',
'from'                    => 'Alkaen',
'duein'                   => 'Valmistuu versioon',
'selectfromdate'          => 'Valitse alkupäivä',
'selecttodate'            => 'Valitse loppupäivä',
'showvoters'              => 'Näytä/piilota äänestäjät',
'roadmap'                 => 'Etenemissuunnitelma',
'roadmapfor'              => 'Etenemissuunnitelma versiolle',
'tasks'                   => 'tehtävät',
'completed'               => 'suoritettu.',
'opentasks'               => 'avointa tehtävää',
'of'                      => '%',
'severity5'               => 'Kriittinen',
'severity4'               => 'Korkea',
'severity3'               => 'Keskinkertainen',
'severity2'               => 'Matala',
'severity1'               => 'Erittäin alhainen',
'Redirect'                => 'Uudelleenohjaa',
'redirectmsg'             => 'Jos selaimesi ei tue automaattista uudelleenohjausta klikkaa %sHERE%s jatkaaksesi',
'allowclosedcomments'     => 'Salli kommentit suljettuihin tehtäviin',
'comment'                 => 'Kommentti',
'editowncomments'         => 'Muokkaa omia kommentteja',
'reopened'                => 'Avattu uudelleen',
'loading'                 => 'Ladataan...',
'notifyown'               => 'Ilmoita omista muutoksista',
'youremail'               => 'Sähköpostiosoitteesi',
'thankyouforbug'          => 'Kiitos raportoimastasi ongelmasta. Näet tehtävän ja voit seurata sen etenemistä koska tahansa seuraavasta osoitteesta:',
'anonuser'                => 'Tuntematon käyttäjä',
'conflict'                => 'Konflikti',
'file'                    => 'Tiedosto',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Koko',
'projectgroup'            => 'Projektiryhmä',
'profile'                 => 'Profiili:',
'viewprofile'             => 'Näytä profiili',
'regdate'                 => 'Rekisteröitynyt alkaen',
'tasksopened'             => 'Avattuja tehtäviä',
'replyto'                 => 'Vastaa',
'notifytypes'             => 'Ilmoitustyypit',
'pm.taskchanged'          => 'Tehtävä muutettu',
'pm.taskreopened'         => 'Tehtävä avattu uudelleen',
'pm.depadded'             => 'Riippuvuussuhde lisätty',
'pm.depremoved'           => 'Riippuvuussuhde poistettu',
'pmrequest'               => 'Pyyntö projektin ylläpitäjille',
'pmrequestdenied'         => 'Pyyntö projektin ylläpitäjille evätty',
'newassignee'             => 'Uusi tekijä',
'revdepadded'             => 'Käänteinen riippuvuus lisätty',
'revdepaddedremoved'      => 'Käänteinen riippuvuus poistettu',
'assigneeadded'           => 'Tekijä lisätty',
'addusergroup'            => 'Lisää käyttäjä tähän ryhmään',
'groupmembers'            => 'Ryhmän jäsenet',
'deleteuser'              => 'Poista tämä käyttäjä',
'userdeleted'             => 'Käyttäjä poistettu',
'autoassign'              => 'Osoita tehtävä automaattisesti luokituksen omistajalle',
'ssl'                     => 'SSL',
'updatewrong'             => 'Olet aktivoinut päivitysten tarkistuksen, mutta otettaessa yhteyttä päivityspalvelimeen tapahtui virhe. Joko palvelimesi ei salli ulossuuntautuvia yhteyksiä tai virheen syynä oli verkko-ongelma. Käy Flysprayn verkkosivuilla tarkistamassa että käytössäsi on viimeisin versio.',
'deleteproject'           => 'Poista tämä projekti ja siirrä sen sisältö',
'projectdeleted'          => 'Projekti poistettu onnistuneesti',
'feedforall'              => 'Kaikkien projektien syöte',
'usercreated'             => 'Käyttäjä luotu',
'created'                 => 'Luotu',
'deleted'                 => 'Poistettu',
'userid'                  => 'Käyttäjätunnus',
'editassignments'         => 'Salli tehtävien osoitus',
'preview'                 => 'Esikatselu',
'anyprogress'             => 'Kaikki',
'tasksrelated'            => 'Tähän tehtävään liittyvät tehtävät',
'duplicatetasks'          => 'Tämän tehtävän toisinto',
'databasemodfailed'       => 'Tietokannan muokkaus epäonnistui. Mahdollinen syy voi olla riittämättömät oikeudet.',
'frequency'               => 'Tiheys',
'newuserregistered'       => 'Uusi käyttäjä on rekisteröitynyt Flysprayhin. Hänen tietonsa ovat seuraavat:',
'newuserregisterednotify' => 'Uusi käyttäjä on rekisteröitynyt',
'notify_registration'     => 'Ilmoita ylläpitäjille uuden käyttäjän rekisteröinnistä',
'textversion'             => 'Tekstiversio',
'onlyprimary'             => 'Muita tehtäviä sulkemasta estämättömät tehtävät',
'onlyblocker'             => 'Tehtävät jotka estävät muiden sulkemisen',
'blockerornoblocker'      => 'Molempien hakuvaihtoehtojen valitseminen yhtäaikaa ei ole kovin mielekästä.',
'switch'                  => 'Vaihda',
'max'                     => 'en.',
'dates'                   => 'Päivät',
'selectduedatefrom'       => 'Valmistumisajasta',
'selectduedateto'         => 'Päättyen',
'selectsincedatefrom'     => 'Muutettu alkaen',
'selectsincedateto'       => 'Päättyen',
'selectdate'              => 'Valitse päivä',
'selectopenedfrom'        => 'Avattu alkaen',
'selectopenedto'          => 'Päättyen',
'selectclosedfrom'        => 'Suljettu alkaen',
'selectclosedto'          => 'Päättyen',
'startat'                 => 'Alkaen',
'hasattachment'           => 'Sisältää liitetiedostoja',
'private'                 => 'Yksityinen',
'watching'                => 'Tarkkailussa',
'alreadyvotedthistask'    => 'olet äänestänyt tätä tehtävää',
'alreadyvotedthisday'     => 'olet jo äänestänyt tänään',
'visibility'              => 'Näkyvyys',
'public'                  => 'Julkinen',
'leaveemptyauto'          => 'Jätä salasanakentät tyhjiksi, jos haluat automaattisesti luodun salasanan.',
'novalidemail'            => 'Et antanut oikeaa sähköpostiosoitetta.',
'novalidjabber'           => 'Et antanut oikeaa Jabber-osoitetta',
'missingrequired'         => 'Et täyttänyt kaikkia vaadittuja kenttiä.',
'entervalidusername'      => 'Ole hyvä, ja anna pätevä käyttäjätunnus sekä oikea nimi.',
'couldnotaddusernotif'    => 'Käyttäjää ei voitu lisätä ilmoituslistaan.',
'defaulttask'             => 'Oletustehtäväkuvaus',
'all'                     => 'kaikki',
'events.useraddedtoassignees'=> 'Käyttäjä lisätty tekijöihin',
'eventlog'                => 'Tapahtumalogi',
'assignmentchanged'       => 'Osoitus muuttunut',
'detailedinfo'            => 'Yksityiskohtaiset tiedot',
'All'                     => 'Kaikki',
'tasksireported'          => 'Raportoimani tehtävät',
'recentlyopened'          => 'Viime aikoina avatut',
'stats'                   => 'Tilastot',
'totaltasks'              => 'tehtävää yhteensä',
'mostwanted'              => 'Halutuimmat tehtävät',
'defaultentry'            => 'Oletusalkusivu',
'toplevel'                => 'Päänäkymä',
'overview'                => 'Yleiskatsaus',
'error#'                  => 'Virhe #',
'error1'                  => 'Käyttöoikeutesi eivät riitä tämän liitteen avaamiseen.',
'error3'                  => 'Toiminto toistettu, ohjataan pääsivulle.',
'error4'                  => 'Sinulla ei ole ylläpitäjän oikeuksia.',
'error5'                  => 'Tuntematon käyttäjä.',
'error6'                  => 'Virheellinen ylläpitäjän alue.',
'error7'                  => 'Kirjautuminen epäonnistui, virheellinen salasana!',
'error71'                 => 'Käyttäjätili on lukittu %d minuutiksi liian monen epäonnistuneen kirjautumisyrityksen vuoksi!',
'error8'                  => 'Et antanut sekä käyttäjätunnusta että salasanaa.',
'error9'                  => 'Tehtävää ei ole tai käyttäjäoikeutesi eivät riitä sen katseluun.',
'error10'                 => 'Tätä tehtävää ei ole olemassa.',
'error101'                => 'Oikeutesi eivät riitä tämän tehtävän katseluun.',
'error102'                => 'Oikeutesi eivät riitä tämän tehtävän katseluun, sisäänkirjautuminen saattaa auttaa.',
'error11'                 => 'Ei oikeuksia muokata tätä kommenttia,',
'error13'                 => 'Tuntemattomilla käyttäjillä ei ole profiilia.',
'error14'                 => 'Sinulla ei ole riittäviä oikeuksia luoda uutta ryhmää.',
'error15'                 => 'Sinulla ei ole riittäviä oikeuksia avata uutta tehtävää.',
'error16'                 => 'Et ole projektin ylläpitäjä.',
'error17'                 => 'Virheellinen projektin ylläpidon alue.',
'error18'                 => 'Kirjautumiseen tarvittava URL-osoite puutteellinen.',
'error19'                 => 'Tuntematon käyttäjä',
'error20'                 => 'Virheellinen tietokantamuokkaus.',
'error21'                 => 'Yhtä tai useampaa sähköpostia ei voitu lähettää. Tarkista asetukset.',
'error22'                 => 'Uusien käyttäjien rekisteröinti ei ole sallittu.',
'error23'                 => 'Käyttäjän tai ryhmän kirjautuminen ei ole sallittu.',
'error25'                 => 'Etenemissuunnitelma on saatavilla vain tietyissä projekteissa.',
'error26'                 => 'oauth tarjoaja ei ole tuettu',
'error28'                 => 'Oikeutesi eivät riitä pääsyyn tälle alueelle.',
'done'                    => 'suoritettu',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projektia ei voitu poistaa.',
'GMT'                     => 'GMT',
'timezone'                => 'Aikavyöhyke',
'accept'                  => 'Hyväksy',
'reasonfordeinal'         => 'Eväämisen syy',
'pruneclosedlinks'        => 'Karsi suljetut linkit',
'pruneclosedtasks'        => 'Karsi suljetut tehtävät',
'pagegenerated'           => 'Sivu ja kuva luotu %d sekunnissa.',
'pruninglevel'            => 'Karsintataso',
'lastuser'                => 'Viimeistä käyttäjää ei voi poistaa.',
'allprivate'              => 'Kaikki projektit ovat yksityisiä.',
'deletegroup'             => 'Poista ryhmä ja siirrä käyttäjät',
'parent'                  => 'Emo',
'ordertip'                => 'Näytä listassa tässä järjestyksessä',
'showtip'                 => 'Lisää listaan',
'deletetip'               => 'Poista listasta',
'del'                     => 'del',
'request1'                => 'Tehtävän sulkemista pyydetty.',
'request2'                => 'Tehtävän uudelleen avaamista pyydetty.',
'allpriorities'           => 'Kaikki',
'noroadmap'               => 'Etenemissuunnitelmaa ei ole saatavilla (projektilla ei ole yhtäkään tulevaisuuteen määriteltyä versiota).',
'expand'                  => 'Laajenna',
'collapse'                => 'Supista',
'expandall'               => 'Laajenna kaikki',
'collapseall'             => 'Supista kaikki',
'minpwsize'               => 'Salasanan vähimmäispituus on 5 merkkiä.',
'passwordtoosmall'        => 'Salasana on liian lyhyt.',
'accountwaslocked'        => 'Käyttäjätilisi on lukittu liian monen epäonnistuneen kirjautumisyrityksen vuoksi.',
'failedattempts'          => '% epäonnistunutta kirjautumisyritystä.',
'groupnotexist'           => 'Valittu ryhmä ei kuulu projektiin.',
'searchindetails'         => 'Hae kuvauksesta',
'showasassignees'         => 'Näytä tekijänä',
'find'                    => 'Hae',
'tls'                     => 'TLS',
'isadmin'                 => 'On ylläpitäjä',
'addvotes'                => 'Anna ääniä',
'removevote'              => 'Poista ääni',
'voteremoved'             => 'Äänesi on poistettu',
'voteremovefailed'        => 'Ääntäsi ei voitu poistaa juuri nyt.',
'novotes'                 => 'Sinulla ei ole tällä hetkellä yhtään annettua ääntä missään tehtävässä.',
'connectedtasks'          => 'Riippuvuussuhteessa olevat tehtävät:',
'taskdependencies'        => 'Riippuvuussuhteet',
'viewgraph'               => 'Näytä graafi',
'notaskdependencies'      => 'Tämä tehtävä on riippumaton muista tehtävistä.',
'dependson'               => 'Riippuu',
'blocks'                  => 'Estää sulkemasta',
'newdependency'           => 'Uusi riippuvuussuhde:',
'nouserstoadd'            => 'Ei lisättäviä käyttäjiä. Ole hyvä, ja varmista, että kaikille käyttäjille on määritetty nimi, käyttäjänimi sekä sähköpostiosoite.',
'dispintro'               => 'Näytä tervetuloviesti',
'mainmessage'             => 'Tervetuloviesti',
'setsupertask'            => 'Aseta emotehtävän tunnus:',
'supertaskmodified'       => 'Emotehtävän tunnusta muokattu',
'set'                     => 'Aseta',
'supertask'               => 'Emotehtävä',
'setparent'               => 'Aseta emotehtävän tunnus',
'selfsupertasknotallowed' => 'Tehtävää ei voi asettaa itsensä emotehtäväksi.',
'quickaction'             => 'Pikatoiminnat',
'updateselectedtasks'     => 'Päivitä valitut tehtävät',
'notspecified'            => 'Ei määritelty',
'editselectedtasks'       => 'Muokkaa valittuja tehtäviä',
'information'             => 'Lisätietoja',
'taskclosedisabled'       => 'Tehtävän sulkeminen ei ole mahdollista seuraavien siitä riippuvien tehtävien ollessa avoimia:-',
'daysleft'                => 'päivää jäljellä',
'dayoverdue'              => 'päivää yli',
'duetoday'                => 'Valmistuu tänään.',
'daysbeforealert'         => 'Päivää ennen varoitusta',
'associatedsubtask'       => 'Liitetty onnistuneesti alitehtävä FS#',
'associatesubtask'        => 'Liitä alitehtävä',
'subtaskid'               => 'Alitehtävän ID',
'subtaskalreadyhasparent' => 'Lisäämälläsi alitehtävällä on jo emotehtävä, poista se ensin.',
'subtaskisparent'         => 'Lisäämäsi alitehtävä on jo tämän tehtävän emotehtävä. Alitehtävää ei liitetty.',
'subtasknotexist'         => 'Annettu alitehtävä ei ole olemassa,',
'subtaskremovedmsg'       => 'Alitehtävä poistettu onnistuneesti.',
'subtaskadded'            => 'Alitehtävä lisätty',
'subtaskremoved'          => 'Alitehtävä poistettu',
'addnewsubtask'           => 'Lisää uusi alitehtävä',
'hidesubtasks'            => 'Piilota alitehtävät',
'voteforthistask'         => 'Äänestä tehtävää',
'watchthistask'           => 'Tarkkaile tehtävää',
'privatethistask'         => 'Muuta tehtävä yksityiseksi',
'adddependenttask'        => 'Lisää riippuvuus',
'associatetaskid'         => 'Alitehtävän tunnus',
'parenttaskid'            => 'Emotehtävän tunnus',
'invalidsupertaskid'      => 'Emotehtävän tunnus puutteellinen',
'supertaskadded'          => 'Emotehtävä lisätty',
'supertaskremoved'        => 'Emotehtävä poistettu',
'effort'                  => 'Työaika',
'efforttracking'          => 'Työajanseuranta',
'useeffort'               => 'Projekti käyttää työajanseurantaa',
'estimatedeffort'         => 'Arvioitu työaika',
'totalestimatedeffort'    => 'Arvioitu työaika yhteensä',
'currenteffortdone'       => 'Toteutunut työaika tähän mennessä',
'starteffort'             => 'Aloita työajanseuranta',
'endeffort'               => 'Päätä työajanseuranta',
'cleareffort'             => 'Tyhjennä työajanseuranta',
'addeffort'               => 'Lisää työaika',
'manualeffort'            => 'Lisää käsin työaika (TT:MM)',
'efforttrackingstarted'   => 'Tehtävän työajanseuranta on käynnistetty.',
'efforttrackingnotstarted'=> 'Työajanseuranta on jo käynnissä. Päätä edellinen ennen uuden aloittamista.',
'efforttrackingstopped'   => 'Tehtävän työajanseuranta on pysäytetetty.',
'efforttrackingcancelled' => 'Tehtävän työajanseuranta on peruutettu.',
'efforttrackingadded'     => 'Manuaalinen työaika taltioitu tehtävälle,',
'trackinginprogress'      => 'Työajan seuranta käynnissä',
'viewestimatedeffort'     => 'Salli arvioidun työajan näkeminen',
'viewcurrenteffortdone'   => 'Salli toteutuneen työajan näkeminen',
'trackeffort'             => 'Salli työajanseuranta',
'invalideffort'           => 'Syöttämäsi työaika ei ollut tunnistettavassa muodossa.',
'showpass'                => 'Näytä salasana',
'chooseafile'             => 'Ole hyvä ja valitse tiedosto!',
'incorrectfiletype'       => 'Virheellinen tiedostotyyppi. Sallitut: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Ei salasanaa jota pyytää. Olet rekisteröitynyt käyttämällä %s',
'addmultipletasks'        => 'Lisää useita tehtäviä',
'pendingnewuserrequest'   => 'Liittymispyynnöt',
'adminrequestswaiting'    => 'pyyntöä ylläpitäjille',
'clicktoedit'             => 'Pikamuokkaa kenttiä klikkaamalla',
'confirmedit'             => 'vahvista',
'regapprovedbyadmin'      => 'Ylläpitäjät hyväksyvät rekisteröinnit (vahvistuskoodi ei ole käytössä)',
'activity'                => 'Aktiviteetti',
'myactivity'              => 'Oma aktiviteetti',
'emailverificationwrong'  => 'Sähköpostivahvistus ei täsmää annetun osoitteen kanssa',
'verifyemailaddress'      => 'Vahvista sähköpostiosoite',
'hideemails'              => 'Piilota käyttäjien sähköpostiosoitteet',
'hidemyemail'             => 'Piilota sähköpostiosoitteeni',
'exporttasklist'          => 'Vie tehtävälista',
'onedecimal'              => 'yksi desimaali',
'manday'                  => 'työpäivä',
'mandays'                 => 'työpäivää',
'mandayabbrev'            => 'tp',
'hourspermanday'          => 'Tuntia työpäivässä (TT:MM)',
'itemexists'              => '% on jo tietokannassa',
'categoryitemexists'      => '% on jo tietokannassa luokituksen % alla.',
'pageswelcomemsg'         => 'Tervetuloviesti näytetään sivuilla',
'pagesintromsg'           => 'Esittelyviesti näytetään sivuilla',
'activeoauths'            => 'Aktiiviset Oauth-tarjoajat',
'onlyoauthreg'            => 'Salli vain Oauth-rekisteröinnit',
'estimatedeffortformat'   => 'Arvioidun työmäärän esitystapa',
'currenteffortdoneformat' => 'Toteutuneen työmäärän esitystapa',
'minute'                  => 'minuutti',
'minutes'                 => 'minuuttia',
'minuteplural'            => 'minuuttia',
'minutesingular'          => 'minuutti',
'minuteabbrev'            => 'm.',
'hourplural'              => 'tuntia',
'hoursingular'            => 'tunti',
'hourabbrev'              => 't.',
'estimatedeffortopen'     => 'Arvioitu työmäärä avoimille tehtäville',
'currenteffortdoneopen'   => 'Toteutunut työmäärä avoimille tehtäville',
'signinwith'              => 'Kirjaudu käyttämällä %s',
'canviewroadmap'          => 'Salli etenemissuunnitelman näyttäminen',
'enableavatars'           => 'Salli avatarien käyttö',
'maxavatarsize'           => 'Avatarin maksimikoko pikseleinä',
'taskhassubtask'          => 'Tehtävä sisältää seuraavan alitehtävän',
'taskhassubtasks'         => 'Tehtävä sisältää seuraavat alitehtävät',
'translations'            => 'Käännökset',
'translate'               => 'Käännä',
'taskdescription'         => 'Tehtävän kuvaus',
'notaskdescription'       => 'Ei tehtävän kuvausta',
'pleaseselect'            => 'Ole hyvä ja valitse',
'closeselectedtasks'      => 'Sulje valitut tehtävät',
'closetasks'              => 'sulje tehtävät',
'hintforbulkimport'       => "<b>Vihjeitä tietojen tuontiin:</b>\n<ol>\n<li>Kopioi ja liitä Excel-taulukosta tai csv-tiedostosta liittämällä kokonainen solu.</li>\n<li>Vain nimi- ja sisältötietojen liittäminen on mahdollista toistaiseksi.</li>\n<li>Tehtävien osoituksessa näytetään vihje, jos nimi täsmää. Muutoin näytetään tuntematon tekijä.</li>\n</ol>",
'taskissubtaskof'         => 'Tämä tehtävä on seuraavan tehtävän alitehtävä',
'applyfirstline'          => 'Hyväksy rivi',
'addmorerows'             => 'Lisää rivejä',
'addtasks'                => 'Lisää tehtäviä',
'massopsdisabled'         => 'Valitamme, massaoperaatiot eivät toistaiseksi ole käytettävissä. Toteutuksen viimeistely on suunnitelmissa jossakin Flysprayn myöhemmässä versiossa. Voit ottaa sen käyttöön omalla vastuulla muokkaamalla lähdekoodia, mutta lue kommentit ennen kuin teet sen.',
'viewroadmap'             => 'Salli etenemissuunnitelman näyttäminen',
'nosuicide'               => 'Rakas käyttäjä, ohjelmointini ei salli sinun tuhota kirjautumisoikeuksiasi Flysprayhin poistamalla käytöstä oman käyttäjätilisi tai vaihtamalla omaa ryhmääsi. Ystävällisin terveisin, HAL9000:n velipoika.',
'movingtodifferentproject'=> 'Riippuvuussuhteessa olevien tehtävien siirto toiseen projektiin ei ole sallittu. Riippuvuussuhde tulee purkaa ensin.',
'musthavesameproject'     => 'Riippuvuussuhteessa olevien tehtävien tulee kuulua samaan projektiin.',
'defaultorderby'          => 'Tehtävälistan oletusjärjestys',
'defaultorderby2'         => 'sitten',
'viewowntasks'            => 'Näytä omat tehtäväni',
'viewgroupstasks'         => 'Ryhmän tehtävät',
'urlrewriting'            => 'Käytä muokattuja URL-osoitteita.',
'nomodrewrite'            => 'Mod_rewrite ei ole käytettävissä tällä palvelimella, valitan mutta muokattuja urleja ei voida ottaa käyttöön ',
'on'                      => 'Päällä',
'off'                     => 'Pois',
'defaultorderbydirection' => 'Oletuslajittelu',
'ascending'               => 'Nouseva',
'descending'              => 'Laskeva',
'myassignedtasks'         => 'Tehtäväni',
'commentedon'             => 'kommentoi',
'maxvoteperday'           => 'Päiväkohtainen äänikiintiö',
'votesperproject'         => 'Käyttäjän projektikohtainen äänikiintiö',
'votelimitreached'        => 'Olet antanut projektikohtaisen raja-arvosi mukaisen määrän ääniä. Tarkista profiilisivultasi äänestystilanteesi. Voit tarvittaessa poistaa antamiasi ääniä ja siten vapauttaa niitä parempaan käyttöön. Näin voimme parhaiten seurata tehtäviä, jotka ovat sinulle tärkeimpiä. Suljetut tehtävät palauttavat äänikiintiötäsi.',
'myvotes'                 => 'Äänestykseni',
'tag'                     => 'Tägi',
'tags'                    => 'Tägit',
'tagsinfo'                => 'Tehtävien vapaa tägitys Flysprayssa. Erota tägit \';\':llä (puolipiste) toisistaan. Niitä ei toistaiseksi käytetä hakuihin, lajitteluun tai suodatukseen.',
'novalues'                => 'Ei arvoja',
'youhaveregistered'       => 'Olet rekisteröitynyt käyttäjäksi Flysprayhin. Antamasi tiedot:',
'youhaveregisterednotify' => 'Ylläpitäjät hyväksyivät sinun Flyspray rekisteröitymisen.',
'usedintasks'             => 'Käytetty tehtävissä',
'freetagging'             => 'Salli käyttäjien määrittelemät tagit',
'keyboardshortcuts'       => 'Näppäimistökomennot',
'testmailsettings'        => 'Kokeile aktiivisia sähköpostiasetuksia',
'test'                    => 'Kokeile',
'testmailsettingsnotice'  => 'Ja varmista myös että olet vastaanottanut emailin käyttämääsi postilaatikkoon (tarkista sivulta \'myprofile\')',
'invalidinput'            => 'Tehtävällä on joitakin epäyhteensopivia ominaisuuksia jotka tulee ratkaista ennen sen siirtämistä toiseen projektiin.',
'invalidstatus'           => 'Valitse sopiva tehtävän tila siirtäessäsi tehtävää toiseen projektiin.',
'invalidcategory'         => 'Valitse sopiva luokitus siirtäessäsi tehtävää toiseen projektiin.',
'invalidreportedversion'  => 'Valitse sopiva raportointiversio siirtäessäsi tehtävää toiseen projektiin.',
'invaliddueversion'       => 'Valitse sopiva tavoiteversio siirtäessäsi tehtävää toiseen projektiin.',
'invalidos'               => 'Valitse sopiva käyttöjärjestelmä siirtäessäsi tehtävää toiseen projektiin.',
'invalidtags'             => 'Valitse vain sallittuja tägejä siirtäessäsi tehtävää toiseen projektiin.',
'invalidassignees'        => 'Valitse vain sallittuja suorittajia siirtäessäsi tehtävää toiseen projektiin.',
'customize'               => 'Kustomoi',
'hidesubs'                => 'Piilota alitehtävät',
'hideprivate'             => 'Piilota yksityiset tehtävät',
'hideclosed'              => 'Piilota suljetut tehtävät',
'currentproject'          => 'Nykyinen projekti',
'targetproject'           => 'Kohdeprojekti',
'availablekeybshortcuts'  => 'Käytettävissä olevat näppäinkomennot',
'logindialoglogout'       => 'Sisään-/uloskirjautuminen',
'focustaskidsearch'       => 'Siirry hakuun tehtävän id:llä',
'openselectedtask'        => 'Avaa valittu tehtävä',
'movecursorup'            => 'Siirrä kursoria ylöspäin',
'movecursordown'          => 'Siirrä kursoria alaspäin',
'taskdetails'             => 'Tehtävän yksityiskohdat',
'taskediting'             => 'Tehtävän muokkaus',
'savetask'                => 'Tallenna tehtävä',
);

?>
