<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
//
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
//
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Modifier l\'utilisateur',
'accountenabled'          => 'Compte actif',
'editallusers'            => 'Voir tous les utilisateurs',
'username'                => 'Nom d\'utilisateur',
'usersupdated'            => 'Utilisateur mis à jour',
'realname'                => 'Nom réel',
'emailaddress'            => 'Adresse courriel',
'jabberid'                => 'ID Jabber',
'profileimage'            => 'Image de profil',
'notifytype'              => 'Type de notification',
'group'                   => 'Groupe',
'enableaccounts'          => 'Activer les comptes',
'disableaccounts'         => 'Désactiver les comptes',
'deleteaccounts'          => 'Supprimer les comptes',
'updatedetails'           => 'Mettre les informations à jour',
'setglobally'             => 'Ces options ont été définies globalement.',
'usergroupmanage'         => 'Gestion des utilisateurs et des groupes',
'newuser'                 => 'Enregistrer un nouvel utilisateur',
'newuserbulk'             => 'Enregistrer plusieurs nouveaux utilisateurs',
'bulkuserstoadd'          => 'Liste des nouveaux utilisateurs',
'optionsforallusers'      => 'Options pour tous les nouveaux utilisateurs',
'newgroup'                => 'Créer un nouveau groupe',
'yes'                     => 'Oui',
'no'                      => 'Non',
'editgroup'               => 'Modifier le groupe',
'groupname'               => 'Nom du groupe',
'description'             => 'Description',
'admin'                   => 'Appartient au groupe Admin',
'opennewtasks'            => 'Ouvrir de nouvelles tâches',
'modifytasks'             => 'Modifier des tâches existantes',
'addcomments'             => 'Ajouter des commentaires',
'attachfiles'             => 'Joindre des fichiers',
'vote'                    => 'Vote',
'groupenabled'            => 'Les membres peuvent se connecter',
'groupopen'               => 'Les membres peuvent se connecter',
'tasktypelist'            => 'Liste des types de tâche',
'categorylist'            => 'Liste des catégories',
'oslist'                  => 'Liste des systèmes d\'exploitation',
'resolutionlist'          => 'Liste des raisons de fermeture',
'versionlist'             => 'Liste des versions',
'severitylist'            => 'Liste des sévérités',
'listnote'                => 'Note : décocher la case "Afficher" peut altérer certaines tâches en cours de modification. Modifier le champ "Nom" changera toutes les tâches associées à ce nom. Certaines options ne sont pas supprimables car déjà utilisées dans des tâches, ou bien nécessaires au bon fonctionnement de l\'outil.',
'name'                    => 'Nom',
'order'                   => 'Ordre',
'back'                    => 'Précédent',
'text'                    => 'Texte',
'highlight'               => 'Mettre en évidence',
'show'                    => 'Afficher',
'owner'                   => 'Responsable',
'selectowner'             => 'Sélectionner un responsable',
'update'                  => 'Mettre à jour',
'addnew'                  => 'Ajouter',
'flysprayprefs'           => 'Préférences de Flyspray',
'projecttitle'            => 'Nom du projet',
'baseurl'                 => 'URL de base pour cette installation',
'replyaddress'            => 'Adresse courriel de réponse pour les notifications',
'themestyle'              => 'Thème / Style',
'language'                => 'Langue',
'anonview'                => 'Permettre aux utilisateurs anonymes de consulter les tâches',
'allowanon'               => 'Permettre aux utilisateurs anonymes d\'ouvrir de nouvelles tâches',
'never'                   => 'Jamais',
'anonymously'             => 'Anonymement',
'afterregister'           => 'Seulement après inscription',
'spamproof'               => 'Activer le code de confirmation pour l\'inscription de nouveaux utilisateurs',
'anongroup'               => 'Groupe des nouveaux utilisateurs',
'groupassigned'           => 'Des tâches peuvent être assignées aux membres des groupes',
'forcenotify'             => 'Mode de notification des tâches',
'neversend'               => 'Aucun envoi',
'userchoose'              => 'Laisser l\'utilisateur choisir',
'email'                   => 'Courriel',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Responsable des catégories par défaut',
'noone'                   => 'Personne',
'jabbernotify'            => 'Notifications par Jabber',
'jabberserver'            => 'Serveur',
'jabberport'              => 'Port',
'jabberuser'              => 'Nom d\'utilisateur Jabber',
'jabberpass'              => 'Mot de passe Jabber',
'saveoptions'             => 'Sauvegarder les options',
'editcomment'             => 'Modifier le commentaire',
'commentby'               => 'Commentaire de',
'saveeditedcomment'       => 'Sauvegarder le commentaire modifié',
'projectprefs'            => 'Préférences du projet',
'pagetitle'               => 'Titre de la page',
'defaultproject'          => 'Projet par défaut',
'projectlists'            => 'Listes du projet',
'showlogo'                => 'Afficher le logo',
'showgravatars'           => 'Afficher les gravatars',
'emailNoHTML'             => 'Désactiver HTML dans les courriels',
'intromessage'            => 'Message d\'accueil',
'isactive'                => 'Le projet est actif',
'createproject'           => 'Créer un nouveau projet',
'nopermission'            => 'Vous n\'avez pas la permission d\'utiliser cette page',
'listordertip'            => 'L\'ordre d\'apparition des articles dans la liste',
'listshowtip'             => 'Montrer cet article dans la liste',
'categoryownertip'        => 'Cette personne reçoit une notification quand une tâche de cette catégorie est ouverte',
'categoryparenttip'       => 'La catégorie parent à laquelle cette nouvelle appartient',
'notsubcategory'          => 'Aucune - Catégorie de premier niveau',
'showinlineimages'        => 'Afficher les images jointes',
'dateformat'              => 'Format de date',
'dateformat_extended'     => 'Format de date détaillé',
'cache_feeds'             => 'Conserver les flux en cache',
'no_cache'                => 'Pas de cache',
'cache_disk'              => 'Cacher sur disque',
'cache_db'                => 'Cacher en base de données',
'subcategoryof'           => 'Sous-catégorie de',
'visiblecolumns'          => 'Colonnes affichées dans la liste des tâches',
'visiblefields'           => 'Champs visibles en ouverture/modification/consultation de tâche',
'tense'                   => 'Temps',
'listtensetip'            => 'Passé, Présent ou Futur',
'past'                    => 'Passé',
'present'                 => 'Présent',
'future'                  => 'Futur',
'oldpass'                 => 'Ancien mot de passe',
'nooldpass'               => 'Veuillez saisir votre ancien mot de passe',
'oldpasswrong'            => 'Votre ancien mot de passe est faux',
'changepass'              => 'Changer mot de passe',
'confirmpass'             => 'Confirmer le mot de passe',
'projectmanager'          => 'Chef de projet',
'viewtasks'               => 'Consulter les tâches',
'modifyowntasks'          => 'Modifier ses propres tâches',
'modifyalltasks'          => 'Modifier les tâches des autres',
'viewcomments'            => 'Voir les commentaires',
'editcomments'            => 'Modifier les commentaires',
'deletecomments'          => 'Supprimer les commentaires',
'viewattachments'         => 'Voir les pièces jointes',
'createattachments'       => 'Ajouter des pièces jointes',
'deleteattachments'       => 'Supprimer les pièces jointes',
'viewhistory'             => 'Consulter l\'historique',
'closeowntasks'           => 'Fermer ses propres tâches',
'closeothertasks'         => 'Fermer les tâches des autres',
'assigntoself'            => 'S\'assigner des tâches',
'assignotherstoself'      => 'S\'assigner les tâches des autres',
'viewreports'             => 'Consulter les rapports',
'othersview'              => 'Tout le monde peut voir ce projet',
'othersviewroadmap'       => 'Tout le monde peut voir la feuille de route',
'usersandgroups'          => 'Utilisateurs & Groupes',
'globalgroup'             => 'Groupe global',
'globalgroups'            => 'Groupes globaux',
'defaultglobalgroup'      => 'Groupe global par défaut pour les nouveaux utilisateurs',
'addtogroup'              => 'Ajouter au groupe',
'moveuserstogroup'        => 'Déplacer dans le groupe',
'nogroup'                 => 'Pas de groupe - Supprimer du projet',
'eventdesc'               => 'Description de l\'événement',
'requestedby'             => 'Demandé par',
'daterequested'           => 'Date demandée',
'closetask'               => 'Fermer cette tâche',
'reopentask'              => 'Rouvrir cette tâche',
'applymember'             => 'Postuler pour être membre du projet',
'forcurrentproj'          => 'Pour le projet courant',
'lostpw'                  => 'Récupération du mot de passe oublié',
'lostpwexplain'           => 'Entrez votre identifiant pour obtenir un lien de modification du mot de passe. Ce lien sera envoyé à l\'adresse de notification spécifiée dans votre profil.',
'sendlink'                => 'Envoyer le lien',
'savenewpass'             => 'Enregistrer mon nouveau mot de passe',
'anonreg'                 => 'Autoriser l\'inscription de nouveaux utilisateurs',
'allowanonopentask'       => 'Autoriser les utilisateurs anonymes à ouvrir des tâches',
'editglobalgroup'         => 'Modifier le groupe global',
'editgroupforproj'        => 'Modifier le groupe pour le projet',
'notshownforadmin'        => 'Les droits ne sont pas affichés pour le groupe Admin car il n\'est pas nécessaire de les modifier.',
'general'                 => 'Général',
'userregistration'        => 'Inscription',
'notifications'           => 'Notifications',
'resetoptions'            => 'Réinitialiser les options',
'preferences'             => 'Préférences',
'tasktypes'               => 'Types de tâche',
'resolutions'             => 'Raisons de fermeture',
'categories'              => 'Catégories',
'operatingsystems'        => 'Systèmes d\'exploitation',
'versions'                => 'Versions',
'admintoolboxlong'        => 'Boîte à outils Administrateur',
'newproject'              => 'Nouveau projet',
'delete'                  => 'Supprimer',
'link'                    => 'Lien',
'referencelinks'          => 'Liens de référence',
'listdeletetip'           => 'Supprimer cet élément de la liste',
'lookandfeel'             => 'Apparence',
'globaltheme'             => 'Thème général',
'emailnotify'             => 'Notifications par courriel',
'fromaddress'             => 'Adresse de l\'expéditeur',
'smtpserver'              => 'Serveur SMTP',
'smtpuser'                => 'Identifiant SMTP',
'smtppass'                => 'Mot de passe SMTP',
'addrewrite'              => 'Utiliser la réécriture d\'adresse',
'usereminderdaemon'       => 'Activer le démon de rappels',
'tasksperpage'            => 'Nombre des tâches par page',
'addtoassignees'          => 'S\'ajouter aux assignés',
'taskstatuses'            => 'Statuts des tâches',
'canvote'                 => 'Voter pour des tâches',
'loginsuccessful'         => 'Connexion réussie.',
'youareloggedout'         => 'Vous avez été déconnecté.',
'waitwhiletransfer'       => 'Veuillez patienter pendant le transfert...',
'clicknowait'             => 'Cliquez ici si vous ne souhaitez pas attendre.',
'accountdisabled'         => 'Votre compte est désactivé. Contactez un administrateur',
'task'                    => 'Tâche',
'edittask'                => 'Modifier cette tâche',
'openedby'                => 'Ouverte par',
'editedby'                => 'Dernière modification par',
'tasktype'                => 'Type',
'category'                => 'Catégorie',
'status'                  => 'État',
'assignedto'              => 'Assignée à',
'operatingsystem'         => 'Système d\'exploitation',
'severity'                => 'Sévérité',
'reportedversion'         => 'Basée sur la version',
'dueinversion'            => 'Due pour la version',
'defaultdueinversion'     => 'Due pour la version par défaut pour les nouvelles tâches',
'undecided'               => 'Non décidée',
'percentcomplete'         => 'Pourcentage achevé',
'details'                 => 'Détails',
'savedetails'             => 'Sauvegarder les informations',
'canceledit'              => 'Annuler la modification',
'anonymous'               => 'Auteur anonyme',
'complete'                => 'terminé',
'closedby'                => 'Fermée par',
'reasonforclosing'        => 'Raison de la fermeture :',
'reopenthistask'          => 'Rouvrir cette tâche',
'comments'                => 'Commentaires',
'attachments'             => 'Fichiers joints',
'relatedtasks'            => 'Tâches liées',
'edit'                    => 'Modifier',
'addcomment'              => 'Ajouter un commentaire',
'fileuploadedby'          => 'Fichier téléchargé par',
'uploadafile'             => 'Joindre un fichier',
'addalink'                => 'Ajouter un lien',
'addanotherlink'          => 'Ajouter un autre lien',
'uploadnow'               => 'Envoyer maintenant !',
'thesearerelated'         => 'Ces tâches sont liées à cette autre tâche',
'remove'                  => 'Supprimer',
'addnewrelated'           => 'Lier une tâche à celle-ci',
'add'                     => 'Ajouter',
'otherrelated'            => 'Autres tâches auxquelles cette tâche est liée',
'receivenotify'           => 'Ces utilisateurs reçoivent une notification détaillée quand cette tâche est modifiée.',
'addusertolist'           => 'Ajouter un utilisateur à cette liste',
'addtolist'               => 'Ajouter à la liste',
'addmyself'               => 'M\'ajouter à cette liste',
'removemyself'            => 'Me supprimer de cette liste',
'theseusersnotify'        => 'Ces utilisateurs reçoivent une notification détaillée quand cette tâche est modifiée.',
'attachedtoproject'       => 'Concerne le projet',
'reminders'               => 'Rappels',
'system'                  => 'Système',
'systemvalues'            => 'Liste des valeurs globales',
'projectvalues'           => 'Liste des valeurs spécifiques au projet',
'remindthisuser'          => 'Destinataire du rappel : ',
'thisoften'               => 'Tou(te)s les : ',
'startafter'              => 'Avant le premier rappel, attendre',
'hour'                    => 'heure',
'hours'                   => 'Heure(s)',
'day'                     => 'jour',
'days'                    => 'Jour(s)',
'week'                    => 'semaine',
'weeks'                   => 'Semaine(s)',
'addreminder'             => 'Créer un rappel',
'defaultreminder'         => 'Ceci est un rappel de surveillance de tâche :',
'message'                 => 'Message',
'closed'                  => 'Fermée',
'filename'                => 'Nom de fichier :',
'date'                    => 'Date',
'filesize'                => 'Taille du fichier :',
'closurecomment'          => 'Commentaires de fermeture :',
'history'                 => 'Historique',
'nohistory'               => 'Aucun historique disponible.',
'eventdate'               => 'Date',
'user'                    => 'Utilisateur',
'event'                   => 'Événement',
'fieldchanged'            => 'Champ modifié',
'taskopened'              => 'Tâche ouverte',
'taskreopened'            => 'La tâche a été rouverte.',
'taskclosed'              => 'La tâche a été fermée.',
'commentadded'            => 'Commentaire ajouté',
'commentedited'           => 'Commentaire modifié',
'commentdeleted'          => 'Le commentaire a été supprimé',
'attachmentadded'         => 'Fichier joint ajouté',
'attachmentdeleted'       => 'Fichier joint supprimé',
'taskedited'              => 'Détails de la tâche modifiée',
'notificationadded'       => 'Utilisateur ajouté à la liste de notifications',
'notificationdeleted'     => 'Utilisateur supprimé de la liste de notifications',
'relatedadded'            => 'Tâche liée ajoutée à la liste',
'relateddeleted'          => 'Tâche liée supprimée',
'taskassigned'            => 'Tâche assignée à',
'taskreassigned'          => 'Tâche ré-assignée à',
'assignmentremoved'       => 'Assignation supprimée',
'summary'                 => 'Résumé',
'addedasrelated'          => 'Tâche ajoutée à la liste liée de',
'deletedasrelated'        => 'Tâche supprimée de la liste liée de',
'reminderadded'           => 'Rappel ajouté',
'reminderdeleted'         => 'Rappel supprimé',
'priority'                => 'Priorité',
'previousvalue'           => 'Valeur précédente',
'newvalue'                => 'Nouvelle valeur',
'selectareason'           => 'Choisissez une raison',
'assigntome'              => 'Me l\'assigner',
'reopenrequest'           => 'Rouvrir la demande',
'requestclose'            => 'Fermer la demande',
'ownershiptaken'          => 'Un utilisateur a pris la responsabilité',
'closerequestmade'        => 'Demande de fermeture de tâche',
'reopenrequestmade'       => 'Demande de réouverture de tâche',
'taskdependson'           => 'Cette tâche dépend de',
'taskdependsontask'       => 'Cette tâche dépend de',
'taskdependsontasks'      => 'Cette tâche dépend de',
'taskblock'               => 'Cette tâche bloque la fermeture',
'taskblocks'              => 'Cette tâche bloque la fermeture de ces autres tâches',
'depadded'                => 'Dépendance ajoutée',
'depaddedother'           => 'Cette tâche a été ajoutée en tant que dépendance',
'depremoved'              => 'Dépendance supprimée',
'depremovedother'         => 'Cette tâche a été supprimée de la liste des dépendances d\'une autre tâche',
'showdetailserror'        => 'Cette tâche n\'existe pas ou vous n\'avez pas la permission de la consulter',
'makeprivate'             => 'Rendre privée',
'makepublic'              => 'Rendre publique',
'taskmadeprivate'         => 'Cette tâche a été rendue privée',
'taskmadepublic'          => 'Cette tâche a été rendue publique',
'confirmdeletecomment'    => 'Voulez-vous vraiment supprimer ce commentaire ? %s',
'attachementswilldeleted' => 'Toutes les pièces jointes seront supprimées !',
'confirmdeleteattach'     => 'Voulez-vous vraiment supprimer cette pièce jointe ?',
'selectedhistory'         => 'Historique des tâches sélectionnées',
'showallhistory'          => 'Réafficher l\'historique complet',
'hidethis'                => 'Cacher de nouveau cette zone',
'mark100'                 => 'Marquer l\'achèvement à 100%',
'watchtask'               => 'Surveiller',
'stopwatching'            => 'Ne plus surveiller',
'commentlink'             => 'Lien vers ce commentaire',
'submitreq'               => 'Soumettre la demande',
'reasonforreq'            => 'Raison de cette demande',
'pmreqdenied'             => 'Le chef de projet a refusé la demande',
'taskpendingreq'          => 'En attente de décision du gestionnaire de projet. Consulter l\'historique pour plus de détails.',
'previoustask'            => 'Tâche précédente',
'nexttask'                => 'Tâche suivante',
'duedate'                 => 'Échéance',
'attachnoperms'           => 'Ce commentaire contient des pièces jointes, mais vous n\'avez pas l\'autorisation de les consulter.',
'linknoperms'             => 'Il y a des liens avec ce commentaire mais vous n\'avez pas les permissions pour les consulter',
'open'                    => 'Ouvertes',
'depgraph'                => 'Consulter le graphique des dépendances',
'reset'                   => 'Réinitialiser',
'selectusers'             => 'Sélectionner les utilisateurs...',
'addmetoassignees'        => 'M\'ajouter aux destinataires',
'addedtoassignees'        => 'Utilisateur ajouté aux destinataires',
'dependencygraph'         => 'Graphique des dépendances',
'attachanotherfile'       => 'Joindre un autre fichier',
'OK'                      => 'OK',
'addvote'                 => 'Ajouter un vote',
'disable_lostpw'          => 'Désactiver la fonction de "Mot de passe perdu"',
'disable_changepw'        => 'Désactiver créer/modifier mot de passe',
'notifyfromfs'            => 'Notification de Flyspray',
'autogenerated'           => 'CE MESSAGE A ÉTÉ GÉNÉRÉ AUTOMATIQUEMENT, NE PAS RÉPONDRE',
'forward'                 => 'Suivant',
'previous'                => 'Précédente',
'next'                    => 'Suivante',
'first'                   => 'Premier',
'last'                    => 'Dernier',
'page'                    => 'Page %d sur %d',
'search'                  => 'Rechercher',
'alltasktypes'            => 'Tout type de tâche',
'allseverities'           => 'Toutes les sévérités',
'alldevelopers'           => 'Tous les développeurs',
'notyetassigned'          => 'Non assignées',
'allcategories'           => 'Toutes les catégories',
'allstatuses'             => 'Tous les états',
'allopentasks'            => 'Toutes les tâches ouvertes',
'sortthiscolumn'          => 'Trier selon cette colonne',
'id'                      => 'ID',
'project'                 => 'Projet',
'dateopened'              => 'Ouverte',
'progress'                => 'Progression',
'searchthisproject'       => 'Rechercher dans ce projet',
'dueanyversion'           => 'N\'importe quelle version',
'anyversion'              => 'Toutes versions',
'dueversion'              => 'Due pour la version',
'lastedit'                => 'Dernière modification',
'os'                      => 'Système d\'exploitation',
'reportedin'              => 'Basée sur',
'taskrange'               => 'Tâches %d - %d sur %d',
'noresults'               => 'Aucun résultat ne correspond à vos critères de recherche.',
'takeaction'              => 'Valider',
'watchtasks'              => 'Surveiller les tâches sélectionnées',
'stopwatchingtasks'       => 'Ne plus surveiller les tâches sélectionnées',
'assigntaskstome'         => 'M\'assigner les tâches sélectionnées',
'dueby'                   => 'Due pour',
'dueanytime'              => 'Due pour n\'importe quand',
'selectduedate'           => 'Choisir une date d\'échéance',
'toggleselected'          => 'Inverser la sélection',
'due'                     => 'Due',
'assignedtome'            => 'Assignées à moi-même',
'tasklist'                => 'Liste des tâches',
'dateclosed'              => 'Date de fermeture',
'advanced'                => 'Avancé',
'searchcomments'          => 'Rechercher dans les commentaires',
'searchforall'            => 'Rechercher tous les mots',
'anonusers'               => 'Utilisateurs anonymes',
'miscellaneous'           => 'Divers',
'users'                   => 'Utilisateurs',
'taskproperties'          => 'Propriétés de la tâche',
'selectsincedate'         => 'Sélectionner modifié depuis',
'changedsince'            => 'Modifié depuis',
'updatefs'                => 'Veuillez mettre à jour Flyspray',
'currentversion'          => 'Votre version actuelle est',
'latestversion'           => 'et la version la plus récente est',
'hidemessage'             => '(me rappeler plus tard)',
'saveas'                  => 'Enregistrer la recherche sous',
'nosearches'              => 'Aucune recherche enregistrée',
'saving'                  => 'Enregistrement...',
'votes'                   => 'Votes',
'tovote'                  => 'Voter',
'allclosedtasks'          => 'Toutes les tâches fermées',
'password'                => 'Mot de passe',
'login'                   => 'Connexion',
'rememberme'              => 'Se souvenir de moi',
'lostpassword'            => 'Mot de passe perdu ?',
'lostpwforfs'             => 'Mot de passe perdu pour Flyspray',
'lostpwmsg1'              => "Bonjour,\n\nJ'ai perdu mon mot de passe pour Flyspray le",
'lostpwmsg2'              => ", merci de m'en fournir un nouveau s'il vous plaît.\n\nNom utilisateur :",
'regards'                 => "\n\nCordialement,",
'yourusername'            => ' votre nom utilisateur ',
'locale'                  => 'fr-FR',
'filenotexist'            => 'Le fichier n\'existe pas. Contacter l\'administrateur de Flyspray pour ce projet.',
'showtask'                => 'Afficher la tâche',
'now'                     => 'Maintenant',
'go'                      => 'Go !',
'opentaskanon'            => 'Ouvrir une nouvelle tâche anonymement',
'register'                => 'Inscription',
'addnewtask'              => 'Ouvrir une tâche',
'reports'                 => 'Rapports',
'editmydetails'           => 'Modifier mes informations',
'logout'                  => 'Déconnexion',
'disabledaccount'         => 'Votre compte a été désactivé !<br />Déconnexion immédiate...',
'poweredby'               => 'Propulsé par Flyspray',
'sponsoredby'             => 'Flyspray est fièrement sponsorisé par',
'projects'                => 'Projets',
'allprojects'             => 'Tous les projets',
'selectproject'           => 'du projet :',
'tasksall'                => 'Toutes les tâches',
'tasksassigned'           => 'Tâches qui me sont assignées',
'tasksreported'           => 'Tâches que j\'ai rapportées',
'taskswatched'            => 'Surveillées par moi',
'mysearch'                => 'Mes recherches',
'admintoolbox'            => 'Boîte à outils Administrateur',
'manageproject'           => 'Gérer le projet',
'permissions'             => 'Voir les permissions',
'hide'                    => 'Masquer',
'pendingreq'              => 'Requêtes en attente de décision',
'errorpage'               => "Flyspray ne peut pas afficher la page demandée : soit vous avez demandé une tâche qui n'existe pas, soit vous n'avez pas la permission de consulter cette page.\nVous avez peut-être tenté d'utiliser une URL malveillante pour interagir avec la base de données via une injection SQL. Si c'est le cas, allez au coin et réfléchissez à vos actes. Quand vous reviendrez, ne recommencez pas !",
'permissionsforproject'   => 'Permissions pour ',
'switchto'                => 'Basculer vers',
'lastsearch'              => 'Ma dernière recherche',
'modify'                  => 'Modifier',
'noticefrom'              => 'Note de',
'hasopened'               => 'a ouvert une nouvelle tâche, et vous l\'a assignée :',
'moreinfonew'             => 'Vous trouverez plus d\'information sur cette tâche à la page :',
'newtaskcategory'         => 'Une nouvelle tâche a été ouverte dans cette catégorie',
'categoryowner'           => 'Vous recevez ce message car vous figurez dans la liste des responsables de cette catégorie.',
'tasksummary'             => 'Résumé de la tâche :',
'newtaskadded'            => 'Votre nouvelle tâche a été ajoutée.',
'summaryanddetails'       => 'Vous devez remplir le résumé ET les détails.',
'goback'                  => 'Retour.',
'messagefrom'             => 'Ceci est un message du système de gestion de tâches sur ',
'hasjustmodified'         => 'vient de modifier la tâche suivante.',
'changedfields'           => 'Les champs modifiés sont préfixés d\'astérisques (**)',
'moreinfomodify'          => 'Vous aurez plus d\'information sur cette tâche à cette adresse :',
'nolongerassigned'        => 'La tâche suivante ne vous est plus assignée. Elle est maintenant affectée à',
'hasassigned'             => 'vous a assigné la tâche suivante :',
'taskupdated'             => 'La tâche a été mise à jour.',
'tasksupdated'            => 'Les tâches ont été mises à jour',
'hasclosedassigned'       => 'a fermé cette tâche qui vous était assignée :',
'unassigned'              => 'Non assignée',
'hasclosed'               => 'a fermé la tâche suivante.',
'youonnotify'             => 'Vous recevez ce message car vous figurez dans la liste de notification.',
'taskclosedmsg'           => 'La tâche a été fermée',
'returntotask'            => 'Revenir au détail de la tâche',
'backtoindex'             => 'Revenir à la liste des tâches',
'noclosereason'           => 'Vous n\'avez pas choisi la raison de fermeture de cette tâche.',
'hasreopened'             => 'a rouvert la tâche suivante que vous aviez fermée :',
'taskreopenedmsg'         => 'La tâche a été rouverte',
'backtotask'              => 'Revenir sur la tâche.',
'commentaddedmsg'         => 'Le commentaire a été ajouté',
'commenttoassigned'       => 'a ajouté un commentaire à une tâche qui vous est assignée :',
'commenttotask'           => 'a ajouté le commentaire suivant à cette tâche.',
'nocommententered'        => 'Vous devez entrer un commentaire avant de cliquer le bouton d\'envoi.',
'fillinfields'            => 'Vous n\'avez pas rempli tous les champs.',
'notcurrentpass'          => 'Ce n\'est pas votre mot de passe actuel !',
'passchanged'             => 'Votre mot de passe a été modifié.',
'closewindow'             => 'Vous pouvez maintenant fermer cette fenêtre.',
'passnomatch'             => 'Vos nouveaux mots de passe ne sont pas identiques !',
'usernametaken'           => 'Ce nom d\'utilisateur est déjà enregistré. Veuillez en choisir un différent.',
'usernametakenbulk'       => 'Ce nom d\'utilisateur est déjà enregistré',
'newusercreated'          => 'Le nouveau compte utilisateur a été créé.',
'accountcreated'          => 'Votre compte a été créé.',
'newuserwarning'          => 'Notez que les options globales pourraient requérir l\'approbation de votre compte par un administrateur. Si vous ne pouvez pas vous connecter, c\'est sûrement pour cette raison.',
'nomatchpass'             => 'Les mots de passe ne correspondent pas.',
'confirmwrong'            => 'Le code de confirmation est incorrect !',
'formnotcomplete'         => 'Le formulaire n\'a pas été complètement rempli.',
'formnotnumeric'          => 'Les données renseignées ne sont pas numériques !',
'groupnametaken'          => 'Ce nom de groupe est déjà enregistré.',
'newgroupadded'           => 'Nouveau groupe ajouté.',
'optionssaved'            => 'Options Flyspray sauvegardées.',
'hasuploaded'             => 'a joint un fichier à une tâche qui vous est assignée :',
'hasattached'             => 'a joint un fichier à la tâche suivante.',
'fileuploaded'            => 'Le fichier a été envoyé.',
'fileerror'               => 'Erreur lors de l\'envoi du fichier : les droits sur le répertoire <i>attachments/</i> sont peut-être incorrects.',
'contactadmin'            => 'Contactez l\'administrateur de ce projet.',
'selectfileerror'         => 'Vous n\'avez pas sélectionné de fichier et/ou saisi de description.',
'userupdated'             => 'Les informations utilisateur ont été mises à jour',
'realandemail'            => 'Vous n\'avez pas saisi les champs Nom réel ET adresse courriel.',
'groupupdated'            => 'Définition du groupe mise à jour.',
'groupanddesc'            => 'Vous n\'avez pas saisi les champs Nom du groupe ET Description.',
'fillallfields'           => 'Veuillez remplir tous les champs.',
'listPmustN'              => 'Le champ "ORDER" doit être numérique',
'listupdated'             => 'La liste a été mise à jour.',
'listitemadded'           => 'Nouvel élément ajouté dans la liste.',
'relatedaddedmsg'         => 'Tâche liée ajoutée à la liste',
'relatederror'            => 'Cette tâche est déjà dans la liste des tâches liées.',
'relatedremoved'          => 'Tâche liée retirée de la liste.',
'notifyadded'             => 'Utilisateur ajouté à la liste de notification.',
'notifyerror'             => 'Cet utilisateur est déjà dans la liste de notification pour cette tâche.',
'notifyremoved'           => 'Utilisateur retiré de la liste de notification.',
'editcommentsaved'        => 'Commentaire mis à jour sauvegardé.',
'commentdeletedmsg'       => 'Commentaire supprimé',
'gotonewtask'             => 'Aller à la nouvelle tâche nouvellement créée',
'projectcreated'          => 'Votre nouveau projet a été créé. Suivez le lien ci-dessous pour définir vos catégories, systèmes d\'exploitation et listes de versions',
'customiseproject'        => 'Personnaliser ce projet',
'projectupdated'          => 'Préférences du projet mises à jour',
'emptytitle'              => 'Vous n\'avez pas saisi le nom du projet.',
'loginbelow'              => 'Vous pouvez maintenant tenter de vous connecter via le formulaire ci-dessous.',
'attachmentdeletedmsg'    => 'La pièce jointe a été supprimée',
'reminderaddedmsg'        => 'Votre rappel a été ajouté',
'reminderdeletedmsg'      => 'Le rappel sélectionné a été supprimé',
'flyspraytask'            => 'Tâche Flyspray',
'fieldsmissing'           => 'Certains champs étaient vides ou invalides.',
'relatedinvalid'          => 'Il n\'y a pas de telle tâche.',
'relatedproject'          => 'La tâche appartient à un projet différent.',
'addanyway'               => 'Ajouter quand-même',
'cancel'                  => 'Annuler',
'alreadyedited'           => 'Cette tâche a été modifiée par un autre utilisateur avant que vous la sauvegardiez.',
'saveanyway'              => 'Sauvegarder quand-même mes modifications',
'nouserselected'          => 'Aucun utilisateur sélectionné. Sélectionnez-en au moins un avant de recommencer',
'groupswitchupdated'      => 'Groupe d\'utilisateurs modifié avec succès.',
'takenownershipmsg'       => 'Vous êtes maintenant responsable de cette tâche',
'adminrequestmade'        => 'Votre demande a été envoyée au chef de projet',
'newdepnotify'            => 'Une dépendance a été ajoutée à la tâche suivante :',
'dependadded'             => 'Dépendance ajoutée',
'dependaddfailed'         => 'Erreur lors de l\'ajout de la dépendance : vérifiez que la tâche existe et qu\'il n\'y a pas d\'interblocage.',
'depremovedmsg'           => 'Dépendance supprimée',
'newdepis'                => 'La nouvelle dépendance est',
'magicurlsent'            => 'Un message a été envoyé à votre adresse de notification. Il contient un lien qui vous dirigera vers une page pour compléter cette tâche',
'changefspass'            => 'Modifier le mot de passe Flyspray',
'magicurlmessage'         => 'Veuillez suivre le lien ci-dessous pour modifier votre mot de passe :',
'erroronform'             => 'Il y a une erreur dans le formulaire',
'addressused'             => 'Cette adresse a déjà été utilisée pour créer un compte. Si vous recevez ce message par erreur, ignorez-le et effacez-le. Votre code de confirmation est :',
'confirmcodeis'           => 'Votre code de confirmation est :',
'codesent'                => 'Votre code de confirmation a été envoyé. Veuillez suivre les instructions contenues dans le message.',
'codenotsent'             => 'Échec d\'envoi de votre code. Réessayez plus tard.',
'taskmadeprivatemsg'      => 'Cette tâche a été rendue privée',
'taskmadepublicmsg'       => 'Cette tâche a été rendue publique',
'realandnotify'           => 'Vous devez remplir votre nom réel ainsi que votre adresse courriel ou votre ID Jabber.',
'pmreqdeniedmsg'          => 'Demande de Chef de projet refusée',
'massopsuccess'           => 'Opérations en masse réussies - quand les permissions étaient bonnes',
'usernotexist'            => 'Cet utilisateur n\'existe pas dans cette installation de Flyspray',
'commentattachperms'      => 'Vous ne pouvez pas supprimer ce commentaire - vous n\'avez pas la permission de supprimer les pièces jointes',
'voterecorded'            => 'Votre vote a été enregistré',
'votefailed'              => 'Votre vote ne peut pas être enregistré pour le moment',
'createnewgroup'          => 'Créer un nouveau groupe',
'requiredfields'          => 'Les champs requis sont marqués d\'une',
'addthisgroup'            => 'Ajouter ce groupe',
'createnewproject'        => 'Créer un nouveau projet',
'addnewproject'           => 'Créer un projet',
'htmlallowed'             => 'Le code HTML est autorisé',
'createthisproject'       => 'Créer ce projet',
'inlineimages'            => 'Afficher les images jointes',
'createnewtask'           => 'Ouvrir une nouvelle tâche dans le projet :',
'addanother'              => 'Ouvrir une autre tâche après celle-ci',
'addthistask'             => 'Ouvrir cette tâche',
'notifyme'                => 'M\'avertir quand cette tâche est modifiée',
'newtask'                 => 'Nouvelle tâche :',
'attachafile'             => 'Joindre un fichier',
'registernewuser'         => 'Enregistrer un nouvel utilisateur',
'none'                    => 'Aucun(e)',
'registeraccount'         => 'Enregistrer ce compte',
'registerbulkaccount'     => 'Enregistrer comptes',
'both'                    => 'Les deux',
'notifyfrom'              => 'Notification de ',
'donotreply'              => 'CECI EST UN MESSAGE AUTOMATIQUE, MERCI DE NE PAS RÉPONDRE.',
'disclaimer'              => 'Vous recevez ce message car vous en avez fait la demande sur le gestionnaire de tâches Flyspray. Vous pouvez stopper toute future notification en cliquant sur le lien ci-dessus.',
'userwho'                 => 'Action effectuée par ',
'moreinfo'                => 'Plus d\'informations sont disponibles à cette adresse :',
'newtaskopened'           => 'Une nouvelle tâche a été ouverte. Voir les détails ci-dessous.',
'notify.taskclosed'       => 'La tâche suivante a été fermée :',
'notify.taskreopened'     => 'La tâche suivante a été rouverte :',
'newdep'                  => 'La tâche suivante a une nouvelle dépendance :',
'notify.depremoved'       => 'Une dépendance a été supprimée sur la tâche suivante :',
'olddepwas'               => 'La dépendance était',
'notify.commentadded'     => 'Un nouveau commentaire a été ajouté dans la tâche suivante :',
'commentis'               => 'Le contenu du commentaire concerné est ci-dessous.',
'newattachment'           => 'Un nouveau fichier a été joint à la tâche suivante :',
'detailsbelow'            => 'Les détails sont ci-dessous.',
'notify.relatedadded'     => 'Une nouvelle tâche a été liée à la tâche suivante :',
'relatedis'               => 'La tâche liée est',
'assignedtoyou'           => 'La tâche suivante vous a été assignée :',
'takenownership'          => 'a pris la responsabilité de la tâche suivante :',
'requiresaction'          => 'La tâche suivante requière une intervention du chef de projet :',
'requiresactionnotify'    => 'Tâche requérant une intervention du chef de projet',
'pmdeny'                  => 'Un chef de projet a refusé la demande en cours sur cette tâche :',
'pmdenynotify'            => 'Demande refusée par un chef de projet',
'fileaddedtoo'            => 'Il y avait un ou plusieurs fichiers joints au commentaire.',
'taskwatching'            => 'La tâche que vous surveillez',
'isdepfor'                => 'est une nouvelle dépendance pour',
'denialreason'            => 'Raison du refus',
'taskchanged'             => 'La tâche suivante a été modifiée. Les modifications effectuées sont décrites ci-dessous. Pour le détail de ce qui a changé depuis le début, suivez le lien vers la tâche concernée et consultez l\'historique.',
'useraddedtoassignees'    => 'Un utilisateur s\'est ajouté à la liste des destinataires de cette tâche.',
'removeddepis'            => 'La dépendance supprimée est',
'isnodepfor'              => 'n\'est plus une dépendance de',
'usergroups'              => 'Groupes d\'utilisateurs',
'pmtoolbox'               => 'Boîte à outils du Chef de projet',
'groupmanage'             => 'Gestion de groupe',
'pendingrequests'         => 'Demandes en attente',
'reasongiven'             => 'Raison invoquée',
'nopendingreq'            => 'Il n\'y a aucune demande de Chef de Projet en attente.',
'givereason'              => 'Donner une raison',
'catlisted'               => 'Éditeur de catégories',
'oslisted'                => 'Éditeur de systèmes d\'exploitation',
'verlisted'               => 'Éditeur de versions',
'tasktypeed'              => 'Éditeur de types de tâche',
'resed'                   => 'Éditeur de résolutions',
'deny'                    => 'Refus',
'notifiedwhen'            => 'Notifié quand',
'onlynewtasks'            => 'Des nouvelles tâches sont ouvertes',
'allevents'               => 'N\'importe quel événement se produit sur n\'importe quelle tâche',
'feeds'                   => 'Flux',
'feeddescription'         => 'Description du flux',
'feedimgurl'              => 'URL de l\'image du flux (sinon laisser blanc)',
'notifysubject'           => 'Sujet des notifications',
'notifysubjectinfo'       => '(%p = nom du projet, %s = titre de la tâche, %t = ID de la tâche, %a = action, %u = nom d\'utilisateur)',
'priority6'               => 'Très haute',
'priority5'               => 'Haute',
'priority4'               => 'Moyenne',
'priority3'               => 'Basse',
'priority2'               => 'Très Basse',
'priority1'               => 'Ajourné',
'sendcode'                => 'Envoyer le code !',
'entercode'               => 'Votre code de confirmation a été envoyé. Une fois reçu, entrez le ci-dessous. Entrez également le mot de passe souhaité.',
'confirmationcode'        => 'Code de confirmation',
'registererror'           => 'Assurez-vous d\'avoir rempli tous les champs requis, et que vous avez entré des données correctes pour le type de notification souhaité.',
'validusername'           => '(seuls les caractères alphanumériques et - _ . sont autorisés',
'validemail'              => '(utilisez ; pour séparer des adresses courriel multiples',
'emailtakenbulk'          => 'Adresse courriel déjà enregistrée',
'emailtaken'              => 'Adresse courriel ou ID Jabber déjà utilisé(e). Vous devez en choisir un(e) autre.',
'note'                    => '<b>Note :</b> Vous recevrez un code de confirmation avant la création de votre compte. Le code vous sera envoyé selon la méthode de notification choisie ci-dessus.<br />EN CAS DE SAISIE ERRONÉE, VOUS NE POURREZ PAS RECEVOIR VOTRE CODE.',
'changelog'               => 'Journal des modifications',
'changeloggen'            => 'Génération du Journal',
'listfrom'                => 'Lister les entrées du journal du',
'to'                      => 'au',
'oldestfirst'             => 'La plus ancienne en premier',
'recentfirst'             => 'La plus récente en premier',
'severityrep'             => 'Rapport de Sévérité',
'totalopen'               => 'Total des tâches ouvertes',
'age'                     => 'Age',
'agerep'                  => 'Rapport d\'âge',
'eventsrep'               => 'Rapport d\'événements',
'events'                  => 'événements',
'Tasks'                   => 'Tâches',
'opened'                  => 'Ouverte',
'edited'                  => 'Modifiée',
'assigned'                => 'Assignées',
'within'                  => 'Dans',
'pastday'                 => 'Le jour passé',
'pastweek'                => 'La semaine passée',
'pastmonth'               => 'Le mois passé',
'pastyear'                => 'L\'année passée',
'nolimit'                 => 'Pas de limite',
'from'                    => 'Du',
'duein'                   => 'Échéance le',
'selectfromdate'          => 'Sélectionner date de début',
'selecttodate'            => 'Sélectionner date de fin',
'showvoters'              => 'Afficher/masquer les votants',
'roadmap'                 => 'Feuille de route',
'roadmapfor'              => 'Feuille de route pour la version',
'tasks'                   => 'tâches',
'completed'               => 'terminé.',
'opentasks'               => 'tâches ouvertes',
'of'                      => '% de ',
'severity5'               => 'Critique',
'severity4'               => 'Haute',
'severity3'               => 'Moyenne',
'severity2'               => 'Basse',
'severity1'               => 'Très basse',
'Redirect'                => 'Redirection',
'redirectmsg'             => 'Si votre navigateur ne supporte pas la redirection automatique, %scliquez ici%s pour être redirigé ',
'allowclosedcomments'     => 'Autoriser les commentaires sur les tâches fermées',
'comment'                 => 'Commentaire',
'editowncomments'         => 'Modifier ses propres commentaires',
'reopened'                => 'Rouverte',
'loading'                 => 'Chargement...',
'notifyown'               => 'Notifier pour ses propres changements',
'youremail'               => 'Votre adresse courriel',
'thankyouforbug'          => 'Merci d\'avoir signalé ce problème. Vous pouvez consulter la tâche et observer sa progression à tout moment à cette adresse :',
'anonuser'                => 'Utilisateur anonyme',
'conflict'                => 'Conflit',
'file'                    => 'Fichier',
'KiB'                     => 'ko',
'MiB'                     => 'Mo',
'size'                    => 'Taille',
'projectgroup'            => 'Groupe de projets',
'profile'                 => 'Profil :',
'viewprofile'             => 'Voir le profil',
'regdate'                 => 'Inscrit depuis',
'tasksopened'             => 'Tâches ouvertes',
'replyto'                 => 'Répondre à',
'notifytypes'             => 'Type de notification',
'pm.taskchanged'          => 'Tâche modifiée',
'pm.taskreopened'         => 'Tâche rouverte',
'pm.depadded'             => 'Dépendance ajoutée',
'pm.depremoved'           => 'Dépendance supprimée',
'pmrequest'               => 'demande au Gestionnaire de Projet',
'pmrequestdenied'         => 'demande au Gestionaire de Projet refusée',
'newassignee'             => 'Nouveau destinataire',
'revdepadded'             => 'Dépendance inverse ajoutée',
'revdepaddedremoved'      => 'Dépendance inverse supprimée',
'assigneeadded'           => 'Destinataire ajouté',
'addusergroup'            => 'Ajouter l\'utilisateur suivant à ce groupe',
'groupmembers'            => 'Membres du groupe',
'deleteuser'              => 'Supprimer cet utilisateur',
'userdeleted'             => 'Utilisateur supprimé',
'autoassign'              => 'Assigner automatiquement une tâche au responsable de la catégorie',
'ssl'                     => 'SSL',
'updatewrong'             => "L'option de recherche automatique de mises à jour est activée, mais une erreur s'est produite en essayant de contacter le serveur de mises à jour. Raisons probables : votre hôte n'autorise pas les connexions sortantes, ou un problème réseau est survenu.\nVeuillez visiter le site de Flyspray pour vous assurer que vous possédez la dernière version.",
'deleteproject'           => 'Supprimer ce projet et déplacer son contenu vers',
'projectdeleted'          => 'Projet supprimé avec succès',
'feedforall'              => 'Flux pour tous les projets',
'usercreated'             => 'Utilisateur créé',
'created'                 => 'Créé',
'deleted'                 => 'Supprimé',
'userid'                  => 'ID de l\'utilisateur',
'editassignments'         => 'Modifier les assignations',
'preview'                 => 'Prévisualisation',
'anyprogress'             => 'N\'importe',
'tasksrelated'            => 'Tâches associées à cette tâche',
'duplicatetasks'          => 'Tâches doublons de cette tâche',
'databasemodfailed'       => 'La modification de la base de données a échoué. Vous n\'avez peut-être pas les droits suffisants ?',
'frequency'               => 'Fréquence',
'newuserregistered'       => 'Un nouvel utilisateur s\'est inscrit sur votre installation Flyspray. Vous trouverez les détails ci-après :',
'newuserregisterednotify' => 'Un nouvel utilisateur s\'est inscrit',
'notify_registration'     => 'Notifier les administrateurs à l\'inscription d\'un nouvel utilisateur',
'textversion'             => 'Version texte',
'onlyprimary'             => 'Tâches n\'en bloquant aucune autre',
'onlyblocker'             => 'Tâches bloquant d\'autres tâches',
'blockerornoblocker'      => 'La sélection simultanée des options "bloquant" et "non bloquant" n\'est pas cohérente.',
'switch'                  => 'Basculer',
'max'                     => 'max.',
'dates'                   => 'Dates',
'selectduedatefrom'       => 'Échéance du',
'selectduedateto'         => 'au',
'selectsincedatefrom'     => 'Modifiée du',
'selectsincedateto'       => 'au',
'selectdate'              => 'Sélectionner la date',
'selectopenedfrom'        => 'Ouverte du',
'selectopenedto'          => 'au',
'selectclosedfrom'        => 'Fermée du',
'selectclosedto'          => 'au',
'startat'                 => 'Démarre le : ',
'hasattachment'           => 'Avec pièce jointe',
'private'                 => 'Privée',
'watching'                => 'Surveillée',
'alreadyvotedthistask'    => 'vous avez déjà voté pour cette tâche',
'alreadyvotedthisday'     => 'déjà voté aujourd\'hui',
'visibility'              => 'Visibilité',
'public'                  => 'Publique',
'leaveemptyauto'          => 'Laissez ces 2 champs vides si vous voulez qu\'un mot de passe soit généré automatiquement.',
'novalidemail'            => 'L\'adresse courriel que vous avez saisie n\'est pas valide.',
'novalidjabber'           => 'L\'ID Jabber que vous avez saisi n\'est pas valide.',
'missingrequired'         => 'Vous n\'avez pas rempli tous les champs obligatoires.',
'entervalidusername'      => 'Veuillez entrer un nom d\'utilisateur et un nom réel valide.',
'couldnotaddusernotif'    => 'Impossible d\'ajouter cet utilisateur à la liste des notifications.',
'defaulttask'             => 'Description par défaut des tâches',
'all'                     => 'tous',
'events.useraddedtoassignees'=> 'Utilisateur ajouté aux destinataires',
'eventlog'                => 'Journal des événements',
'assignmentchanged'       => 'Assignation modifiée',
'detailedinfo'            => 'Informations détaillées',
'All'                     => 'Toutes',
'tasksireported'          => 'Ouvertes par moi',
'recentlyopened'          => 'Ouvertes récemment',
'stats'                   => 'Statistiques',
'totaltasks'              => 'tâches au total',
'mostwanted'              => 'Tâches les plus voulues',
'defaultentry'            => 'Affichage par défaut',
'toplevel'                => 'Vue d\'ensemble',
'overview'                => 'Vue d\'ensemble',
'error#'                  => 'Erreur n°',
'error1'                  => 'Vous n\'avez pas les droits suffisants pour voir cette pièce jointe.',
'error3'                  => 'Action répétée, redirection vers la page principale.',
'error4'                  => 'Vous n\'êtes pas administrateur.',
'error5'                  => 'Cet utilisateur n\'existe pas sur cette installation de Flyspray.',
'error6'                  => 'Zone d\'administration invalide.',
'error7'                  => 'Connexion échouée, mot de passe incorrect !',
'error71'                 => 'Compte verrouillé pour %d minutes en raison de trop nombreux échecs de connexion !',
'error8'                  => 'Vous n\'avez pas entré à la fois un nom d\'utilisateur et un mot de passe.',
'error9'                  => 'Cette tâche n\'existe pas ou vous n\'avez pas la permission de la consulter.',
'error10'                 => 'Cette tâche n\'existe pas.',
'error101'                => 'Vous n\'avez pas la permission de consulter cette tâche.',
'error102'                => 'Vous n\'avez pas la permission de consulter cette tâche : vous devez vous connecter.',
'error11'                 => 'Vous n\'avez pas la permission de modifier ce commentaire.',
'error12'                 => 'Clé magique non valide ! Êtes-vous sûr de l\'avoir obtenue depuis un message de notification ?',
'error13'                 => 'Les utilisateurs anonymes ne disposent pas d\'un profil.',
'error14'                 => 'Vous n\'avez pas les droits suffisants pour créer un groupe.',
'error15'                 => 'Vous n\'avez pas les droits suffisants pour ouvrir une tâche.',
'error16'                 => 'Vous n\'êtes pas un chef de projet.',
'error17'                 => 'Zone de gestion de projet invalide.',
'error18'                 => 'URL magique invalide.',
'error19'                 => 'Cet utilisateur n\'existe pas sur cette installation de Flyspray.',
'error20'                 => 'Modification de la base de données invalide.',
'error21'                 => 'Un ou plusieurs courriels n\'ont pas pu être envoyés. Vérifiez votre configuration.',
'error22'                 => 'Les nouvelles inscriptions ne sont pas autorisées.',
'error23'                 => 'Utilisateur ou groupe non autorisé à se connecter.',
'error24'                 => 'Ni l\'exécutable dot ni le serveur public dot n\'ont été paramétrés.',
'error25'                 => 'La feuille de route est uniquement disponible pour un projet donné.',
'error26'                 => 'Fournisseur OAuth non supporté.',
'error27'                 => 'Impossible de se connecter. Autorisez-nous à voir votre courriel.',
'error28'                 => 'Vous n\'avez pas les droits suffisants pour accéder à cette page',
'done'                    => 'terminé',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Le projet n\'a pas pu être supprimé',
'GMT'                     => 'GMT',
'timezone'                => 'Fuseau horaire',
'accept'                  => 'Accepter',
'reasonfordeinal'         => 'Raison du refus',
'pruneclosedlinks'        => 'Purger les liens fermés',
'pruneclosedtasks'        => 'Purger les tâches fermées',
'pagegenerated'           => 'Page et image générées en %d secondes',
'pruninglevel'            => 'Niveau de purge',
'lastuser'                => 'Le dernier utilisateur ne peut pas être supprimé.',
'allprivate'              => 'Tous les projets sont privés.',
'deletegroup'             => 'Supprimer ce groupe et déplacer les utilisateurs vers',
'parent'                  => 'Parent',
'ordertip'                => 'L\'ordre dans lequel ces éléments vont apparaitre dans la liste',
'showtip'                 => 'Afficher cet élément dans la liste',
'deletetip'               => 'Supprimer cet élément de la liste',
'del'                     => 'supprimer',
'request1'                => 'Une fermeture de tâche a été demandée',
'request2'                => 'Une réouverture de tâche a été demandée',
'allpriorities'           => 'Toutes les priorités',
'noroadmap'               => 'Aucune feuille de route disponible (le projet n\'a pas de future version définie)',
'expand'                  => 'Dérouler',
'collapse'                => 'Replier',
'expandall'               => 'Tout dérouler',
'collapseall'             => 'Tout replier',
'minpwsize'               => 'Taille minimale : 5 caractères',
'passwordtoosmall'        => 'Mot de passe trop court.',
'accountwaslocked'        => 'Votre compte a été bloqué suite à un trop grand nombre d\'échecs de connexion.',
'failedattempts'          => 'Il y a eu %d échecs de connexion.',
'groupnotexist'           => 'Le groupe sélectionné n\'existe pas dans ce projet.',
'searchindetails'         => 'Rechercher dans les détails',
'showasassignees'         => 'Afficher dans les destinataires',
'find'                    => 'Rechercher',
'tls'                     => 'TLS',
'isadmin'                 => 'Est administrateur',
'addvotes'                => 'Ajouter des votes',
'removevote'              => 'Supprimer le vote',
'voteremoved'             => 'Votre vote a été supprimé',
'voteremovefailed'        => 'Impossible de supprimer votre vote pour le moment.',
'novotes'                 => 'Vous n\'avez actuellement voté pour aucune tâche.',
'connectedtasks'          => 'Tâches liées :',
'taskdependencies'        => 'Dépendances de tâche',
'viewgraph'               => 'voir le graphe',
'notaskdependencies'      => 'Cette tâche ne dépend d\'aucune autre.',
'dependson'               => 'Dépend de',
'blocks'                  => 'bloque',
'newdependency'           => 'Nouvelle dépendance :',
'nouserstoadd'            => 'Aucun utilisateur à ajouter. Vérifiez que les noms, identifiants, et courriels sont définis pour chaque utilisateur.',
'dispintro'               => 'Afficher le message d\'introduction principal',
'mainmessage'             => 'Message d\'introduction principal',
'setsupertask'            => 'Définir la tâche parente:',
'supertaskmodified'       => 'Identifiant de la tâche parente modifié',
'set'                     => 'Définir',
'supertask'               => 'Tâche parente',
'setparent'               => 'Définir l\'identifiant de la tâche parente',
'selfsupertasknotallowed' => 'L\'identifiant de tâche parente ne peut pas être le même que celui de la tâche elle-même',
'quickaction'             => 'Actions rapides',
'updateselectedtasks'     => 'Tâches sélectionnées mises à jour',
'notspecified'            => 'Non spécifié',
'editselectedtasks'       => 'Modification de cette tâche',
'information'             => 'Information',
'taskclosedisabled'       => 'La fermeture de cette tâche est temporairement suspendue, due aux tâches dépendantes encore ouvertes',
'daysleft'                => 'Jours restants',
'dayoverdue'              => 'Jours de retard',
'duetoday'                => 'Dernier jour.',
'daysbeforealert'         => 'Jours avant alerte',
'associatedsubtask'       => 'Sous-tâche associée',
'associatesubtask'        => 'Associer cet identifiant de sous-tâche avec cette tâche',
'subtaskid'               => 'Identifiant de sous-tâche',
'subtaskalreadyhasparent' => 'Cette sous-tâche a déjà une tâche parente. Merci de la supprimer au préalable.',
'subtaskisparent'         => 'Cette sous-tâche est la tâche parente. Elle ne peut être associée.',
'subtasknotexist'         => 'Cette sous-tâche n\'existe pas.',
'subtaskremovedmsg'       => 'Cette sous-tâche a été supprimée',
'subtaskadded'            => 'Sous-tâche ajoutée',
'subtaskremoved'          => 'Sous-tâche retirée',
'addnewsubtask'           => 'Ajouter une sous-tâche',
'hidesubtasks'            => 'Cacher une sous-tâche',
'voteforthistask'         => 'Voter pour cette tâche',
'watchthistask'           => 'Consulter cette tâche',
'privatethistask'         => 'Marquer cette tâche comme privée',
'adddependenttask'        => 'Ajouter une tâche dépendante',
'associatetaskid'         => 'Identifiant de tâche associée',
'parenttaskid'            => 'Identifiant de tâche parente',
'invalidsupertaskid'      => 'Identifiant de tâche parente invalide.',
'supertaskadded'          => 'Tâche parente ajoutée',
'supertaskremoved'        => 'Tâche parente supprimée',
'effort'                  => 'Effort',
'efforttracking'          => 'Suivi d\'effort',
'useeffort'               => 'Le projet utilise le suivi d\'effort',
'estimatedeffort'         => 'Effort estimé',
'totalestimatedeffort'    => 'Effort estimé total',
'currenteffortdone'       => 'Effort fourni',
'starteffort'             => 'Démarrer le suivi',
'endeffort'               => 'Arrêter le suivi',
'cleareffort'             => 'Effacer le suivi',
'addeffort'               => 'Ajouter effort',
'manualeffort'            => 'Ajouter effort manuellement (H:M)',
'efforttrackingstarted'   => 'Suivi d\'effort démarré pour cette tâche.',
'efforttrackingnotstarted'=> 'Impossible de démarrer le suivi pour une tâche qui est déjà suivie',
'efforttrackingstopped'   => 'Le suivi d\'effort est terminé pour cette tâche.',
'efforttrackingcancelled' => 'Suivi d\'effort annulé pour cette tâche.',
'efforttrackingadded'     => 'Effort manuel enregistré pour cette tâche.',
'trackinginprogress'      => 'Suivi en cours',
'viewestimatedeffort'     => 'Peut voir le suivi d\'effort',
'viewcurrenteffortdone'   => 'Peut voir l\'effort dépensé actuel',
'trackeffort'             => 'Peut suivre l\'effort',
'invalideffort'           => 'L\'effort entré est invalide. Ce doit être un nombre',
'showpass'                => 'Afficher le mot de passe',
'chooseafile'             => 'Merci de sélectionner un fichier !',
'incorrectfiletype'       => 'Type de fichier incorrect. Autorisé : jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Aucun mot de passe nécessaire. Enregistrement via %s',
'addmultipletasks'        => 'Ouvrir des tâches en lot',
'pendingnewuserrequest'   => 'Demande d\'utilisateur en attente',
'adminrequestswaiting'    => 'Demandes pour l\'administrateur en attente',
'clicktoedit'             => 'Cliquez sur les champs pour effectuer une modification rapide',
'confirmedit'             => 'confirmer',
'regapprovedbyadmin'      => 'Inscriptions approuvées par les administrateurs (code de confirmation inutile)',
'activity'                => 'Activité',
'myactivity'              => 'Mon activité',
'emailverificationwrong'  => 'La confirmation par courriel ne correspond pas au courriel',
'verifyemailaddress'      => 'Confirmer l\'adresse courriel',
'hideemails'              => 'Cacher les adresses courriel',
'hidemyemail'             => 'Cacher mon adresse courriel',
'exporttasklist'          => 'Exporter la liste des tâches',
'onedecimal'              => 'Une décimale',
'manday'                  => 'jour-homme',
'mandays'                 => 'jours-hommes',
'mandayabbrev'            => 'JH',
'hourspermanday'          => 'Heures par jour-homme (HH:mm)',
'itemexists'              => 'L\'entrée %s existe déjà en base de données.',
'categoryitemexists'      => 'L\'entrée %s existe déjà dans la catégorie %s en base de données.',
'pageswelcomemsg'         => 'Pages sur lesquelles afficher le message de bienvenue',
'pagesintromsg'           => 'Pages sur lesquelles afficher le message d\'intro',
'activeoauths'            => 'Fournisseurs OAuth actifs',
'onlyoauthreg'            => 'Autoriser uniquement les inscriptions via OAuths',
'estimatedeffortformat'   => 'Format d\'affichage de l\'effort estimé',
'currenteffortdoneformat' => 'Format actuel de l\'affichage de l\'effort',
'minute'                  => 'minute',
'minutes'                 => 'minutes',
'minuteplural'            => 'minutes',
'minutesingular'          => 'minute',
'minuteabbrev'            => 'm',
'hourplural'              => 'heures',
'hoursingular'            => 'heure',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'Effort estimé pour les tâches ouvertes',
'currenteffortdoneopen'   => 'Effort fourni pour les tâches ouvertes',
'signinwith'              => 'Se connecter avec %s',
'canviewroadmap'          => 'Peut consulter la feuille de route',
'enableavatars'           => 'Activer les avatars',
'maxavatarsize'           => 'Taille maximum des avatars',
'taskhassubtask'          => 'Cette tâche a la sous-tâche suivante',
'taskhassubtasks'         => 'Cette tâche a les sous-tâches suivantes',
'translations'            => 'Traductions',
'translate'               => 'Traduire',
'taskdescription'         => 'Description de la tâche',
'notaskdescription'       => 'Aucune description',
'pleaseselect'            => 'Veuillez sélectionner',
'closeselectedtasks'      => 'Fermer les tâches sélectionnées',
'closetasks'              => 'Fermer les tâches',
'hintforbulkimport'       => '<b>Conseils pour l\'importation en lot :</b>
  <ol>
  <li>Copiez/collez d\'une feuille de calcul Excel ou CSV en collant une colonne entière</li>
  <li>Pour le moment vous ne pouvez coller que "Résumé" et "Détails"</li>
  <li>La colonne "Assignée à" est intelligente et vous suggère les utilisateurs en fonction de ce que vous saisissez</li>
  </ol>',
'taskissubtaskof'         => 'Cette tâche est une sous-tâche de',
'applyfirstline'          => 'Appliquer la première ligne',
'addmorerows'             => 'Ajouter plus de lignes',
'addtasks'                => 'Ouvrir les tâches',
'massopsdisabled'         => 'Désolé, la modification par lot est désactivée pour Flyspray 1.0. Nous avons décidé de terminer son implémentation pour une future version de Flyspray. Vous pouvez activer cette fonction dans le code source à vos risques, mais lisez attentivement les commentaires avant de le faire.',
'viewroadmap'             => 'Peut consulter la feuille de route',
'nosuicide'               => 'Cher utilisateur, mon programme ne vous autorise pas à détruire votre accès à Flyspray en désactivant votre propre compte ou en changeant votre groupe d\'utilisateur. Signé le sympathique frère de HAL9000',
'movingtodifferentproject'=> 'Déplacer une tâche ayant une tâche parente ou une sous-tâche dans un autre projet n\'est pas autorisé. Supprimer d\'abord les connexions entre elles.',
'musthavesameproject'     => 'La tâche parente et la sous-tâche doivent appartenir au même projet.',
'defaultorderby'          => 'Par défaut, ordonner les tâches par',
'viewowntasks'            => 'Voir ses propres tâches',
'viewgroupstasks'         => 'Voir les tâches de groupes',
'urlrewriting'            => 'Réécriture d\'url',
'enablehtaccess'          => 'Veuillez activer votre fichier .htaccess à la racine de Flyspray avant d\'activer la réécriture d\'url',
'nomodrewrite'            => 'Mod rewrite ne semble pas disponible sur ce serveur, désolé mais je ne peux pas activer la rééecriture d\'url',
'on'                      => 'Activé',
'off'                     => 'Désactivé',
'defaultorderbydirection' => 'Ordre par défaut',
'ascending'               => 'Ascendant',
'descending'              => 'Descendant',
'myassignedtasks'         => 'Mes tâches',
'commentedon'             => 'a commenté le',
'maxvoteperday'           => 'Maximum de votes par jour',
'votesperproject'         => 'Nombre limite de votes utilisateur par projet',
'votelimitreached'        => 'Vous avez atteint la limite de votes pour ce projet. Consultez votre profil pour voir les tâches pour lesquelles vous avez voté. Vous pouvez également revenir sur vos votes. De cette façon, nous pouvons voir quelles tâches sont plus importantes pour vous. Les tâches résolues vous permettent de voter de nouveau.',
'myvotes'                 => 'Mes Votes',
'tag'                     => 'Tag',
'tags'                    => 'Tags',
'tagsinfo'                => 'Tagguer librement des tâches dans Flyspray :
Séparer les tags par ;
Les Tags ne sont actuellement pas gérables et ne sont pas utilisés dans la recherche ou les filtres. Ils sont actuellement juste comme des post-it sur une fenêtre.',
'novalues'                => 'aucune entrée',
'youhaveregistered'       => 'Vous êtes inscrit sur Flyspray. Vous trouverez vos détails ci-après :',
'youhaveregisterednotify' => 'Votre inscription sur Flyspray a été acceptée par les Administrateurs.',
'usedintasks'             => 'Utilisation',
'active'                  => 'Actif(s)',
'inactive'                => 'Désactivé(s)',
'showinactive'            => 'Afficher les projets désactivés',
'hideinactive'            => 'Masquer les projets désactivés',
'summaryrequired'         => 'Vous devez renseigner un court résumé de la tâche',
'defaultorderby2'         => 'Ensuite par',
'freetagging'             => "Autoriser la création de tags par l'utilisateur",
'customstyle'             => 'personnalisé',
'keyboardshortcuts'       => 'Raccourcis clavier',
'testmailsettings'        => 'Tester l\'envoi de courriel avec la configuration actuellement active',
'test'                    => 'Tester',
'testmailsettingsnotice'  => 'Et vérifier également que vous avez bien reçu le courriel de test dans la boîte mail de l\'utilisateur actuel (Voir la page "Mon profil")',
'invalidinput'            => 'Certaines propriétés sont incompatibles et doivent être modifiées avant de déplacer cette tâche vers un autre projet.',
'invalidstatus'           => 'Veuillez sélectionner un statut valide pour cette tâche lors d\'un déplacement vers un autre projet',
'invalidcategory'         => 'Veuillez sélectionner une catégorie valide pour cette tâche lors d\'un déplacement vers un autre projet',
'invalidreportedversion'  => 'Veuillez sélectionner une version de base valide pour cette tâche lors d\'un déplacement vers un autre projet',
'invaliddueversion'       => 'Veuillez sélectionner une version de livrable valide pour cette tâche lors d\'un déplacement vers un autre projet',
'invalidos'               => 'Veuillez sélectionner un système d\'exploitation valide pour cette tâche lors d\'un déplacement vers un autre projet',
'invalidtags'             => 'Veuillez ne sélectionner que des tags autorisés pour cette tâche lors d\'un déplacement vers un autre projet',
'invalidassignees'        => 'Veuillez ne sélectionner que des utilisateurs assignés autorisés pour cette tâche lors d\'un déplacement vers un autre projet',
'customize'               => 'Personnaliser',
'hidesubs'                => 'Masquer les sous-tâches',
'hideprivate'             => 'Masquer les tâches privées',
'hideclosed'              => 'Masquer les tâches closes',
'currentproject'          => 'Projet actuel',
'targetproject'           => 'Projet de destination',
'invalidprogress'         => 'Merci de choisir une valeur de progression correcte.',
'invalidpriority'         => 'Merci de choisir une valeur de priorité correcte.',
'invalidseverity'         => 'Merci de choisir une valeur de gravité correcte.',
'availablekeybshortcuts'  => 'Activer les raccourcis clavier',
'logindialoglogout'       => 'Se connecter/Se déconnecter',
'focustaskidsearch'       => 'Rechercher par ID de tâche',
'openselectedtask'        => 'Ouvrir la tâche sélectionnée',
'movecursorup'            => 'Déplacer le curseur vers le haut',
'movecursordown'          => 'Déplacer le curseur vers le bas',
'taskdetails'             => 'Détails de la tâche',
'taskediting'             => 'Édition de la tâche',
'savetask'                => 'Enregistrer la tâche',
'generalintegration'      => 'Chaînes de caractères globales',
'generalintegrationdesc'  => 'Dans le thème par défaut, ce contenu est positionné dans la balise "body", juste avant la balise "footer". Il est possible de modifier l\'endroit où il apparaît à l\'aide de CSS. Utilisez un fichier custom_*.css dans ce cas.',
'footerintegration'       => 'Texte du pied de page',
'footerintegrationdesc'   => 'Dans le thème par défaut, ce contenu est positionné dans le pied de page. Il est possible de modifier l\'endroit où il apparaît à l\'aide de CSS. Utilisez un fichier custom_*.css dans ce cas.',
'editorbold'              => 'G',
'editorboldhint'          => 'gras',
'editoritalic'            => 'I',
'editoritalichint'        => 'italique',
'editorunderline'         => 'S',
'editorunderlinehint'     => 'souligné',
'editorstrikethrough'     => 'B',
'editorstrikethroughhint' => 'barré',
'lastlogin'               => 'Dernière connexion',
'categoriesglobal'        => 'Catégories Globales',
'categoriesproject'       => 'Catégories Projets',
'categoriestarget'        => 'Catégories Destination',
  
'captchaerror'            => 'CAPTCHA non résolu. Veuillez réessayer.',
'registercaptcha'         => 'Veuillez résoudre le CAPTCHA.',
'regcaptcha'              => 'Montrer un CAPTCHA à l\'enregistrement des nouveaux utilisateurs.',
'invalidsecurimage'       => 'CAPTCHA invalide',
'invalidrecaptcha'        => 'Google reCAPTCHA invalide',
'antispam'                => 'Antispam',
'antispamprefsinfo'       => 'Paramètres de l\'antispam. Actuellement, Securimage et Google reCAPTCHA sont utilisés pour l\'enregistrement des nouveaux utilisateurs',
'securimageprefsinfo'     => 'Un test CAPTCHA classique où les utilisateurs doivent reconnaitre un texte pour prouver qu\'ils sont humains.',
'securimageenable'        => 'Activer Securimage',
'recaptchaprefsinfo'      => 'Google reCAPTCHA est une alternative au CAPTCHA classique.
Google décide selon les informations collectées, le comportement de l\'utilisateur et potentiellement un test de reconnaissance d\'image si vous êtes un humain ou un robot.
Pour utiliser ceci, vous avez besoin d\'un compte Google et de configuer reCAPTCHA pour votre domaine depuis https://www.google.com/recaptcha en insérent "sitekey" et "secret" de cette configuration.
Selon votre configuration - "reCAPTCHA V2" ou "Invisible reCAPTCHA" - il est possible que vous deviez informer vos utilisateurs à propos de la protection des données.',
'recaptchaenable'         => 'Activer Google reCAPTCHA',
'adminchecks'             => 'Vérification',
'adminchecksinfo'         => 'Information et vérification de l\'installation actuelle',
'repeatpassword'          => 'Répétez le mot de passe',
'repeatemailaddress'      => 'Répétez l\'adresse courriel',
'tooltipshorttasktitle'   => 'Écrivez un titre résumant le problème et le rendant compréhensible d\'un coup d\'oeil',
);

?>
