<?php

$language = array(
'edituser'                => 'Edit user',
'accountenabled'          => 'Account Enabled',
'editallusers'            => 'View All Users',
'username'                => 'Username',
'usersupdated'            => 'Users successfully updated',
'realname'                => 'Real Name',
'emailaddress'            => 'Email Address',
'jabberid'                => 'Jabber ID',
'profileimage'            => 'Profile Image',
'notifytype'              => 'Notify Type',
'group'                   => 'Group',
'enableaccounts'          => 'Enable Accounts',
'disableaccounts'         => 'Disable Accounts',
'deleteaccounts'          => 'Delete Accounts',
'updatedetails'           => 'Update details',
'setglobally'             => 'This preference has been set globally.',
'usergroupmanage'         => 'User and Group management',
'newuser'                 => 'Register New User',
'newuserbulk'             => 'Register Multiple New Users',
'bulkuserstoadd'          => 'List of new users',
'optionsforallusers'      => 'Options For All New Users',
'newgroup'                => 'Create New Group',
'yes'                     => 'Yes',
'no'                      => 'No',
'editgroup'               => 'Edit Group',
'groupname'               => 'Group Name',
'description'             => 'Description',
'admin'                   => 'Admin group',
'opennewtasks'            => 'Open new tasks',
'modifytasks'             => 'Modify existing tasks',
'addcomments'             => 'Add comments',
'attachfiles'             => 'Attach files',
'vote'                    => 'Vote',
'groupenabled'            => 'Members can login',
'groupopen'               => 'Members can login',
'tasktypelist'            => 'Task Types list',
'categorylist'            => 'Categories list',
'oslist'                  => 'Operating Systems list',
'resolutionlist'          => 'Resolutions list',
'versionlist'             => 'Versions list',
'severitylist'            => 'Severities list',
'listnote'                => 'Note:  Unchecking the "show" box may alter some tasks when in edit mode.  Changing the "Name" field will change all tasks with that name. Items that can not be deleted are either protected because they are needed for correct functioning or used in tasks.',
'name'                    => 'Name',
'order'                   => 'Order',
'back'                    => 'Back',
'text'                    => 'Text',
'highlight'               => 'Highlight',
'show'                    => 'Show',
'owner'                   => 'Owner',
'selectowner'             => 'Select Owner',
'update'                  => 'Update',
'addnew'                  => 'Add new',
'flysprayprefs'           => 'Flyspray preferences',
'projecttitle'            => 'Project Title',
'baseurl'                 => 'Base URL for this installation',
'replyaddress'            => 'Reply email address for notifications',
'themestyle'              => 'Theme / Style',
'customstyle'             => 'custom',
'language'                => 'Language',
'anonview'                => 'Allow anonymous users to view tasks',
'allowanon'               => 'Allow anonymous users to open new tasks',
'never'                   => 'Never',
'anonymously'             => 'Anonymously',
'afterregister'           => 'Only after registering',
'spamproof'               => 'Enable confirmation code for new user registrations',
'anongroup'               => 'Group for new user registrations',
'groupassigned'           => 'Members of these groups can be assigned tasks',
'forcenotify'             => 'Force task notifications as',
'neversend'               => 'Never send',
'userchoose'              => 'Let each user choose',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Default category owner',
'noone'                   => 'No-one',
'jabbernotify'            => 'Jabber Notifications',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Account Username',
'jabberpass'              => 'Account Password',
'saveoptions'             => 'Save Options',
'editcomment'             => 'Edit Comment',
'commentby'               => 'Comment by',
'saveeditedcomment'       => 'Save edited comment',
'projectprefs'            => 'Project Preferences',
'pagetitle'               => 'Page Title',
'defaultproject'          => 'Default Project',
'projectlists'            => 'Project lists',
'showlogo'                => 'Show title logo image',
'showgravatars'           => 'Show Gravatars',
'emailNoHTML'             => 'No HTML in E-Mails',
'intromessage'            => 'Introductory message',
'active'                  => 'active',
'inactive'                => 'inactive',
'isactive'                => 'Project is active',
'showinactive'            => 'Show inactive projects',
'hideinactive'            => 'Hide inactive projects',
'createproject'           => 'Create a new Project',
'nopermission'            => 'You don\'t have permission to use this page.',
'listordertip'            => 'The order these items will appear in the list',
'listshowtip'             => 'Show this item in the list',
'categoryownertip'        => 'This person will receive notifications when a task in this category is opened',
'categoryparenttip'       => 'The parent category this new one will fall under',
'notsubcategory'          => 'None (top-level category)',
'showinlineimages'        => 'Show image attachments inline',
'dateformat'              => 'Date format',
'dateformat_extended'     => 'Detailed date format',
'cache_feeds'             => 'Cache feeds',
'no_cache'                => 'No caching',
'cache_disk'              => 'Cache on disk',
'cache_db'                => 'Cache in DB',
'subcategoryof'           => 'Sub-category of',
'visiblecolumns'          => 'Columns displayed in task list',
'visiblefields'           => 'Fields when add/edit/view task',
'tense'                   => 'Tense',
'listtensetip'            => 'Past, Present or Future',
'past'                    => 'Past',
'present'                 => 'Present',
'future'                  => 'Future',
'oldpass'                 => 'Old Password',
'nooldpass'               => 'No Old Password was set',
'oldpasswrong'            => 'Old password was wrong',
'changepass'              => 'Change Password',
'confirmpass'             => 'Confirm Password',
'projectmanager'          => 'Project Manager',
'viewtasks'               => 'View tasks',
'modifyowntasks'          => 'Modify own tasks',
'modifyalltasks'          => 'Modify tasks that are not user\'s own',
'viewcomments'            => 'View comments',
'editcomments'            => 'Edit comments',
'deletecomments'          => 'Delete comments',
'viewattachments'         => 'View attachments',
'createattachments'       => 'Create attachments',
'deleteattachments'       => 'Delete attachments',
'viewhistory'             => 'View history',
'closeowntasks'           => 'Close own tasks',
'closeothertasks'         => 'Close tasks that are not user\'s own',
'assigntoself'            => 'Assign tasks to self if not already assigned',
'assignotherstoself'      => 'Assign others\' tasks to self',
'viewreports'             => 'View event log',
'othersview'              => 'Allow anyone to view tasks of this project',
'othersviewroadmap'       => 'Allow anyone to view roadmap of this project',
'usersandgroups'          => 'Users and Groups',
'globalgroup'             => 'Global Group',
'globalgroups'            => 'Global Groups',
'defaultglobalgroup'      => 'Default global group for new users',
'addtogroup'              => 'Add to group',
'moveuserstogroup'        => 'Move users to group',
'nogroup'                 => 'No Group - Remove from project',
'eventdesc'               => 'Event Description',
'requestedby'             => 'Requested by',
'daterequested'           => 'Date Requested',
'closetask'               => 'Close Task',
'reopentask'              => 'Reopen Task',
'applymember'             => 'Apply for Project membership',
'forcurrentproj'          => 'For current project',
'lostpw'                  => 'Lost password retrieval',
'lostpwexplain'           => 'Enter your username to send a link to change your password.  This will be sent to the notification address in your profile.',
'sendlink'                => 'Send link',
'savenewpass'             => 'Save new password',
'anonreg'                 => 'Allow new user registrations',
'allowanonopentask'       => 'Allow anonymous users to open tasks',
'editglobalgroup'         => 'Edit Global Group',
'editgroupforproj'        => 'Edit group for Project',
'notshownforadmin'        => 'Permissions are not shown for the admin group.  You don\'t need to edit them.',
'general'                 => 'General',
'userregistration'        => 'User Registration',
'notifications'           => 'Notifications',
'resetoptions'            => 'Reset Options',
'preferences'             => 'Preferences',
'tasktypes'               => 'Task Types',
'resolutions'             => 'Resolutions',
'categories'              => 'Categories',
'categoriesglobal'        => 'Global Categories',
'categoriesproject'       => 'Project Categories',
'categoriestarget'        => 'Target Categories',
'operatingsystems'        => 'Operating Systems',
'versions'                => 'Versions',
'admintoolboxlong'        => 'Administrator\'s Toolbox',
'newproject'              => 'New Project',
'delete'                  => 'Delete',
'link'                    => 'Link',
'referencelinks'          => 'Reference links:',
'listdeletetip'           => 'Delete this item from the list',
'lookandfeel'             => 'Look and Feel',
'globaltheme'             => 'Global Theme',
'emailnotify'             => 'Email Notifications',
'fromaddress'             => 'From address',
'smtpserver'              => 'SMTP Server',
'smtpuser'                => 'SMTP Username',
'smtppass'                => 'SMTP Password',
'addrewrite'              => 'Use address rewriting',
'usereminderdaemon'       => 'Enable background reminder daemon',
'tasksperpage'            => 'Tasks per page of the task list',
'addtoassignees'          => 'Add self to assignees',
'taskstatuses'            => 'Task Statuses',
'canvote'                 => 'Can Vote for tasks',
'loginsuccessful'         => 'Login successful.',
'youareloggedout'         => 'You have been logged out.',
'waitwhiletransfer'       => 'Please wait while you are transferred...',
'clicknowait'             => 'Click here if you do not wish to wait.',
'accountdisabled'         => 'Your account is disabled. Contact a full admin.',
'task'                    => 'Task',
'edittask'                => 'Edit this task',
'openedby'                => 'Opened by',
'editedby'                => 'Last edited by',
'tasktype'                => 'Task Type',
'category'                => 'Category',
'status'                  => 'Status',
'assignedto'              => 'Assigned To',
'operatingsystem'         => 'Operating System',
'severity'                => 'Severity',
'reportedversion'         => 'Reported Version',
'dueinversion'            => 'Due in Version',
'defaultdueinversion'     => 'Default due in Version for new tasks',
'undecided'               => 'Undecided',
'percentcomplete'         => 'Percent Complete',
'details'                 => 'Details',
'savedetails'             => 'Save Details',
'canceledit'              => 'Cancel Edit',
'anonymous'               => 'Anonymous Submitter',
'complete'                => 'complete',
'closedby'                => 'Closed by',
'reasonforclosing'        => 'Reason for closing:',
'reopenthistask'          => 'Reopen this task',
'comments'                => 'Comments',
'attachments'             => 'Attachments',
'relatedtasks'            => 'Related Tasks',
'edit'                    => 'Edit',
'addcomment'              => 'Add comment',
'fileuploadedby'          => 'File uploaded by',
'uploadafile'             => 'Attach a file',
'addalink'                => 'Add a link',
'addanotherlink'          => 'Add another link',
'uploadnow'               => 'Upload now!',
'thesearerelated'         => 'These tasks are related to this task',
'remove'                  => 'Remove',
'addnewrelated'           => 'Add a new related task',
'add'                     => 'Add',
'otherrelated'            => 'Other tasks that this task is related to',
'receivenotify'           => 'These users will receive detailed notifications when this task changes.',
'addusertolist'           => 'Add user to this list',
'addtolist'               => 'Add to list',
'addmyself'               => 'Add myself to this list',
'removemyself'            => 'Remove myself from this list',
'theseusersnotify'        => 'These users will receive detailed notifications whenever this task changes.',
'attachedtoproject'       => 'Attached to Project',
'reminders'               => 'Reminders',
'system'                  => 'System',
'systemvalues'            => 'System wide list values',
'projectvalues'           => 'Project specific list values',
'remindthisuser'          => 'Remind this user',
'thisoften'               => 'This often',
'startafter'              => 'Wait before starting reminders',
'hour'                    => 'hour',
'hours'                   => 'hours',
'day'                     => 'day',
'days'                    => 'days',
'week'                    => 'week',
'weeks'                   => 'weeks',
'addreminder'             => 'Add Reminder',
'defaultreminder'         => 'This is a reminder to look at the following Flyspray task:',
'message'                 => 'Message',
'closed'                  => 'Closed',
'filename'                => 'Filename:',
'date'                    => 'Date',
'filesize'                => 'File Size:',
'closurecomment'          => 'Additional comments about closing:',
'history'                 => 'History',
'nohistory'               => 'No history available.',
'eventdate'               => 'Date',
'user'                    => 'User',
'event'                   => 'Event',
'fieldchanged'            => 'Field changed',
'taskopened'              => 'Task opened',
'taskreopened'            => 'Task reopened',
'taskclosed'              => 'Task closed',
'commentadded'            => 'Comment added',
'commentedited'           => 'Comment edited',
'commentdeleted'          => 'Comment deleted',
'attachmentadded'         => 'Attachment added',
'attachmentdeleted'       => 'Attachment deleted',
'taskedited'              => 'Task details edited',
'notificationadded'       => 'User added to notification list',
'notificationdeleted'     => 'User removed from notification list',
'relatedadded'            => 'Related task added',
'relateddeleted'          => 'Related task removed',
'taskassigned'            => 'Task assigned to',
'taskreassigned'          => 'Task reassigned to',
'assignmentremoved'       => 'Assignment removed',
'summary'                 => 'Summary',
'addedasrelated'          => 'Task added to the related list of',
'deletedasrelated'        => 'Task removed from the related list of',
'reminderadded'           => 'Reminder added',
'reminderdeleted'         => 'Reminder removed',
'priority'                => 'Priority',
'previousvalue'           => 'Previous value',
'newvalue'                => 'New value',
'selectareason'           => 'Select a reason',
'assigntome'              => 'Assign to me',
'reopenrequest'           => 'Request reopen',
'requestclose'            => 'Request closure',
'ownershiptaken'          => 'User took ownership',
'closerequestmade'        => 'Requested task closure',
'reopenrequestmade'       => 'Requested task to be reopened',
'taskdependson'           => 'The task depends upon',
'taskdependsontask'       => 'The task depends upon',
'taskdependsontasks'      => 'The task depends upon',
'taskblock'               => 'The task blocks this from closing',
'taskblocks'              => 'The task blocks these from closing',
'depadded'                => 'Dependency added',
'depaddedother'           => 'This task added as dependency',
'depremoved'              => 'Dependency removed',
'depremovedother'         => 'This task removed from other task\'s dependency list',
'showdetailserror'        => 'That task does not exist, or you don\'t have permission to view it.',
'makeprivate'             => 'make private',
'makepublic'              => 'make public',
'taskmadeprivate'         => 'Task made private',
'taskmadepublic'          => 'Privacy removed - task made public',
'confirmdeletecomment'    => 'Are you sure you want to delete this comment? %s',
'attachementswilldeleted' => 'All attachments will also be deleted!',
'confirmdeleteattach'     => 'Are you sure you want to delete this attachment?',
'selectedhistory'         => 'Showing selected history details',
'showallhistory'          => 'Show full history tab again',
'hidethis'                => 'Hide this area again',
'mark100'                 => 'Mark task 100% complete',
'watchtask'               => 'watch task',
'stopwatching'            => 'stop watching',
'commentlink'             => 'Link to this comment',
'submitreq'               => 'Submit request',
'reasonforreq'            => 'Reason for request',
'pmreqdenied'             => 'Project Manager denied request',
'taskpendingreq'          => 'Project Manager action pending.  See the History tab for details.',
'previoustask'            => 'Previous task',
'nexttask'                => 'Next task',
'duedate'                 => 'Due Date',
'attachnoperms'           => 'There are attachments with this comment, but you have no permission to view them.',
'linknoperms'             => 'There are links with this comment, but you have no permission to view them.',
'open'                    => 'Open',
'depgraph'                => 'View Dependency Graph',
'reset'                   => 'Reset',
'selectusers'             => 'Select Users...',
'addmetoassignees'        => 'Add me to assignees',
'addedtoassignees'        => 'User added to assignees list',
'dependencygraph'         => 'Dependency graph',
'attachanotherfile'       => 'Attach another file',
'OK'                      => 'OK',
'addvote'                 => 'Add Vote',
'disable_lostpw'          => 'Disable lost password retrieval',
'disable_changepw'        => 'Disable create/edit password',
'notifyfromfs'            => 'Notification from Flyspray',
'autogenerated'           => 'THIS IS AN AUTOMATICALLY GENERATED MESSAGE, DO NOT REPLY',
'forward'                 => 'Forward',
'previous'                => 'Previous',
'next'                    => 'Next',
'first'                   => 'First',
'last'                    => 'Last',
'page'                    => 'Page %d of %d',
'search'                  => 'Search',
'alltasktypes'            => 'All Task Types',
'allseverities'           => 'All Severities',
'alldevelopers'           => 'All Developers',
'notyetassigned'          => 'Not yet assigned',
'allcategories'           => 'All Categories',
'allstatuses'             => 'All Statuses',
'allopentasks'            => 'All Open Tasks',
'sortthiscolumn'          => 'Sort by this column',
'id'                      => 'ID',
'project'                 => 'Project',
'dateopened'              => 'Opened',
'progress'                => 'Progress',
'searchthisproject'       => 'Search this project for',
'dueanyversion'           => 'Due In Any Version',
'anyversion'              => 'Reported In Any Version',
'dueversion'              => 'Due In Version',
'lastedit'                => 'Last Edited',
'os'                      => 'Operating System',
'reportedin'              => 'Reported In',
'taskrange'               => 'Showing tasks %d - %d of %d',
'noresults'               => 'Your search returned no results.',
'takeaction'              => 'Take action',
'watchtasks'              => 'Watch selected tasks',
'stopwatchingtasks'       => 'Stop watching selected tasks',
'assigntaskstome'         => 'Assign selected tasks to me',
'dueby'                   => 'Due by',
'dueanytime'              => 'Due anytime',
'selectduedate'           => 'Select Due Date',
'toggleselected'          => 'Toggle Selected',
'due'                     => 'Due',
'assignedtome'            => 'Assigned to myself',
'tasklist'                => 'Tasklist',
'dateclosed'              => 'Date closed',
'advanced'                => 'Advanced',
'searchcomments'          => 'Search in comments',
'searchforall'            => 'Search for all words',
'anonusers'               => 'Anonymous Users',
'miscellaneous'           => 'Miscellaneous',
'users'                   => 'Users',
'taskproperties'          => 'Task Properties',
'selectsincedate'         => 'Select Changed since',
'changedsince'            => 'Changed since',
'updatefs'                => 'Please update Flyspray.',
'currentversion'          => 'Your current version is',
'latestversion'           => 'and the latest version is',
'hidemessage'             => '(remind me later)',
'saveas'                  => 'Save search as',
'nosearches'              => 'No saved searches',
'saving'                   => 'Saving...',
'votes'                   => 'Votes',
'tovote'                  => 'Vote',
'allclosedtasks'          => 'All Closed Tasks',
'password'                => 'Password',
'login'                   => 'Login!',
'rememberme'              => 'Remember me',
'lostpassword'            => 'Lost password?',
'lostpwforfs'             => 'Lost password for Flyspray',
'lostpwmsg1'              => 'Hi.

I have lost my password for Flyspray on ',
'lostpwmsg2'              => ', please provide me with a new password.

Username: ',
'regards'                 => '

Regards,',
'yourusername'            => ' your username ',
'locale'                  => 'en-US',
'filenotexist'            => 'File does not exist, or you do not have permission to access it.',
'showtask'                => 'Show Task',
'now'                     => 'Now',
'go'                      => 'Go!',
'opentaskanon'            => 'Open a new Task anonymously',
'register'                => 'Register',
'addnewtask'              => 'Add new task',
'reports'                 => 'Event log',
'editmydetails'           => 'Edit my details',
'logout'                  => 'Logout',
'disabledaccount'         => 'Your account has been disabled!<br />Immediately logging you out...',
'poweredby'               => 'powered by Flyspray',
'sponsoredby'             => 'Flyspray is proudly sponsored by',
'projects'                => 'Projects',
'allprojects'             => 'All Projects',
'selectproject'           => 'for Project:',
'tasksall'                => 'All tasks',
'tasksassigned'           => 'Tasks assigned to me',
'tasksreported'           => 'Tasks reported by me',
'taskswatched'            => 'Tasks I watch',
'mysearch'                => 'My searches',
'admintoolbox'            => 'Admin Toolbox',
'manageproject'           => 'Manage Project',
'permissions'             => 'View Permissions',
'hide'                    => 'Hide',
'pendingreq'              => 'PM requests waiting',
'errorpage'               => 'Flyspray cannot provide the page you requested.
                                 Perhaps you requested a task that does not exist, or you
                                 do not have permission to view the page you wanted.<br /><br />
                                 You may have tried to use a naughty URL to interact with the database
                                 backend using SQL injection.  If this is true, go to the corner and think
                                 about your actions.  When you return, please do not do it again!',
'permissionsforproject'   => 'Permissions for ',
'switchto'                => 'Switch to',
'lastsearch'              => 'Last search',
'modify'                  => 'Modify',
'noticefrom'              => 'Notice from',
'hasopened'               => 'has OPENED A NEW Flyspray task, and assigned it to you:',
'moreinfonew'             => 'You can find more information about this bug at the Flyspray page:',
'newtaskcategory'         => 'A new Flyspray task has been opened in this category',
'categoryowner'           => 'You are receiving this because you are listed as the category owner.',
'tasksummary'             => 'Task summary:',
'newtaskadded'            => 'Your new task has been added.',
'summaryanddetails'       => 'You need to fill in both the summary and the details.',
'summaryrequired'         => 'You need to fill in a short task summary.',
'goback'                  => 'Go back.',
'messagefrom'             => 'This is a message from the Flyspray bug tracking system at ',
'hasjustmodified'         => 'has just modified the following task.',
'changedfields'           => 'Changed fields are prefixed with asterisks (**)',
'moreinfomodify'          => 'You can get more information about this task at the following URL:',
'nolongerassigned'        => 'The following task is no longer assigned to you.  It is now assigned to',
'hasassigned'             => 'has assigned to you the following Flyspray task:',
'taskupdated'             => 'Task has been updated.',
'tasksupdated'            => 'Tasks have been updated.',
'hasclosedassigned'       => 'has closed the following Flyspray task that you were assigned:',
'unassigned'              => 'Unassigned',
'hasclosed'               => 'has closed the following task.',
'youonnotify'             => 'You are receiving this because you are on the notification list.',
'taskclosedmsg'           => 'Task has been closed.',
'returntotask'            => 'Return to the task details',
'backtoindex'             => 'Go back to the task list',
'noclosereason'           => 'You didn\'t select a reason for closing this task.',
'hasreopened'             => 'has reopened the following Flyspray task that you closed:',
'taskreopenedmsg'         => 'Task has been reopened.',
'backtotask'              => 'Go back to the task.',
'commentaddedmsg'         => 'Comment has been added.',
'commenttoassigned'       => 'has added a comment to a task that you have been assigned:',
'commenttotask'           => 'has added the following comment to this task.',
'nocommententered'        => 'You really should enter a comment before clicking the submit button.',
'fillinfields'            => 'You didn\'t fill in all the fields.',
'notcurrentpass'          => 'That\'s not your current password!',
'passchanged'             => 'Your password has been changed.',
'closewindow'             => 'You can now close this window.',
'passnomatch'             => 'Your new passwords weren\'t the same!',
'usernametaken'           => 'That username is already taken.  You will need to choose another one.',
'usernametakenbulk'       => 'Username Already Taken',
'newusercreated'          => 'New User Account has been created.',
'accountcreated'          => 'Your account has been created.',
'newuserwarning'          => 'Note that the global preferences might require your account to be approved by an admin.  If you cannot login, this is probably why.',
'nomatchpass'             => 'Passwords didn\'t match.',
'confirmwrong'            => 'Confirmation code is incorrect!',
'formnotcomplete'         => 'Form was not completely filled in.',
'formnotnumeric'          => 'Inserted data was not numeric!',
'groupnametaken'          => 'That Group name is already taken.',
'newgroupadded'           => 'New Group added.',
'optionssaved'            => 'Flyspray Options saved.',
'hasuploaded'             => 'has uploaded a file attachment to a task that have been assigned:',
'hasattached'             => 'has attached a file to the following task.',
'fileuploaded'            => 'File has been uploaded.',
'fileerror'               => 'There was an error uploading your file.  Perhaps the permissions on the <i>attachments/</i> directory are incorrect.',
'contactadmin'            => 'Contact the Administrator for this project.',
'selectfileerror'         => 'You didn\'t select a file.',
'userupdated'             => 'User details have been updated',
'realandemail'            => 'You didn\'t fill in both the Real Name and Email Address fields.',
'groupupdated'            => 'Group definition updated.',
'groupanddesc'            => 'You didn\'t fill in the group name.',
'fillallfields'           => 'Please fill in all fields.',
'listPmustN'              => '"Order" entry has to be numeric.',
'listupdated'             => 'List has been updated.',
'listitemadded'           => 'New list item added.',
'relatedaddedmsg'         => 'Related task added to list.',
'relatederror'            => 'That task is already on this related task list.',
'relatedremoved'          => 'Related task removed from list.',
'notifyadded'             => 'User added to notification list.',
'notifyerror'             => 'That user is already on the notification list for that task.',
'notifyremoved'           => 'User removed from notification list.',
'editcommentsaved'        => 'Updated comment saved.',
'commentdeletedmsg'       => 'Comment has been deleted.',
'gotonewtask'             => 'Go to the new task you just created',
'projectcreated'          => 'Your new Project has been created.  You can now customise the project in the project management area.',
'customiseproject'        => 'Customise this project',
'projectupdated'          => 'Project preferences updated',
'emptytitle'              => 'You left the Project Title field blank.  Go back and fix it.',
'loginbelow'              => 'You may now attempt to login.',
'attachmentdeletedmsg'    => 'The attachment has been deleted',
'reminderaddedmsg'        => 'Your reminder has been added.',
'reminderdeletedmsg'      => 'The selected reminder has been deleted.',
'flyspraytask'            => 'Flyspray task',
'fieldsmissing'           => 'Some fields contained no or invalid data.',
'relatedinvalid'          => 'There is no such task.',
'relatedproject'          => 'This task is attached to a different project. Add relation anyway?',
'addanyway'               => 'Add anyway',
'cancel'                  => 'Cancel',
'alreadyedited'           => 'This task was edited by someone else before you saved. Do you still want to save your changes?',
'saveanyway'              => 'Save my changes anyway',
'nouserselected'          => 'No user selected.  Select at least one user before trying again.',
'groupswitchupdated'      => 'User groups modified successfully.',
'takenownershipmsg'       => 'This task is now assigned to you.',
'adminrequestmade'        => 'Your request has been sent to a Project Manager.',
'newdepnotify'            => 'A new dependency has been added to the following task:',
'dependadded'             => 'Task dependency has been added',
'dependaddfailed'         => 'There was an error when adding the dependency. Check that the task exists and there is no mutual block.',
'depremovedmsg'           => 'Task dependency has been removed',
'newdepis'                => 'The new dependency is',
'magicurlsent'            => 'A message has been sent to your notification address.  It contains a link that will take you to a page to complete this task.',
'changefspass'            => 'Change Flyspray password',
'magicurlmessage'         => 'Please follow the link below to change your Flyspray password:',
'erroronform'             => 'There was an problem with your form submission',
'addressused'             => 'This address has been used to register a Flyspray account.  If you were not expecting this message, please ignore and delete it.  Go to the following URL to complete your registration:',
'confirmcodeis'           => 'Your confirmation code is:',
'codesent'                => 'Your confirmation code has been sent.  Please follow the instructions contained in the message.',
'codenotsent'             => 'Cannot send your code, please try again later.',
'taskmadeprivatemsg'      => 'This task has been made private',
'taskmadepublicmsg'       => 'This task has been made public again',
'realandnotify'           => 'You need to fill in the Real Name field, and either the Email Address or Jabber ID field.',
'pmreqdeniedmsg'          => 'Project Manager request denied',
'massopsenable'           => 'Enable mass operations',
'massopsuccess'           => 'Mass operations successful - where permissions allowed',
'usernotexist'            => 'That user does not exist on this Flyspray installation',
'commentattachperms'      => 'You cannot delete that comment - no permission to delete attachments',
'voterecorded'            => 'Your vote has been recorded',
'votefailed'              => 'Your vote could not be added at this time.',
'createnewgroup'          => 'Create new group',
'requiredfields'          => 'Required fields are marked with a',
'addthisgroup'            => 'Add this group',
'createnewproject'        => 'Create a new Project',
'addnewproject'           => 'Add New Project',
'htmlallowed'             => 'HTML code is allowed',
'createthisproject'       => 'Create this project',
'inlineimages'            => 'Show image attachments inline',
'createnewtask'           => 'Create a new task in project:',
'addanother'              => 'Add another task after this one',
'addthistask'             => 'Add this task',
'notifyme'                => 'Notify me whenever this task changes',
'newtask'                 => 'New Task',
'attachafile'             => 'Attach a file',
'registernewuser'         => 'Register new user',
'none'                    => 'None',
'registeraccount'         => 'Register this account',
'registerbulkaccount'     => 'Register accounts',
'both'                    => 'Both',
'notifyfrom'              => 'Notification from ',
'donotreply'              => 'THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.',
'disclaimer'              => 'You are receiving this message because you have requested it from the Flyspray bugtracking system.  If you did not expect this message or don\'t want to receive mails in future, you can change your notification settings at the URL shown above.',
'userwho'                 => 'User who did this',
'moreinfo'                => 'More information can be found at the following URL:',
'newtaskopened'           => 'A new Flyspray task has been opened.  Details are below.',
'notify.taskclosed'       => 'The following task is now closed:',
'notify.taskreopened'     => 'The following task has been reopened:',
'newdep'                  => 'The following task has a new dependency:',
'notify.depremoved'       => 'The following task has had a dependency removed:',
'olddepwas'               => 'The old dependency was',
'notify.commentadded'     => 'The following task has a new comment added:',
'commentis'               => 'The comment text is below.',
'newattachment'           => 'A new file has been attached to the following task:',
'detailsbelow'            => 'The details are below.',
'notify.relatedadded'     => 'A new related task has been added to the following task:',
'relatedis'               => 'The related task is',
'assignedtoyou'           => 'You have been assigned the following task:',
'takenownership'          => 'has taken ownership of the following task:',
'requiresaction'          => 'The following task requires action by a Project Manager:',
'requiresactionnotify'    => 'Task requires action by a Project Manager',
'pmdeny'                  => 'A Project Manager has denied the request pending for the following task:',
'pmdenynotify'            => 'A Project Manager has denied the request',
'fileaddedtoo'            => 'One or more files have been attached.',
'taskwatching'            => 'The following task you are watching',
'isdepfor'                => 'is a new dependency for',
'denialreason'            => 'Reason for denial',
'taskchanged'             => 'The following task has been changed.  The changes are listed below.  For full information about what has changed, visit the URL and click the History tab.',
'useraddedtoassignees'    => 'A user has added themself to the list of users assigned to this task.',
'removeddepis'            => 'The removed dependency is',
'isnodepfor'              => 'is no dependency anymore for',
'usergroups'              => 'User Groups',
'pmtoolbox'               => 'Project Manager\'s Toolbox',
'groupmanage'             => 'Group Management',
'pendingrequests'         => 'Pending Requests',
'reasongiven'             => 'Reason given',
'nopendingreq'            => 'There are no pending Project Manager requests.',
'givereason'              => 'Give a reason',
'catlisted'               => 'Category List Editor',
'oslisted'                => 'Operating System List Editor',
'verlisted'               => 'Version List Editor',
'tasktypeed'              => 'Task Types List Editor',
'resed'                   => 'Resolutions List Editor',
'deny'                    => 'Deny',
'notifiedwhen'            => 'Notified when',
'onlynewtasks'            => 'New tasks are opened',
'allevents'               => 'Any event occurs in any task',
'feeds'                   => 'Feeds',
'feeddescription'         => 'Feed description',
'feedimgurl'              => 'Feed image URL (leave blank for no image)',
'notifysubject'           => 'Subject for notifications',
'notifysubjectinfo'       => '(%p = project title, %s = task summary, %t = task id, %a = action, %u = user)',
'priority6'               => 'Very High',
'priority5'               => 'High',
'priority4'               => 'Medium',
'priority3'               => 'Low',
'priority2'               => 'Very Low',
'priority1'               => 'Defer',
'sendcode'                => 'Send code!',
'entercode'               => 'Enter the confirmation code you received in your notification message.  Also enter your desired account password.',
'confirmationcode'        => 'Confirmation Code',
'registererror'           => 'Ensure that you have filled in all required fields, and that you have entered correct details for your desired notification type.',
'validusername'           => '(only alphanumeric chars and - _ . are allowed)',
'validemail'              => '(use ; to seperate multiple email addresses)',
'emailtakenbulk'          => 'Email Address Already Taken',
'emailtaken'              => 'That email address or Jabber-ID is already taken. You will need to choose another one.',
'note'                    => '<strong>Note:</strong>  You will be sent a confirmation code before your account is created.  The code will be sent using your preferred notification method, above.<br />If you enter fake details, you will <strong>not receive your code</strong>.',
'changelog'               => 'Changelog',
'changeloggen'            => 'Changelog Generator',
'listfrom'                => 'List changelog entries from',
'to'                      => 'to',
'oldestfirst'             => 'Oldest first',
'recentfirst'             => 'Most recent first',
'severityrep'             => 'Severity Report',
'totalopen'               => 'Total open tasks',
'age'                     => 'Age',
'agerep'                  => 'Age Report',
'eventsrep'               => 'Events Report',
'events'                  => 'Events',
'Tasks'                   => 'Tasks',
'opened'                  => 'Opened',
'edited'                  => 'Edited',
'assigned'                => 'Assigned',
'within'                  => 'Within',
'pastday'                 => 'The past day',
'pastweek'                => 'The past week',
'pastmonth'               => 'The past month',
'pastyear'                => 'The past year',
'nolimit'                 => 'No limit',
'from'                    => 'From',
'duein'                   => 'Due in',
'selectfromdate'          => 'Select From Date',
'selecttodate'            => 'Select To Date',
'showvoters'              => 'Show/hide voters',
'roadmap'                 => 'Roadmap',
'roadmapfor'              => 'Roadmap for version',
'tasks'                   => 'tasks',
'completed'               => 'completed.',
'opentasks'               => 'open tasks',
'of'                      => '% of',
'severity5'               => 'Critical',
'severity4'               => 'High',
'severity3'               => 'Medium',
'severity2'               => 'Low',
'severity1'               => 'Very Low',
'Redirect'                => 'Redirect',
'redirectmsg'             => 'If your browser does not support meta redirection please click %sHERE%s to be redirected',
'allowclosedcomments'     => 'Allow comments on closed tasks',
'comment'                 => 'Comment',
'editowncomments'         => 'Edit own comments',
'reopened'                => 'Reopened',
'loading'                 => 'Loading...',
'notifyown'               => 'Notify for own changes',
'youremail'               => 'Your e-mail address',
'thankyouforbug'          => 'Thank you for reporting your problem. You can see the task and observe its progress any time using the following URL:',
'anonuser'                => 'Anonymous user',
'conflict'                => 'Conflict',
'file'                    => 'File',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Size',
'projectgroup'            => 'Project Group',
'profile'                 => 'Profile:',
'viewprofile'             => 'View Profile',
'regdate'                 => 'Registered since',
'tasksopened'             => 'Tasks opened',
'replyto'                 => 'Reply to',
'notifytypes'             => 'Notification types',
'pm.taskchanged'          => 'Task changed',
'pm.taskreopened'         => 'Task reopened',
'pm.depadded'             => 'Dependency added',
'pm.depremoved'           => 'Dependency removed',
'pmrequest'               => 'PM request',
'pmrequestdenied'         => 'PM request denied',
'newassignee'             => 'New assignee',
'revdepadded'             => 'Reverse dependency added',
'revdepaddedremoved'      => 'Reverse dependency removed',
'assigneeadded'           => 'Assignee added',
'addusergroup'            => 'Add user to this group',
'groupmembers'            => 'Group Members',
'deleteuser'              => 'Delete this user',
'userdeleted'             => 'User deleted',
'autoassign'              => 'Auto-assign a task to the category owner',
'ssl'                     => 'SSL',
'updatewrong'             => 'You have the update check feature enabled, but an error ocurred while trying
                             to contact the update server, either your host do not allow outbound connections
                             or the error was caused by a network problem.
                             Please visit the flyspray website to make sure you are running the latest version.',
'deleteproject'           => 'Delete this project and move contents to',
'projectdeleted'          => 'Project deleted successfully',
'feedforall'              => 'Feed for all projects',
'usercreated'             => 'User created',
'userdeleted'             => 'User deleted',
'created'                 => 'Created',
'deleted'                 => 'Deleted',
'userid'                  => 'User ID',
'editassignments'         => 'Edit assignments',
'preview'                 => 'Preview',
'anyprogress'             => 'Any Progress',
'tasksrelated'            => 'Tasks related to this task',
'duplicatetasks'          => 'Duplicate tasks of this task',
'databasemodfailed'       => 'Database modification failed. Possible reasons are insufficient permissions.',
'frequency'               => 'Frequency',
'newuserregistered'       => 'A new user has registered at your Flyspray installation. The user details are as follows:',
'newuserregisterednotify' => 'A new user has registered',
'notify_registration'     => 'Notify admins on new user registration',
'textversion'             => 'Text Version',
'onlyprimary'             => 'Tasks not blocking other tasks',
'onlyblocker'             => 'Tasks blocking other tasks',
'blockerornoblocker'      => 'Blocker or nonblocker, selecting both filter options doesn\'t make sense.',
'switch'                  => 'Switch',
'max'                     => 'max.',
'dates'                   => 'Dates',
'selectduedatefrom'       => 'Due from',
'selectduedateto'         => 'to',
'selectsincedatefrom'     => 'Changed from',
'selectsincedateto'       => 'to',
'selectdate'              => 'Select Date',
'selectopenedfrom'        => 'Opened from',
'selectopenedto'          => 'to',
'selectclosedfrom'        => 'Closed from',
'selectclosedto'          => 'to',
'startat'                 => 'Start at',
'hasattachment'           => 'Has attachment',
'private'                 => 'Private',
'watching'                => 'Watching',
'alreadyvotedthistask'    => 'you voted for this task',
'alreadyvotedthisday'     => 'already voted today',
'visibility'              => 'Visibility',
'public'                  => 'Public',
'leaveemptyauto'          => 'Leave password fields empty if you want the password to be automatically generated.',
'novalidemail'            => 'You did not enter a valid email address.',
'novalidjabber'           => 'You did not enter a valid Jabber address.',
'missingrequired'         => 'You did not fill in all required fields.',
'entervalidusername'      => 'Please enter a valid user and real name.',
'couldnotaddusernotif'    => 'Could not add this user to the notification list.',
'defaulttask'             => 'Default task description',
'all'                     => 'all',
'events.useraddedtoassignees' => 'User added to assignees',
'eventlog'                => 'Event log',
'assignmentchanged'       => 'Assignment changed',
'detailedinfo'            => 'Detailed information',
'All'                     => 'All',
'tasksireported'          => 'Tasks I reported',
'recentlyopened'          => 'Recently opened',
'stats'                   => 'Stats',
'totaltasks'              => 'total tasks',
'mostwanted'              => 'Most wanted tasks',
'defaultentry'            => 'Default entry page',
'toplevel'                => 'Top level view',
'overview'                => 'Overview',
'error#'                  => 'Error #',
'error1'                  => 'You don\'t have sufficient permissions to view this attachment.',
'error3'                  => 'Repeated action, redirecting to main page.',
'error4'                  => 'You don\'t have administrative rights.',
'error5'                  => 'That user does not exist on this Flyspray installation.',
'error6'                  => 'Invalid admin area.',
'error7'                  => 'Login failed, password incorrect!',
'error71'                 => 'Account locked for %d minutes due to too many failed login attempts!',
'error8'                  => 'You didn\'t enter both a username and password.',
'error9'                  => 'Task does not exist or no permissions to view this task.',
'error10'                 => 'This task does not exist.',
'error101'                => 'You have no permission to view this task.',
'error102'                => 'You have no permission to view this task, logging in might help.',
'error11'                 => 'No permission to edit this comment.',
'error12'                 => 'No valid magic key! Are you sure that you got that from your notification message?',
'error13'                 => 'Anonymous users don\'t have a profile.',
'error14'                 => 'You don\'t have sufficient permissions to create a new group.',
'error15'                 => 'You don\'t have sufficient permissions to open a task.',
'error16'                 => 'You are not a project manager.',
'error17'                 => 'Invalid PM area.',
'error18'                 => 'Invalid magic URL.',
'error19'                 => 'That user does not exist on this Flyspray installation.',
'error20'                 => 'Invalid database modification.',
'error21'                 => 'One or more emails could not be sent. Check your config.',
'error22'                 => 'No new user registration allowed.',
'error23'                 => 'User or group not enabled for login.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Roadmap only available for a specific project.',
'error26'                 => 'Unsupported oauth provider.',
'error27'                 => 'Unable to login in. Authorize us to view your email address.',
'error28'                 => 'You have no permission to access this area.',
'done'                    => 'done',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Project couldn\'t be deleted.',
'GMT'                     => 'GMT',
'timezone'                => 'Time zone',
'accept'                  => 'Accept',
'reasonfordeinal'         => 'Reason for denial',
'pruneclosedlinks'        => 'Prune Closed Links',
'pruneclosedtasks'        => 'Prune Closed Tasks',
'pagegenerated'           => 'Page and image generated in %d seconds.',
'pruninglevel'            => 'Pruning Level',
'lastuser'                => 'The last user cannot be deleted.',
'allprivate'              => 'All projects are private.',
'deletegroup'             => 'Delete this group and move users to',
'parent'                  => 'Parent',
'ordertip'                => 'The order these items will appear in the list',
'showtip'                 => 'Show this item in the list',
'deletetip'               => 'Delete this item from the list',
'del'                     => 'del',
'request1'                => 'A task closure has been requested.',
'request2'                => 'A request to reopen the task has been made.',
'allpriorities'           => 'All Priorities',
'noroadmap'               => 'No roadmap available (no project specific "future" versions exist).',
'expand'                  => 'Expand',
'collapse'                => 'Collapse',
'expandall'               => 'Expand all',
'collapseall'             => 'Collapse all',
'minpwsize'               => 'Minimum password size is 5 chars',
'passwordtoosmall'        => 'Password size too small.',
'accountwaslocked'        => 'Your account had been locked due to too many failed login attempts.',
'failedattempts'          => 'There were %d failed login attempts.',
'groupnotexist'           => 'Selected group does not exist in this project.',
'searchindetails'         => 'Search details',
'showasassignees'         => 'Show as assignees',
'find'                    => 'Find',
'tls'                     => 'TLS',
'isadmin'                 => 'Is admin',
'addvotes'                => 'Add votes',
'removevote'              => 'Remove vote',
'voteremoved'             => 'Your vote has been removed',
'voteremovefailed'        => 'Your vote could not be removed at this time.',
'novotes'                 => 'You currently have no votes on any task.',
'connectedtasks'          => 'Connected tasks:',
'taskdependencies'        => 'Task dependencies',
'viewgraph'               => 'view graph',
'notaskdependencies'      => 'This task does not depend on any other tasks.',
'dependson'               => 'Depends on',
'blocks'                  => 'Blocks',
'newdependency'           => 'New dependency:',
'nouserstoadd'            => 'No Users To Add. Please ensure Name, Username, and Email are defined for each user.',
'dispintro'               => 'Display main introductory message',
'mainmessage'             => 'Main introductory message',
/* note only the English version for 'dispintro' is supported
 * other languages should also be taken cared of in the future*/

'setsupertask'            => 'Set Super-Task ID:',
'supertaskmodified'       => 'Super-Task ID has been modified',
'set'                     => 'Set',
'supertask'               => 'Super-Task',
'setparent'               => 'Set parent task id for this task',
'selfsupertasknotallowed' => 'Super-Task ID cannot be same as self Task ID',
'quickaction'             => 'Quick Actions',
'updateselectedtasks'     => 'Update Selected Tasks',
'notspecified'            => 'Not Specified',
'editselectedtasks'       => 'Edit Selected Tasks',
'information'             => 'Information',
'taskclosedisabled'       => 'Close Task is currently disabled as the following dependant tasks are still open:-',
'daysleft'                => 'days left',
'dayoverdue'              => 'days overdue',
'duetoday'                => 'Due today.',
'daysbeforealert'         => 'Days before alert',
'associatedsubtask'       => 'Successfully associated subtask #FS%d',
'associatesubtask'        => 'Associate sub task ID with this task',
'subtaskid'               => 'Sub task ID',
'subtaskalreadyhasparent' => 'The sub task you entered already has a parent task, please clear this before associating.',
'subtaskisparent'         => 'The sub task you entered is the parent task of this task. Sub task not associated.',
'subtasknotexist'         => 'The sub task you entered does not exist.',
'subtaskremovedmsg'       => 'The sub task has successfully been removed',
'subtaskadded'            => 'Sub task added',
'subtaskremoved'          => 'Sub task removed',
'addnewsubtask'           => 'Add new sub task',
'hidesubtasks'            => 'Hide SubTasks',
'voteforthistask'         => 'Vote for this task',
'watchthistask'           => 'Watch this task',
'privatethistask'         => 'Make this task private',
'adddependenttask'        => 'Associate dependent task',
'associatetaskid'         => 'Sub task id',
'parenttaskid'            => 'Parent task id',
'invalidsupertaskid'      => 'Parent task id is not valid.',
'supertaskadded'          => 'Supertask added',
'supertaskremoved'        => 'Supertask removed',
'effort'                  => 'Effort',
'efforttracking'          => 'Effort Tracking',
'useeffort'               => 'Project Uses Effort Tracking',
'estimatedeffort'         => 'Estimated Effort',
'totalestimatedeffort'    => 'Total estimated effort',
'currenteffortdone'       => 'Current effort done',
'starteffort'             => 'Start Tracking',
'endeffort'               => 'Stop Tracking',
'cleareffort'             => 'Clear Tracking',
'addeffort'               => 'Add Effort',
'manualeffort'            => 'Manually Add Effort (H:M)',
'efforttrackingstarted'   => 'Effort Tracking Commenced for this task.',
'efforttrackingnotstarted'=> 'Unable to start tracking on an issue that is already being tracked',
'efforttrackingstopped'   => 'Effort Tracking Ended for this task.',
'efforttrackingcancelled' => 'Effort Tracking Cancelled for this task.',
'efforttrackingadded'     => 'Manual effort recorded for task.',
'trackinginprogress'      => 'Tracking in Progress',
'viewestimatedeffort'     => 'Can View Effort Tracking',
'viewcurrenteffortdone'   => 'Can View Current Effort done',
'trackeffort'             => 'Can Track Effort',
'invalideffort'           => 'The effort entered is invalid. Must be a number',
'showpass'                => 'Show Password',
'chooseafile'             => 'Please choose a file!',
'incorrectfiletype'       => 'Incorrect file type. Allowed: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'No password to request. You registered through %s',
'addmultipletasks'        => 'Add multiple tasks',
'pendingnewuserrequest'   => 'Pending New User Request',
'adminrequestswaiting'    => 'Admin requests waiting',
'clicktoedit'             => 'Click on each field to quick edit',
'confirmedit'             => 'confirm',
'canceledit'              => 'cancel',
'regapprovedbyadmin'      => 'Registrations approved by admins (disable confirmation code)',
'activity'                => 'Activity',
'myactivity'              => 'My activity',
'emailverificationwrong'  => 'The email confirmation doesn\'t match the given email address',
'verifyemailaddress'      => 'Confirm email address',
'hideemails'              => 'Hide users email addresses',
'hidemyemail'             => 'Hide my email address',
'exporttasklist'          => 'Export Tasklist',
'onedecimal'              => 'one decimal',
'manday'                  => 'man-day',
'mandays'                 => 'man-days',
'mandayabbrev'            => 'md',
'hourspermanday'          => 'Hours per one manday (HH:mm)',
'itemexists'              => 'Item %s already exists in database.',
'categoryitemexists'      => 'Item %s already exists under category %s in database.',
'pageswelcomemsg'         => 'Pages where to show main intro message',
'pagesintromsg'           => 'Pages where to show intro message',
'activeoauths'            => 'Active Oauth providers',
'onlyoauthreg'            => 'Only allow Oauths registrations',
'estimatedeffortformat'   => 'Estimated effort display format',
'currenteffortdoneformat' => 'Current effort done display format',
'minute'                  => 'minute',
'minutes'                 => 'minutes',
'minuteplural'            => 'minutes',
'minutesingular'          => 'minute',
'minuteabbrev'            => 'min',
'hourplural'              => 'hours',
'hoursingular'            => 'hour',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'Estimated effort for open tasks',
'currenteffortdoneopen'   => 'Current effort spent in open tasks',
'signinwith'              => 'Sign in with %s',
'canviewroadmap'          => 'Can view roadmap',
'enableavatars'           => 'Enable avatars',
'maxavatarsize'           => 'Max avatar size in pixels',
'taskhassubtask'          => 'This task has the following sub-task',
'taskhassubtasks'         => 'This task has the following sub-tasks',
'translations'            => 'Translations',
'translate'               => 'Translate',
'taskdescription'         => 'Task Description',
'notaskdescription'       => 'no task description',
'pleaseselect'            => 'Please select',
'closeselectedtasks'      => 'Close selected tasks',
'closetasks'              => 'close tasks',
'hintforbulkimport'       => '<b>Tips for bulk importing:</b>
  <ol>
  <li>Copy and paste from an excel spreadsheet or CSV by pasting one entire column.</li>
  <li>Currently you can only paste Summary and Details.</li>
  <li>There are suggestions when you assign to someone, and to no-one if there is no matched name.</li>
  </ol>',
'taskissubtaskof'         => 'This task is a sub task of',
'applyfirstline'          => 'Apply first line',
'addmorerows'             => 'Add more rows',
'addtasks'                => 'Add tasks',
'massopsdisabled'         => 'Sorry, bulk editing is currently disabled for Flyspray 1.0. We plan to finish implementation for a later release of Flyspray. You can enable them in source code again at your own risk, but read the comments there before doing it.',
'viewroadmap'             => 'Can view roadmap',
'nosuicide'               => 'Dear user, my program doesn\'t allow you to destroy your access to Flyspray by disabling your own account or switching your own group. The empathic brother of HAL9000',
'movingtodifferentproject' => 'Moving a task that has either a parent or subtasks to a different project is not allowed. You must break the connection between them first.',
'musthavesameproject'     => 'Parent and subtask must belong to the same project.',
'defaultorderby'          => 'Order tasklist by default by',
'defaultorderby2'         => 'then by',
'viewowntasks'            => 'View own tasks',
'viewgroupstasks'         => 'View groups tasks',
'urlrewriting'            => 'Url rewriting',
'enablehtaccess'          => 'Please enable your .htaccess file at Flyspray root before turning url rewriting on',
'nomodrewrite'            => 'Mod rewrite doesn\'t seem to be available on this server, sorry but I can\'t turn url rewriting on',
'on'                      => 'On',
'off'                     => 'Off',
'defaultorderbydirection' => 'Default order by direction',
'ascending'               => 'Ascending',
'descending'              => 'Descending',
'myassignedtasks'         => 'My assigned tasks',
'commentedon'             => 'commented on',
'maxvoteperday'           => 'Maximum votes per day',
'votesperproject'         => 'User\'s limit of votes per project',
'votelimitreached'        => 'You reached your vote limit for this project. See your profile page for which tasks you currently vote. There you can also take back votes. So we can see what tasks are most important for you. Solved tasks get your vote back into your available voting limit.',
'myvotes'                 => 'My Votes',
'tag'                     => 'Tag',
'tags'                    => 'Tags',
'tagsavail'               => 'Available tags',
'tagsinfo'                => 'Free tagging/labeling of tasks in Flyspray: Separate tags by ; They aren\'t used yet for searching, sorting or filtering.',
'novalues'                => 'no entries',
'youhaveregistered'       => 'You have registered at Flyspray. Your details are as follows:',
'youhaveregisterednotify' => 'Your registration at Flyspray has been accepted by Administrators.',
'usedintasks'             => 'Usage',
'freetagging'             => 'allow user defined tags',
'keyboardshortcuts'       => 'Keyboard shortcuts',
'testmailsettings'        => 'Test currently active email settings',
'test'                    => 'Test',
'testmailsettingsnotice'  => 'And also check if you received the test email in the mail account of the current user (see \'myprofile\'-page)',
'invalidinput'            => 'Oh, there are some incompatible properties sent or missing.',
'invalidprogress'         => 'Please choose a valid progress value.',
'invalidpriority'         => 'Please choose a valid priority value.',
'invalidseverity'         => 'Please choose a valid severity value.',
'invalidstatus'           => 'Please choose a valid task status.',
'invalidtasktype'         => 'Please choose a valid task type.',
'invalidcategory'         => 'Please choose a valid category.',
'invalidreportedversion'  => 'Please choose a valid report version.',
'invaliddueversion'       => 'Please choose a valid due version.',
'invalidos'               => 'Please choose a valid operating system.',
'invalidtags'             => 'Please choose only allowed tags.',
'invalidassignees'        => 'Please choose only allowed assignees.',
'invalidtargetproject'    => 'Please choose a valid target project.',
'customize'               => 'customize',
'hidesubs'                => 'hide subtasks',
'hideprivate'             => 'hide private tasks',
'hideclosed'              => 'hide closed tasks',
'globaloptions'           => 'global options',
'currentproject'          => 'current project',
'targetproject'           => 'target project',
'availablekeybshortcuts'  => 'Available keyboard shortcuts',
'logindialoglogout'       => 'Login Dialog / Logout',
'focustaskidsearch'       => 'focus taskid search',
'openselectedtask'        => 'open selected task',
'movecursorup'            => 'move cursor up',
'movecursordown'          => 'move cursor down',
'taskdetails'             => 'Task Details',
'taskediting'             => 'Task Editing',
'savetask'                => 'save task',
'generalintegration'      => 'General Integration Strings',
'generalintegrationdesc'  => 'This content is put by default theme inside the body-tag, below main content and before footer tag. Where it really appears on screen depends on CSS. Use a custom_*.css for that.',
'footerintegration'       => 'Footer Integration Strings',
'footerintegrationdesc'   => 'This content is put by default theme into the logical footer area by default. Where it really appears on screen depends on CSS. Use a custom_*.css for that.',
'editorbold'              => 'B',
'editorboldhint'          => 'bold',
'editoritalic'            => 'I',
'editoritalichint'        => 'italic',
'editorunderline'         => 'U',
'editorunderlinehint'     => 'underline',
'editorstrikethrough'     => 'S',
'editorstrikethroughhint' => 'strikethrough',
'editorh1'                => 'H1 level 1 heading, prefer not to use as it is used for page title',
'editorh2'                => 'H2 level 2 heading, prefer not to use as it is used for task title',
'editorh3'                => 'H3 level 3 heading',
'editorh4'                => 'H4 level 4 heading',
'editorh5'                => 'H5 level 5 heading',
'editororderedli'         => 'ordered list item',
'editorunorderedli'       => 'unordered list item',
'editorhorizontalrule'    => 'horizontal rule',
'editorlink'              => 'link',
'editorcode'              => 'code section',
'captchaerror'            => 'CAPTCHA not solved. Please try again.',
'registercaptcha'         => 'Please solve the CAPTCHA.',
'regcaptcha'              => 'Show a CAPTCHA for new user registration.',
'invalidsecurimage'       => 'Invalid CAPTCHA',
'invalidrecaptcha'        => 'Invalid Google reCAPTCHA',
'antispam'                => 'Spam Prevention',
'antispamprefsinfo'       => 'Settings for countermeasures against spambots. Currently Securimage and Google reCAPTCHA are used for new user registration.',
'securimageprefsinfo'     => 'A classic CAPTCHA riddle where users must recognize a text sequence to prove to be human.',
'securimageenable'        => 'Enable Securimage',
'recaptchaprefsinfo'      => 'Google reCAPTCHA is an alternative to a classic CAPTCHA.
Google decides on collected data and user behavior and maybe additional image recognition riddles if you are human or bot.
To use this you need an Google Account and configure reCAPTCHA for your domain at https://www.google.com/recaptcha and insert "sitekey" and "secret" of that configuration.
Depending on the configuration at Google - "reCAPTCHA V2" or "Invisible reCAPTCHA" - you maybe must inform your potential users about "Data protection".',
'recaptchaenable'         => 'Enable Google reCAPTCHA',
'adminchecks'             => 'Checks',
'adminchecksinfo'         => 'Info and checks for your current installation',
'repeatpassword'          => 'repeat password',
'repeatemailaddress'      => 'repeat email address',
'tooltipshorttasktitle'   => 'Write a title that summarizes the problem and makes it understandable at a glance',
'lastlogin'               => 'Last Login',
'relnofollow'             => 'add rel="nofollow" to links in task details and comments',
'relnofollowdescription'  => 'Tells search engines to not use user generated links for page ranking. Used to reduce the motivation of linkspammers.',
'usetags'                 => 'Enable tags',
'usegantt'                => 'Enable Gantt view',
'usekanban'               => 'Enable Kanban view',
'gantt'                   => 'Gantt view',
'kanban'                  => 'Kanban view',
'accountfilter'           => 'User filter',
'accountstatus'           => 'Account status',
'showaccountsall'         => 'All',
'showaccountsenabled'     => 'Enabled',
'showaccountsdisabled'    => 'Disabled',
);
?>
