<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit49d197a7027db7f833355cecaa97ef5e
{
    public static $files = array (
        'bf9f5270ae66ac6fa0290b4bf47867b7' => __DIR__ . '/..' . '/adodb/adodb-php/adodb.inc.php',
        '2cffec82183ee1cea088009cef9a6fc3' => __DIR__ . '/..' . '/ezyang/htmlpurifier/library/HTMLPurifier.composer.php',
        '2c102faa651ef8ea5874edb585946bce' => __DIR__ . '/..' . '/swiftmailer/swiftmailer/lib/swift_required.php',
        'd1c03ca96ded033379de1f19323a3063' => __DIR__ . '/../..' . '/includes/utf8.inc.php',
    );

    public static $prefixLengthsPsr4 = array (
        'S' => 
        array (
            'Symfony\\Component\\EventDispatcher\\' => 34,
        ),
        'L' => 
        array (
            'League\\OAuth2\\Client\\' => 21,
        ),
        'F' => 
        array (
            'Flyspray\\' => 9,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Symfony\\Component\\EventDispatcher\\' => 
        array (
            0 => __DIR__ . '/..' . '/symfony/event-dispatcher',
        ),
        'League\\OAuth2\\Client\\' => 
        array (
            0 => __DIR__ . '/..' . '/league/oauth2-client/src',
        ),
        'Flyspray\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src',
        ),
    );

    public static $prefixesPsr0 = array (
        'H' => 
        array (
            'HTMLPurifier' => 
            array (
                0 => __DIR__ . '/..' . '/ezyang/htmlpurifier/library',
            ),
        ),
        'G' => 
        array (
            'Guzzle\\Tests' => 
            array (
                0 => __DIR__ . '/..' . '/guzzle/guzzle/tests',
            ),
            'Guzzle' => 
            array (
                0 => __DIR__ . '/..' . '/guzzle/guzzle/src',
            ),
        ),
    );

    public static $classMap = array (
        'Backend' => __DIR__ . '/../..' . '/includes/class.backend.php',
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'ContentSecurityPolicy' => __DIR__ . '/../..' . '/includes/class.csp.php',
        'Cookie' => __DIR__ . '/../..' . '/includes/class.gpc.php',
        'Database' => __DIR__ . '/../..' . '/includes/class.database.php',
        'FSTpl' => __DIR__ . '/../..' . '/includes/class.tpl.php',
        'Filters' => __DIR__ . '/../..' . '/includes/class.gpc.php',
        'FlySprayI18N' => __DIR__ . '/../..' . '/includes/i18n.inc.php',
        'Flyspray' => __DIR__ . '/../..' . '/includes/class.flyspray.php',
        'Get' => __DIR__ . '/../..' . '/includes/class.gpc.php',
        'GithubProvider' => __DIR__ . '/../..' . '/includes/GithubProvider.php',
        'Jabber' => __DIR__ . '/../..' . '/includes/class.jabber2.php',
        'Notifications' => __DIR__ . '/../..' . '/includes/class.notify.php',
        'Post' => __DIR__ . '/../..' . '/includes/class.gpc.php',
        'Project' => __DIR__ . '/../..' . '/includes/class.project.php',
        'Req' => __DIR__ . '/../..' . '/includes/class.gpc.php',
        'Securimage' => __DIR__ . '/..' . '/dapphp/securimage/securimage.php',
        'Securimage_Color' => __DIR__ . '/..' . '/dapphp/securimage/securimage.php',
        'TextFormatter' => __DIR__ . '/../..' . '/includes/class.tpl.php',
        'Tpl' => __DIR__ . '/../..' . '/includes/class.tpl.php',
        'Url' => __DIR__ . '/../..' . '/includes/class.tpl.php',
        'User' => __DIR__ . '/../..' . '/includes/class.user.php',
        'effort' => __DIR__ . '/../..' . '/includes/class.effort.php',
        'recaptcha' => __DIR__ . '/../..' . '/includes/class.recaptcha.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit49d197a7027db7f833355cecaa97ef5e::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit49d197a7027db7f833355cecaa97ef5e::$prefixDirsPsr4;
            $loader->prefixesPsr0 = ComposerStaticInit49d197a7027db7f833355cecaa97ef5e::$prefixesPsr0;
            $loader->classMap = ComposerStaticInit49d197a7027db7f833355cecaa97ef5e::$classMap;

        }, null, ClassLoader::class);
    }
}
