<?php
$translation=array(
'needcomposer'       => '请先通过 Composer 来安装一些依赖库。',
'installcomposer'    => '运行 Composer',
'upgrade'            => '升级',
'adminemail'         => '管理员邮箱',
'adminusername'      => '管理员帐户',
'adminpassword'      => '管理员密码',
'progress'           => '安装进度',
'documents'          => '文档',
'preinstallcheck'    => '运行环境检查',
'databasesetup'      => '数据库设置',
'administration'     => '管理员设置',
'install'            => '安装',
'libcheck'           => 'PHP和数据库',
'libchecktext'       => '在开始设置前，必须安装好合适的PHP版本，并且<strong>最少</strong>要支持一种数据库。',
'recsettings'        => '推荐设置项',
'recsettingstext1'   => '为了使Flyspray获得更好的兼容性，建议参考此处的 PHP 配置。',
'recsettingstext2'   => '当然，即使你的PHP环境配置和此处不同，Flyspray 仍然可以正常工作。',
'dirandfileperms'    => '目录和文件权限',
'proceedtodbsetup'   => '前往数据库设置',
'library'            => '库',
'status'             => '状态',
'database'           => '数据库',
'recommended'        => '推荐',
'actual'             => '实际',
'yes'                => '是',
'no'                 => '否',
'databaseconfiguration'=> '数据库连接设置，版本:',
'proceedtoadmin'=> '前往管理员设置',
'databasehostname'=> '数据库主机',
'databasehostnamehint'  => '请输入<strong>数据库主机名</strong>，通常可能是 "localhost" 或者 IP 地址。',
'databasetype'          => '数据库类型',
'databasename'          => '数据库名',
'databaseusername'      => '用户名',
'databasepassword'      => '密码',
'tableprefix'           => '表前缀',
'next'                  => '下一步',
'showpassword'            => '显示密码',
'lgpllicense'             => 'LGPL协议',
'installationguide'       => '安装手册',
'developermanual'         => '开发者手册',
'writeable'               => '可写',
'unwriteable'             => '不可写',
);
?>
