<?php
//
// This file is auto generated with .langedit.php
// Characters are UTF-8 encoded
//
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
//
// Furthermore, nothing else than the language array is saved
// when using the .langedit.php editor!
//
$translation = array(
'edituser'                => 'Потребител',
'username'                => 'Потребителско име',
'realname'                => 'Истинско име',
'emailaddress'            => 'Е-мейл адрес',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Тип на известяване',
'group'                   => 'Група',
'accountenabled'          => 'Акаунтът е активиран',
'updatedetails'           => 'Обновяване',
'setglobally'             => 'Това предпочитание е установено глобално.',
'usergroupmanage'         => 'Управление на потребители и групи',
'newuser'                 => 'Регистриране на нов потребител',
'newgroup'                => 'Създаване на нова група',
'yes'                     => 'Да',
'no'                      => 'Не',
'editgroup'               => 'Редактиране на група',
'groupname'               => 'Име на групата',
'description'             => 'Описание',
'admin'                   => 'Административна група',
'opennewtasks'            => 'Отваряне на нови задачи',
'modifytasks'             => 'Редактиране на съществуващи задачи',
'addcomments'             => 'Добавяне на коментари',
'attachfiles'             => 'Прикачане на файлове',
'vote'                    => 'Гласуване',
'groupenabled'            => 'Членовете могат да влизат в системата',
'groupopen'               => 'Членовете могат да влизат в системата',
'tasktypelist'            => 'Списък на типовете задачи',
'categorylist'            => 'Списък на категориите',
'oslist'                  => 'Списък на операционните системи',
'resolutionlist'          => 'Списък на резолюциите',
'versionlist'             => 'Списък на версиите',
'severitylist'            => 'Списък на степените на трудност',
'listnote'                => 'Забележка: Изключването на поле "Показване" може да промени някои задачи в режим на редактиране. Промяната в полето "Име" ще се отрази във всички задачи, които използват промененото име. Някои от полетата са забранени за изтриване. Това е така или за коректното функциониране на системата или пък те се използват в задачите.',
'name'                    => 'Име',
'order'                   => 'Ред',
'back'                    => 'Назад',
'text'                    => 'Текст',
'highlight'               => 'Осветяване',
'show'                    => 'Показване',
'owner'                   => 'Собственик',
'selectowner'             => 'Избери собственик',
'update'                  => 'Обновяване',
'addnew'                  => 'Добавяне',
'flysprayprefs'           => 'Flyspray конфигурация',
'projecttitle'            => 'Име на проекта',
'baseurl'                 => 'Базов URL за тази инсталация',
'replyaddress'            => 'Обратен е-майл адрес за известяване',
'themestyle'              => 'Тема / стил',
'language'                => 'Език',
'anonview'                => 'Разрешаване на анонимните потребители да виждат задачите',
'allowanon'               => 'Разрешаване на анонимните потребители да отварят нови задачи',
'never'                   => 'Никога',
'anonymously'             => 'Анонимно',
'afterregister'           => 'Само след регистриране',
'spamproof'               => 'Разрешаване на код за потвърждение за регистрации на нови потребители',
'anongroup'               => 'Група за новите потребители',
'groupassigned'           => 'На членовете на тези групи могат да бъдат назначавани задачи',
'forcenotify'             => 'Известията за задачи да бъдат като',
'neversend'               => 'Да не се изпращат',
'userchoose'              => 'Всеки потребител да избира',
'email'                   => 'Е-майл',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Собственик на категорията по подразбиране',
'noone'                   => 'Никой',
'jabbernotify'            => 'Jabber известяване',
'jabberserver'            => 'Сървър',
'jabberport'              => 'Порт',
'jabberuser'              => 'Потребителско име',
'jabberpass'              => 'Потребителска парола',
'saveoptions'             => 'Запис на конфигурацията',
'editcomment'             => 'Редактиране на коментар',
'commentby'               => 'Коментар от',
'saveeditedcomment'       => 'Запис на редактирания коментар',
'projectprefs'            => 'Опции на проекта',
'pagetitle'               => 'Заглавие на страницата',
'defaultproject'          => 'Проект по подразбиране',
'projectlists'            => 'Списък от проекти',
'showlogo'                => 'Показване на лого изображение',
'intromessage'            => 'Уводно съобщение',
'isactive'                => 'Проектът е активен',
'createproject'           => 'Създаване на нов проект',
'nopermission'            => 'Нямате разрешение да използвате тази страница.',
'listordertip'            => 'Ред, в който елементите ще се появяват в списъка',
'listshowtip'             => 'Показване на този елемент в списъка',
'categoryownertip'        => 'Този потребител ще получава известия, когато бъде отворена задача в тази категория',
'categoryparenttip'       => 'Родителската категория, под която ще бъде тази нова категория',
'notsubcategory'          => 'Никоя (категория на най-горно ниво)',
'showinlineimages'        => 'Показване на прикачените изображения в текста',
'dateformat'              => 'Формат на датата',
'dateformat_extended'     => 'Подробен формат на датата',
'cache_feeds'             => 'Кеширане на емисиите',
'no_cache'                => 'Без кеширане',
'cache_disk'              => 'Кеширане на диск',
'cache_db'                => 'Кеширане в база данни',
'subcategoryof'           => 'Под-категория на',
'visiblecolumns'          => 'Колони, показвани в списъка със задачи',
'tense'                   => 'Време',
'listtensetip'            => 'Минало, Настояще или Бъдеще',
'past'                    => 'Минало',
'present'                 => 'Настояще',
'future'                  => 'Бъдеще',
'oldpass'                 => 'Стара парола',
'nooldpass'               => 'Не е била установена стара парола',
'oldpasswrong'            => 'Неправилна стара парола',
'changepass'              => 'Смени паролата',
'confirmpass'             => 'Потвърждение на паролата',
'projectmanager'          => 'Проект Менажер',
'viewtasks'               => 'Разглеждане на задачи',
'modifyowntasks'          => 'Редактиране на собствените задачи',
'modifyalltasks'          => 'Редактиране на задачи на други потребители',
'viewcomments'            => 'Разглеждане на коментари',
'editcomments'            => 'Редактиране на коментари',
'deletecomments'          => 'Изтриване на коментари',
'viewattachments'         => 'Разглеждане на прикачени файлове',
'createattachments'       => 'Създаване на прикачени файлове',
'deleteattachments'       => 'Изтриване на прикачени файлове',
'viewhistory'             => 'Разглеждане на историята',
'closeowntasks'           => 'Затваряне на собствени задачи',
'closeothertasks'         => 'Затваряне на задачи на други потребители',
'assigntoself'            => 'Назначаване на задачи на себе си, ако вече не са назначени на друг',
'assignotherstoself'      => 'Назначаване на чужди задачи на себе си',
'viewreports'             => 'Разглеждане на списъка със събития',
'othersview'              => 'Позволяване на всеки да разглежда този проект',
'usersandgroups'          => 'Потребители и групи',
'globalgroup'             => 'Глобална група',
'globalgroups'            => 'Глобални групи',
'defaultglobalgroup'      => 'Подразбираща се глобална група за нови потребители',
'addtogroup'              => 'Добавяне към групата',
'moveuserstogroup'        => 'Преместване на тези потребители към група',
'nogroup'                 => 'Няма група - премахване от проекта',
'eventdesc'               => 'Описание на събитието',
'requestedby'             => 'Заявено от',
'daterequested'           => 'Заявена дата',
'closetask'               => 'Затваряне на задачата',
'reopentask'              => 'Повторно отваряне на задачата',
'applymember'             => 'Заявка за членство в проекта',
'forcurrentproj'          => 'За текущия проект',
'lostpw'                  => 'Възстановяване на забравена парола',
'lostpwexplain'           => 'Въведете вашето потребителско име, за да ви бъде изпратена връзка за смяна на паролата. Тя ще бъде изпратена на адреса за известяване на във вашия профил.',
'sendlink'                => 'Изпращане',
'savenewpass'             => 'Съхраняване на новата парола',
'anonreg'                 => 'Разрешаване на регистрации на нови потребители',
'allowanonopentask'       => 'Разрешаване на анонимни потребители да отварят задачи',
'editglobalgroup'         => 'Редактиране на глобална група',
'editgroupforproj'        => 'Редактиране на група за проект',
'notshownforadmin'        => 'Разрешенията за административната група не са показани. Няма нужда да ги редактирате.',
'general'                 => 'Общи',
'userregistration'        => 'Регистрация на потребител',
'notifications'           => 'Известия',
'resetoptions'            => 'Начално установяване',
'preferences'             => 'Предпочитания',
'tasktypes'               => 'Типове задачи',
'resolutions'             => 'Резолюции',
'categories'              => 'Категории',
'operatingsystems'        => 'Операционни системи',
'versions'                => 'Версии',
'admintoolboxlong'        => 'Административни инструменти',
'newproject'              => 'Нов проект',
'delete'                  => 'Изтриване',
'listdeletetip'           => 'Изтриване на този елемент от списъка',
'lookandfeel'             => 'Външен вид (оформление)',
'globaltheme'             => 'Глобална тема',
'emailnotify'             => 'Известяване по е-майл',
'fromaddress'             => 'Обратен адрес',
'smtpserver'              => 'SMTP сървър',
'smtpuser'                => 'SMTP потребителско име',
'smtppass'                => 'SMTP парола',
'addrewrite'              => 'Използване на пренаписване на URL адреси (rewrite)',
'usereminderdaemon'       => 'Разрешаване на фонов демон/процес за напомняне',
'tasksperpage'            => 'Задачи на страница в списъка със задачи',
'addtoassignees'          => 'Добавяне на себе си към списъка с потребители, които могат да приемат задачи',
'taskstatuses'            => 'Състояние на задачите',
'canvote'                 => 'Може да гласува за задачите',
'loginsuccessful'         => 'Успешен вход.',
'youareloggedout'         => 'Успешен изход.',
'waitwhiletransfer'       => 'Моля изчакайте докато бъдете прехвърлен...',
'clicknowait'             => 'Натиснете тук, ако не желаете да чакате.',
'accountdisabled'         => 'Вашият акаунт е заключен. Обърнете се към администратора.',
'task'                    => 'Задача',
'edittask'                => 'Редактиране на тази задача',
'openedby'                => 'Отворена от',
'editedby'                => 'Последно редактирана от',
'tasktype'                => 'Тип на задачата',
'category'                => 'Категория',
'status'                  => 'Състояние',
'assignedto'              => 'Назначена на',
'operatingsystem'         => 'Операционна система',
'severity'                => 'Трудност',
'reportedversion'         => 'Версия на появяване на задачата',
'dueinversion'            => 'Готовност за версия',
'undecided'               => 'Нерешено',
'percentcomplete'         => 'Завършено (%)',
'details'                 => 'Подробности',
'savedetails'             => 'Запис',
'canceledit'              => 'Отмяна на редактирането',
'anonymous'               => 'Анонимен подател',
'complete'                => 'завършено',
'closedby'                => 'Затворена от',
'reasonforclosing'        => 'Причина за затварянето:',
'reopenthistask'          => 'Повторно отваряне на задачата',
'comments'                => 'Коментари',
'attachments'             => 'Прикачени файлове',
'relatedtasks'            => 'Свързани задачи',
'edit'                    => 'Редактиране',
'addcomment'              => 'Добавяне на коментар',
'fileuploadedby'          => 'Файлът е качен от',
'uploadafile'             => 'Прикачане на файл',
'uploadnow'               => 'Качи сега!',
'thesearerelated'         => 'Следващите задачи са свързани с тази задача',
'remove'                  => 'Премахване',
'addnewrelated'           => 'Добавяне на нова свързана задача',
'add'                     => 'Добавяне',
'otherrelated'            => 'Други задачи, към които тази задача е свързана',
'receivenotify'           => 'Тези потребители ще приемат известия, когато има промени в задачата.',
'addusertolist'           => 'Добавяне на потребител към списъка',
'addtolist'               => 'Добавяне към списъка',
'addmyself'               => 'Добавяне на себе си към списъка',
'removemyself'            => 'Премахване на себе си към списъка',
'theseusersnotify'        => 'Тези потребители ще приемат известия, когато има промени в задачата.',
'attachedtoproject'       => 'Прикачена към проект',
'reminders'               => 'Напомняния',
'system'                  => 'Система',
'remindthisuser'          => 'Напомни на този потребител',
'thisoften'               => 'Честота',
'startafter'              => 'Изчакване преди да започне напомнянето',
'hours'                   => 'Час(ове)',
'days'                    => 'Ден(дни)',
'weeks'                   => 'Седмица(и)',
'addreminder'             => 'Добавяне на напомняне',
'defaultreminder'         => 'Това съобщение ви напомня да обърнете внимание на следващата Flyspray задача:',
'message'                 => 'Съобщение',
'closed'                  => 'Затворена',
'filename'                => 'Име на файл:',
'date'                    => 'Дата',
'filesize'                => 'Големина на файла:',
'closurecomment'          => 'Допълнителен коментар при затварянето:',
'history'                 => 'История',
'nohistory'               => 'Няма записана история на задачата.',
'eventdate'               => 'Дата',
'user'                    => 'Потребител',
'event'                   => 'Събитие',
'fieldchanged'            => 'Променено поле',
'taskopened'              => 'Отворена задача',
'taskreopened'            => 'Отворена отново задача',
'taskclosed'              => 'Затворена задача',
'commentadded'            => 'Добавен коментар',
'commentedited'           => 'Редактиран коментар',
'commentdeleted'          => 'Премахнат коментар',
'attachmentadded'         => 'Прикачен е файл',
'attachmentdeleted'       => 'Прикаченият файл е премахнат',
'taskedited'              => 'Данните за задачата са редактирани',
'notificationadded'       => 'Добавен потребител към списъка за известяване',
'notificationdeleted'     => 'Премахнат потребител от списъка за известяване',
'relatedadded'            => 'Добавени свързани задачи',
'relateddeleted'          => 'Премахнати свързани задачи',
'taskassigned'            => 'Задачата е назначена на',
'taskreassigned'          => 'Задачата е преназначена на',
'assignmentremoved'       => 'Назначаването отменено',
'summary'                 => 'Обобщение',
'addedasrelated'          => 'Задачата е добавена списъка със свързани задачи на',
'deletedasrelated'        => 'Задачата е премахната от списъка със свързани задачи на',
'reminderadded'           => 'Добавено напомняне',
'reminderdeleted'         => 'Премахнато напомняне',
'priority'                => 'Приоритет',
'previousvalue'           => 'Предишна стойност',
'newvalue'                => 'Нова стойност',
'selectareason'           => 'Изберете причина',
'assigntome'              => 'Назначи на мен',
'reopenrequest'           => 'Заяви повторно отваряне',
'requestclose'            => 'Заяви затваряне',
'ownershiptaken'          => 'Потребителят взе задачата',
'closerequestmade'        => 'Заявка за затваряне на задача',
'reopenrequestmade'       => 'Заявка за повторно отваряне на задачата',
'taskdependson'           => 'Тази задача зависи от',
'taskblocks'              => 'Тази задача блокира следните задачи от затваряне',
'depadded'                => 'Добавена зависимост',
'depaddedother'           => 'Тази задача беше добавена като зависимост',
'depremoved'              => 'Зависмостта е премахната',
'depremovedother'         => 'Тази задача е премахната от списъка на зависимостите на друга задача',
'showdetailserror'        => 'Тази задача не съществува или нямате право да я раглеждате.',
'makeprivate'             => 'Направи задачата лична',
'makepublic'              => 'Направи задачата публична',
'taskmadeprivate'         => 'Задачата е направена лична',
'taskmadepublic'          => 'Задачата е направена публична',
'confirmdeletecomment'    => 'Наистина ли желаете да премахнете този коментар? %s',
'confirmdeleteattach'     => 'Наистина ли да бъде премахнат този прикачен файл?',
'selectedhistory'         => 'Показване на избрани събития от историята',
'showallhistory'          => 'Показване на пълната история',
'hidethis'                => 'Скриване на тази област отново',
'mark100'                 => 'Маркиране на тази задача 100% изпълнена',
'watchtask'               => 'Наблюдаване на задачата',
'stopwatching'            => 'Край на наблюдаване на задачата',
'commentlink'             => 'Връзка към този коментар',
'submitreq'               => 'Изпращане на заявка',
'reasonforreq'            => 'Причина за тази заявка',
'pmreqdenied'             => 'Проект Менажерът е забранил заявката',
'taskpendingreq'          => 'Заявка към Проект Менажера в очакване. Вижте историята за подробности.',
'previoustask'            => 'Предишна задача',
'nexttask'                => 'Следваща задача',
'duedate'                 => 'Краен срок',
'attachnoperms'           => 'Към този коментар има прикачени файлове, но вие нямате право да ги разглеждате.',
'open'                    => 'Отворени',
'depgraph'                => 'Разглеждане на графиката на зависимостите',
'reset'                   => 'Начално установяване',
'selectusers'             => 'Избери потребители...',
'addmetoassignees'        => 'Добави ме към списъка за назначаване на задачи',
'addedtoassignees'        => 'Потребителят е добавен към списъка за назначаване на задачи',
'dependencygraph'         => 'Графика на зависимостите',
'attachanotherfile'       => 'Прикачане на нов файл',
'OK'                      => 'ОК',
'addvote'                 => 'Добавяне на вот',
'notifyfromfs'            => 'Известие от Flyspray',
'autogenerated'           => 'ТОВА СЪОБЩЕНИЕ Е ГЕНЕРИРАНО АВТОМАТИЧНО. НЕ ОТГОВАРЯЙТЕ.',
'forward'                 => 'Напред',
'previous'                => 'Предишна',
'next'                    => 'Следваща',
'first'                   => 'Първа',
'last'                    => 'Последна',
'page'                    => 'Страница %d от %d',
'search'                  => 'Търсене',
'alltasktypes'            => 'Всички типове задачи',
'allseverities'           => 'Всички степени на важност',
'alldevelopers'           => 'Всички разработчици',
'notyetassigned'          => 'Все още не назначена',
'allcategories'           => 'Всички категории',
'allstatuses'             => 'Всички състояния',
'allopentasks'            => 'Всички отворени задачи',
'sortthiscolumn'          => 'Сортиране по тази колона',
'id'                      => 'ID',
'project'                 => 'Проект',
'dateopened'              => 'Отворен',
'progress'                => 'Прогрес',
'searchthisproject'       => 'Търсене в този проект за',
'dueanyversion'           => 'За изпълнение във която и да е версия',
'anyversion'              => 'Съобщено във всяка версия',
'dueversion'              => 'За изпълнение във версия',
'lastedit'                => 'Последно редактиране',
'os'                      => 'Операционна система',
'reportedin'              => 'Съобщено в',
'taskrange'               => 'Показани задачи %d - %d от %d',
'noresults'               => 'Търсенето не върна резултати.',
'takeaction'              => 'Изпълнение на избраното действие',
'watchtasks'              => 'Наблюдаване на избраните задачи',
'stopwatchingtasks'       => 'Край на наблюдаването на избраните задачи',
'assigntaskstome'         => 'Назначаване на избраните задачи на мен',
'dueby'                   => 'За изпълнение от',
'dueanytime'              => 'За изпълнение когато и да е',
'selectduedate'           => 'Изберете краен срок за изпълнение',
'toggleselected'          => 'Обръщане на избраните',
'due'                     => 'Срок',
'assignedtome'            => 'Назначени на мене',
'tasklist'                => 'Списък от задачи',
'dateclosed'              => 'Дата на затваряне',
'advanced'                => 'Разширено',
'searchcomments'          => 'Търсене в коментарите',
'searchforall'            => 'търсене за всички думи',
'anonusers'               => 'Анонимни потребители',
'miscellaneous'           => 'Разнообразни',
'users'                   => 'Потребители',
'taskproperties'          => 'Свойства на задачите',
'selectsincedate'         => 'Изберете променени след',
'changedsince'            => 'Променени след',
'updatefs'                => 'Моля обновете Flyspray.',
'currentversion'          => 'Вашата текуща версия е',
'latestversion'           => 'а последната достъпна версия е',
'hidemessage'             => '(напомни ми по-късно)',
'saveas'                  => 'Записване на заявката за търсене като',
'nosearches'              => 'Няма записани заявки за търсене',
'saving'                  => 'Запис...',
'votes'                   => 'Гласуване',
'allclosedtasks'          => 'Всички затворени задачи',
'password'                => 'Парола',
'login'                   => 'Влизане',
'rememberme'              => 'Запомни ме',
'lostpassword'            => 'Забравена парола?',
'lostpwforfs'             => 'Забравена парола за Flyspray',
'lostpwmsg1'              => "Здравейте.\n\nАз съм загубил паролата си за Flyspray на _",
'lostpwmsg2'              => ", моля дайте ми нова парола.\n\nПотребителско име: _",
'regards'                 => "\n\nПоздрави,",
'yourusername'            => '_ вашето потребителско име _',
'locale'                  => 'bg-BG',
'filenotexist'            => 'Файлът не съществува или вие нямате достъп до него.',
'showtask'                => 'Показване на задача',
'now'                     => 'Сега',
'go'                      => 'Давай!',
'opentaskanon'            => 'Отвори нова задача анонимно',
'register'                => 'Регистриране',
'addnewtask'              => 'Нова задача',
'reports'                 => 'Събития (списък)',
'editmydetails'           => 'Редактиране на данните ми',
'logout'                  => 'Изход',
'disabledaccount'         => 'Вашият акаунт е забранен!<br />Сега излизате от системата...',
'poweredby'               => 'Тази система е базирана на Flyspray',
'projects'                => 'Проекти',
'allprojects'             => 'Всички проекти',
'selectproject'           => 'за проект:',
'tasksall'                => 'Всички задачи',
'tasksassigned'           => 'Задачи, назначени на мен',
'tasksreported'           => 'Задачи, reported от мен',
'taskswatched'            => 'Задачи, които следя',
'mysearch'                => 'Моите заявки за търсене',
'admintoolbox'            => 'Административен панел',
'manageproject'           => 'Конфигурация',
'permissions'             => 'Виж разрешенията',
'hide'                    => 'Скрий',
'pendingreq'              => 'Има чакащи заявки за проект менажера',
'errorpage'               => "Flyspray не може да покаже страницата, която сте заявили.\n                                 Може би сте поискали задача, която не съществува, или нямате\n                                 разрешение да я виждате.<br /><br />\n                                 Може да сте опитали неправилен URL, за да работите с базата данни\n                                 използвайки SQL injection. Ако това е така, отидете в ъгъла и помислете\n                                 какви ги вършите. Като се върнете, не правете ката отново!",
'permissionsforproject'   => 'Разрешения за _',
'switchto'                => 'Превключи към',
'lastsearch'              => 'Последно търсене',
'modify'                  => 'Промяна',
'noticefrom'              => 'Известие от',
'hasopened'               => 'е ОТВОРИЛ НОВА Flyspray задача и я е назначил на вас:',
'moreinfonew'             => 'Можете да намерите повече информация за тази грешка на Flyspray страница:',
'newtaskcategory'         => 'Нова Flyspray задача беше отворена в тази категория',
'categoryowner'           => 'Вие получавате това, понеже сте собственик на категорията.',
'tasksummary'             => 'Подробности на задачата:',
'newtaskadded'            => 'Вашата нова задача беше добавена.',
'summaryanddetails'       => 'Вие трябва да запишете нещо както в заглавието, така и в подробностите на задачата.',
'goback'                  => 'Връщане назад.',
'messagefrom'             => 'Това е съобщение от Flyspray - система за проследяване на грешки на',
'hasjustmodified'         => 'е редактирал следващата задача.',
'changedfields'           => 'Променените полета са отбелязани със звездички (**)',
'moreinfomodify'          => 'Вие можете да получите повече информация за тази задача на следващия адрес:',
'nolongerassigned'        => 'Следващата задача повече не е назнаечна на вас. Тя сега е назначена на',
'hasassigned'             => 'е назначил на вас следващата Flyspray задача:',
'taskupdated'             => 'Задачата беше променена.',
'hasclosedassigned'       => 'е затворил следващата Flyspray, която е била назначена на вас:',
'unassigned'              => 'Неназначена',
'hasclosed'               => 'е затворил следващата задача.',
'youonnotify'             => 'Вие получавате това съобщение, понеже сте в списъка за известяване.',
'taskclosedmsg'           => 'Задачата е затворена.',
'returntotask'            => 'Връщане към задачата',
'backtoindex'             => 'Връщане към списъка със задачи',
'noclosereason'           => 'Не сте избрали причина за затварянето на задачата.',
'hasreopened'             => 'е отворил отново следващата Flyspray задача, която вие сте затворил:',
'taskreopenedmsg'         => 'Задачата е отворена отново.',
'backtotask'              => 'Обратно към задачата.',
'commentaddedmsg'         => 'Беше добавен коментар.',
'commenttoassigned'       => 'е добавил коментар към задача, назначена на вас:',
'commenttotask'           => 'е добавил следния коментар към тази задача.',
'nocommententered'        => 'Трябва все пак да въведете коментар преди на натиснете бутон "Изпращане".',
'fillinfields'            => 'Не сте попълнили всички полета.',
'notcurrentpass'          => 'Това не е вашата настояща парола!',
'passchanged'             => 'Вашата парола беше променена.',
'closewindow'             => 'Сега можете да затворите този прозорец.',
'passnomatch'             => 'Новата парола и потвърждението й не са еднакви!',
'usernametaken'           => 'Това потребителско име вече е заето. Трябва да изберете някое друго.',
'newusercreated'          => 'Беше създаден нов потребителски акаунт.',
'accountcreated'          => 'Вашият акаунт беше създаден.',
'newuserwarning'          => 'Моля да имате предвид, че глобалната конфигурация може да изисква вашият акаунт да бъде одобрен от администратор. Ако не можете да влезете в системата, това може да е причината.',
'nomatchpass'             => 'паролите не съвпадат.',
'confirmwrong'            => 'Кодът за потвърждение не е верен!',
'formnotcomplete'         => 'Не са попълнени всички полета.',
'formnotnumeric'          => 'Въведените данни не са числови!',
'groupnametaken'          => 'Това име на група вече е заето.',
'newgroupadded'           => 'Беше добавена нова група.',
'optionssaved'            => 'Конфигурацията на Flyspray е записана.',
'hasuploaded'             => 'е прикачил файл към задача, която е назначена на вас:',
'hasattached'             => 'е прикачил файл към следващата задача.',
'fileuploaded'            => 'Файлът е прикачен.',
'fileerror'               => 'Грешка по време на прикачване на файла. Може би разрешенията на директория <i>attachments/</i> не са коректни.',
'contactadmin'            => 'Обърнете се към администратора на проекта.',
'selectfileerror'         => 'Не сте избрали файл.',
'userupdated'             => 'Информацията за потребителя е обновена',
'realandemail'            => 'Не сте попълнили полетата за истинско име и e-mail адрес.',
'groupupdated'            => 'Конфигурацията на групата беше обновена.',
'groupanddesc'            => 'Не сте задали име на група.',
'fillallfields'           => 'Моля попълнете всички полета.',
'listPmustN'              => 'Поле "Ред" трябва да бъде число.',
'listupdated'             => 'Списъкът беше обновен.',
'listitemadded'           => 'Беше добавен нов елемент към списъка.',
'relatedaddedmsg'         => 'Беше добавена свързана задача към списъка.',
'relatederror'            => 'Тази задача вече се намира в този списък.',
'relatedremoved'          => 'От списъка на свързани задачи беше премахната задача.',
'notifyadded'             => 'Към списъка за известяване беше добавен потребител.',
'notifyerror'             => 'Този потребител вече се намира в списъка за известяване на тази задача.',
'notifyremoved'           => 'От списъка за известяване беше премахнат потребител.',
'editcommentsaved'        => 'Коментарът беше обновен.',
'commentdeletedmsg'       => 'Коментарът беше изтрит.',
'gotonewtask'             => 'Преход към задачата, която току-що създадохте',
'projectcreated'          => 'Вашият нов проект е създаден. Сега можете да го конфигурирате допълнително.',
'customiseproject'        => 'Конфигуриране на проекта',
'projectupdated'          => 'Конфигурацията на проекта беше обновена.',
'emptytitle'              => 'Вие сте оставил името на проекта празно. Моля, върнете се обратно и въведете име.',
'loginbelow'              => 'Сега може да да пробвате да влезете в системата.',
'attachmentdeletedmsg'    => 'Прикаченият файл беше изтрит.',
'reminderaddedmsg'        => 'Вашето напомняне беше добавено.',
'reminderdeletedmsg'      => 'Избраното напомняне беше изтрито.',
'flyspraytask'            => 'Flyspray задача',
'fieldsmissing'           => 'Някои полета са празни или съдържат невалидни данни.',
'relatedinvalid'          => 'Няма такава задача.',
'relatedproject'          => 'Тази задача е от друг проект. Да бъде ли добавена връзка към нея независимо от това?',
'addanyway'               => 'Добавяне въпреки това',
'cancel'                  => 'Отказ',
'alreadyedited'           => 'Тази задача е редактирана от някой друг преди да я запишете. Все още ли искате да направите запис?',
'saveanyway'              => 'Записване въпреки това',
'nouserselected'          => 'Не е избран потребител. Изберете най-малкожедин потребител преди да опитате отново.',
'groupswitchupdated'      => 'Потребителските групи са модифицирани успешно.',
'takenownershipmsg'       => 'Тази задача сега е назначена на вас.',
'adminrequestmade'        => 'Вашата заявка беше изпратена на проект менажера.',
'newdepnotify'            => 'Нова зависимост беше добавена към следващата задача:',
'dependadded'             => 'Добавена зависимост между задачи',
'dependaddfailed'         => 'Грешка по време на добавяне на зависимост между задачи. Проверете дали задачата съществува и че няма взаимна зависимост между тях.',
'depremovedmsg'           => 'Беше премахната зависимост между задачи',
'newdepis'                => 'Новата зависимост е',
'magicurlsent'            => 'Беше изпратено съобщение на вашия адрес за известяване. То съдържа връзка, която ще ви изпрати на страницата, за да попълните данните за задачата.',
'changefspass'            => 'Промяна на Flyspray парола',
'magicurlmessage'         => 'Моля последвайте тази връзка, за да промените вашата Flyspray парола:',
'erroronform'             => 'Има някакъв проблем с изпраящането на формуляра',
'addressused'             => 'Този адрес е използван за регистриране на Flyspray акаунт. Ако не очаквате това съобщение, моля игнорирайте го. Отидете на следващия адрес и направете вашата регистрация:',
'confirmcodeis'           => 'Вашият код за потвърждение е:',
'codesent'                => 'Вашият код е изпратен. Моля следвайте инструкциите в съобщението, което ще получите.',
'codenotsent'             => 'Кодът не може да бъде изпратен. Опитайте по-късно.',
'taskmadeprivatemsg'      => 'Тази задача беше направена лична',
'taskmadepublicmsg'       => 'Тази задача беше направена отново публично',
'realandnotify'           => 'Трябва да попълните полето за действително име и поне едно от полетата за е-майл адрес или Jabber ID.',
'pmreqdeniedmsg'          => 'Заявката към Проект менажера е отхвърлена',
'massopsuccess'           => 'Операцията е успешна - където има подходящи разрешения',
'usernotexist'            => 'Този потребител не съществува в тази инсталация на Flyspray',
'commentattachperms'      => 'Не можете да изтриете този коментар - нямате разрешение да изтривате прикачени файлове',
'voterecorded'            => 'Вашият вот е записан.',
'votefailed'              => 'Вашият вот не може да бъде добавен в този момент.',
'createnewgroup'          => 'Създаване на нова група',
'requiredfields'          => 'Задължителните полета са маркирани с',
'addthisgroup'            => 'Добавяне на тази група',
'createnewproject'        => 'Създаване на нов проект',
'addnewproject'           => 'Добавяне на нов проект',
'htmlallowed'             => 'HTML кодът е позволен',
'createthisproject'       => 'Създаване на този проект',
'inlineimages'            => 'Показване на изображенията в текста',
'createnewtask'           => 'Създаване на нова задача в проект:',
'addanother'              => 'Добавяне на нова задача след тази',
'addthistask'             => 'Добавяне на тази задача',
'notifyme'                => 'Известявай ме при промяна в задачата',
'newtask'                 => 'Нова задача',
'attachafile'             => 'Прикачване на файл',
'registernewuser'         => 'Регистриране на нов потребител',
'none'                    => 'Няма',
'registeraccount'         => 'Регистриране на този потребител',
'both'                    => 'И двете',
'notifyfrom'              => 'Формуляр за известяване _',
'donotreply'              => 'ТОВА СЪОБЩЕНИЕ Е ГЕНЕРИРАНО АВТОМАТИЧНО, МОЛЯ НЕ ОТГОВАРЯЙТЕ.',
'disclaimer'              => 'Получавате това съобщение, понеже така сте заявили в Flyspray bugtracking system. Ако не очаквате това съобщение или не желате да получавате е-майли за в бъдеще, можете да промените конфигурацията за известяване на адреса по-горе.',
'userwho'                 => 'Потребителят, който е направил това',
'moreinfo'                => 'Повече информация може да бъде намерена на следващия адрес:',
'newtaskopened'           => 'Нова Flyspray задача беше отворена. Подробностите са по-долу.',
'notify.taskclosed'       => 'Следващата задача сега е затворена:',
'notify.taskreopened'     => 'Следващата задача е отворена отново:',
'newdep'                  => 'Следващата задача има нова зависимост:',
'notify.depremoved'       => 'Следващата задача има премахната зависимост:',
'olddepwas'               => 'Старата зависимост беше',
'notify.commentadded'     => 'Към следващата задача има добавен нов коментар:',
'commentis'               => 'Съдържанието на коментара е по-долу.',
'newattachment'           => 'Към следващата задача беше прикачен нов файл:',
'detailsbelow'            => 'Подробностите са по-долу.',
'notify.relatedadded'     => 'Нова свързана задача беше добавена към следващата задача:',
'relatedis'               => 'Свързаната задача е',
'assignedtoyou'           => 'Следващата задача е назначена на вас:',
'takenownership'          => 'взе следващата задача:',
'requiresaction'          => 'Следващата задача изисква реакция от проект менажера:',
'requiresactionnotify'    => 'Задача изисква реакция от проект менажера',
'pmdeny'                  => 'Проект Менажерът е забранил заявките за следващата задача:',
'pmdenynotify'            => 'Проект Менажерът е забранил заявката',
'fileaddedtoo'            => 'Един или повече файлове са прикачени.',
'taskwatching'            => 'Задачата, която наблюдавате',
'isdepfor'                => 'е нова зависимост за',
'denialreason'            => 'Причина за забрана',
'taskchanged'             => 'Следващата задача е променена. Промените са показани по-долу. За пълна информация относно промените отидете на адреса и натиснете "История".',
'useraddedtoassignees'    => 'Потребител се е добавил към списъка наназначените на тази задача.',
'removeddepis'            => 'Премахнатата зависимост е',
'isnodepfor'              => 'не е повече зависимост за',
'usergroups'              => 'Потребителски групи',
'pmtoolbox'               => 'Инструментариум на Проект Менажера',
'groupmanage'             => 'Управление на групите',
'pendingrequests'         => 'Чакащи заявки',
'reasongiven'             => 'Причина',
'nopendingreq'            => 'Няма чакащи заявки за Проект Менажера.',
'givereason'              => 'Укажете причина',
'catlisted'               => 'Редактор на списъка от категории',
'oslisted'                => 'Редактор на списъка от операционни системи',
'verlisted'               => 'Редактор на списъка от версии',
'tasktypeed'              => 'Редактор на списъка от типове задачи',
'resed'                   => 'Редактор на списъка от резолюциите',
'deny'                    => 'Забрана',
'notifiedwhen'            => 'Известяване когато',
'onlynewtasks'            => 'Нови задачи са отворени',
'allevents'               => 'Събитие в задача',
'feeds'                   => 'Емисии',
'feeddescription'         => 'Описание на емисията',
'feedimgurl'              => 'Връзка към изображение за емисията (оставете празно, ако няма изображение)',
'notifysubject'           => 'Предмет на известяването',
'notifysubjectinfo'       => '(%p = име на проекта, %s = обобщение на задачата, %t = идентификатор на задачата, %a = действие, %u = Потребителско име)',
'priority6'               => 'Светкавично',
'priority5'               => 'Веднага',
'priority4'               => 'Неотложен',
'priority3'               => 'Висок',
'priority2'               => 'Нормален',
'priority1'               => 'Нисък',
'sendcode'                => 'Изпрати кода!',
'entercode'               => 'Въведете кода за потвърждение, който се намира в съобщението. Също така въведете и вашата парола.',
'confirmationcode'        => 'Код за потвърждаване',
'registererror'           => 'Уверете се, че сте попълнили всички задължителни полета, и че сте въвели коректни данни за избрания тип на известяване.',
'validusername'           => '(позволени са само букви, цифри и _)',
'emailtaken'              => 'Този е-майл адрес или Jabber-ID вече е зает. Трябва да изберете някой друг.',
'note'                    => '<strong>Забележка:</strong>  Ще ви бъде изпратен код за потвърждение преди вашият акаунт да бъде създаден. Този код ще бъде изпратен чрез предпочетения метод на известяване по-горе.<br />Ако сте въвели фалшиви данни, вие <strong>няма да получите вашия код</strong>.',
'changelog'               => 'Хронология на промените',
'changeloggen'            => 'Генератор на хронология на промените',
'listfrom'                => 'Списък на промените от',
'to'                      => 'до',
'oldestfirst'             => 'Най-старата първо',
'recentfirst'             => 'Най-новата първо',
'severityrep'             => 'Отчет за степента на трудност',
'totalopen'               => 'Общо отворени задачи',
'age'                     => 'Възраст',
'agerep'                  => 'Отчет на възрастта на задачите',
'eventsrep'               => 'Отчет на събитията',
'events'                  => 'Събития',
'Tasks'                   => 'Задачи',
'opened'                  => 'Отворени',
'edited'                  => 'Редактирани',
'assigned'                => 'Назначени',
'within'                  => 'В',
'pastday'                 => 'Последния ден',
'pastweek'                => 'Последната седмица',
'pastmonth'               => 'Последния месец',
'pastyear'                => 'Последната година',
'nolimit'                 => 'Неограничено',
'from'                    => 'От',
'duein'                   => 'За изпълнение в',
'selectfromdate'          => 'Изберете От дата',
'selecttodate'            => 'Изберете До дата',
'showvoters'              => 'Скриване/Показване на гласуващите',
'roadmap'                 => 'Пътна карта',
'roadmapfor'              => 'Пътна карта за версия',
'tasks'                   => 'задачи',
'completed'               => 'изпълнени.',
'opentasks'               => 'отворени задачи',
'of'                      => '% от',
'severity5'               => 'Критична',
'severity4'               => 'Висока',
'severity3'               => 'Средна',
'severity2'               => 'Ниска',
'severity1'               => 'Много ниска',
'Redirect'                => 'Пренасочване',
'redirectmsg'             => 'Ако вашиат браузър не поддържа пренасочване моля натиснете %sHERE%s, за да бъдете пренасочени',
'allowclosedcomments'     => 'Разрешаване на коментари на затворени задачи',
'comment'                 => 'Коментар',
'editowncomments'         => 'Редактиране на собствените коментари',
'reopened'                => 'Повторно отворени',
'loading'                 => 'Зареждане...',
'notifyown'               => 'Известяване за собствени промени',
'youremail'               => 'Вашиат е-майл адрес',
'thankyouforbug'          => 'Благодаря за съобщаването на този проблем. Вие можете да видите задачата и наблюдавате развитието й по всяко време на този адрес:',
'anonuser'                => 'Анонимен потребител',
'conflict'                => 'Конфликт',
'file'                    => 'Файл',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => 'Големина',
'projectgroup'            => 'Проектна група',
'profile'                 => 'Профил:',
'viewprofile'             => 'Разглеждане на профила',
'regdate'                 => 'Регистриран от',
'tasksopened'             => 'Отворени задачи',
'replyto'                 => 'Отговори на',
'notifytypes'             => 'Типове известяване',
'pm.taskchanged'          => 'Променени задачи',
'pm.taskreopened'         => 'Отворени отново задачи',
'pm.depadded'             => 'Добавени зависимости',
'pm.depremoved'           => 'Премахнати зависимости',
'pmrequest'               => 'Заявка към проект менажера',
'pmrequestdenied'         => 'Отхвърлена заявка проект менажера',
'newassignee'             => 'Нов изпълнител',
'revdepadded'             => 'Добавена обратна зависимост',
'revdepaddedremoved'      => 'Премахната обратна зависимост',
'assigneeadded'           => 'Добавен изпълнител на задача',
'addusergroup'            => 'Добавяне на потребител към тази група',
'groupmembers'            => 'Членове на групата',
'deleteuser'              => 'Изтриване на този потребител',
'userdeleted'             => 'Потребителят е изтрит',
'autoassign'              => 'Автоматично назначаване на задачата  на собственика на категорията',
'ssl'                     => 'SSL',
'updatewrong'             => "Проверката за обновяване е позволена, но е възникнала грешка по време опита за контакт със сървъра. Възможно е вашият сървър да не позволява външни връзки или да има някакъв мрежов проблем.\nМоля посетете сайта на flyspray, за да проверите дали имате последната версия.",
'deleteproject'           => 'Изтриване на този проект и преместване на съдържанието му в',
'projectdeleted'          => 'Проектът е изтрит успешно',
'feedforall'              => 'Емисия за всички проекти',
'usercreated'             => 'Потребителят е създаден',
'created'                 => 'Създаден потребител',
'deleted'                 => 'Изтрит',
'userid'                  => 'Потребителски ID',
'editassignments'         => 'Редактиране на назначенията',
'preview'                 => 'Преглед',
'anyprogress'             => 'Всякакъв прогрес',
'tasksrelated'            => 'Задачи, свързани с тази задача',
'duplicatetasks'          => 'Дублиране на задачите на тази задача',
'databasemodfailed'       => 'Неуспешна модификация на базата данни. Възможно е да имате ограничения на достъпа.',
'frequency'               => 'Честота',
'newuserregistered'       => 'Нов потребител е регистриран във вашата Flyspray система. Данните за него са както следва:',
'newuserregisterednotify' => 'Нов потребител е регистриран',
'notify_registration'     => 'Известяване на администраторите при регистриране на нов потребител',
'textversion'             => 'Текстова версия',
'onlyprimary'             => 'Задачи, неблокиращи други задачи',
'switch'                  => 'Превключване',
'max'                     => 'макс.',
'dates'                   => 'Дати',
'selectduedatefrom'       => 'За изпълнение от',
'selectduedateto'         => 'до',
'selectsincedatefrom'     => 'Променена от',
'selectsincedateto'       => 'до',
'selectdate'              => 'Изберете дата',
'selectopenedfrom'        => 'Отворена от',
'selectopenedto'          => 'до',
'selectclosedfrom'        => 'Затворена от',
'selectclosedto'          => 'до',
'startat'                 => 'Стартиране на',
'hasattachment'           => 'Има прикачен файл',
'private'                 => 'Частна',
'watching'                => 'Наблюдаване',
'alreadyvotedthistask'    => 'вие гласувахте за тази задача',
'alreadyvotedthisday'     => 'вече гласувахте днес',
'visibility'              => 'Видимост',
'public'                  => 'Публична',
'leaveemptyauto'          => 'Оставете полетата за паролата празни, ако желаете тя да бъде генерирана автоматично.',
'novalidemail'            => 'Не сте въвели валиден е-майл адрес.',
'novalidjabber'           => 'Не сте въвели валиден Jabber адрес.',
'missingrequired'         => 'Не сте попълнили всички задължителни полета.',
'entervalidusername'      => 'Моля въведете валидно потребителско и реално име.',
'couldnotaddusernotif'    => 'Потребителят не беше добавен към списъка за известяване по някаква причина.',
'defaulttask'             => 'Подразбиращо се описание на задачата',
'all'                     => 'всички',
'events.useraddedtoassignees'=> 'Добавен е потребител към списъка с изпълнители',
'vote(s)'                 => 'глас(ове)',
'eventlog'                => 'Хронология на събитията',
'assignmentchanged'       => 'Assignment changed',
'detailedinfo'            => 'Подробна информация',
'All'                     => 'Всички',
'tasksireported'          => 'Задачи, за които аз съм съобщил',
'recentlyopened'          => 'Последно отворени',
'stats'                   => 'Статистика',
'totaltasks'              => 'общо задачи',
'mostwanted'              => 'Най-търсени задачи',
'defaultentry'            => 'Начална страница по подразбиране',
'toplevel'                => 'Изглед на най-горно ниво',
'overview'                => 'Обобщение',
'error#'                  => 'Грешка #',
'error1'                  => 'Нямате достатъчно права да видите този прикачен файл.',
'error3'                  => 'Повторено действие, препращане към главната страница.',
'error4'                  => 'Вие нямате административни права.',
'error5'                  => 'Този потребител не съществува в базата данни.',
'error6'                  => 'Невалидна административна област.',
'error7'                  => 'Неуспешен вход (неправилно потребителско име или парола)!',
'error71'                 => 'Потребителското име е блокирано за %d минути вследствие твърде много неуспешни опити за влизане в системата!',
'error8'                  => 'Не сте въвели потребителското име и/или паролата.',
'error9'                  => 'Задачата не съществува или нямате права да видите тази задача.',
'error10'                 => 'Задачата не съществува или нямате права да видите тази задача.',
'error101'                => 'Нямате разрешение да видите тази задача.',
'error102'                => 'Нямате разрешение да видите тази задача, влезте в системата с потребителското си име и парола и пробвайте отново.',
'error11'                 => 'Нямате право да редактирате този коментар.',
'error12'                 => 'Невалиден ключ! Сигурен ли сте, че сте го взели от изпратеното ви известие?',
'error13'                 => 'Анонимните потребители нямат профил.',
'error14'                 => 'Нямате достатъчно права да създавате нова група.',
'error15'                 => 'Нямате достатъчно права да отваряте задача.',
'error16'                 => 'Вие не сте проект менажер.',
'error17'                 => 'Невалидна област за проект менажер.',
'error18'                 => 'Невалиден URL адрес.',
'error19'                 => 'Този потребител не съществува в тази база данни.',
'error20'                 => 'Невалидна модификация на базата данни.',
'error21'                 => 'Един или повече е-майли не са изпратени. Проверете конфигурацията.',
'error22'                 => 'Не е позволена регистрацията на нови потребители.',
'error23'                 => 'Потребителят или групата нямат разрешение за влизане в системата.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Пътна карта може да бъде показана само за специфичен проект.',
'done'                    => 'готово',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Проектът не може да бъде изтрит.',
'GMT'                     => 'GMT',
'timezone'                => 'Времева зона',
'accept'                  => 'Приемане',
'reasonfordeinal'         => 'Причина за забраната',
'pruneclosedlinks'        => 'Премахване на затворените връзки',
'pruneclosedtasks'        => 'Премахване на затворените задачи',
'pagegenerated'           => 'Страницата и изображението са генерирани за %d секунди.',
'pruninglevel'            => 'Ниво на очистване',
'lastuser'                => 'Последният потребител не може да бъде изтрит.',
'allprivate'              => 'Всички проекти са частни.',
'deletegroup'             => 'Изтриване на тази група и преместване на потребителите в',
'parent'                  => 'Родител',
'ordertip'                => 'Ред, в който тези елементи да се появят в списъка',
'showtip'                 => 'Покажи този елемент в списъка',
'deletetip'               => 'Изтрий този елемент от списъка',
'del'                     => 'del',
'request1'                => 'Има заявка за затваряне на задача.',
'request2'                => 'Има заявка за повторно отваряне на задача.',
'allpriorities'           => 'Всички приоритети',
'noroadmap'               => 'Няма работна карта (не съществуват бъдещи версии за проекта).',
'expand'                  => 'Отваряне',
'collapse'                => 'Затваряне',
'expandall'               => 'Пълно отваряне',
'collapseall'             => 'Пълно затваряне',
'minpwsize'               => 'Минималната дължина на паролата е 5 символа',
'passwordtoosmall'        => 'Дължината на паролата е твърде малка.',
'accountwaslocked'        => 'Вашият акаунт е блокиран поради твърде много неуспешни опити за влизане.',
'failedattempts'          => '%d неуспешни опита за влизане.',
'groupnotexist'           => 'Избраната група не съществува в този проект.',
'searchindetails'         => 'Разширено търсене',
'showasassignees'         => 'Показване като потребител, който може да приема задачи',
'find'                    => 'Търсене',
'tls'                     => 'TLS',
);

?>
