<?php
$language=array(
'needcomposer'       => 'Sono richieste alcune librerie installate da Composer.',
'installcomposer'    => 'Esegui Composer',
'performupgrade'     => 'Esegui Aggiornamento',
'precautions'        => 'Attenzione',
'precautionbackup'   => 'Crea un backup del database e di tutti i file relativi a Flyspray prima di eseguire l\'aggiornamento',
'preconditionchecks' => 'Verifica dei prerequisiti',
'upgrade'            => 'Aggiorna',
'upgradepossible'    => 'Sembra che sia possibile aggiornare.',
'versioncompare'     => 'La tua versione installata è <strong>%s</strong> e la versione a cui si può aggiornare è <strong>%s</strong>.',
'writeaccessconf'    => 'Per essere aggiornato correttamente Flyspray deve avere i diritti di lettura e scrittura su flyspray.conf.php.',
'adminemail'         => 'Indirizzo Email di Admin',
'adminxmpp'          => 'Indirizzo Jabber di Admin',
'adminusername'      => 'Username di Admin',
'adminrealname'      => 'Nome Reale di Admin',
'adminpassword'      => 'Password di Admin',
'slogan'             => 'The bug Killer!',
'progress'           => 'Avanzamento',
'documents'          => 'Documentazione',
'preinstallcheck'    => 'Verifiche Preliminari',
'databasesetup'      => 'Impostazione Database',
'administration'     => 'Amministrazione',
'installflyspray'    => 'Installa Flyspray',
'libcheck'           => 'PHP e Librerie Supportate',
'libchecktext'       => 'Per eseguire l\'installazione devi avere la versione corretta di PHP ed <strong>almeno uno</strong> dei database supportati.',
'recsettings'        => 'Impostazioni Consigliate',
'recsettingstext1'   => 'Queste sono le impostazioni di PHP consigliate per la piena compatibilità con Flyspray.',
'recsettingstext2'   => 'Ad ogni modo, Flyspray può funzionare anche se le tue impostazioni non sono totalmente corrispondenti a quelle consigliate.',
'dirandfileperms'    => 'Permessi per File e Directory',
'dirandfilepermstext'=> 'Per funzionare correttamente Flyspray deve avere accesso, a volte anche in scrittura, ad alcuni file e directory. Se vedi la scritta "Non scrivibile" devi cambiare i permessi sul file o la directory corrispondente per consentirne l\'accesso a Flyspray.',
'proceedtodbsetup'   => 'Prosegui con il Setup del Database',
'proceedtodbsetuptext'=>'Tutte le configurazioni sembrano corrette. Puoi proseguire con l\'impostazione del database',
'library'            => 'Libreria',
'status'             => 'Stato',
'database'           => 'database',
'recommended'        => 'Consigliato',
'actual'             => 'Attuale',
'yes'                => 'Sì',
'no'                 => 'No',
'explainwhatandwhyheader' => 'La formattazione nella descrizione dei task e nei commenti è cambiata',
'explainwhatandwhycontent' => 'Precedentemente, le installazioni di Flyspray che non usavano il motore di formattazione di Dokuwiki memorizzavano i dati come testo semplice. '
    . 'Adesso utilizziamo HTML come default e proviamo ad aggiungere i tag di paragrafo e a capo ai dati preesitenti così i tuoi dati mantengono '
    . 'la propria struttura. Se i tuoi dati contengono già dei tag HTML inseriti manualmente, c\'è il rischio che qualcosa possa andare storto e risulti in dati corrotti '
    . 'nel database che andranno poi corretti manualmente. Se non sei sicuro, rispondi "No", a meno che tu non sia in grado di analizzare la situazione prima di procedere. '
    . 'Se sai programmare in PHP, esamina la parte finale dello script setup/upgrade.php, guarda cosa fa ed eventualmente modificalo in base alle tue necessità.',
'databaseconfiguration'=>'Configurazione Database per ',
'proceedtoadmin'=>'Prosegui con il Setup Amministrazione',
'databasehostname'=>'Hostname',
'databasehostnamehint'=>'Inserisci l\'<strong>hostname del database</strong> su cui stai installando Flyspray. Di solito è "localhost" o un indirizzo IP.',
'databasetype'=>'Tipo DB',
'databasetypehint'=>'Seleziona il <strong>tipo di database</strong>. Se hai installati entrambi i driver MySQL e MySQLi, <strong>usa MySQLi</strong>. Il vecchio driver MySQL (mysql_*) è stato deprecato in PHP da tempo immemore. Se hai MariaDB al posto di MySQL, seleziona comunque MySQLi.',
'databasename'=>'Nome del DB',
'databasenamehint'=>'Inserisci il nome di un database esistente o un nuovo nome. Se il database non esiste, Flyspray tenterà di crearlo. È consigliabile un nome semplice tipo "flyspray".',
'databaseusername'=>'Nome Utente',
'databaseusernamehint'=>'Inserisci il <strong>nome utente e la password per il database</strong>.
Flyspray richiede un database impostato con nome utente e password per installarvi lo schema.
Se non sei sicuro di questi parametri, chiedi all\'amministratore del database o al tuo hosting provider.
(A volte le installazioni locali di XAMPP o WAMPP sono configurate di default come "root" con password vuota)',
'databasepassword'=>'Password',
'databasepasswordhint'=>'',
'tableprefix'=>'Prefisso per le Tabelle',
'tableprefixhint'=>'Prefisso opzionale per le tabelle al fine di evitare conflitti con eventuali tabelle già esistenti. È consigliabile un prefisso semplice come "flyspray_" o "fs_" .',
'next'=>'Prossimo',
'showpassword'            => 'Mostra la Password',
'lgpllicense'             => 'Licenza LGPL',
'installationguide'       => 'Guida all\'Installazione',
'developermanual'         => "Manuale per Sviluppatori",
'supported'               => 'Supportato',
'inphp'                   => 'in PHP',
'available'               => 'Disponibile',
'missing'                 => 'Mancante',
'writeable'               => 'Scrivibile',
'unwriteable'             => 'Non scrivibile',
'on'                      => 'ON',
'off'                     => 'OFF',
'x'                       => 'X',
'true'                    => 'Vero',
'false'                   => 'Falso',
'directive'               => 'Direttiva',
'enable'                  => 'Abilita',
'disable'                 => 'Disabilita',
'administrationsetup'     => 'Impostazione Amministrazione',
'setupapplicationvalue'   => 'Impostazione di tutti i valori dell\'Applicazione',
'adminsetuptip1'          => 'Lo schema del database è stato configurato. Segui le istruzioni per completare le impostazioni di Amministrazione.',
'adminsetuptip2'          => '1) <strong>Email, Nome Utente e Password</strong> di Admin sono per l\'Amministratore della tua installazione di Flyspray. Puoi modificare questi valori dalla sezione di amministrazione di Flyspray.',
'adminsetuptip3'          => 'L\'impostazione di una Sintassi non è semplice da cambiare una volta installato Flyspray perciò viene impostata globalmente all\'atto dell\'installazione. Se non sei sicuro su cosa scegliere, seleziona Text/Dokuwiki.',
'syntax'                  => 'Sintassi',
'syntaxtext'              => 'Se non sei sicuro, seleziona Text/Dokuwiki. Il cambio da Dokuwiki a HTML è semplice. Invece, cambiare successivamente da HTML a Dokuwiki o un altro formato come Markdown, è praticamente impossibile senza la perdita di alcune informazioni come HTML fortemente nidifcati o altra formattazione.',
'scheduletitle'           => 'Puoi impostare un crontab che richiamerà scheduler.php a intervalli di tempo predefiniti. Questa impostazione può essere abilitata e disabilitata a piacere dalla sezione di amministrazione di Flyspray.',
'enablescheduling'        => 'Abilita la schedulazione',
'proceedtofinalsetup'     => 'Prosegui con il Setup finale',
'proceedtofinalsetuptext' => 'Prosegui per completare l\'installazione di Flyspray.',
'installstatus'           => 'Stato dell\'Installazione',
'congratulations'         => 'Congratulazioni! Flyspray è stato installato ed è pronto all\'uso.',
'removesetupdirectory'    => 'Ricordati di eliminare la directory setup ora.',
'viewsite'                => 'Visualizza il Sito',
'proceedtoindex'          => 'Vai alla pagina principale di Flyspray',
);
?>
