<?php

$translation = array(
'edituser'                => 'Edycja danych użytkownika',
'username'                => 'Nazwa',
'realname'                => 'Imię i nazwisko',
'emailaddress'            => 'Adres e-mail',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Rodzaj powiadomienia',
'group'                   => 'Grupa',
'accountenabled'          => 'Konto aktywne?',
'updatedetails'           => 'Zapisz zmiany',
'setglobally'             => 'Właściwość zdefiniowana globalnie.',
'usergroupmanage'         => 'Zarządzanie użytkownikami i grupami',
'newuser'                 => 'Zarejestruj nowego użytkownika',
'newgroup'                => 'Utwórz nową grupę',
'yes'                     => 'Tak',
'no'                      => 'Nie',
'editgroup'               => 'Edytuj grupę',
'groupname'               => 'Nazwa grupy',
'description'             => 'Opis',
'admin'                   => 'Admin grupy',
'opennewtasks'            => 'Otwieranie nowych zgłoszeń',
'modifytasks'             => 'Edycja istniejących zgłoszeń',
'addcomments'             => 'Dodawanie komentarzy',
'attachfiles'             => 'Dołączanie plików',
'vote'                    => 'Głosowanie',
'groupenabled'            => 'Członkowie mogą się logować',
'groupopen'               => 'Członkowie mogą się logować',
'tasktypelist'            => 'Lista typów zgłoszeń',
'categorylist'            => 'Lista kategorii',
'oslist'                  => 'Lista systemów operacyjnych',
'resolutionlist'          => 'Lista decyzji',
'versionlist'             => 'Lista wersji',
'severitylist'            => 'Lista typów ważkości',
'listnote'                => 'Uwaga:	Odznaczenie opcji "Pokaż" może zmienić niektóre obecnie edytowane zgłoszenia. Zmiana pola "Nazwa" spowoduje zmianę we wszystkich zgłoszeniach, w których dana nazwa występuje. Niektórych pozycji nie można skasować, ponieważ ich obecność jest niezbędna do prawidłowego funkcjonowania lub są one obecnie w użyciu.',
'name'                    => 'Nazwa',
'order'                   => 'Lp.',
'back'                    => 'Wróć',
'text'                    => 'Tekst',
'highlight'               => 'Wyróżnij',
'show'                    => 'Pokaż',
'owner'                   => 'Właściciel',
'selectowner'             => 'Wybierz właściciela',
'update'                  => 'Zapisz',
'addnew'                  => 'Dodaj nowe',
'flysprayprefs'           => 'Ustawienia Flyspraya',
'projecttitle'            => 'Nazwa projektu',
'baseurl'                 => 'Adres bazowy Flyspraya',
'replyaddress'            => 'E-mail zwrotny dla powiadomień',
'themestyle'              => 'Styl',
'language'                => 'Język',
'anonview'                => 'Pozwól oglądać zgłoszenia niezalogowanym',
'allowanon'               => 'Pozwól tworzyć nowe zgłoszenia niezalogowanym',
'never'                   => 'Nigdy',
'anonymously'             => 'Anonimowo',
'afterregister'           => 'Tylko po rejestracji',
'spamproof'               => 'Użyj kodu potwierdzającego przy rejestracji',
'anongroup'               => 'Grupa dla nowo zarejestrowanych',
'groupassigned'           => 'Grupy, którym można przydzielać prace',
'forcenotify'             => 'Powiadamiaj poprzez',
'neversend'               => 'Nigdy nie wysyłaj',
'userchoose'              => 'Pozwól wybrać użytkownikowi',
'email'                   => 'E-mail',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Domyślny właściciel kategorii',
'noone'                   => 'Nikogo',
'jabbernotify'            => 'Powiadomienia Jabbera',
'jabberserver'            => 'Serwer',
'jabberport'              => 'Port',
'jabberuser'              => 'Nazwa konta',
'jabberpass'              => 'Hasło konta',
'saveoptions'             => 'Zapisz ustawienia',
'editcomment'             => 'Edytuj komentarz',
'commentby'               => 'Komentarz od',
'saveeditedcomment'       => 'Zapisz edytowany komentarz',
'projectprefs'            => 'Ustawienia projektu',
'pagetitle'               => 'Tytuł strony',
'defaultproject'          => 'Projekt domyślny',
'projectlists'            => 'Lista projektów',
'showlogo'                => 'Pokazuj logo',
'intromessage'            => 'Tekst wprowadzający',
'isactive'                => 'Projekt jest aktywny',
'createproject'           => 'Utwórz projekt',
'nopermission'            => 'Nie masz uprawnień do oglądania tej strony',
'listordertip'            => 'Kolejność, w której pozycje pojawią się na liście',
'listshowtip'             => 'Pokazuj pozycję na liście',
'categoryownertip'        => 'Ten użytkownik będzie otrzymywał powiadomienia o zgłoszeniach otwieranych w tej kategorii',
'categoryparenttip'       => 'Kategoria nadrzędna w stosunku do tej kategorii',
'notsubcategory'          => 'brak (główna kategoria)',
'showinlineimages'        => 'Pokazuj załączniki graficzne na stronie',
'dateformat'              => 'Format daty',
'dateformat_extended'     => 'Rozszerzony format daty',
'cache_feeds'             => 'Cache\'owanie kanałów',
'no_cache'                => 'Bez cache\'owania',
'cache_disk'              => 'Cache na dysku',
'cache_db'                => 'Cache w bazie',
'subcategoryof'           => 'Kategoria podrzędna',
'visiblecolumns'          => 'Kolumny widoczne na liście zgłoszeń',
'tense'                   => 'Czas',
'listtensetip'            => 'Przeszłe, obecne lub przyszłe',
'past'                    => 'Przeszła',
'present'                 => 'Obecna',
'future'                  => 'Przyszła',
'oldpass'                 => 'Stare hasło',
'nooldpass'               => 'Stare hasło nie zostało ustawione',
'oldpasswrong'            => 'Stare hasło jest niepoprawne',
'changepass'              => 'Zmień hasło',
'confirmpass'             => 'Potwierdź hasło',
'projectmanager'          => 'Zarządzanie projektem',
'viewtasks'               => 'Podgląd zgłoszeń',
'modifyowntasks'          => 'Zmiana własnych zgłoszeń',
'modifyalltasks'          => 'Zmiana cudzych zgłoszeń',
'viewcomments'            => 'Podgląd komentarzy',
'editcomments'            => 'Edycja komentarzy',
'deletecomments'          => 'Usuwanie komentarzy',
'viewattachments'         => 'Podgląd załączników',
'createattachments'       => 'Dodawanie załączników',
'deleteattachments'       => 'Usuwanie załączników',
'viewhistory'             => 'Podgląd historii',
'closeowntasks'           => 'Zamykanie własnych zgłoszeń',
'closeothertasks'         => 'Zamykanie cudzych zgłoszeń',
'assigntoself'            => 'Przydzielanie sobie nieprzydzielonych zgłoszeń',
'assignotherstoself'      => 'Przydzielanie sobie już przydzielonych zgłoszeń',
'viewreports'             => 'Przeglądanie logu zdarzeń',
'othersview'              => 'Zezwalaj wszystkim na przeglądanie tego projektu',
'usersandgroups'          => 'Użytkownicy i grupy',
'globalgroup'             => 'Grupa globalna',
'globalgroups'            => 'Grupy globalne',
'defaultglobalgroup'      => 'Domyślna grupa globalna dla nowych użytkowników',
'addtogroup'              => 'Dodaj do grupy',
'moveuserstogroup'        => 'Przenieś zaznaczonych do grupy',
'nogroup'                 => 'Brak grupy - usuń z projektu',
'eventdesc'               => 'Opis zdarzenia',
'requestedby'             => 'Zgłoszone przez',
'daterequested'           => 'Data zgłoszenia',
'closetask'               => 'Zamknij zgłoszenie',
'reopentask'              => 'Otwórz ponownie zgłoszenie',
'applymember'             => 'Poproś o uczestnictwo w projekcie',
'forcurrentproj'          => 'Dla bieżącego projektu',
'lostpw'                  => 'Odzyskiwanie utraconego hasła',
'lostpwexplain'           => 'Aby odzyskać hasło, wprowadź swoją nazwę użytkownika. Link umożliwiający zmianę hasła zostanie wysłany na adres podany w Twoim profilu.',
'sendlink'                => 'Wyślij link',
'savenewpass'             => 'Zapisz nowe hasło',
'anonreg'                 => 'Zezwalaj na rejestrację nowych użytkowników',
'allowanonopentask'       => 'Zezwalaj na anonimowe dodawanie zgłoszeń',
'editglobalgroup'         => 'Edytuj grupę globalną',
'editgroupforproj'        => 'Edytuj grupę bieżącego projektu',
'notshownforadmin'        => 'Uprawnienia grupy administratorów nie są wyświetlane. Nie ma potrzeby wprowadzania zmian w tej grupie.',
'general'                 => 'Ogólne',
'userregistration'        => 'Rejestracja użytkowników',
'notifications'           => 'Powiadomienia',
'resetoptions'            => 'Przywróć ustawienia',
'preferences'             => 'Ustawienia',
'tasktypes'               => 'Typy zgłoszeń',
'resolutions'             => 'Powody zamknięcia',
'categories'              => 'Kategorie',
'operatingsystems'        => 'Systemy operacyjne',
'versions'                => 'Wersje',
'admintoolboxlong'        => 'Narzędzia administratora',
'newproject'              => 'Nowy projekt',
'delete'                  => 'Kasuj',
'listdeletetip'           => 'Usuń element',
'lookandfeel'             => 'Wygląd i zachowanie',
'globaltheme'             => 'Temat globalny',
'emailnotify'             => 'Powiadomienia na e-mail',
'fromaddress'             => 'Adres nadawcy',
'smtpserver'              => 'Serwer SMTP',
'smtpuser'                => 'Nazwa użytkownika SMTP',
'smtppass'                => 'Hasło SMTP',
'addrewrite'              => 'Używaj przyjaznych adresów',
'usereminderdaemon'       => 'Włącz demona przypomnień',
'tasksperpage'            => 'Liczba zgłoszeń na stronie',
'addtoassignees'          => 'Przydziel do siebie',
'taskstatuses'            => 'Statusy zgłoszeń',
'canvote'                 => 'Możesz głosować na zgłoszenie',
'loginsuccessful'         => 'Logowanie udane.',
'youareloggedout'         => 'Zostałeś wylogowany.',
'waitwhiletransfer'       => 'Proszę czekać na przekierowanie...',
'clicknowait'             => 'Kliknij tutaj, jeśli nie chcesz czekać.',
'accountdisabled'         => 'Twoje konto jest nieaktywne. Skontaktuj się z administratorem.',
'task'                    => 'Zgłoszenie',
'edittask'                => 'Edytuj zgłoszenie',

'copytask'                => 'Kopiuj zgłoszenie',

'openedby'                => 'Zgłoszone przez',
'editedby'                => 'Ostatnio edytował',
'tasktype'                => 'Typ zgłoszenia',
'category'                => 'Kategoria',
'status'                  => 'Status',
'assignedto'              => 'Przydzielone do',
'operatingsystem'         => 'System operacyjny',
'severity'                => 'Ważkość',
'reportedversion'         => 'Rozpoznane w wersji',
'dueinversion'            => 'Do realizacji w wersji',
'undecided'               => 'Nie zdecydowano',
'percentcomplete'         => 'Procent zaawansowania:',
'details'                 => 'Opis',
'savedetails'             => 'Zapisz',
'canceledit'              => 'Anuluj',
'anonymous'               => 'Anonimowy zgłaszający',
'complete'                => 'gotowe',
'closedby'                => 'Zamknięte przez',
'reasonforclosing'        => 'Powód zamknięcia:',
'reopenthistask'          => 'Ponownie otwórz zgłoszenie',
'comments'                => 'Komentarze',
'attachments'             => 'Załączniki',
'relatedtasks'            => 'Powiązane zgłoszenia',
'edit'                    => 'Edycja',
'addcomment'              => 'Dodaj komentarz',
'fileuploadedby'          => 'Plik przysłany przez',
'uploadafile'             => 'Wyślij załącznik',
'uploadnow'               => 'Wyślij teraz!',
'thesearerelated'         => 'Te zgłoszenia są powiązane z oglądanym',
'remove'                  => 'Usuń',
'addnewrelated'           => 'Dodaj nowe powiązanie',
'add'                     => 'Dodaj!',
'otherrelated'            => 'Inne zgłoszenia powiązane z obecnym',
'receivenotify'           => 'Ci użytkownicy zostaną powiadomieni o zmianach w tym zgłoszeniu.',
'addusertolist'           => 'Dodaj użytkownika do listy',
'addtolist'               => 'Dodaj do listy',
'addmyself'               => 'Dodaj mnie do listy',
'removemyself'            => 'Usuń mnie z listy',
'theseusersnotify'        => 'Ci użytkownicy będą powiadamiani o zmianach w tym zgłoszeniu.',
'attachedtoproject'       => 'Przydzielony do projektu',
'reminders'               => 'Przypomnienia',
'system'                  => 'System',
'remindthisuser'          => 'Przypomnij użytkownikowi',
'thisoften'               => 'Z częstotliwością',
'startafter'              => 'Odczekaj z przypominaniem',
'hours'                   => 'Godzin',
'days'                    => 'Dni',
'weeks'                   => 'Tygodni',
'addreminder'             => 'Dodaj przypomnienie',
'defaultreminder'         => 'To jest przypomnienie, by zająć się następującym zgłoszeniem Flyspraya: ',
'message'                 => 'Wiadomość',
'closed'                  => 'Zamknięte',
'filename'                => 'Nazwa pliku:',
'date'                    => 'Data',
'filesize'                => 'Rozmiar pliku:',
'closurecomment'          => 'Dodatkowe uwagi dotyczące zamknięcia:',
'history'                 => 'Historia',
'nohistory'               => 'To zgłoszenie nie ma historii.',
'eventdate'               => 'Data',
'user'                    => 'Użytkownik',
'event'                   => 'Zdarzenie',
'fieldchanged'            => 'Zmiana pola',
'taskopened'              => 'Otwarcie zgłoszenia',
'taskreopened'            => 'Zgłoszenie ponownie otwarte',
'taskclosed'              => 'Zgłoszenie zamknięte',
'commentadded'            => 'Dodano komentarz',
'commentedited'           => 'Zmieniono komentarza',
'commentdeleted'          => 'Usunięto komentarz',
'attachmentadded'         => 'Dodano załącznik',
'attachmentdeleted'       => 'Usunięto załącznik',
'taskedited'              => 'Zmieniono opis zgłoszenia',
'notificationadded'       => 'Dodanie użytkownika do listy powiadomień',
'notificationdeleted'     => 'Usunięcie użytkownika z listy powiadomień',
'relatedadded'            => 'Dodano powiązane zgłoszenie',
'relateddeleted'          => 'Usunięto powiązane zgłoszenie',
'taskassigned'            => 'Zgłoszenie przydzielone do',
'taskreassigned'          => 'Zmiana przydziału zgłoszenia do',
'assignmentremoved'       => 'Usunięcie przydziału zgłoszenia',
'summary'                 => 'Tytuł',
'addedasrelated'          => 'Zgłoszenie powiązane ze zgłoszeniem',
'deletedasrelated'        => 'Usunięcie powiązania ze zgłoszeniem',
'reminderadded'           => 'Dodano przypomnienie',
'reminderdeleted'         => 'Usunięto przypomnienie',
'priority'                => 'Priorytet',
'previousvalue'           => 'Poprzednia wartość',
'newvalue'                => 'Nowa wartość',
'selectareason'           => 'Wybierz powód',
'assigntome'              => 'Przejmij zgłoszenie',
'reopenrequest'           => 'Poproś o ponowne otwarcie',
'requestclose'            => 'Poproś o zamknięcie',
'ownershiptaken'          => 'Użytkownik przejął zgłoszenie',
'closerequestmade'        => 'Prośba o zamknięcie zgłoszenia',
'reopenrequestmade'       => 'Prośba o ponowne otwarcie zgłoszenia',
'taskdependson'           => 'Zgłoszenie zależy od',
'taskblocks'              => 'Zgłoszenie blokuje następujące zgłoszenia',
'depadded'                => 'Zgłoszenie ma nową zależność',
'depaddedother'           => 'Dodano zgłoszenie zależne',
'depremoved'              => 'Usunięto zależność',
'depremovedother'         => 'Zgłoszenie usunięte z listy zależności innego zgłoszenia',
'showdetailserror'        => 'Zgłoszenie nie istnieje lub nie masz uprawnień, by je oglądać.',
'makeprivate'             => 'Zmień na prywatne',
'makepublic'              => 'Zmień na publiczne',
'taskmadeprivate'         => 'Zgłoszenie ustawione jako prywatne',
'taskmadepublic'          => 'Zgłoszenie ponownie ustawione jako publiczne',
'confirmdeletecomment'    => 'Czy na pewno chcesz usunąć komentarz? %s',
'confirmdeleteattach'     => 'Czy na pewno chcesz usunąć załącznik?',
'selectedhistory'         => 'Pokazane zostały wybrane szczegóły historii.',
'showallhistory'          => 'Ponownie pokaż pełną historię',
'hidethis'                => 'Ponownie ukryj obszar',
'mark100'                 => 'Oznacz zgłoszenie jako wykonane w 100%',
'watchtask'               => 'Obserwuj zgłoszenie',
'stopwatching'            => 'Przestań obserwować',
'commentlink'             => 'Link do komentarza',
'submitreq'               => 'Wyślij prośbę',
'reasonforreq'            => 'Powód tego żądania',
'pmreqdenied'             => 'Menadżer projektu odrzucił prośbę',
'taskpendingreq'          => 'Prośba zgłoszona menadżerowi projektu. Więcej szczegółów w zakładce <i>Historia</i>.',
'previoustask'            => 'Poprzednie zgłoszenie',
'nexttask'                => 'Następne zgłoszenie',
'duedate'                 => 'Do realizacji do dnia',
'attachnoperms'           => 'Komentarz posiada załączniki, ale nie masz uprawnień, by je zobaczyć.',
'open'                    => 'Otwarte',
'depgraph'                => 'Pokaż graf zależności',
'reset'                   => 'Przywróć',
'selectusers'             => 'Zaznacz użytkowników...',
'addmetoassignees'        => 'Przydziel do mnie',
'addedtoassignees'        => 'Użytkownik przydzielony do zadania',
'dependencygraph'         => 'Wykres zależności',
'attachanotherfile'       => 'Załącz inny plik',
'OK'                      => 'OK',
'addvote'                 => 'Dodaj głos',
'notifyfromfs'            => 'Powiadomienie z Flyspraya',
'autogenerated'           => 'WIADOMOŚĆ WYGENEROWANA AUTOMATYCZNIE, NIE ODPOWIADAJ NA NIĄ',
'forward'                 => 'Prześlij',
'previous'                => 'Poprzedni',
'next'                    => 'Następny',
'first'                   => 'Pierwsza',
'last'                    => 'Ostatnia',
'page'                    => 'Strona %d z %d',
'search'                  => 'Szukaj',
'alltasktypes'            => 'Dowolny typ',
'allseverities'           => 'Dowolna ważkość',
'alldevelopers'           => 'Wszyscy programiści',
'notyetassigned'          => 'Zgłoszenia nieprzydzielone',
'allcategories'           => 'Dowolna kategoria',
'allstatuses'             => 'Dowolny status',
'allopentasks'            => 'Zgłoszenia otwarte',
'sortthiscolumn'          => 'Sortuj według kolumny',
'id'                      => 'ID',
'project'                 => 'Projekt:',
'dateopened'              => 'Data otwarcia',
'progress'                => 'Postęp',
'searchthisproject'       => 'Szukaj w bieżącym projekcie',
'dueanyversion'           => 'Realizacji w dowolnej wersji',
'anyversion'              => 'Rozpoznane w dowolnej wersji',
'dueversion'              => 'Realizacji w wersji',
'lastedit'                => 'Data ostatniej edycji',
'os'                      => 'System operacyjny',
'reportedin'              => 'Rozpoznane w',
'taskrange'               => 'Pokazane zgłoszenia %d - %d z %d',
'noresults'               => 'Żadne zgłoszenie nie spełnia warunków wyszukiwania.',
'takeaction'              => 'Wybierz czynność',
'watchtasks'              => 'Obserwuj zaznaczone',
'stopwatchingtasks'       => 'Przestań obserwować zgłoszenie',
'assigntaskstome'         => 'Przyporządkuj zaznaczone zgłoszenia do mnie.',
'dueby'                   => 'Realizacja do',
'dueanytime'              => 'Dowolna data',
'selectduedate'           => 'Wybierz datę realizacji',
'toggleselected'          => 'Przełącz zaznaczone',
'due'                     => 'Realizacja',
'assignedtome'            => 'Przyporządkowane do mnie',
'tasklist'                => 'Lista zgłoszeń',
'dateclosed'              => 'Data zamknięcia',
'advanced'                => 'Zaawansowane',
'searchcomments'          => 'Szukaj w komentarzach',
'searchforall'            => 'Szukaj wszystkich słów',
'anonusers'               => 'Użytkownik anonimowy',
'miscellaneous'           => 'Różne',
'users'                   => 'Użytkownicy',
'taskproperties'          => 'Właściwości zgłoszenia',
'selectsincedate'         => 'Wybierz Zmianę od',
'changedsince'            => 'Zmienione od',
'updatefs'                => 'Proszę zaktualizować Flyspraya.',
'currentversion'          => 'Twoja obecna wersja to',
'latestversion'           => 'najbardziej aktualna wersja to',
'hidemessage'             => '(przypomnij później)',
'saveas'                  => 'Zapisz wynik wyszukania jako',
'nosearches'              => 'Brak zapisanych wyszukiwań',
'saving'                  => 'Zapisywanie...',
'votes'                   => 'Głosy',
'allclosedtasks'          => 'Wszystkie zamknięte zgłoszenia',
'password'                => 'Hasło',
'login'                   => 'Zaloguj!',
'rememberme'              => 'Zapamiętaj mnie',
'lostpassword'            => 'Nie pamiętasz hasła?',
'lostpwforfs'             => 'Zapomniałem hasła do Flyspraya',
'lostpwmsg1'              => "Cześć.

Zapomniałem mojego hasła do Flyspraya na ",
'lostpwmsg2'              => ", proszę o przesłanie nowego hasła.

Użytkownik: ",
'regards'                 => "

Pozdrowienia,",
'yourusername'            => ' twoja nazwa użytkownika ',
'locale'                  => 'pl-PL',
'filenotexist'            => 'Plik nie istnieje lub nie masz uprawnień aby go pobrać.',
'showtask'                => 'Pokaż zgłoszenie',
'now'                     => 'Teraz',
'go'                      => 'Idź!',
'opentaskanon'            => 'Utwórz anonimowo nowe zgłoszenie',
'register'                => 'Zarejestruj nowe konto',
'addnewtask'              => 'Dodaj nowe zgłoszenie',
'reports'                 => 'Log zgłoszeń',
'editmydetails'           => 'Edytuj moje dane',
'logout'                  => 'Wyloguj się',
'disabledaccount'         => 'Twoje konto jest nieaktywne!<br />Zostaniesz wylogowany...',
'poweredby'               => 'Napędzane przez Flyspray',
'projects'                => 'Projekty',
'allprojects'             => 'wszystkie',
'selectproject'           => 'dla projektu:',
'tasksall'                => 'Wszystkie zgłoszenia',
'tasksassigned'           => 'Przydzielone do mnie',
'tasksreported'           => 'Zgłoszone przeze mnie',
'taskswatched'            => 'Obserwowane przeze mnie',
'mysearch'                => 'Moje wyszukiwania',
'admintoolbox'            => 'Narzędzia administratora',
'manageproject'           => 'Zarządzaj projektem',
'permissions'             => 'Pokaż uprawnienia',
'hide'                    => 'Ukryj',
'pendingreq'              => 'Oczekujące prośby',
'errorpage'               => "Flyspray nie znalazł żądanej strony.
				Być może zostało wybrane nieistniejące zgłoszenie 
				lub	nie masz uprawnień, by zobaczyć żądaną stronę.<br /><br />
				A może próbujesz w dziwny sposób zmusić bazę danych
				do wykonania twojego kodu SQL? Jeśli tak, to
				idź do kąta i zastanów się nad swoim postępowaniem. I nie rób tego więcej!",
'permissionsforproject'   => 'Uprawnienia dla ',
'switchto'                => 'Przełącz do',
'lastsearch'              => 'Ostatnio wyszukiwane',
'modify'                  => 'Zmień',
'noticefrom'              => 'Powiadomienie od',
'hasopened'               => ' OTWORZYŁ(A) NOWE ZGŁOSZENIE, które zostało Ci przydzielone:',
'moreinfonew'             => 'Więcej informacji o zgłoszeniu znajdziesz na stronie:',
'newtaskcategory'         => 'Dodano nowe zgłoszenie w tej kategorii',
'categoryowner'           => 'Otrzymałeś wiadomość, bo jesteś wymieniony jako opiekun kategorii.',
'tasksummary'             => 'Tytuł zgłoszenia:',
'newtaskadded'            => 'Twoje nowe zgłoszenie zostało dodane.',
'summaryanddetails'       => 'Musisz wypełnić zarówno tytuł jak i podać opis zgłoszenia.',
'goback'                  => 'Powrót.',
'messagefrom'             => 'To jest wiadomość z systemu śledzenia błędów Flyspray na ',
'hasjustmodified'         => 'właśnie zmienił(-a) zgłoszenie.',
'changedfields'           => 'Pola, które zmienione zostały oznaczone gwiazdkami (**)',
'moreinfomodify'          => 'Więcej informacji o zgłoszeniu znajdziesz na stronie:',
'nolongerassigned'        => 'Poniższe zgłoszenie nie jest już przydzielone do Ciebie. Zostało przydzielone do',
'hasassigned'             => 'przydzielił(-a) Ci następujące zgłoszenie:',
'taskupdated'             => 'Zgłoszenie zostało zaktualizowane.',
'hasclosedassigned'       => 'zamknął(-ęła) zgłoszenie które było przypisane do Ciebie:',
'unassigned'              => 'Nieprzydzielone',
'hasclosed'               => 'zamknął(-ęła) poniższe zgłoszenie.',
'youonnotify'             => 'Otrzymujesz wiadomość, bo jesteś na liście powiadomień.',
'taskclosedmsg'           => 'Zgłoszenie zostało zamknięte.',
'returntotask'            => 'Wróć do szczegółowego opisu zgłoszenia',
'backtoindex'             => 'Wróć do listy zgłoszeń',
'noclosereason'           => 'Nie został wybrany powód zamknięcia zgłoszenia.',
'hasreopened'             => 'ponownie otworzył(-a) zgłoszenie, które zamknąłeś(-aś):',
'taskreopenedmsg'         => 'Zgłoszenia ponownie otwarte.',
'backtotask'              => 'Wróć do zgłoszenia.',
'commentaddedmsg'         => 'Komentarz został dodany.',
'commenttoassigned'       => 'dodał(-a) następujący komentarz do zgłoszenia przydzielonego do:',
'commenttotask'           => 'dodał(-a) następujący komentarz do tego zgłoszenia.',
'nocommententered'        => 'Przed zatwierdzeniem formularza wpisz komentarz.',
'fillinfields'            => 'Nie zostały wypełnione wszystkie pola.',
'notcurrentpass'          => 'To nie jest twoje bieżące hasło!',
'passchanged'             => 'Twoje hasło zostało zmienione.',
'closewindow'             => 'Możesz już zamknąć to okno.',
'passnomatch'             => 'Źle powtórzone nowe hasło!',
'usernametaken'           => 'Ta nazwa użytkownika jest już zajęta. Wybierz inną.',
'newusercreated'          => 'Nowe konto zostało utworzone.',
'accountcreated'          => 'Twoje konto zostało utworzone.',
'newuserwarning'          => 'Jeśli nie możesz się zalogować, prawdopodobnie administrator ustawił wymóg akceptacji konta.',
'nomatchpass'             => 'Źle powtórzono hasło.',
'confirmwrong'            => 'Nieprawidłowy kod potwierdzający!',
'formnotcomplete'         => 'Nie został wypełniony cały formularz.',
'formnotnumeric'          => 'Podane dane nie są liczbowe!',
'groupnametaken'          => 'Grupa o takiej nazwie już istnieje.',
'newgroupadded'           => 'Grupa została dodana.',
'optionssaved'            => 'Opcje programu zostały zapisane.',
'hasuploaded'             => 'załączył(-a) plik do zgłoszenia przydzielonego do:',
'hasattached'             => 'załączył(-a) plik do następującego zgłoszenia.',
'fileuploaded'            => 'Plik został wysłany.',
'fileerror'               => 'Podczas wysyłania pliku wystąpił błąd. Być może jest to problem z niewłaściwymi prawami dostępu do katalogu załączników - <i>attachments/</i>.',
'contactadmin'            => 'Skontaktuj się z administratorem tego projektu.',
'selectfileerror'         => 'Pliku nie został wybrany.',
'userupdated'             => 'Dane użytkownika zostały zaktualizowane',
'realandemail'            => 'Pola imienia i nazwiska oraz adresu e-mail nie zostały podane.',
'groupupdated'            => 'Ustawienia grupy zostały zaktualizowane.',
'groupanddesc'            => 'Nazwa i opis grupy nie zostały podane.',
'fillallfields'           => 'Proszę wypełnić wszystkie pola.',
'listPmustN'              => 'W polu "Lp." należy wpisać liczbę.',
'listupdated'             => 'Lista została zaktualizowana.',
'listitemadded'           => 'Element listy został dodany.',
'relatedaddedmsg'         => 'Zgłoszenie zostało dodane do listy powiązanych.',
'relatederror'            => 'To zgłoszenie jest już na liście zgłoszeń powiązanych.',
'relatedremoved'          => 'Zgłoszenie zostało usunięte z listy powiązanych.',
'notifyadded'             => 'Użytkownik został dodany do listy powiadomień.',
'notifyerror'             => 'Użytkownik jest już na liście powiadomień tego zgłoszenia.',
'notifyremoved'           => 'Użytkownik został usunięty z listy powiadomień.',
'editcommentsaved'        => 'Zmieniony komentarz został zachowany.',
'commentdeletedmsg'       => 'Komentarz został usunięty.',
'gotonewtask'             => 'Przejdź do nowo utworzonego zgłoszenia',
'projectcreated'          => 'Twój nowy projekt został utworzony. Przejdź do zarządzania projektem, aby ustawić odpowiednie opcje.',
'customiseproject'        => 'Dostosuj projekt',
'projectupdated'          => 'Ustawienia projektu zostały zaktualizowane.',
'emptytitle'              => 'Tytuł projektu jest pusty. Wróć i popraw.',
'loginbelow'              => 'Możesz teraz spróbować zalogować się za pomocą formularza logowania.',
'attachmentdeletedmsg'    => 'Załącznik został usunięty',
'reminderaddedmsg'        => 'Twoje przypomnienie zostało dodane.',
'reminderdeletedmsg'      => 'Zaznaczone przypomnienie zostało usunięte.',
'flyspraytask'            => 'Zgłoszenie',
'fieldsmissing'           => 'Niektóre pola były puste lub zawierały błędne dane.',
'relatedinvalid'          => 'Zgłoszenie nie istnieje.',
'relatedproject'          => 'To zgłoszenie jest przypisane do innego projektu. Czy mimo to dodać powiązanie?',
'addanyway'               => 'Dodaj mimo tego',
'cancel'                  => 'Rezygnuj',
'alreadyedited'           => 'Zgłoszenie zostało w międzyczasie zmienione przez inną osobę. Czy mimo to chcesz zachować zmiany?',
'saveanyway'              => 'Mimo tego, zapisz moje zmiany.',
'nouserselected'          => 'Żaden użytkownik nie został wybrany. Wybierz przynajmniej jednego użytkownika i spróbuj ponownie.',
'groupswitchupdated'      => 'Grupy zostały zmodyfikowane.',
'takenownershipmsg'       => 'To zgłoszenie jest teraz przydzielone do Ciebie.',
'adminrequestmade'        => 'Twoja prośba została przesłana osobie zarządzającej projektem.',
'newdepnotify'            => 'Nowa zależność została dodana do poniższego zgłoszenia:',
'dependadded'             => 'Zależność dodana.',
'dependaddfailed'         => 'Nie możesz dodać tego zgłoszenia jako zależności',
'depremovedmsg'           => 'Zależność zgłoszeń została przeniesiona',
'newdepis'                => 'Nowa zależność',
'magicurlsent'            => 'Wiadomość została wysłana na Twój adres. Zawiera ona odnośnik do strony umożliwiającej dokończenie procedury.',
'changefspass'            => 'Zmień hasło',
'magicurlmessage'         => 'Wybierz poniższy odnośnik by zmienić hasło:',
'erroronform'             => 'Wystąpił problem podczas przetwarzania formularza',
'addressused'             => 'Twój adres został użyty do utworzenia konta we Flysprayu. Jeśli ta wiadomość jest nieoczekiwana, to zignoruj ją i skasuj. Aby potwierdzić rejestrację przejdź pod podany poniżej adres URL:',
'confirmcodeis'           => 'Kod weryfikujący:',
'codesent'                => 'Kod weryfikujący został wysłany wraz z dalszymi instrukcjami.',
'codenotsent'             => 'Nie udało się wysłać kodu weryfikującego, proszę spróbować później.',
'taskmadeprivatemsg'      => 'To zgłoszenie uzyskało status prywatnego',
'taskmadepublicmsg'       => 'To zgłoszenie odzyskało status publiczny',
'realandnotify'           => 'Musisz wypełnić pola \'Imię i nazwisko\' oraz \'Adres e-mail\' lub \'Jabber ID\'.',
'pmreqdeniedmsg'          => 'Prośba odrzucona przez Menadżera Projektu',
'massopsuccess'           => 'Operacja zbiorowa udana (tam, gdzie pozwalały na to uprawnienia)',
'usernotexist'            => 'Użytkownik nie istnieje',
'commentattachperms'      => 'Nie możesz usunąć komentarza - brak uprawnień do usuwania załączników',
'voterecorded'            => 'Twój głos został zarejestrowany',
'votefailed'              => 'Twój głos nie może zostać dodany w tej chwili.',
'createnewgroup'          => 'Utwórz nową grupę',
'requiredfields'          => 'Wymagane pola są oznaczone znakiem',
'addthisgroup'            => 'Dodaj grupę',
'createnewproject'        => 'Utwórz nowy projekt',
'addnewproject'           => 'Dodaj projekt',
'htmlallowed'             => 'Zezwalaj na kod HTML',
'createthisproject'       => 'Utwórz projekt',
'inlineimages'            => 'Wyświetl załączniki w treści strony',
'createnewtask'           => 'Utwórz nowe zgłoszenie dla projektu',
'addanother'              => 'Dodaj kolejne zgłoszenie',
'addthistask'             => 'Dodaj to zgłoszenie',
'notifyme'                => 'Powiadom mnie, gdy zgłoszenie zostanie zmienione',
'newtask'                 => 'Nowe zgłoszenie',
'attachafile'             => 'Załącz plik',
'registernewuser'         => 'Rejestracja nowego użytkownika',
'none'                    => 'Brak',
'registeraccount'         => 'Utwórz konto',
'both'                    => 'Obydwa',
'notifyfrom'              => 'Powiadomienie od ',
'donotreply'              => 'WIADOMOŚĆ WYGENEROWANA AUTOMATYCZNIE. NIE ODPOWIADAJ NA NIĄ.',
'disclaimer'              => 'Otrzymujesz tę wiadomość, ponieważ została ona zamówiona ją w aplikacji do śledzenia błędów - Flyspray. Jeśli nie chcesz otrzymywać podobnych wiadomości w przyszłości, to zmień ustawienia dla swoich powiadomień na stronie o adresie widocznym powyżej.',
'userwho'                 => 'Zmiana dokonana przez użytkownika:',
'moreinfo'                => 'Więcej informacji pod poniższym adresem URL:',
'newtaskopened'           => 'Pojawiło się nowe zgłoszenie.  Szczegóły poniżej.',
'notify.taskclosed'       => 'Następujące zgłoszenie zostało zamknięte:',
'notify.taskreopened'     => 'Następujące zgłoszenie zostało ponownie otwarte:',
'newdep'                  => 'Następujące zgłoszenie posiada nową zależność:',
'notify.depremoved'       => 'Z następującego zgłoszenia została usunięta zależność:',
'olddepwas'               => 'Stara zależność',
'notify.commentadded'     => 'Do następującego zgłoszenia został dodany komentarz:',
'commentis'               => 'Treść komentarza poniżej.',
'newattachment'           => 'Nowy plik został załączony do następującego zgłoszenia:',
'detailsbelow'            => 'Szczegóły poniżej.',
'notify.relatedadded'     => 'Nowe powiązanie zostało dodane do następującego zgłoszenia:',
'relatedis'               => 'Powiązane zgłoszenie to',
'assignedtoyou'           => 'Następujące zgłoszenie zostało przydzielone do Ciebie:',
'takenownership'          => 'przejął zgłoszenie:',
'requiresaction'          => 'Następujące zgłoszenie wymaga akcji ze strony Menadżera Projektu:',
'requiresactionnotify'    => 'Zgłoszenie wymaga akcji ze strony Menadżera Projektu:',
'pmdeny'                  => 'Menadżer Projektu odrzucił prośbę dotyczącą zgłoszenia:',
'pmdenynotify'            => 'Menadżer Projektu odrzucił prośbę',
'fileaddedtoo'            => 'Co najmniej jeden plik został dołączony do komentarza.',
'taskwatching'            => 'Obserwujesz następujące zgłoszenia',
'isdepfor'                => 'zależy od',
'denialreason'            => 'Powód odmowy',
'taskchanged'             => 'Zgłoszenie uległo zmianie.  Zmiany są pokazane poniżej.  Aby dowiedzieć się więcej, otwórz stronę zgłoszenia i wybierz zakładkę Historia.',
'useraddedtoassignees'    => 'Użytkownik dodał siebie do listy użytkowników przydzielonych do tego zgłoszenia.',
'removeddepis'            => 'Usunięta zależność to',
'isnodepfor'              => 'już nie jest zależny od',
'usergroups'              => 'Grupy użytkowników',
'pmtoolbox'               => 'Narzędzia Menadżera Projektu',
'groupmanage'             => 'Zarządzanie grupą',
'pendingrequests'         => 'Oczekujące zgłoszenia administratorów',
'reasongiven'             => 'Podana przyczyna',
'nopendingreq'            => 'Brak oczekujących próśb.',
'givereason'              => 'Podaj przyczynę',
'catlisted'               => 'Edytor kategorii',
'oslisted'                => 'Edytor listy systemów operacyjnych',
'verlisted'               => 'Edytor listy wersji',
'tasktypeed'              => 'Edytor listy typów zgłoszeń',
'resed'                   => 'Edytor listy powodów zamknięcia',
'deny'                    => 'Odrzuć',
'notifiedwhen'            => 'Powiadomienia gdy',
'onlynewtasks'            => 'Nowe zgłoszenia są otwarte',
'allevents'               => 'Dowolne zdarzenie dla dowolnego zgłoszenia',
'feeds'                   => 'Kanały',
'feeddescription'         => 'Opis kanału',
'feedimgurl'              => 'Adres URL grafiki kanału (pozostaw puste jeśli brak)',
'notifysubject'           => 'Temat powiadomień',
'notifysubjectinfo'       => '(%p = tytuł projektu, %s = opis zgłoszenia, %t = identyfikator zgłoszenia, %a = akcja, %u = użytkownik)',
'priority6'               => 'Błyskawicznie',
'priority5'               => 'Natychmiast',
'priority4'               => 'Pilne',
'priority3'               => 'Wysoki',
'priority2'               => 'Normalny',
'priority1'               => 'Niski',
'sendcode'                => 'Wyślij kod!',
'entercode'               => 'Podaj kod, który znajduje się w wysłanej do Ciebie wiadomości. Podaj też swoje nowe hasło.',
'confirmationcode'        => 'Kod potwierdzający',
'registererror'           => 'Upewnij się, że wszystkie wymagane pola zostały wypełnione oraz że podałeś odpowiednie dane co do wybranej metody komunikacji.',
'validusername'           => '(dozwolone są wyłącznie znaki alfanumeryczne oraz - _ .)',
'emailtaken'              => 'Ten adres e-mail lub Jabber ID jest już zajęty. Wybierz inny.',
'note'                    => '<b>Uwaga:</b> Zanim Twoje konto zostanie otwarte, wyślemy do Ciebie kod potwierdzający. Kod ten zostanie wysłany w sposób wybrany przez Ciebie powyżej.<br />Jeśli podasz fałszywe dane, <strong>nie otrzymasz kodu</strong>.',
'changelog'               => 'Lista zmian',
'changeloggen'            => 'Generator listy zmian',
'listfrom'                => 'Pokaż zmiany od',
'to'                      => 'do',
'oldestfirst'             => 'Sortuj od najstarszych',
'recentfirst'             => 'Sortuj od najnowszych',
'severityrep'             => 'Raport ważkości',
'totalopen'               => 'Całkowita liczba otwartych zgłoszeń',
'age'                     => 'Wiek',
'agerep'                  => 'Raport wieku',
'eventsrep'               => 'Raport zdarzeń',
'events'                  => 'Zdarzenia',
'Tasks'                   => 'Zgłoszenia',
'opened'                  => 'Otwarte',
'edited'                  => 'Zmieniane',
'assigned'                => 'Przydzielone',
'within'                  => 'Okres',
'pastday'                 => 'wczoraj',
'pastweek'                => 'w zeszłym tygodniu',
'pastmonth'               => 'w zeszłym miesiącu',
'pastyear'                => 'w zeszłym roku',
'nolimit'                 => 'bez ograniczeń',
'from'                    => 'Zakres dni',
'duein'                   => 'Do wersji',
'selectfromdate'          => 'Wybierz datę rozpoczęcia',
'selecttodate'            => 'Wybierz datę zakończenia',
'showvoters'              => 'Wyświetl/ukryj głosujących',
'roadmap'                 => 'Plan działań',
'roadmapfor'              => 'Plan działań dla wersji',
'tasks'                   => 'Zgłoszenia',
'completed'               => 'zakończono.',
'opentasks'               => 'otwarte zgłoszenia',
'of'                      => '% z',
'severity5'               => 'Krytyczna',
'severity4'               => 'Wysoka',
'severity3'               => 'Średnia',
'severity2'               => 'Niska',
'severity1'               => 'Bardzo niska',
'Redirect'                => 'Przekierowanie',
'redirectmsg'             => 'Jeśli Twoja przeglądarka nie obsługuje meta-przekierowań, to kliknij %sTUTAJ%s aby zostać przeniesionym do odpowiedniej strony',
'allowclosedcomments'     => 'Wszystkie komentarze z zamkniętych zgłoszeń',
'comment'                 => 'Komentarz',
'editowncomments'         => 'Edytuj własne komentarze',
'reopened'                => 'Ponownie otwarty',
'loading'                 => 'Wczytywanie...',
'notifyown'               => 'Powiadom o własnych zmianach',
'youremail'               => 'Twój adres e-mail',
'thankyouforbug'          => 'Dziękujemy za zgłoszenie problemu. Możesz obejrzeć zgłoszenie i obserwować postęp używając poniższego adresu URL:',
'anonuser'                => 'użytkownik anonimowy',
'conflict'                => 'Konflikt',
'file'                    => 'Plik',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Rozmiar',
'projectgroup'            => 'Grupa Projektu',
'profile'                 => 'Profil:',
'viewprofile'             => 'Obejrzyj profil',
'regdate'                 => 'Zarejestrowany od',
'tasksopened'             => 'Zgłoszenia otwarte',
'replyto'                 => 'Odpowiedź do',
'notifytypes'             => 'Rodzaje powiadomień',
'pm.taskchanged'          => 'Zgłoszenie zmienione',
'pm.taskreopened'         => 'Zgłoszenie ponownie otwarte',
'pm.depadded'             => 'Zależność dodana',
'pm.depremoved'           => 'Zależność usunięta',
'pmrequest'               => 'Prośba przez PW ',
'pmrequestdenied'         => 'Prośba odrzucona',
'newassignee'             => 'Nowy przydział',
'revdepadded'             => 'Odwrotna zależność dodana',
'revdepaddedremoved'      => 'Odwrotna zależność usunięta',
'assigneeadded'           => 'Przyporządkowanie zostało dodane',
'addusergroup'            => 'Dodaj użytkownika do grupy',
'groupmembers'            => 'Użytkownicy grupy',
'deleteuser'              => 'Usuń użytkownika',
'userdeleted'             => 'Usunięto użytkownika',
'autoassign'              => 'Automatycznie przydziel zgłoszenia do właściciela kategorii',
'ssl'                     => 'SSL',
'updatewrong'             => 'Funkcja sprawdzania dostępności aktualizacji jest włączona,
                             lecz próba kontaktu z serwerem aktualizacji nie powiodła się. Twój serwer nie zezwala na zewnętrzne połączenia
                             lub wystąpiły problemy z siecią.
                             Aby upewnić się, że posiadasz najnowszą wersję Flyspraya, wejdź na stronę http://www.flyspray.org/.',
'deleteproject'           => 'Usuń ten projekt i przenieś zawartość do',
'projectdeleted'          => 'Projekt został pomyślnie usunięty',
'feedforall'              => 'Kanał dla wszystkich projektów',
'usercreated'             => 'Dodano użytkownika',
'userdeleted'             => 'Skasowano użytkownika',
'created'                 => 'Utworzono',
'deleted'                 => 'Usunięto',
'userid'                  => 'ID użytkownika',
'editassignments'         => 'Zmień przydziały',
'preview'                 => 'Podgląd',
'anyprogress'             => 'dowolny postęp',
'tasksrelated'            => 'Zgłoszenia powiązane z tym zgłoszeniem',
'duplicatetasks'          => 'Duplikaty tego zgłoszenia',
'databasemodfailed'       => 'Błąd podczas zmian w bazie danych. Prawdopodobną przyczyną jest brak wystarczających uprawnień.',
'frequency'               => 'Częstotliwość',
'newuserregistered'       => 'Nowy użytkownik został zarejestrowany w Twojej instalacji Flyspraya. Szczegóły użytkownika:',
'newuserregisterednotify' => 'Nowy użytkownik został zarejestrowany',
'notify_registration'     => 'Powiadom administratorów o nowo zarejestrowanym użytkowniku',
'textversion'             => 'Wersja tekstowa',
'onlyprimary'             => 'Zgłoszenia nie blokujące innych zgłoszeń',
'switch'                  => 'Przełącz',
'max'                     => 'maks',
'dates'                   => 'Daty',
'selectduedatefrom'       => 'Realizacja od',
'selectduedateto'         => 'do',
'selectsincedatefrom'     => 'Zmieniane od',
'selectsincedateto'       => 'do',
'selectdate'              => 'Wybierz datę',
'selectopenedfrom'        => 'Otwarte od',
'selectopenedto'          => 'do',
'selectclosedfrom'        => 'Zamknięte od',
'selectclosedto'          => 'do',
'startat'                 => 'Zacznij od',
'hasattachment'           => 'Posiada załącznik',
'private'                 => 'Prywatne',
'watching'                => 'Obserwowanie',
'alreadyvotedthistask'    => 'już głosowałeś na to zgłoszenie',
'alreadyvotedthisday'     => 'już dziś głosowałeś',
'visibility'              => 'Widoczność',
'public'                  => 'Publiczne',
'leaveemptyauto'          => 'Pozostaw pola hasła puste, jeśli chcesz aby zostało ono automatycznie wygenerowane.',
'novalidemail'            => 'Podaj poprawny adres email.',
'novalidjabber'           => 'Podaj poprawny identyfikator Jabbera.',
'missingrequired'         => 'Nie wszystkie wymagane pola zostały wypełnione.',
'entervalidusername'      => 'Proszę podać prawidłową nazwę użytkownika oraz imię i nazwisko.',
'couldnotaddusernotif'    => 'Nie udało się dodać tego użytkownika do listy powiadomień.',
'defaulttask'             => 'Standardowy opis zgłoszenia',
'all'                     => 'Wszystkie',
'events.useraddedtoassignees'=> 'Użytkownik został przydzielony',
'vote(s)'                 => 'głos(y)',
'eventlog'                => 'Log zdarzeń',
'assignmentchanged'       => 'Przydział został zmieniony',
'detailedinfo'            => 'Szczegółowe informacje',
'All'                     => 'Wszystkie',
'tasksireported'          => 'Zgłoszone przeze mnie',
'recentlyopened'          => 'Ostatnio otwarte',
'stats'                   => 'Statystyki',
'totaltasks'              => 'wszystkie zgłoszenia',
'mostwanted'              => 'Najbardziej oczekiwane zgłoszenia',
'defaultentry'            => 'Domyślna strona',
'toplevel'                => 'Widok główny',
'overview'                => 'Przegląd',
'error#'                  => 'Błąd #',
'error1'                  => 'Nie posiadasz wymaganych uprawnień aby móc obejrzeć ten załącznik.',
'error3'                  => 'Powtórzona akcja, przekierowuję do strony głównej.',
'error4'                  => 'Nie posiadasz uprawnień administratora.',
'error5'                  => 'Taki użytkownik nie istnieje w tej instalacji Flyspraya.',
'error6'                  => 'Nieprawidłowa strefa administratora.',
'error7'                  => 'Logowanie nie powiodło się - nieprawidłowe hasło!',
'error71'                 => 'Konto zostało zablokowane na %d minut (zbyt dużo nieudanych prób logowania)!',
'error8'                  => 'Niewypełniona nazwa użytkownika oraz hasło.',
'error9'                  => 'Zgłoszenie nie istnieje lub nie posiadasz wystarczających uprawnień aby je obejrzeć.',
'error10'                 => 'Zgłoszenie nie istnieje lub nie posiadasz uprawnień aby je obejrzeć.',
'error101'                => 'Nie posiadasz uprawnień do oglądania tego zgłoszenia.',
'error102'                => 'Nie posiadasz uprawnień do oglądania tego zgłoszenia - być może wystarczy się zalogować.',
'error11'                 => 'Brak uprawnień do zmiany tego komentarz.',
'error12'                 => 'Brak prawidłowego magicznego klucza! Czy jesteś pewien, że taki właśnie otrzymałeś w powiadomieniu?',
'error13'                 => 'Użytkownicy anonimowi nie posiadają profilu.',
'error14'                 => 'Nie posiadasz wystarczających uprawnień aby utworzyć nową grupę.',
'error15'                 => 'Nie posiadasz wystarczających uprawnień aby otworzyć zgłoszenie.',
'error16'                 => 'Nie jesteś menadżerem projektu.',
'error17'                 => 'Nieprawidłowy obszar prywatnych wiadomości.',
'error18'                 => 'Nieprawidłowy magiczny URL.',
'error19'                 => 'Taki użytkownik nie istnieje w tej instalacji Flyspraya.',
'error20'                 => 'Nieprawidłowa zmiana bazy danych.',
'error21'                 => 'Nie udało się wysłać jednej lub więcej wiadomości e-mail. Sprawdź swoje ustawienia.',
'error22'                 => 'Rejestracja nowych użytkowników jest niedozwolona.',
'error23'                 => 'Nieaktywny użytkownik lub grupa.',
'error24'                 => 'Brak ustawionego dostępu do programu "dot" lub publicznego serwera "dot" do generowania grafów.',
'error25'                 => 'Plan działań jest dostępny jedynie dla wybranych projektów.',
'error26'                 => 'Nieznany klucz OAuth.',
'error27'                 => 'Nie można zalogować. Pozwól nam zobaczyć Twój adres e-mail.',
'done'                    => 'wykonano',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projekt nie mógł zostać usunięty.',
'GMT'                     => 'GMT',
'timezone'                => 'Strefa czasowa',
'accept'                  => 'Akceptuj',
'reasonfordeinal'         => 'Powód odmowy',
'pruneclosedlinks'        => 'Przytnij zamknięte odnośniki',
'pruneclosedtasks'        => 'Przytnij zamknięte zgłoszenia',
'pagegenerated'           => 'Strona i grafika wygenerowane w %d sekund.',
'pruninglevel'            => 'Stopień przycinania',
'lastuser'                => 'Ostatni użytkownik nie może zostać usunięty.',
'allprivate'              => 'Wszystkie projekty są prywatne.',
'deletegroup'             => 'Usuń tę grupę i przenieś użytkowników do',
'parent'                  => 'Nadrzędny',
'ordertip'                => 'Kolejność tych pozycji będzie widoczna na liście',
'showtip'                 => 'Wyświetl to zgłoszenie na liście',
'deletetip'               => 'Usuń tę wartość z listy',
'del'                     => 'kasuj',
'request1'                => 'Poproszono o zamknięcie zgłoszenia.',
'request2'                => 'Poproszono o ponowne otwarcie zgłoszenia.',
'allpriorities'           => 'Wszystkie priorytety',
'noroadmap'               => 'Plan działań jest niedostępny (w tym projekcie nie ma przyszłej wersji).',
'expand'                  => 'Rozwiń',
'collapse'                => 'Zwiń',
'expandall'               => 'Rozwiń wszystkie',
'collapseall'             => 'Zwiń wszystkie',
'minpwsize'               => 'Minimalna długość hasła to 5 znaków',
'passwordtoosmall'        => 'Hasło jest za krótkie.',
'accountwaslocked'        => 'Twoje konto zostało zablokowane z powodu zbyt wielu nieudanych prób zalogowania się.',
'failedattempts'          => 'Liczba nieudanych prób zalogowania się: %d.',
'groupnotexist'           => 'W tym projekcie nie ma wybranej grupy.',
'searchindetails'         => 'Szukaj w opisach',
'showasassignees'         => 'Pokaż przy przydzielaniu',
'find'                    => 'wyszukaj',
'tls'                     => 'TLS',
'isadmin'                 => 'Jest administratorem',
'addvotes'                => 'Dodaj głosy',
'removevote'              => 'Usuń głos',
'voteremoved'             => 'Głos został usunięty',
'voteremovefailed'        => 'Błąd podczas usuwania głosu.',
'connectedtasks'          => 'Połączone zgłoszenia:',
'taskdependencies'        => 'Zależności',
'viewgraph'               => 'wyświetl graf',
'notaskdependencies'      => 'To zgłoszenie nie jest zależne od żadnego innego zgłoszenia.',
'dependson'               => 'Zależny od',
'blocks'                  => 'Bloki',
'newdependency'           => 'Nowa zależność:',
'nouserstoadd'            => 'Brak użytkowników do dodania. Upewnij się, że Imię, Nazwa użytkownika oraz e-mail są zdefiniowane dla każdego użytkownika.',
'dispintro'               => 'Pokaż wstępną wiadomość',
'mainmessage'             => 'Wiadomość wstępna',
/* note only the English version for 'dispintro' is supported
 * other languages should also be taken cared of in the future*/

'setsupertask'            => 'Ustaw ID Super-Zgłoszenia:',
'supertaskmodified'       => 'ID Super-Zgłoszenia został zmieniony',
'set'                     => 'Ustaw',
'supertask'               => 'Super-Zgłoszenie',
'setparent'               => 'Ustaw ID zgłoszenia nadrzędnego dla tego zgłoszenia',
'selfsupertasknotallowed' => 'ID dla Super-Zgłoszenia nie może być taki sam jak ID dla własnego zgłoszenia',
'quickaction'             => 'Szybkie działania',
'updateselectedtasks'     => 'Aktualizuj wybrane zadania',
'notspecified'            => 'Nic nie zaznaczono',
'editselectedtasks'       => 'Edytuj wybrane zadania',
'information'             => 'Informacja',
'taskclosedisabled'       => 'Zamknięcie zgłoszenia jest niemożliwe, ponieważ następujące zgłoszenia zależne są otwarte:-',
'daysleft'                => 'Dni pozostałych',
'dayoverdue'              => 'spóźnionych dni',
'duetoday'                => 'Na dziś.',
'daysbeforealert'         => 'Liczba dni przed ostrzeżeniem',
'associatedsubtask'       => 'Pomyślnie przypisano zadanie podrzędne #FS',
'associatesubtask'        => 'Przypisz ID zadania podrzędnego do tego zadania',
'subtaskid'               => 'ID zadania podrzędnego',
'subtaskalreadyhasparent' => 'Zgłoszenie podrzędne może mieć tylko jedno zgłoszenie nadrzędne. Aby ustawić inne, usuń poprzednie.',
'subtaskisparent'         => 'Nie można ustawić zgłoszenia podrzędnego, ponieważ jest ono ustawione jako nadrzędne.',
'subtasknotexist'         => 'Wybrane zgłoszenie podrzędne nie istnieje.',
'subtaskremovedmsg'       => 'Zgłoszenie podrzędne zostało pomyślnie usunięte',
'subtaskadded'            => 'Zadanie podrzędne dodane',
'subtaskremoved'          => 'Zadanie podrzędne usunięte',
'addnewsubtask'           => 'Dodaj zgłoszenie podrzędne',
'hidesubtasks'            => 'Ukryj zgłoszenie podrzędne',
'voteforthistask'         => 'Głosuj na to zgłoszenie',
'watchthistask'           => 'Śledź to zgłoszenie',
'privatethistask'         => 'Oznacz jako zgłoszenie prywatne',
'adddependenttask'        => 'Przypisz zgłoszenie zależne',
'associatetaskid'         => 'ID zgłoszenia podrzędnego',
'parenttaskid'            => 'ID zgłoszenia nadrzędnego',
'invalidsupertaskid'      => 'ID Super-Zgłoszenia nieprawidłowy.',
'supertaskadded'          => 'Super-Zgłoszenie dodane',
'effort'                  => 'Czas pracy',
'efforttracking'          => 'Śledzenie czasu pracy',
'useeffort'               => 'Projekt używa śledzenia czasu prac',
'estimated_effort'        => 'Przewidziany czas pracy',
'totalestimatedeffort'    => 'Całkowity przewidziany czas prac',
'actualeffort'            => 'Zrealizowany czas pracy',
'starteffort'             => 'Zacznij śledzenie',
'endeffort'               => 'Zakończ śledzenie',
'cleareffort'             => 'Wyczyść śledzenie',
'addeffort'               => 'Dodaj czas pracy',
'manualeffort'            => 'Dodaj czas pracy ręcznie (H:M)',
'efforttrackingstarted'   => 'Śledzenie czasu prac zlecone dla tego zgłoszenia.',
'efforttrackingnotstarted'=> 'Śledzenia czasu prac niemożliwe dla zgłoszeń już śledzonych',
'efforttrackingstopped'   => 'Śledzenie czasu prac zakończone dla tego zgłoszenia.',
'efforttrackingcancelled' => 'Śledzenie czasu prac anulowane dla tego zgłoszenia.',
'efforttrackingadded'     => 'Ręczny czas pracy dodany do zgłoszenia.',
'trackinginprogress'      => 'Śledzenie czasu pracy w toku',
'vieweffort'              => 'Można przeglądać śledzenie czasu pracy',
'trackeffort'             => 'Można śledzić czasu pracy',
'invalideffort'           => 'Błędnie wybrany czas pracy. Wpisz liczbę.',
'showpass'                => 'Pokaż hasło',
'chooseafile'             => 'Proszę wybrać plik!',
'incorrectfiletype'       => 'Niewłaściwy typ pliku. Dozwolone: JPG, JPEG, GIF, PNG.',
'oauthreqpass'            => 'Nie potrzeba hasła. Zarejestrowano przez %s',
'addmultipletasks'        => 'Dodaj wiele zgłoszeń',
'pendingnewuserrequest'   => 'Oczekujące rejestracje',
'adminrequestswaiting'    => 'Oczekujące rejestracje administratora',
'clicktoedit'             => 'Kliknij pola dla szybkiej edycji',
'confirmedit'             => 'zatwierdź',
'canceledit'              => 'anuluj',
'regapprovedbyadmin'      => 'Rejestracja za akceptacją administratora (brak kodów weryfikacyjnych)',
'activity'                => 'Aktywność',
'myactivity'              => 'Moja aktywność',
'emailverificationwrong'  => 'Nieprawidłowo powtórzony adres e-mail',
'verifyemailaddress'      => 'Potwierdź adres e-mail',
'hideemails'              => 'Ukryj adresy e-mail użytkowników',
'hidemyemail'             => 'Ukryj mój adres e-mail',
'exporttasklist'          => 'Eksportuj listę zgłoszeń'
);
?>
