<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Редактировать пользователя',
'accountenabled'          => 'Учетная запись активна',
'editallusers'            => 'Все пользователи',
'username'                => 'Имя пользователя',
'usersupdated'            => 'Пользователь успешно обновлён',
'realname'                => 'Полное имя',
'emailaddress'            => 'Адрес Email',
'jabberid'                => 'Jabber ID',
'profileimage'            => 'Фото профиля',
'notifytype'              => 'Тип уведомления',
'group'                   => 'Группа',
'enableaccounts'          => 'Включить аккаунт',
'disableaccounts'         => 'Отключить аккаунт',
'deleteaccounts'          => 'Удалить аккаунт',
'updatedetails'           => 'Сохранить',
'setglobally'             => 'Настройка была установлена для всей системы.',
'usergroupmanage'         => 'Управление пользователями и группами',
'newuser'                 => 'Создать нового пользователя',
'newuserbulk'             => 'Зарегистрировать несколько новых пользователей',
'bulkuserstoadd'          => 'Список новых пользователей',
'optionsforallusers'      => 'Настройки для всех новых пользователей',
'newgroup'                => 'Создать новую группу',
'yes'                     => 'Да',
'no'                      => 'Нет',
'editgroup'               => 'Редактировать группу',
'groupname'               => 'Имя группы',
'description'             => 'Описание',
'admin'                   => 'Группа администраторов',
'opennewtasks'            => 'Создание задач',
'modifytasks'             => 'Изменять(-ить) существующие задачи',
'addcomments'             => 'Добавить комментарий',
'attachfiles'             => 'Присоединить файлы',
'vote'                    => 'Голосовать',
'groupenabled'            => 'Пользователи из этой группы могут входить в систему',
'groupopen'               => 'Пользователи из этой группы могут входить в систему',
'tasktypelist'            => '-Список типов задач',
'categorylist'            => 'Список категорий',
'oslist'                  => 'Список операционных систем',
'resolutionlist'          => 'Список резолюций',
'versionlist'             => 'Список версий',
'severitylist'            => 'Список значений критичности',
'listnote'                => 'Замечание: снятие отметки с чекбокса "Показать" может изменить некоторые задачи в режиме редактирования. Изменение поля "Название" повлияет на все задачи, использующие это имя. Элементы, которые невозможно удалить, необходимы для правильной работы системы или используются.',
'name'                    => 'Название',
'order'                   => 'Порядок',
'back'                    => 'Назад',
'text'                    => 'Текст',
'highlight'               => 'Выделить',
'show'                    => 'Показать',
'owner'                   => 'Владелец',
'selectowner'             => 'Выбрать владельца',
'update'                  => 'Сохранить',
'addnew'                  => 'Добавить',
'flysprayprefs'           => 'Настройки Flyspray',
'projecttitle'            => 'Название проекта',
'baseurl'                 => 'Базовый URL для этой установки',
'replyaddress'            => 'Адрес для ответа в уведомлениях.',
'themestyle'              => 'Тема / Стиль',
'customstyle'             => 'пользовательский',
'language'                => 'Язык',
'anonview'                => 'Разрешить незарегистрированным пользователям просматривать задачи',
'allowanon'               => 'Разрешить незарегистрированным пользователям создавать задачи',
'never'                   => 'Никогда',
'anonymously'             => 'Анонимно (без регистрации)',
'afterregister'           => 'Только после регистрации',
'spamproof'               => 'Использовать код подтверждения для регистрации новых пользователей',
'anongroup'               => 'Группа для вновь создаваемых пользователей',
'groupassigned'           => 'Членам этой группы могут быть назначены задачи',
'forcenotify'             => 'Способ отправки уведомлений',
'neversend'               => 'Никогда не отправлять',
'userchoose'              => 'На выбор пользователя',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Владелец категории по умолчанию',
'noone'                   => 'Никому',
'jabbernotify'            => 'Уведомление по Jabber',
'jabberserver'            => 'Сервер',
'jabberport'              => 'Порт',
'jabberuser'              => 'Имя пользователя',
'jabberpass'              => 'Пароль',
'saveoptions'             => 'Сохранить настройки',
'editcomment'             => 'Редактировать комментарий',
'commentby'               => 'Комментарий от',
'saveeditedcomment'       => 'Сохранить отредактированный комментарий',
'projectprefs'            => 'Свойства проекта',
'pagetitle'               => 'Заголовок страницы',
'defaultproject'          => 'Проект "по умолчанию"',
'projectlists'            => 'Список проектов',
'showlogo'                => 'Показывать титульный логотип',
'showgravatars'           => 'Показать Gravatars',
'emailNoHTML'             => 'Запретить HTML в E-Mails',
'intromessage'            => 'Приветственное сообщение',
'active'                  => 'активный',
'inactive'                => 'неактивный',
'isactive'                => 'Проект активен',
'showinactive'            => 'Показать неактивные проекты',
'hideinactive'            => 'Скрыть неактивные проекты',
'createproject'           => 'Создать новый проект',
'nopermission'            => 'Недостаточно прав, чтобы использовать эту страницу',
'listordertip'            => 'Порядок, в котором данные элементы будут представлены в списке',
'listshowtip'             => 'Показывать этот элемент в списке',
'categoryownertip'        => 'Данный пользователь получит уведомление, когда в этой категории будет создана задача',
'categoryparenttip'       => 'Родительская категория для вновь создаваемой',
'notsubcategory'          => 'Нет (категория верхнего уровня)',
'showinlineimages'        => 'Показывать вложенные изображения',
'dateformat'              => 'Формат даты',
'dateformat_extended'     => 'Формат даты (подробный)',
'cache_feeds'             => 'Где хранить кэш новостных лент',
'no_cache'                => 'Не кэшировать',
'cache_disk'              => 'Кэш на диске',
'cache_db'                => 'Кэш в базе данных',
'subcategoryof'           => 'Подкатегория',
'visiblecolumns'          => 'Видимые колонки в списке задач',
'visiblefields'           => 'Поля при добавлении, изменении или просмотре задачи',
'tense'                   => 'Когда выпущена',
'listtensetip'            => 'Прошлая, текущая или будущая',
'past'                    => 'Прошлая',
'present'                 => 'Текущая',
'future'                  => 'Будущая',
'oldpass'                 => 'Старый пароль',
'nooldpass'               => 'Старый пароль не был задан',
'oldpasswrong'            => 'Старый пароль был указан неверно',
'changepass'              => 'Изменить пароль',
'confirmpass'             => 'Подтвердить пароль',
'projectmanager'          => 'Руководитель проекта',
'viewtasks'               => 'Просмотр задач',
'modifyowntasks'          => 'Редактирование собственных задач',
'modifyalltasks'          => 'Редактирование чужих задач',
'viewcomments'            => 'Просмотр комментариев',
'editcomments'            => 'Редактирование комментариев',
'deletecomments'          => 'Удаление комментариев',
'viewattachments'         => 'Просмотр вложений',
'createattachments'       => 'Создание вложений',
'deleteattachments'       => 'Удаление вложений',
'viewhistory'             => 'Просмотр истории изменений',
'closeowntasks'           => 'Закрытие собственных задач',
'closeothertasks'         => 'Закрытие чужих задач',
'assigntoself'            => 'Назначение себе еще не назначенных задач',
'assignotherstoself'      => 'Назначение себе чужих задач',
'viewreports'             => 'Просмотр журнала событий',
'othersview'              => 'Разрешить всем просмотр этого проекта',
'othersviewroadmap'       => 'Разрешить всем пользователям просматривать план этого проекта',
'usersandgroups'          => 'Пользователи и группы',
'globalgroup'             => 'Глобальная группа',
'globalgroups'            => 'Глобальные группы',
'defaultglobalgroup'      => 'Глобальная группа для новых пользователей (по умолчанию)',
'addtogroup'              => 'Добавить к группе',
'moveuserstogroup'        => 'Переместить пользователей в группу',
'nogroup'                 => 'Без группы - удалить из проекта',
'eventdesc'               => 'Описание события',
'requestedby'             => 'Кем запрошено',
'daterequested'           => 'Дата и время запроса',
'closetask'               => 'Закрыть задачу',
'reopentask'              => 'Повторно открыть задачу',
'applymember'             => 'Заявка на участие в проекте',
'forcurrentproj'          => 'Для текущего проекта',
'lostpw'                  => 'Восстановление забытого пароля',
'lostpwexplain'           => "Введите свой логин и Вам будет отправлена ссылка для изменения пароля.\nПисьмо будет отправлено на адрес, указанный в Вашем профиле.",
'sendlink'                => 'Послать ссылку',
'savenewpass'             => 'Сохранить новый пароль',
'anonreg'                 => 'Разрешить регистрироваться новым пользователям',
'allowanonopentask'       => 'Разрешить анонимным пользователям создавать задачи',
'editglobalgroup'         => 'Редактировать глобальную группу',
'editgroupforproj'        => 'Редактировать группу для проекта',
'notshownforadmin'        => 'Для группы администраторов права не показаны, потому что Вам не нужно их редактировать.',
'general'                 => 'Общие',
'userregistration'        => 'Самостоятельная регистрация',
'notifications'           => 'Уведомления',
'resetoptions'            => 'Восстановить прежние значения',
'preferences'             => 'Свойства',
'tasktypes'               => 'Типы задач',
'resolutions'             => 'Резолюции',
'categories'              => 'Категории',
'categoriesglobal'        => 'Глобальные категории',
'categoriesproject'       => 'Категории проекта',
'categoriestarget'        => 'Целевые категории',
'operatingsystems'        => 'Операционные системы',
'versions'                => 'Версии',
'admintoolboxlong'        => 'Настройки администратора',
'newproject'              => 'Новый проект',
'delete'                  => 'Удалить',
'link'                    => 'Ссылка',
'referencelinks'          => 'Ссылки:',
'listdeletetip'           => 'Удалить этот элемент из списка',
'lookandfeel'             => 'Внешний вид',
'globaltheme'             => 'Тема по умолчанию',
'emailnotify'             => 'Уведомления по Email',
'fromaddress'             => 'От',
'smtpserver'              => 'Сервер SMTP',
'smtpuser'                => 'Имя пользователя SMTP',
'smtppass'                => 'Пароль SMTP',
'addrewrite'              => '(использовать переопределение адресов)',
'usereminderdaemon'       => 'Включить фоновую службу напоминаний',
'tasksperpage'            => 'Задач на страницу',
'addtoassignees'          => 'Добавление себя к исполнителям',
'taskstatuses'            => 'Состояния задач',
'canvote'                 => 'Можно голосовать за задачи',
'loginsuccessful'         => 'Вход успешен.',
'youareloggedout'         => 'Вы вышли из системы (возможно, принудительно)',
'waitwhiletransfer'       => 'Вы будете переадресованы. Подождите...',
'clicknowait'             => 'Нажмите на ссылку, если не хотите ждать.',
'accountdisabled'         => 'Ваш аккаунт заблокирован. Свяжитесь с администратором',
'task'                    => 'Задача',
'edittask'                => 'Редактировать задачу',
'openedby'                => 'Кем открыта:',
'editedby'                => 'Последним редактировал',
'tasktype'                => 'Тип задачи',
'category'                => 'Категория',
'status'                  => 'Состояние',
'assignedto'              => 'Кому назначена:',
'operatingsystem'         => 'Операционная система',
'severity'                => 'Критичность',
'reportedversion'         => 'Обнаружена в версии',
'dueinversion'            => 'Ожидается в версии',
'defaultdueinversion'     => 'Версия по умолчанию для новых задач',
'undecided'               => 'Не решено',
'percentcomplete'         => 'Завершенность',
'details'                 => 'Подробное описание',
'savedetails'             => 'Сохранить изменения',
'canceledit'              => 'отмена',
'anonymous'               => 'Анонимный источник',
'complete'                => 'завершено',
'closedby'                => 'Кем закрыта:',
'reasonforclosing'        => 'Причина закрытия:',
'reopenthistask'          => 'Открыть задачу повторно',
'comments'                => 'Комментарии',
'attachments'             => 'Вложения',
'relatedtasks'            => 'Родственные задачи и дубликаты',
'edit'                    => 'Редактировать',
'addcomment'              => 'Добавить комментарий',
'fileuploadedby'          => 'Кем выгружен файл:',
'uploadafile'             => 'Прикрепить файл',
'addalink'                => 'Добавить ссылку',
'addanotherlink'          => 'Добавить другую ссылку',
'uploadnow'               => 'Выгрузить!',
'thesearerelated'         => 'Эти задачи связаны с текущей задачей',
'remove'                  => 'Удалить',
'addnewrelated'           => 'Добавить родственную задачу',
'add'                     => 'Добавить!',
'otherrelated'            => 'Задачи, с которыми эта задача связана',
'receivenotify'           => 'Эти пользователи получат подробное уведомление при изменении задачи.',
'addusertolist'           => 'Добавить пользователя к этому списку',
'addtolist'               => 'Добавить к списку',
'addmyself'               => 'Добавить меня к этому списку',
'removemyself'            => 'Удалить меня из этого списка',
'theseusersnotify'        => 'Этим пользователям будет отправлено подробное уведомление при изменении задачи',
'attachedtoproject'       => 'Принадлежит проекту',
'reminders'               => 'Напоминания',
'system'                  => 'Система',
'systemvalues'            => 'Общесистемный список значений',
'projectvalues'           => 'Список значений проекта',
'remindthisuser'          => 'Напоминание пользователю:',
'thisoften'               => 'Частота напоминаний:',
'startafter'              => 'Время ожидания до запуска напоминаний',
'hour'                    => 'Час',
'hours'                   => 'Часов',
'day'                     => 'День',
'days'                    => 'Дней',
'week'                    => 'Неделя',
'weeks'                   => 'Недель',
'addreminder'             => 'Добавить напоминание',
'defaultreminder'         => 'Это напоминание о задаче Flyspray:',
'message'                 => 'Сообщение',
'closed'                  => 'Завершено',
'filename'                => 'Имя файла:',
'date'                    => 'Дата',
'filesize'                => 'Размер файла:',
'closurecomment'          => 'Комментарий при закрытии:',
'history'                 => 'История',
'nohistory'               => 'История отсутствует.',
'eventdate'               => 'Дата',
'user'                    => 'Пользователь',
'event'                   => 'Событие',
'fieldchanged'            => 'Изменилось поле',
'taskopened'              => 'Задача открыта',
'taskreopened'            => 'Задача открыта повторно',
'taskclosed'              => 'Задача закрыта',
'commentadded'            => 'Добавлен комментарий',
'commentedited'           => 'Отредактирован комментарий',
'commentdeleted'          => 'Удален комментарий',
'attachmentadded'         => 'Добавлено вложение',
'attachmentdeleted'       => 'Удалено вложение',
'taskedited'              => 'Задача отредактирована',
'notificationadded'       => 'Пользователь добавлен к списку уведомлений',
'notificationdeleted'     => 'Пользователь удален из списка уведомлений',
'relatedadded'            => 'Добавлена родственная задача',
'relateddeleted'          => 'Удалена родственная задача',
'taskassigned'            => 'Задача назначена',
'taskreassigned'          => 'Задача переназначена',
'assignmentremoved'       => 'Назначение удалено',
'summary'                 => 'Название',
'addedasrelated'          => 'Задача добавлена к родственным задачам ',
'deletedasrelated'        => 'Задача удалена из родственных задач',
'reminderadded'           => 'Напоминание добавлено',
'reminderdeleted'         => 'Напоминание удалено',
'priority'                => 'Приоритет',
'previousvalue'           => 'Предыдущее значение',
'newvalue'                => 'Новое значение',
'selectareason'           => 'Выберите причину',
'assigntome'              => 'Назначить себе',
'reopenrequest'           => 'Запрос на повторное открытие',
'requestclose'            => 'Запросить закрытие',
'ownershiptaken'          => 'Пользователь стал владельцем',
'closerequestmade'        => 'Запрошено закрытие задачи',
'reopenrequestmade'       => 'Запрошено повторное открытие задачи',
'taskdependson'           => 'Задача зависит от',
'taskdependsontask'       => 'Задача зависит от',
'taskdependsontasks'      => 'Задача зависит от',
'taskblock'               => 'Задача болокирует закрытие',
'taskblocks'              => 'Эта задача не позволит завершить следующие задачи',
'depadded'                => 'Добавлена зависимость',
'depaddedother'           => 'Эта задача добавлена как зависимость для задачи',
'depremoved'              => 'Зависимость удалена',
'depremovedother'         => 'Эта задача удалена из списка зависимостей другой задачи',
'showdetailserror'        => 'Задача не существует, или у Вас нет прав для ее просмотра.',
'makeprivate'             => 'сделать частной',
'makepublic'              => 'сделать общедоступной',
'taskmadeprivate'         => 'Задача помечена как частная',
'taskmadepublic'          => 'Задача помечена как общедоступная',
'confirmdeletecomment'    => 'Удалить этот комментарий? %s',
'attachementswilldeleted' => 'Все вложения будут удалены!',
'confirmdeleteattach'     => 'Удалить это вложение?',
'selectedhistory'         => '-Отображаются свойства выбранных событий (?)',
'showallhistory'          => 'Показать вкладку с полной историей',
'hidethis'                => 'Скрыть эту область',
'mark100'                 => 'Пометить задачу "Готова на 100%"',
'watchtask'               => 'отслеживать задачу',
'stopwatching'            => 'прекратить отслеживание',
'commentlink'             => 'Ссылка на этот комментарий',
'submitreq'               => 'Отправить запрос',
'reasonforreq'            => 'Причина запроса',
'pmreqdenied'             => 'Руководитель Проекта отказал в ответ на запрос',
'taskpendingreq'          => 'Есть запросы Руководителю Проекта. Смотрите вкладку "История" для подробной информации.',
'previoustask'            => 'Предыдущая задача',
'nexttask'                => 'Следующая задача',
'duedate'                 => 'Ожидается к дате',
'attachnoperms'           => 'У комментария есть вложения, но у Вас нет прав для их просмотра.',
'linknoperms'             => 'У комментария есть ссылки, но у вас нет прав для их просмотра.',
'open'                    => 'Открытые',
'depgraph'                => 'Посмотреть зависимости',
'reset'                   => 'Сбросить',
'selectusers'             => 'Выбрать пользователей...',
'addmetoassignees'        => 'Добавить меня к исполнителям',
'addedtoassignees'        => 'Пользователь добавлен к списку исполнителей',
'dependencygraph'         => 'График зависимостей',
'attachanotherfile'       => 'Прикрепить другой файл',
'OK'                      => 'ОК',
'addvote'                 => 'Проголосовать "за"',
'disable_lostpw'          => 'Отключить восстановление пароля',
'disable_changepw'        => 'Отключить создание и редактирование пароля',
'notifyfromfs'            => 'Уведомление от Flyspray',
'autogenerated'           => 'СООБЩЕНИЕ СОЗДАНО АВТОМАТИЧЕСКИ. ОТВЕТ НЕ ТРЕБУЕТСЯ',
'forward'                 => 'Вперед',
'previous'                => 'Предыдущая',
'next'                    => 'Следующая',
'first'                   => 'Первая',
'last'                    => 'Последняя',
'page'                    => 'Страница %d из %d',
'search'                  => 'Поиск',
'alltasktypes'            => 'Все типы задач',
'allseverities'           => 'Любая',
'alldevelopers'           => 'Все разработчики',
'notyetassigned'          => 'Пока не назначена',
'allcategories'           => 'Все категории',
'allstatuses'             => 'Все состояния',
'allopentasks'            => 'Все открытые задачи',
'sortthiscolumn'          => 'Сортировать по этой колонке',
'id'                      => 'ID',
'project'                 => 'Проект',
'dateopened'              => 'Когда открыта',
'progress'                => 'Прогресс',
'searchthisproject'       => 'Искать в этом проекте:',
'dueanyversion'           => 'Неважно (в любой версии)',
'anyversion'              => 'Неважно (в любой версии)',
'dueversion'              => 'Ожидается в версии',
'lastedit'                => 'Последнее изменение',
'os'                      => 'Операционная система',
'reportedin'              => 'Обнаружена в версии',
'taskrange'               => 'Показаны задачи с %d по %d (из %d)',
'noresults'               => 'Ничего не найдено',
'takeaction'              => 'Выполнить',
'watchtasks'              => 'Отслеживать изменения в выбранных задачах',
'stopwatchingtasks'       => 'Перестать отслеживать изменения в выбранных задачах',
'assigntaskstome'         => 'Назначить выбранные задачи мне',
'dueby'                   => 'Ожидается',
'dueanytime'              => 'В любое время',
'selectduedate'           => 'Укажите ожидаемую дату завершения',
'toggleselected'          => 'Инвертировать выбранные',
'due'                     => 'Ожидается',
'assignedtome'            => 'Назначенные мне',
'tasklist'                => 'Список задач',
'dateclosed'              => 'Дата завершения',
'advanced'                => 'Параметры фильтра',
'searchcomments'          => 'Искать в комментариях',
'searchforall'            => 'Искать все слова',
'anonusers'               => 'Анонимные пользователи',
'miscellaneous'           => 'Дополнительно',
'users'                   => 'Пользователи',
'taskproperties'          => 'Свойства задачи',
'selectsincedate'         => 'Укажите дату "изменено с"',
'changedsince'            => 'Изменено с',
'updatefs'                => 'Пожалуйста, обновите FlySpray',
'currentversion'          => 'Текущая версия',
'latestversion'           => 'последняя доступная версия',
'hidemessage'             => '(напомнить позже)',
'saveas'                  => 'Сохранить фильтр под именем',
'nosearches'              => 'Нет сохраненных фильтров',
'saving'                  => 'Сохранение...',
'votes'                   => 'Голосов за задачу',
'tovote'                  => 'Голосовать',
'allclosedtasks'          => 'Все завершенные задачи',
'password'                => 'Пароль',
'login'                   => 'Вход!',
'rememberme'              => 'Запомнить меня',
'lostpassword'            => 'Забыли пароль?',
'lostpwforfs'             => 'Забыт пароль Flyspray',
'lostpwmsg1'              => "Привет.\n\nЯ тут свой пароль забыл ",
'lostpwmsg2'              => ", пожалуйста, пришлите мне новый\n\nИмя пользователя: ",
'regards'                 => 'Приветствую,',
'yourusername'            => ' Ваше имя пользователя ',
'locale'                  => 'ru',
'filenotexist'            => 'Файл не найден или у Вас недостаточно прав для доступа',
'showtask'                => 'Показать задачу',
'now'                     => 'Сейчас',
'go'                      => 'Поехали!',
'opentaskanon'            => 'Анонимно открыть задачу',
'register'                => 'Зарегистрироваться',
'addnewtask'              => 'Создать задачу',
'reports'                 => 'Журнал событий',
'editmydetails'           => 'Редактировать мои данные',
'logout'                  => 'Выход',
'disabledaccount'         => 'Ваш аккаунт был заблокирован!<br>Автоматический выход из системы...',
'poweredby'               => 'Поддерживается Flyspray',
'sponsoredby'             => 'Flyspray спонсируется',
'projects'                => 'Проекты',
'allprojects'             => 'Все проекты',
'selectproject'           => 'для проекта:',
'tasksall'                => 'Все задачи',
'tasksassigned'           => 'Задачи, назначенные мне',
'tasksreported'           => 'Задачи, созданные мной',
'taskswatched'            => 'Задачи, которые я отслеживаю',
'mysearch'                => 'Мои фильтры',
'admintoolbox'            => 'Настройки администратора',
'manageproject'           => 'Управление проектом',
'permissions'             => 'Просмотреть разрешения',
'hide'                    => 'Скрыть',
'pendingreq'              => 'запрос(-ов) Руководителю Проекта',
'errorpage'               => 'Flyspray не может найти указанную страницу. Возможно, Вы запросили задачу, которой не существует, или у Вас недостаточно прав для просмотра запрошенных данных.<br /><br />А может быть, Вы что-то намудрили с URL, чтобы в базу данных залезть? Если так, то марш в угол и подумайте о своем поведении. Когда вернетесь, - больше так не делайте!',
'permissionsforproject'   => 'Права для проекта:',
'switchto'                => 'Перейти к',
'lastsearch'              => 'Последний фильтр',
'modify'                  => 'Изменить',
'noticefrom'              => 'Уведомление от',
'hasopened'               => 'создал новую задачу и назначил ее Вам:',
'moreinfonew'             => 'Более подробно об этой ошибке Вы можете узнать на странице FlySpray',
'newtaskcategory'         => 'В этой категории была создана новая задача',
'categoryowner'           => 'Вы получили это сообщение, потому что Вы указаны, как владелец категории.',
'tasksummary'             => 'Кратко о задаче:',
'newtaskadded'            => 'Создана новая задача.',
'summaryanddetails'       => 'Вам надо заполнить как краткое, так и полное описание.',
'summaryrequired'         => 'Вам необходимо заполнить краткое описание задачи.',
'goback'                  => 'Назад.',
'messagefrom'             => 'Сообщение от системы слежения за ошибками Flyspray, установленной по адресу ',
'hasjustmodified'         => 'только что изменил указанную задачу.',
'changedfields'           => 'Изменившиеся поля отмечены звездочками (**)',
'moreinfomodify'          => 'Подробную информацию о задаче можно получить по URL:',
'nolongerassigned'        => 'Данная задача переназначена для (to)',
'hasassigned'             => 'назначил(-а) Вам следующую задачу:',
'taskupdated'             => 'Задача была обновлена.',
'tasksupdated'            => 'Задачи были обновлены.',
'hasclosedassigned'       => 'закрыл(-а) назначенную Вам задачу:',
'unassigned'              => 'Не назначена',
'hasclosed'               => 'закрыл(-а) задачу:',
'youonnotify'             => 'Вы получили это сообщение, потому что вы в списке для уведомлений.',
'taskclosedmsg'           => 'Задача (была) закрыта',
'returntotask'            => 'Вернуться к свойствам задачи',
'backtoindex'             => 'Назад к списку задач',
'noclosereason'           => 'Вы не указали причину завершения задачи',
'hasreopened'             => 'повторно открыл задачу Flyspray, ранее закрытую Вами:',
'taskreopenedmsg'         => 'Задача была открыта повторно.',
'backtotask'              => 'Назад к задаче',
'commentaddedmsg'         => 'Добавлен комментарий.',
'commenttoassigned'       => 'добавил комментарий к назначенной Вам задаче:',
'commenttotask'           => 'добавил комментарий к этой задаче.',
'nocommententered'        => 'Желательно ввести комментарий перед тем, как на кнопку "Добавить комментарий" жать.',
'fillinfields'            => 'Не все поля заполнены',
'notcurrentpass'          => 'Введен неправильный пароль!',
'passchanged'             => 'Пароль изменен',
'closewindow'             => 'Это окно можно закрыть',
'passnomatch'             => 'Введенные пароли не совпадают!',
'usernametaken'           => 'Имя пользователя уже используется. Выберите другое.',
'usernametakenbulk'       => 'Это имя пользователя уже занято',
'newusercreated'          => 'Новый пользователь создан.',
'accountcreated'          => 'Ваш аккаунт создан.',
'newuserwarning'          => 'Обратите внимание, что глобальные настройки могут требовать подтверждение вашей регистрации администратором. Это может быть причиной того, что Вы не можете войти.',
'nomatchpass'             => 'Пароли не совпадают.',
'confirmwrong'            => 'Неверный код подтверждения!',
'formnotcomplete'         => 'Форма заполнена не полностью.',
'formnotnumeric'          => 'Нечисловое значение!',
'groupnametaken'          => 'Имя группы уже используется.',
'newgroupadded'           => 'Добавлена новая группа.',
'optionssaved'            => 'Настройки Flyspray сохранены.',
'hasuploaded'             => 'выгрузил файл для задачи, которая была назначена:',
'hasattached'             => 'прикрепил файл к следующей задаче:',
'fileuploaded'            => 'Файл успешно выгружен.',
'fileerror'               => 'Ошибки при выгрузке Вашего файла. Возможно, неверно настроены права для каталога <i>attachments</i>.',
'contactadmin'            => 'Свяжитесь с администратором этого проекта.',
'selectfileerror'         => 'Не выбран файл.',
'userupdated'             => 'Информация о пользователе обновлена',
'realandemail'            => 'Не введены имя пользователя и Email',
'groupupdated'            => 'Описание группы обновлено.',
'groupanddesc'            => 'Не введено имя группы',
'fillallfields'           => 'Заполните все поля',
'listPmustN'              => 'В поле "Порядок" должно быть числовое значение.',
'listupdated'             => 'Список обновлен.',
'listitemadded'           => 'Добавлен новый элемент списка.',
'relatedaddedmsg'         => 'К списку добавлена родственная задача.',
'relatederror'            => 'Задача уже в списке родственных задач.',
'relatedremoved'          => 'Родственная задача удалена из списка.',
'notifyadded'             => 'Пользователь добавлен к списку уведомлений.',
'notifyerror'             => 'Пользователь уже в списке уведомлений для этой задачи.',
'notifyremoved'           => 'Пользователь удален из списка уведомлений.',
'editcommentsaved'        => 'Измененный комментарий сохранен.',
'commentdeletedmsg'       => 'Комментарий был удален',
'gotonewtask'             => 'Перейти к только что созданной задаче',
'projectcreated'          => 'Проект успешно создан. Теперь можете изменить настройки в разделе "Управление проектом"',
'customiseproject'        => 'Настроить этот проект',
'projectupdated'          => 'Настройки проекта обновлены',
'emptytitle'              => 'Поле "Заголовок проекта" пусто. Вернитесь и заполните его.',
'loginbelow'              => 'Теперь Вы можете войти в систему.',
'attachmentdeletedmsg'    => 'Вложение было удалено',
'reminderaddedmsg'        => 'Напоминание добавлено.',
'reminderdeletedmsg'      => 'Выбранное напоминание было удалено.',
'flyspraytask'            => 'Задача Flyspray',
'fieldsmissing'           => 'Некоторые поля содержат неверные данные или пусты.',
'relatedinvalid'          => 'Нет такой задачи.',
'relatedproject'          => 'Эта задача относится к другому проекту. Все равно добавить связь?',
'addanyway'               => 'Добавить принудительно',
'cancel'                  => 'Отмена',
'alreadyedited'           => 'Кто-то уже внес изменения в задачу, пока Вы ее тут разглядывали. Все еще хотите сохранить свои изменения (перезаписать чужие)?',
'saveanyway'              => 'Сохранить изменения принудительно',
'nouserselected'          => 'Не выбрано ни одного пользователя. Перед тем, как пробовать еще раз, выберите кого-нибудь.',
'groupswitchupdated'      => 'Группы пользователей обновлены',
'takenownershipmsg'       => 'Эта задача назначена Вам',
'adminrequestmade'        => 'Ваш запрос был отправлен Руководителю Проекта',
'newdepnotify'            => 'К задаче была добавлена новая зависимость:',
'dependadded'             => 'Добавлена зависимость',
'dependaddfailed'         => 'Ошибка при добавлении зависимости. Убедитесь, что задача существует и не возникает взаимной блокировки (задачи не должны зависеть друг от друга).',
'depremovedmsg'           => 'Зависимость была удалена',
'newdepis'                => 'Новая зависимость',
'magicurlsent'            => 'Сообщение было отправлено по вашему адресу. В нем содержится ссылка на страницу, с которой Вы сможете завершить запрошенное действие.',
'changefspass'            => 'Изменить пароль Flyspray',
'magicurlmessage'         => 'Пожалуйста, перейдите по указанной ссылке, чтобы изменить свой пароль для Flyspray:',
'erroronform'             => 'Возникла ошибка при обработке запроса',
'addressused'             => 'Этот адрес был использован для регистрации пользователя Flyspray. Если Вы не ожидаете данное сообщение, пожалуйста, просто удалите его. Для завершения регистрации воспользуйтесь ссылкой:',
'confirmcodeis'           => 'Код подтверждения:',
'codesent'                => 'Вам был выслан код подтверждения. Следуйте инструкциям в сообщении.',
'codenotsent'             => 'Не могу выслать Ваш код, повторите попытку попозже.',
'taskmadeprivatemsg'      => 'Эта задача была помечена как "Частная"',
'taskmadepublicmsg'       => 'Эта задача опять общедоступна',
'realandnotify'           => 'Вам надо указать полное имя пользователя и Email или Jabber ID.',
'pmreqdeniedmsg'          => 'Отказ в ответ на запрос Руководителю Проекта',
'massopsenable'           => 'Включить массовые операции',
'massopsuccess'           => 'Групповая операция успешна (где разрешения позволили)',
'usernotexist'            => 'Пользователь не найден',
'commentattachperms'      => 'Вы не можете удалить этот комментарий - нет прав для удаления вложений',
'voterecorded'            => 'Ваш голос был учтен',
'votefailed'              => 'Ваш голос не может быть учтен в данный момент',
'createnewgroup'          => 'Создать новую группу',
'requiredfields'          => 'Поля, обязательные для заполнения, отмечены',
'addthisgroup'            => 'Добавить эту группу',
'createnewproject'        => 'Создать новый проект',
'addnewproject'           => 'Добавить новый проект',
'htmlallowed'             => 'Разрешен код HTML',
'createthisproject'       => 'Создать проект',
'inlineimages'            => 'Показывать картинки в тексте',
'createnewtask'           => 'Создать новую задачу в проекте:',
'addanother'              => 'Добавить еще задачу после этой',
'addthistask'             => 'Добавить задачу',
'notifyme'                => 'Уведомить меня, когда задача изменится',
'newtask'                 => 'Новая задача',
'attachafile'             => 'Прикрепить файл',
'registernewuser'         => 'Создание нового пользователя',
'none'                    => 'Никакого/Никуда/Нет/Ничего',
'registeraccount'         => 'Создать учетную запись',
'registerbulkaccount'     => 'Создать несколько учетных записей',
'both'                    => 'Оба типа',
'notifyfrom'              => 'Уведомление от ',
'donotreply'              => 'СООБЩЕНИЕ СОЗДАНО АВТОМАТИЧЕСКИ. ОТВЕЧАТЬ НЕ НАДО!',
'disclaimer'              => 'Вы получили это сообщение, потому что Вы запросили его от системы слежения за ошибками Flyspray. Если вы не ожидаете этого сообщения или не хотите получать почтовые сообщения в дальнейшем, Вы можете настроить способы уведомления, перейдя на страницу Flyspray по ссылке, указанной выше.',
'userwho'                 => 'Автор изменений',
'moreinfo'                => 'Более подробно - по ссылке:',
'newtaskopened'           => 'Создана новая задача Flyspray. Подробности ниже.',
'notify.taskclosed'       => 'Задача закрыта:',
'notify.taskreopened'     => 'Следующая задача была открыта повторно:',
'newdep'                  => 'У следующей задачи новая зависимость:',
'notify.depremoved'       => 'У следующей задачи зависимость удалена:',
'olddepwas'               => 'Старая зависимость была',
'notify.commentadded'     => 'К задаче добавлен комментарий:',
'commentis'               => 'Текст комментария.',
'newattachment'           => 'Новый файл был прикреплен к задаче:',
'detailsbelow'            => 'Подробности ниже.',
'notify.relatedadded'     => 'Новая родственная задача была добавлена к задаче:',
'relatedis'               => 'Родственная задача -',
'assignedtoyou'           => 'Вам назначена задача:',
'takenownership'          => 'назначил себя владельцем следующей задачи:',
'requiresaction'          => 'Следующая задача требует вмешательства Руководителя Проекта',
'requiresactionnotify'    => 'Задача требует вмешательства Руководителя Проекта',
'pmdeny'                  => 'Руководитель проекта отклонил запрос для следующей задачи:',
'pmdenynotify'            => 'Руководитель Проекта отказал в ответ на запрос',
'fileaddedtoo'            => 'К этому комментарию прикреплен один или более файлов.',
'taskwatching'            => 'Задача, которую Вы отслеживаете ',
'isdepfor'                => 'теперь является зависимостью для следующей задачи',
'denialreason'            => 'Причина отказа',
'taskchanged'             => 'Задача Flyspray изменилась. Изменения приведены далее по тексту. Для полного отчета об изменениях, перейдите на страницу задачи по указанной ссылке и откройте вкладку "История"',
'useraddedtoassignees'    => 'Пользователь добавил себя к списку исполнителей.',
'removeddepis'            => 'Удаленная зависимость:',
'isnodepfor'              => 'больше не является зависимостью для задачи',
'usergroups'              => 'Группы и пользователи',
'pmtoolbox'               => 'Настройки Руководителя Проекта',
'groupmanage'             => 'Управление группами и пользователями',
'pendingrequests'         => 'Запросы Руководителю Проекта',
'reasongiven'             => 'Причина запроса',
'nopendingreq'            => 'Нет запросов Руководителю Проекта.',
'givereason'              => 'Укажите причину',
'catlisted'               => 'Редактор списка категорий',
'oslisted'                => 'Редактор списка операционных систем',
'verlisted'               => 'Редактор списка версий',
'tasktypeed'              => 'Редактор списка типов задач',
'resed'                   => 'Редактор списка резолюций',
'deny'                    => 'Отказать',
'notifiedwhen'            => 'Уведомлен, когда',
'onlynewtasks'            => 'Созданы новые задачи',
'allevents'               => 'Все события во всех задачах',
'feeds'                   => 'Ленты новостей',
'feeddescription'         => 'Описание ленты новостей',
'feedimgurl'              => 'Ссылка на картинку для ленты новостей (оставите пустой - будет без картинки)',
'notifysubject'           => 'Тема для уведомлений',
'notifysubjectinfo'       => '(%p = заголовок проекта, %s = краткое описание задачи, %t = идентификатор задачи, %a = действие, %u = имя пользователя)',
'priority6'               => 'В мгновение!',
'priority5'               => 'Немедленно',
'priority4'               => 'Срочно',
'priority3'               => 'Высокий',
'priority2'               => 'Обычный',
'priority1'               => 'Низкий',
'sendcode'                => 'Выслать код!',
'entercode'               => 'Введите высланный Вам код подтверждения и новый пароль',
'confirmationcode'        => 'Код подтверждения',
'registererror'           => 'Убедитесь, что Вы заполнили все необходимые поля и указали правильные данные для выбранного типа уведомлений.',
'validusername'           => '(разрешены алфавитно-цифровые символы и - _ .)',
'validemail'              => '(используйте ; для разделения нескольких адресов электронной почты)',
'emailtakenbulk'          => 'Адрес электронной почты уже используется',
'emailtaken'              => 'Адрес email или идентификатор Jabber уже заняты. Вам придется выбрать себе другие.',
'note'                    => '<strong>Внимание:</strong> Вам будет выслан код подтверждения до того, как ваш аккаунт будет создан.  Код будет выслан тем методом, который Вы выбрали для уведомлений (см. выше).<br />Если Вы указали неверные данные, то Вы <strong>не получите Ваш код</strong>.',
'changelog'               => 'Журнал изменений',
'changeloggen'            => 'Генератор журнала изменений',
'listfrom'                => 'Показать журнал изменений с',
'to'                      => 'до',
'oldestfirst'             => 'Сначала более старые',
'recentfirst'             => 'Сначала более новые',
'severityrep'             => 'Отчет о критичности задач',
'totalopen'               => 'Всего открытых задач',
'age'                     => 'Возраст',
'agerep'                  => 'Отчет о возрасте',
'eventsrep'               => 'Отчет о событиях',
'events'                  => 'Событий',
'Tasks'                   => 'Задачи',
'opened'                  => 'Открытых',
'edited'                  => 'Отредактированных',
'assigned'                => 'Назначенных',
'within'                  => 'За',
'pastday'                 => 'Прошедший день',
'pastweek'                => 'Последняя неделя',
'pastmonth'               => 'Последний месяц',
'pastyear'                => 'Последний год',
'nolimit'                 => 'Без ограничений',
'from'                    => 'От',
'duein'                   => 'Ожидается в',
'selectfromdate'          => 'Дата начала выборки',
'selecttodate'            => 'Дата окончания выборки',
'showvoters'              => 'Показать/скрыть проголосовавших',
'roadmap'                 => 'План работ',
'roadmapfor'              => 'План работ для версии',
'tasks'                   => 'задач(-и)',
'completed'               => 'завершены (-ные).',
'opentasks'               => 'задач открыто',
'of'                      => '% из',
'severity5'               => 'Критично',
'severity4'               => 'Высоко',
'severity3'               => 'Средне',
'severity2'               => 'Низко',
'severity1'               => 'Очень низко',
'Redirect'                => 'Перенаправить',
'redirectmsg'             => 'Если Ваш браузер не поддерживает автоматическое перенаправление, перейдите по ссылке %HERE%',
'allowclosedcomments'     => 'Разрешить комментировать закрытые задачи',
'comment'                 => 'Комментарий',
'editowncomments'         => 'Редактирование собственных комментариев',
'reopened'                => 'Открыта повторно',
'loading'                 => 'Загрузка...',
'notifyown'               => 'Уведомлять о собственных изменениях.',
'youremail'               => 'Ваш e-mail  адрес',
'thankyouforbug'          => 'Спасибо за сообщение о проблеме. Вы можете отслеживать состояние задачи по следующей ссылке:',
'anonuser'                => 'Анонимный пользователь',
'conflict'                => 'Конфликт',
'file'                    => 'Файл',
'KiB'                     => 'КБ',
'MiB'                     => 'МБ',
'size'                    => 'Размер',
'projectgroup'            => 'Группа проекта',
'profile'                 => 'Профиль:',
'viewprofile'             => 'Просмотр профиля',
'regdate'                 => 'Зарегистрирован с',
'tasksopened'             => 'Открыто задач',
'replyto'                 => 'Обратный адрес',
'notifytypes'             => 'Тип уведомления',
'pm.taskchanged'          => 'Задача изменена',
'pm.taskreopened'         => 'Задача открыта повторно',
'pm.depadded'             => 'Добавлена зависимость',
'pm.depremoved'           => 'Зависимость удалена',
'pmrequest'               => 'Запрос руководителю проекта',
'pmrequestdenied'         => 'Запрос руководителю проекта отклонен',
'newassignee'             => 'Новый исполнитель',
'revdepadded'             => 'Добавлена обратная зависимость',
'revdepaddedremoved'      => 'Обратная зависимость удалена',
'assigneeadded'           => 'Добавлен исполнитель',
'addusergroup'            => 'Добавить пользователя к этой группе',
'groupmembers'            => 'Члены группы',
'deleteuser'              => 'Удалить этого пользователя',
'userdeleted'             => 'Пользователь удалён',
'autoassign'              => 'Автоматически назначать задачу владельцу категории',
'ssl'                     => 'SSL',
'updatewrong'             => 'Вы разрешили проверку на наличие обновлений, но связь с сервером обновлений не установлена. Либо у Вас запрещен исходящий трафик, либо ошибка возникла из-за каких-то проблем в сети. Зайдите на сайт Flyspray чтобы убедиться, что Вы работаете с последней версией программы.',
'deleteproject'           => 'Удалить этот проект и переместить все данные в',
'projectdeleted'          => 'Проект успешно удален',
'feedforall'              => 'Новостная лента для всех проектов',
'usercreated'             => 'Пользователь создан',
'created'                 => 'Создан',
'deleted'                 => 'Удален',
'userid'                  => 'Идентификатор пользователя',
'editassignments'         => 'Редактировать назначения',
'preview'                 => 'Предпросмотр',
'anyprogress'             => 'Любой прогресс',
'tasksrelated'            => 'Родственные задачи',
'duplicatetasks'          => 'Задачи с этой же проблемой (дубликаты)',
'databasemodfailed'       => 'Ошибка при обновлении базы данных. Возможно, недостаточно прав для доступа к базе данных.',
'frequency'               => 'Частота',
'newuserregistered'       => 'Зарегистрирован новый пользователь Flyspray. Подробные данные о пользователе:',
'newuserregisterednotify' => 'Зарегистрирован новый пользователь',
'notify_registration'     => 'Уведомлять администраторов о новых зарегистрированных пользователях',
'textversion'             => 'Текстовая версия',
'onlyprimary'             => 'Задачи, которые не блокируют другие задачи',
'onlyblocker'             => 'Задачи, которые блокируют другие задачи',
'blockerornoblocker'      => '- Блокирует или не блокирует, выбор обоих параметров не имеет смысла. (?)',
'switch'                  => 'Сменить проект',
'max'                     => 'макс.',
'dates'                   => 'Даты',
'selectduedatefrom'       => 'Ожидаются с',
'selectduedateto'         => 'по',
'selectsincedatefrom'     => 'Измененные с',
'selectsincedateto'       => 'по',
'selectdate'              => 'Выберите дату',
'selectopenedfrom'        => 'Открытые с',
'selectopenedto'          => 'по',
'selectclosedfrom'        => 'Закрытые с',
'selectclosedto'          => 'по',
'startat'                 => 'Начать напоминания с даты:',
'hasattachment'           => 'Содержат вложение',
'private'                 => 'Частная задача',
'watching'                => 'Отслеживаемая',
'alreadyvotedthistask'    => 'вы уже проголосовали',
'alreadyvotedthisday'     => 'сегодня уже проголосовали',
'visibility'              => 'Видимость',
'public'                  => 'Общедоступна',
'leaveemptyauto'          => 'Оставьте поля ввода пароля пустыми, если хотите, чтобы пароль был сгенерирован автоматически.',
'novalidemail'            => 'Введите корректный адрес email.',
'novalidjabber'           => 'Введите корректный адрес Jabber.',
'missingrequired'         => 'Вы не заполнили все необходимые поля.',
'entervalidusername'      => 'Введите корректные логин и имя пользователя',
'couldnotaddusernotif'    => 'Не могу добавить этого пользователя к списку уведомлений.',
'defaulttask'             => 'Описание задачи "по умолчанию"',
'all'                     => 'все',
'events.useraddedtoassignees'=> 'Пользователь добавлен к списку исполнителей',
'eventlog'                => 'Журнал событий',
'assignmentchanged'       => 'Назначение изменено',
'detailedinfo'            => 'Подробная информация',
'All'                     => 'Все',
'tasksireported'          => 'Открытые мной',
'recentlyopened'          => 'Недавно открытые',
'stats'                   => 'Статистика',
'totaltasks'              => 'всего задач',
'mostwanted'              => 'Самые ожидаемые задачи',
'defaultentry'            => 'Страница по умолчанию',
'toplevel'                => 'Просмотр верхнего уровня',
'overview'                => 'Обзор',
'error#'                  => 'Ошибка #',
'error1'                  => 'Недостаточно прав для просмотра вложения',
'error3'                  => 'Повтор действия, перенаправление на главную страницу.',
'error4'                  => 'У Вас нет административных прав',
'error5'                  => 'Пользователь не существует',
'error6'                  => 'Неверная область администрирования (неверный адрес?)',
'error7'                  => 'Попытка входа неудачна (неверные имя пользователя или пароль)!',
'error71'                 => 'Аккаунт заблокирован на %d минут из-за слишком большого числа неудачных попыток входа!',
'error8'                  => 'Вы не указали имя пользователя и пароль.',
'error9'                  => 'Задача не существует или у Вас нет прав для ее просмотра.',
'error10'                 => 'Задача не существует или у Вас нет прав для ее просмотра.',
'error101'                => 'У вас нет прав для просмотра этой задачи',
'error102'                => 'У вас нет прав для просмотра этой задачи, регистрация может помочь.',
'error11'                 => 'Нет прав для редактирования этого комментария',
'error12'                 => 'Неверный секретный код! Вы уверены, что именно это было указано в вашем уведомлении?',
'error13'                 => 'У анонимных пользователей нет собственных настроек.',
'error14'                 => 'Вы не можете создать новую группу - недостаточно прав.',
'error15'                 => 'Вы не можете создать новую задачу - недостаточно прав.',
'error16'                 => 'Вы не Руководитель Проекта.',
'error17'                 => 'Неверная область Руководителя Проекта',
'error18'                 => 'Неверная секретная ссылка',
'error19'                 => 'Этот пользователь не существует в данной базе Flyspray.',
'error20'                 => 'Некорректный запрос к базе данных',
'error21'                 => 'Один или несколько электронных писем не могут быть отправлены. Проверьте настройки.',
'error22'                 => 'Регистрация новых пользователей запрещена.',
'error23'                 => 'Пользователю или группе запрещен вход в систему.',
'error24'                 => 'Не найден ни исполняемый файл dot, ни общедоступный dot-сервер.',
'error25'                 => 'План работ может быть сформирован только для проектов.',
'error26'                 => 'Неподдерживаемый провайдер OAuth.',
'error27'                 => 'Не удается войти. Разрешаю нам посмотреть ваш адрес электронной почты.',
'error28'                 => 'У вас нет разрешения на доступ в этот раздел.',
'done'                    => 'завершено',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Проект не может быть удален',
'GMT'                     => 'GMT',
'timezone'                => 'Часовой пояс',
'accept'                  => 'Подтвердить',
'reasonfordeinal'         => 'Причина отказа',
'pruneclosedlinks'        => 'Скрыть закрытые связи',
'pruneclosedtasks'        => 'Скрыть закрытые задачи',
'pagegenerated'           => 'Страница и изображение созданы за %d секунд.',
'pruninglevel'            => 'Режим отображения',
'lastuser'                => 'Единственный пользователь не может быть удален',
'allprivate'              => 'Нет проектов для общего доступа',
'deletegroup'             => 'Удалить эту группу и переместить пользователей в',
'parent'                  => 'Родитель',
'ordertip'                => 'Порядок, в котором эти элементы будут отображены в списке',
'showtip'                 => 'Отображать этот элемент в списке',
'deletetip'               => 'Удалить этот элемент из списка',
'del'                     => 'удалить',
'request1'                => 'Запрошено закрытие задачи',
'request2'                => 'Запрошено повторное открытие задачи',
'allpriorities'           => 'Любой',
'noroadmap'               => 'Невозможно создать план работ (не существует версии проекта, помеченной как "будущая")',
'expand'                  => 'Развернуть',
'collapse'                => 'Свернуть',
'expandall'               => 'Развернуть все',
'collapseall'             => 'Свернуть все',
'minpwsize'               => 'Минимальный размер пароля 5 символов',
'passwordtoosmall'        => 'Короткий пароль',
'accountwaslocked'        => 'Ваша учетная запись была заблокирована из-за слишком большого числа неудачных попыток входа.',
'failedattempts'          => 'Там были %d неудачные попытки входа.',
'groupnotexist'           => 'Выбранная группа не существует в этом проекте.',
'searchindetails'         => 'Поиск подробностей',
'showasassignees'         => 'Показать как представителя',
'find'                    => 'Искать',
'tls'                     => 'TLS',
'isadmin'                 => 'Это админ',
'addvotes'                => 'Добавить голос',
'removevote'              => 'Удалить голос',
'voteremoved'             => 'Ваш голос был удален',
'voteremovefailed'        => 'Ваш голос не может быть удален сейчас.',
'novotes'                 => 'У вас пока нет голосов за задачи',
'connectedtasks'          => 'Связанные задачи:',
'taskdependencies'        => 'Зависимости задачи',
'viewgraph'               => 'Посмотреть график',
'notaskdependencies'      => 'Эта задача не зависит ни от каких других задач.',
'dependson'               => 'Зависит от',
'blocks'                  => 'Блоки',
'newdependency'           => 'Новая зависимость',
'nouserstoadd'            => 'Нет пользователей для добавления. Пожалуйста, убедитесь, что имя, логин и e-mail определены для каждого пользователя.',
'dispintro'               => 'Показать приветственное сообщение',
'mainmessage'             => 'Моё приветственное сообщение',
'setsupertask'            => 'Установить ID сверхзадачи:',
'supertaskmodified'       => 'ID сверхзадачи был изменён',
'set'                     => 'Установить',
'supertask'               => 'Сверхзадача',
'setparent'               => 'Для решения этой задачи установите ID родительской задачи',
'selfsupertasknotallowed' => 'ID сверхзадачи не может быть таким же как и ID самой задачи',
'quickaction'             => 'Быстрые действия',
'updateselectedtasks'     => 'Обновить выбранные задачи',
'notspecified'            => 'Не указано',
'editselectedtasks'       => 'Изменить выбранные задачи',
'information'             => 'Информация',
'taskclosedisabled'       => 'Закрыть задачу нельзя, т.к. следующие зависимые задачи открыты: -',
'daysleft'                => 'дней осталось',
'dayoverdue'              => 'дней проскочено',
'duetoday'                => 'Ожидается сегодня.',
'daysbeforealert'         => 'Несколько дней до готовности',
'associatedsubtask'       => 'Подзадачи успешно связаны #FS',
'associatesubtask'        => 'ID подзадачи для привязки к этой задиче',
'subtaskid'               => 'ID подзадачи',
'subtaskalreadyhasparent' => 'Подзадача, которую вы указали, имеет родительскую задачу, устраните это для привязки.',
'subtaskisparent'         => 'Подзадача, которую вы указали, является родителем этой задачи. Подзадача не привязана.',
'subtasknotexist'         => 'Подзадачи, которую вы указали, не существует',
'subtaskremovedmsg'       => 'Подзадача успешно удалена',
'subtaskadded'            => 'Подзадача добавлена',
'subtaskremoved'          => 'Подзадача удалена',
'addnewsubtask'           => 'Добавить новую подзадачу',
'hidesubtasks'            => 'Скрыть подзадачи',
'voteforthistask'         => 'Голосовать за эту задачу',
'watchthistask'           => 'Отслеживать задачу',
'privatethistask'         => 'Сделать частной',
'adddependenttask'        => 'Связать задачи',
'associatetaskid'         => 'ID подзадачи',
'parenttaskid'            => 'ID родительской задачи',
'invalidsupertaskid'      => 'ID родительской задачи не действительно.',
'supertaskadded'          => 'Сверхзадача создана',
'supertaskremoved'        => 'Сверхзадача удалена',
'effort'                  => 'Effort',
'efforttracking'          => 'Effort Tracking',
'useeffort'               => 'Project Uses Effort Tracking',
'estimatedeffort'         => 'Estimated Effort',
'totalestimatedeffort'    => 'Total estimated effort',
'currenteffortdone'       => 'Current effort done',
'starteffort'             => 'Start Tracking',
'endeffort'               => 'Stop Tracking',
'cleareffort'             => 'Clear Tracking',
'addeffort'               => 'Add Effort',
'manualeffort'            => 'Manually Add Effort (H:M)',
'efforttrackingstarted'   => 'Effort Tracking Commenced for this task.',
'efforttrackingnotstarted'=> 'Unable to start tracking on an issue that is already being tracked',
'efforttrackingstopped'   => 'Effort Tracking Ended for this task.',
'efforttrackingcancelled' => 'Effort Tracking Cancelled for this task.',
'efforttrackingadded'     => 'Manual effort recorded for task.',
'trackinginprogress'      => 'Tracking in Progress',
'viewestimatedeffort'     => 'Can View Effort Tracking',
'viewcurrenteffortdone'   => 'Can View Current Effort done',
'trackeffort'             => 'Can Track Effort',
'invalideffort'           => 'The effort entered is invalid. Must be a number',
'showpass'                => 'Показать пароль',
'chooseafile'             => 'Пожалуйста, выберите файл!',
'incorrectfiletype'       => 'Неверный тип файла. Разрешены: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Пароль не восстановить. Вы зарегестрированы через %s',
'addmultipletasks'        => 'Добавить несколько задач',
'pendingnewuserrequest'   => 'Новые пользователи, ожидающие рассмотрения',
'adminrequestswaiting'    => 'Администратор просит подождать',
'clicktoedit'             => 'Для быстрого редактирования, нажимайте на поля',
'confirmedit'             => 'подтвердить',
'regapprovedbyadmin'      => 'Регистрация утверждается администратором (отключить код подтверждения)',
'activity'                => 'Активность',
'myactivity'              => 'Моя активность',
'emailverificationwrong'  => 'Подтверждение не соответствуют заданному адресу электронной почты',
'verifyemailaddress'      => 'Подтвердите адрес электронной почты',
'hideemails'              => 'Скрывать адреса электронной почты пользователей',
'hidemyemail'             => 'Скрыть мой адрес электронной почты',
'exporttasklist'          => 'Экспортировать список задач',
'onedecimal'              => 'одна десятая',
'manday'                  => 'человеко-день',
'mandays'                 => 'человеко-дней',
'mandayabbrev'            => 'чд',
'hourspermanday'          => 'Часов в одном человеко-дне (HH:mm)',
'itemexists'              => 'Пункт %s уже существует в базе данных.',
'categoryitemexists'      => 'Пункт %s уже существует в категории %s в базе данных.',
'pageswelcomemsg'         => 'Страницы, где отображается основное приветственное сообщение',
'pagesintromsg'           => 'Страницы, где отображается приветственное сообщение',
'activeoauths'            => 'Активировать OAuth провайдеров',
'onlyoauthreg'            => 'Разрешить только OAuths регистрацию',
'estimatedeffortformat'   => 'Estimated effort display format',
'currenteffortdoneformat' => 'Current effort done display format',
'minute'                  => 'минута',
'minutes'                 => 'минут',
'minuteplural'            => 'минут',
'minutesingular'          => 'минута',
'minuteabbrev'            => 'мин',
'hourplural'              => 'часов',
'hoursingular'            => 'час',
'hourabbrev'              => 'ч',
'estimatedeffortopen'     => 'Estimated effort for open tasks',
'currenteffortdoneopen'   => 'Current effort spent in open tasks',
'signinwith'              => 'Войти в систему с помощью %s',
'canviewroadmap'          => 'Может просматривать план работ',
'enableavatars'           => 'Включить аватарки',
'maxavatarsize'           => 'Максимальный размер аватарки в пикселях',
'taskhassubtask'          => 'Эта задача имеет следующую подзадачу',
'taskhassubtasks'         => 'Эта задача имеет следующие подзадачи',
'translations'            => 'Переводы',
'translate'               => 'Перевод',
'taskdescription'         => 'Описание задачи',
'notaskdescription'       => 'нет описания задачи',
'pleaseselect'            => 'Пожалуйста, выберите',
'closeselectedtasks'      => 'Закрыть выбранные задачи',
'closetasks'              => 'закрыть задачи',
'hintforbulkimport'       => "<b>Tips for bulk importing:</b>\n  <ol>\n  <li>Copy and paste from an excel spreadsheet or CSV by pasting one entire column.</li>\n  <li>Currently you can only paste Summary and Details.</li>\n  <li>There are suggestions when you assign to someone, and to no-one if there is no matched name.</li>\n  </ol>",
'taskissubtaskof'         => 'Эта задача является подзадачей',
'applyfirstline'          => 'Применить первую строку',
'addmorerows'             => 'Добавить несколько строк',
'addtasks'                => 'Добавить задачи',
'massopsdisabled'         => 'Sorry, bulk editing is currently disabled for Flyspray 1.0. We plan to finish implementation for a later release of Flyspray. You can enable them in source code again at your own risk, but read the comments there before doing it.',
'viewroadmap'             => 'Может просматривать план работ',
'nosuicide'               => 'Dear user, my program doesn\'t allow you to destroy your access to Flyspray by disabling your own account or switching your own group. The empathic brother of HAL9000',
'movingtodifferentproject'=> 'Перемещение задачи, которая является или родителем, или подзадачей в другом проекте, не допускается. Сначала вы должны разорвать связь между ними.',
'musthavesameproject'     => 'Родитель и подзадача должны принадлежать к одному проекту',
'defaultorderby'          => 'Порядок списка задач по умолчанию',
'defaultorderby2'         => 'затем',
'viewowntasks'            => 'Смотреть свои задачи',
'viewgroupstasks'         => 'Смотреть групповые задач',
'urlrewriting'            => 'Url rewriting',
'enablehtaccess'          => 'Please enable your .htaccess file at Flyspray root before turning url rewriting on',
'nomodrewrite'            => 'Mod rewrite doesn\'t seem to be available on this server, sorry but I can\'t turn url rewriting on',
'on'                      => 'Включить',
'off'                     => 'Выключить',
'defaultorderbydirection' => 'Направление по умолчанию',
'ascending'               => 'По возростанию',
'descending'              => 'По убыванию',
'myassignedtasks'         => 'Назначенные мне задачи',
'commentedon'             => 'прокомментировал',
'maxvoteperday'           => 'Максимум голосов в день',
'votesperproject'         => 'Лимит голосов за проект для пользователя',
'votelimitreached'        => 'Вы достигли предела своих голосов за этот проект. См. страницу вашего профиля, для какие задачи вы в данный момент проголосовали. Там вы также можете забрать свои голоса. Так мы можем видеть, какие задачи наиболее важны для вас. За решенные задачи  вы получите свой голос обратно в свой лимит голосов.',
'myvotes'                 => 'Мои голоса',
'tag'                     => 'Тег',
'tags'                    => 'Теги',
'tagsinfo'                => "Free tagging/labeling of tasks in Flyspray:\nSeparate tags by ;\nTags are currently not managable and are not used for search or filtering. They are currently just like additional stickers on a window.",
'novalues'                => 'нет записей',
'youhaveregistered'       => 'Вы зарегистрировались на Flyspray. Детали:',
'youhaveregisterednotify' => 'Ваша регистрация на Flyspray была принята администратором.',
'usedintasks'             => 'Использовать',
'freetagging'             => 'разрешить пользовательские тэги',
'keyboardshortcuts'       => 'Горячие клавиши',
'testmailsettings'        => 'Проверить текущую активную настройку email',
'test'                    => 'Тест',
'testmailsettingsnotice'  => 'Проверьте, что Вы получили email на аккаунт элетронной почты текущего пользователя (см. страницу "Профиль")',
'invalidprogress'         => 'Пожалуйста, выберите правильное значение прогресса.',
'invalidpriority'         => 'Пожалуйста, выберите правильное значение приоритета.',
'invalidseverity'         => 'Пожалуйста, выберите правильное значение критичности.',
'invalidstatus'           => 'Пожалуйста, выберите правильный статус задачи',
'invalidtasktype'         => 'Пожалуйста, выберите правильный тип задачи.',
'invalidcategory'         => 'Пожалуйста, выберите правильную категорию.',
'invalidreportedversion'  => 'Пожалуйста, выберите правильную версию журнала событий.',
'invaliddueversion'       => 'Пожалуйста, выберите действующую версию.',
'invalidos'               => 'Пожалуйста, выберите правильную ОС.',
'invalidtags'             => 'Пожалуйста, выберите только допустимые тэги.',
'invalidassignees'        => 'Пожалуйста, выберите только разрешенных исполнителей.',
'invalidtargetproject'    => 'Пожалуйста, выберите правильный целевой проект.',
'hidesubs'                => 'скрыть подзадачи',
'hideprivate'             => 'скрыть частные задачи',
'hideclosed'              => 'скрыть закрытые задачи',
'globaloptions'           => 'глобальные настройки',
'currentproject'          => 'текущий проект',
'targetproject'           => 'целевой проект',
'availablekeybshortcuts'  => 'Доступные горячие клавиши',
'logindialoglogout'       => 'Диалог входа / Выход',
'openselectedtask'        => 'открыть выбранную задачу',
'movecursorup'            => 'сдвинуть курсор вверх',
'movecursordown'          => 'сдвинуть курсор вниз',
'taskdetails'             => 'Детали задачи',
'taskediting'             => 'Редактирование задачи',
'savetask'                => 'сохранить задачу',
'editorbold'              => 'Ж',
'editorboldhint'          => 'жирный',
'editoritalic'            => 'К',
'editoritalichint'        => 'курсив',
'editorunderline'         => 'П',
'editorunderlinehint'     => 'подчеркнутый',
'editorstrikethrough'     => 'З',
'editorstrikethroughhint' => 'зачеркнутый',
'captchaerror'            => 'CAPTCHA не решена, Пожалуйста, попробуйте снова.',
'registercaptcha'         => 'Пожалуйста, решите CAPTCHA.',
'regcaptcha'              => 'Показывать CAPTCHA при регистрации новых пользователей.',
'invalidsecurimage'       => 'Неверная CAPTCHA',
'invalidrecaptcha'        => 'Неверная Google reCAPTCHA',
'antispam'                => 'Анти-спам',
'antispamprefsinfo'       => 'Настройки против спам-ботов. В настоящее время Securimage и Google reCAPTCHA используются для регистрации новых пользователей.',
'securimageprefsinfo'     => 'Классическая CAPTCHA, где пользователи должны распознать текстовую последовательность.',
'securimageenable'        => 'Включить Securimage',
'recaptchaenable'         => 'Включить Google reCAPTCHA',
'adminchecks'             => 'Проверки',
'adminchecksinfo'         => 'Информация и проверки Вашей текущей установки',
'repeatpassword'          => 'повторите пароль',
'repeatemailaddress'      => 'повторите адрес email',
'tooltipshorttasktitle'   => 'Напишите название, которое обобщает проблему и делает ее понятной с первого взгляда',
'lastlogin'               => 'Последний вход в систему',
);

?>
