<?php

$translation = array(
'edituser'                => 'Redigera användare',
'accountenabled'	  => 'Konto Aktiverat',
'editallusers'		  => 'Visa alla användare',
'username'                => 'Användarnamn',
'usersupdated'		  => 'Användare uppdaterade',
'realname'                => 'Fullständigt namn',
'emailaddress'            => 'Epostadress',
'jabberid'                => 'Jabber ID',
'profileimage' 		  => 'Profilbild',
'notifytype'              => 'Aviseringssätt',
'group'                   => 'Grupp',
'enableaccounts'	  => 'Aktivera konton',
'disableaccounts'	  => 'Avaktivera konton',
'deleteaccounts'	  => 'Ta bort konton',
'updatedetails'           => 'Uppdatera detaljer',
'setglobally'             => 'Denna inställning är global.',
'usergroupmanage'         => 'Användar- och grupphantering',
'newuser'                 => 'Skapa ny användare',
'newuserbulk'		  => 'Skapa flera nya användare',
'bulkuserstoadd'	  => 'Lista över nya användare',
'optionsforallusers'	  => 'Inställningar för alla nya användare',
'newgroup'                => 'Skapa ny grupp',
'yes'                     => 'Ja',
'no'                      => 'Nej',
'editgroup'               => 'Redigera grupp',
'groupname'               => 'Gruppnamn',
'description'             => 'Beskrivning',
'admin'                   => 'Administratörsgrupp',
'opennewtasks'            => 'Nytt ärende',
'modifytasks'             => 'Ändra befintliga ärenden',
'addcomments'             => 'Lägga till kommentarer',
'attachfiles'             => 'Bifoga filer',
'vote'                    => 'Rösta',
'groupenabled'            => 'Medlemmar kan logga in',
'groupopen'               => 'Medlemmar kan logga in',
'tasktypelist'            => 'Ärendetypslista',
'categorylist'            => 'Kategorilista',
'oslist'                  => 'Operativsystemslista',
'resolutionlist'          => 'Lösningslista',
'versionlist'             => 'Versionslista',
'severitylist'            => 'Allvarlighetslista',
'listnote'                => 'Tänk på:  Om man kryssar ur "Visa", kan ärenden ändras i redigeringsläge. Om man ändrar "Namn", ändras alla ärenden med det namnet. Objekt som inte går att ta bort är endera skyddade eftersom de behövs för funktionaliteten eller används i något ärende.',
'name'                    => 'Namn',
'order'                   => 'Ordning',
'back'                    => 'Tillbaka',
'text'                    => 'Text',
'highlight'               => 'Markera',
'show'                    => 'Visa',
'owner'                   => 'Ägare',
'selectowner'             => 'Välj ägare',
'update'                  => 'Uppdatera',
'addnew'                  => 'Lägg till ny',
'flysprayprefs'           => 'Flyspray-inställningar',
'projecttitle'            => 'Projektnamn',
'baseurl'                 => 'Base URL för installationen',
'replyaddress'            => 'Svarsadress för aviseringar',
'themestyle'              => 'Tema/stil',
'language'                => 'Språk',
'anonview'                => 'Tillåt anonyma användare att se ärenden',
'allowanon'               => 'Tillåt anonyma användare att öppna nya ärenden',
'never'                   => 'Aldrig',
'anonymously'             => 'Anonymt',
'afterregister'           => 'Enbart efter registrering',
'spamproof'               => 'Slå på bekräftelse för nya användarregistreringar',
'anongroup'               => 'Grupp för nya användare',
'groupassigned'           => 'Medlemmar av dessa grupper kan kopplas till ärenden',
'forcenotify'             => 'Tvinga ärendeaviseringar som',
'neversend'               => 'Skicka aldrig',
'userchoose'              => 'Låt varje användare välja',
'email'                   => 'Epost',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Förvald kategoriägare',
'noone'                   => 'Ingen',
'jabbernotify'            => 'Jabber-aviseringar',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Användarnamn för konto',
'jabberpass'              => 'Lösenord för konto',
'saveoptions'             => 'Spara inställningar',
'editcomment'             => 'Ändra kommentar',
'commentby'               => 'Kommentar av',
'saveeditedcomment'       => 'Sparar ändrad kommentar',
'projectprefs'            => 'Projektinställningar',
'pagetitle'               => 'Sidnamn',
'defaultproject'          => 'Förvalt projekt',
'projectlists'            => 'Projektlistor',
'showlogo'                => 'Visa titelbild',
'showgravatars'		  => 'Visa gravatars',
'emailNoHTML'		  => 'Ingen HTML i E-Postmeddelanden',
'intromessage'            => 'Introduktionstext',
'isactive'                => 'Projektet är aktivt',
'createproject'           => 'Skapa ett nytt projekt',
'nopermission'            => 'Du har inte behörighet att använda denna sida.',
'listordertip'            => 'Listan visas i denna ordning',
'listshowtip'             => 'Visa detta objekt i listan',
'categoryownertip'        => 'Denna person får meddelande när ett ärende med denna kategori öppnas',
'categoryparenttip'       => 'Den kategori som denna nya kommer att ligga under',
'notsubcategory'          => 'Ingen (högstanivåkategori)',
'showinlineimages'        => 'Visa bifogade bilder i meddelandet',
'dateformat'              => 'Datumformat',
'dateformat_extended'     => 'Detaljerat datumformat',
'cache_feeds'             => 'Mellanlagra feeds',
'no_cache'                => 'Ingen mellanlagring',
'cache_disk'              => 'Mellanlagra på disk',
'cache_db'                => 'Mellanlagra i databasen',
'subcategoryof'           => 'Underkategori',
'visiblecolumns'          => 'Kolumner som visas i ärendelistan',
'visiblefields'		  => 'Kolumner som visas vid lägg till/ändra/visa ärende',
'tense'                   => 'Tid',
'listtensetip'            => 'Dåtid, nutid eller framtid',
'past'                    => 'Dåtid',
'present'                 => 'Nutid',
'future'                  => 'Framtid',
'oldpass'                 => 'Gammalt lösenord',
'nooldpass'               => 'Inget gammalt lösenord',
'oldpasswrong'            => 'Felaktigt gammalt lösenord',
'changepass'              => 'Ändra lösenord',
'confirmpass'             => 'Bekräfta lösenord',
'projectmanager'          => 'Projektadministrering',
'viewtasks'               => 'Visa ärenden',
'modifyowntasks'          => 'Ändra egna ärenden',
'modifyalltasks'          => 'Ändra andras ärenden',
'viewcomments'            => 'Visa kommentarer',
'editcomments'            => 'Ändra kommentarer',
'deletecomments'          => 'Ta bort kommentarer',
'viewattachments'         => 'Visa bifogade filer',
'createattachments'       => 'Bifoga filer',
'deleteattachments'       => 'Ta bort bifogade filer',
'viewhistory'             => 'Visa historik',
'closeowntasks'           => 'Stänga egna ärenden',
'closeothertasks'         => 'Stänga andras ärenden',
'assigntoself'            => 'Tilldela ärende till sig själv om det inte redan är det',
'assignotherstoself'      => 'Tilldela andras ärenden till sig själv',
'viewreports'             => 'Visa händelselogg',
'othersview'              => 'Tillåt vem som helst att se detta projekt',
'usersandgroups'          => 'Användare och grupper',
'globalgroup'             => 'Global grupp',
'globalgroups'            => 'Globala grupper',
'defaultglobalgroup'      => 'Förvald global grupp för nya användare',
'addtogroup'              => 'Lägg till grupp',
'moveuserstogroup'        => 'Flytta användare till grupp',
'nogroup'                 => 'Ingen grupp - ta bort från projekt',
'eventdesc'               => 'Händelsebeskrivning',
'requestedby'             => 'Efterfrågad av',
'daterequested'           => 'Datum för efterfrågan',
'closetask'               => 'Stäng ärende',
'reopentask'              => 'Återta ärende',
'applymember'             => 'Ansök om medlemskap i projekt',
'forcurrentproj'          => 'För nuvarande projekt',
'lostpw'                  => 'Bortglömt lösenord',
'lostpwexplain'           => 'Ange ditt användarnamn och klicka på Skicka länk så får du en länk till en sida där du kan ange ett nytt lösenord. Länken skickas till din aviseringsadress.',
'sendlink'                => 'Skicka länk',
'savenewpass'             => 'Spara nytt lösenord',
'anonreg'                 => 'Tillåt nyregistreringar av användare',
'allowanonopentask'       => 'Tillåt anonyma användare att skapa ärenden',
'editglobalgroup'         => 'Ändra global grupp',
'editgroupforproj'        => 'Ändra grupp för projekt',
'notshownforadmin'        => 'Behörigheter visas inte för administratörer. Du behöver inte ändra dem.',
'general'                 => 'Generellt',
'userregistration'        => 'Användarregistrering',
'notifications'           => 'Aviseringar',
'resetoptions'            => 'Återställ',
'preferences'             => 'Inställningar',
'tasktypes'               => 'Ärendetyper',
'resolutions'             => 'Lösningar',
'categories'              => 'Kategorier',
'operatingsystems'        => 'Operativsystem',
'versions'                => 'Versioner',
'admintoolboxlong'        => 'Administratörsverktyg',
'newproject'              => 'Nytt projekt',
'delete'                  => 'Ta bort',
'link'			  => 'Länk',
'referencelinks'	  => 'Referens länkar',
'listdeletetip'           => 'Ta bort objektet från listan',
'lookandfeel'             => 'Utseende och känsla',
'globaltheme'             => 'Globalt tema',
'emailnotify'             => 'Epostavisering',
'fromaddress'             => 'Från-adress',
'smtpserver'              => 'SMTP Server',
'smtpuser'                => 'SMTP användarnamn',
'smtppass'                => 'SMTP lösenord',
'addrewrite'              => 'Använd adressomskrivning',
'usereminderdaemon'       => 'Använd bakgrundspåminnelse-daemon',
'tasksperpage'            => 'Ärenden per sida i ärendelistan',
'addtoassignees'          => 'Lägg till sig själv till tilldelare',
'taskstatuses'            => 'Ärendestatus',
'canvote'                 => 'Kan rösta på ärenden',
'loginsuccessful'         => 'Inloggning lyckades.',
'youareloggedout'         => 'Du är utloggad.',
'waitwhiletransfer'       => 'Vänta medan du blir vidarebefodrad...',
'clicknowait'             => 'Klicka här om du inte vill vänta.',
'accountdisabled'         => 'Ditt konto är inaktiverat. Kontakta en administratör.',
'task'                    => 'Ärende',
'edittask'                => 'Ändra detta ärende',
'openedby'                => 'Skapad av',
'editedby'                => 'Senast ändrad av',
'tasktype'                => 'Ärendetyp',
'category'                => 'Kategori',
'status'                  => 'Status',
'assignedto'              => 'Tilldelad',
'operatingsystem'         => 'Operativsystem',
'severity'                => 'Allvarlighet',
'reportedversion'         => 'Rapporterad version',
'dueinversion'            => 'Åtgärdad till version',
'defaultdueinversion'	  => 'Standard åtgärd till version för nya ärenden',
'undecided'               => 'Inte bestämt',
'percentcomplete'         => 'Procent färdig',
'details'                 => 'Beskrivning',
'savedetails'             => 'Spara ändringar',
'canceledit'              => 'Avbryt ändring',
'anonymous'               => 'Anonym inskickare',
'complete'                => 'färdig',
'closedby'                => 'Stängd av',
'reasonforclosing'        => 'Anledning till stängning:',
'reopenthistask'          => 'Återta ärendet',
'comments'                => 'Kommentarer',
'attachments'             => 'Bifogade filer',
'relatedtasks'            => 'Besläktade ärenden',
'edit'                    => 'Ändra',
'addcomment'              => 'Kommentera',
'fileuploadedby'          => 'Filen uppladdad av',
'uploadafile'             => 'Bifoga en fil',
'addalink'		  => 'Lägg till en länk',
'addanotherlink'	  => 'Lägg till en länk till',
'uploadnow'               => 'Ladda upp nu!',
'thesearerelated'         => 'Dessa ärenden är besläktade med detta',
'remove'                  => 'Ta bort',
'addnewrelated'           => 'Lägg till ett besläktat ärende',
'add'                     => 'Lägg till!',
'otherrelated'            => 'Andra besläktade ärenden',
'receivenotify'           => 'Användare som får aviseringar när ärendet ändras.',
'addusertolist'           => 'Lägg till användare till listan',
'addtolist'               => 'Lägg till',
'addmyself'               => 'Lägg till mig själv till listan',
'removemyself'            => 'Ta bort mig själv från listan',
'theseusersnotify'        => 'Användare som får detaljerade aviseringar när ärendet ändras.',
'attachedtoproject'       => 'Kopplad till projekt',
'reminders'               => 'Påminnelser',
'system'                  => 'System',
'remindthisuser'          => 'Påminn denna användare',
'thisoften'               => 'Så här ofta',
'startafter'              => 'Starta påminnelser efter',
'hour'			  => 'Timma',
'hours'                   => 'Timmar',
'day'			  => 'Dag',
'days'                    => 'Dagar',
'week'			  => 'Vecka',
'weeks'                   => 'Veckor',
'addreminder'             => 'Lägg till påminnelse',
'defaultreminder'         => 'Det här är en påminnelse för att titta på detta ärende i Flyspray:',
'message'                 => 'Meddelande',
'closed'                  => 'Stängd',
'filename'                => 'Filnamn:',
'date'                    => 'Datum',
'filesize'                => 'Filstorlek:',
'closurecomment'          => 'Ytterligare stängningskommentar:',
'history'                 => 'Historik',
'nohistory'               => 'Det finns ingen historik.',
'eventdate'               => 'Datum',
'user'                    => 'Användare',
'event'                   => 'Händelse',
'fieldchanged'            => 'Fält ändrat',
'taskopened'              => 'Ärende öppnat',
'taskreopened'            => 'Ärende återaktiverat',
'taskclosed'              => 'Ärende stängt',
'commentadded'            => 'Kommentar tillagd',
'commentedited'           => 'Kommentar ändrad',
'commentdeleted'          => 'Kommentar borttagen',
'attachmentadded'         => 'Ny bifogad fil',
'attachmentdeleted'       => 'Borttagen bifogad fil',
'taskedited'              => 'Ändrade ärendebeskrivning',
'notificationadded'       => 'Användare tillagd till aviseringslistan',
'notificationdeleted'     => 'Användare borttagen från aviseringslistan',
'relatedadded'            => 'Besläktat ärende tillagt',
'relateddeleted'          => 'Besläktat ärende borttaget',
'taskassigned'            => 'Ärende tilldelat till',
'taskreassigned'          => 'Ärende återtilldelat till',
'assignmentremoved'       => 'Tilldelning borttagen',
'summary'                 => 'Sammanfattning',
'addedasrelated'          => 'Ärende tillagt till relationslistan för',
'deletedasrelated'        => 'Ärende borttaget från relationslistan för',
'reminderadded'           => 'Påminnelse tillagd',
'reminderdeleted'         => 'Påminnelse borttagen',
'priority'                => 'Prioritet',
'previousvalue'           => 'Föregående värde',
'newvalue'                => 'Nytt värde',
'selectareason'           => 'Välj anledning',
'assigntome'              => 'Tilldela mig',
'reopenrequest'           => 'Efterfråga återöppning',
'requestclose'            => 'Efterfråga stängning',
'ownershiptaken'          => 'Tilldelade sig själv',
'closerequestmade'        => 'Begärd stängning',
'reopenrequestmade'       => 'Begärd återöppning',
'taskdependson'           => 'Ärendet beror på',
'taskblocks'              => 'Ärendet blockerar dessa',
'depadded'                => 'Lagt till beroende av',
'depaddedother'           => 'Detta ärende tillagd som beroende för',
'depremoved'              => 'Tagit bort beroende av',
'depremovedother'         => 'Ärende borttaget som beroende för',
'showdetailserror'        => 'Endera så finns inte ärendet eller så har du inte behörighet att se det.',
'makeprivate'             => 'gör privat',
'makepublic'              => 'gör publikt',
'taskmadeprivate'         => 'Ärendet gjort privat',
'taskmadepublic'          => 'Privat borttagen - ärendet gjort publikt',
'confirmdeletecomment'    => 'Vill du verkligen ta bort kommentaren? %s',
'confirmdeleteattach'     => 'Vill du verkligen ta bort denna bifogade fil?',
'selectedhistory'         => 'Visa valda historikdetaljer',
'showallhistory'          => 'Visa all historik igen',
'hidethis'                => 'Göm detta fält igen',
'mark100'                 => 'Sätt ärendet som 100% färdigt',
'watchtask'               => 'avisera mig',
'stopwatching'            => 'avsluta avisering',
'commentlink'             => 'Kommentarlänk',
'submitreq'               => 'Sänd önskemål',
'reasonforreq'            => 'Anledning för önskemål',
'pmreqdenied'             => 'Projektadministratör nekade efterfrågan',
'taskpendingreq'          => 'Väntar på svar från projektadministratör. Se historikfliken för detaljer.',
'previoustask'            => 'Föregående ärende',
'nexttask'                => 'Nästa ärende',
'duedate'                 => 'Färdigdatum',
'attachnoperms'           => 'Det finns bifogade filer till denna kommentar med du har inte behörighet att se dem.',
'open'                    => 'Öppna',
'depgraph'                => 'Visa beroendegraf',
'reset'                   => 'Återställ',
'selectusers'             => 'Välj användare...',
'addmetoassignees'        => 'Lägg till mig som tilldelare',
'addedtoassignees'        => 'Användare tillagd till tilldelarlistan',
'dependencygraph'         => 'Beroendegraf',
'attachanotherfile'       => 'Bifoga en till fil',
'OK'                      => 'OK',
'addvote'                 => 'rösta',
'notifyfromfs'            => 'Avisering från Flyspray',
'autogenerated'           => 'DETTA ÄR ETT AUTOMATGENERERAT MEDDELANDE. SVARA INTE',
'forward'                 => 'Framåt',
'previous'                => 'Föregående',
'next'                    => 'Nästa',
'first'                   => 'Första',
'last'                    => 'Sista',
'page'                    => 'Sida %d av %d',
'search'                  => 'Sök',
'alltasktypes'            => 'Alla ärendetyper',
'allseverities'           => 'Alla allvarlighetsgrader',
'alldevelopers'           => 'Alla utvecklare',
'notyetassigned'          => 'Inte tilldelad',
'allcategories'           => 'Alla kategorier',
'allstatuses'             => 'Oberoende av status',
'allopentasks'            => 'Alla öppna ärenden',
'sortthiscolumn'          => 'Sortera på denna kolumn',
'id'                      => 'Id',
'project'                 => 'Projekt',
'dateopened'              => 'Öppnad den',
'progress'                => 'Framsteg',
'searchthisproject'       => 'Sök i detta projekt efter',
'dueanyversion'           => 'Färdig i alla versioner',
'anyversion'              => 'Rapporterad för alla versioner',
'dueversion'              => 'Färdig i version',
'lastedit'                => 'Senast ändrad',
'os'                      => 'Operativsystem',
'reportedin'              => 'Rapporterad i',
'taskrange'               => 'Visar ärende %d - %d av %d',
'noresults'               => 'Sökningen gav inga resultat.',
'takeaction'              => 'Utför',
'watchtasks'              => 'Aviseringar för valda ärenden',
'stopwatchingtasks'       => 'Avsluta avisering för valda ärenden',
'assigntaskstome'         => 'Tilldela valda ärenden till mig',
'dueby'                   => 'Färdig den',
'dueanytime'              => 'Färdig när som helst',
'selectduedate'           => 'Välj färdigdatum',
'toggleselected'          => 'Byt val',
'due'                     => 'Färdig den',
'assignedtome'            => 'Tilldela mig själv',
'tasklist'                => 'Ärendelista',
'dateclosed'              => 'Stängningsdatum',
'advanced'                => 'Avancerad',
'searchcomments'          => 'Sök i kommentarer',
'searchforall'            => 'Sök alla ord',
'anonusers'               => 'Anonyma användare',
'miscellaneous'           => 'Diverse',
'users'                   => 'Användare',
'taskproperties'          => 'Ärendeegenskaper',
'selectsincedate'         => 'Välj ändrad sedan',
'changedsince'            => 'Ändrad sedan',
'updatefs'                => 'Vänligen uppdatera Flyspray.',
'currentversion'          => 'Din version är',
'latestversion'           => 'och den senaste versionen är',
'hidemessage'             => '(påminn mig senare)',
'saveas'                  => 'Spara sökning som',
'nosearches'              => 'Inga sparade sökningar',
'saving'                  => 'Sparar...',
'votes'                   => 'Röster',
'allclosedtasks'          => 'Alla stängda ärenden',
'password'                => 'Lösenord',
'login'                   => 'Logga in!',
'rememberme'              => 'Kom ihåg mig',
'lostpassword'            => 'Glömt lösenordet?',
'lostpwforfs'             => 'Bortglömt lösenord för Flyspray',
'lostpwmsg1'              => "Hej.\n\nJag har glömt mitt lösenord för ",
'lostpwmsg2'              => ", kan ni ordna ett nytt lösenord till mig?\n\nanvändarnamn: ",
'regards'                 => "\n\nMvh,",
'yourusername'            => ' ditt användarnamn ',
'locale'                  => 'sv-SE',
'filenotexist'            => 'Endera så finns inte filen eller så har du inte behörighet att komma åt den.',
'showtask'                => 'Visa ärende',
'now'                     => 'Nu',
'go'                      => 'Kör!',
'opentaskanon'            => 'Öppna ett nytt ärende anonymt',
'register'                => 'Registrera',
'addnewtask'              => 'Nytt ärende',
'reports'                 => 'Händelselogg',
'editmydetails'           => 'Ändra mina uppgifter',
'logout'                  => 'Logga ut',
'disabledaccount'         => 'Ditt konto är avstängt!<br />Loggar ut dig nu...',
'poweredby'               => 'Drivs av Flyspray',
'projects'                => 'Projekt',
'allprojects'             => 'Alla Projekt',
'selectproject'           => 'till Projekt:',
'tasksall'                => 'Alla ärenden',
'tasksassigned'           => 'Ärenden tilldelad mig',
'tasksreported'           => 'Ärenden rapporterade av mig',
'taskswatched'            => 'Ärenden som aviseras mig',
'mysearch'                => 'Mina sökningar',
'admintoolbox'            => 'Administratörsverktyg',
'manageproject'           => 'Administrera projekt',
'permissions'             => 'Visa behörigheter',
'hide'                    => 'Göm',
'pendingreq'              => 'Det finns gjorda efterfrågningar',
'errorpage'               => "Flyspray kan inte hitta den sida som du efterfrågade.\n                              Du kanske sökte ett ärende som inte finns eller så\n                              har du inte behörighet att se sidan.<br /><br />\n                              Du kanske försökte med en otillåten URL för att komma åt\n                              databasen via SQL injection. Om du gjort det så gå till närmsta\n                              hörn, sätt dig ner och fundera över vad du gjort. När du kommer\n                              tillbaka så gör inte om det!",
'permissionsforproject'   => 'Behörigheter för ',
'switchto'                => 'Byt till',
'lastsearch'              => 'Senaste sökning',
'modify'                  => 'Ändra',
'noticefrom'              => 'Avisering från',
'hasopened'               => 'har öppnat ett nytt ärende i Flyspray och tilldelat ärendet till dig:',
'moreinfonew'             => 'Du kan få mer infomation om den här buggen på Flyspraysidan:',
'newtaskcategory'         => 'Det har öppnats ett nytt ärende i Flyspray med denna kategori',
'categoryowner'           => 'Du får detta meddelande för att du är angiven som kategoriägare.',
'tasksummary'             => 'Sammanfattning:',
'newtaskadded'            => 'Ditt nya ärende är nu tillagt.',
'summaryanddetails'       => 'Du måste fylla i både sammanfattning och beskrivning.',
'goback'                  => 'Gå tillbaka.',
'messagefrom'             => 'Detta är ett meddelande från bugghanteringssystemet Flyspray på',
'hasjustmodified'         => 'har nyss ändrat ärendet som följer.',
'changedfields'           => 'Ändrade fält är markerade med stjärnor (**)',
'moreinfomodify'          => 'Du kan få mer information om detta ärende på adressen:',
'nolongerassigned'        => 'Ärendet som följer är inte tilldelat till dig längre. Det är nu tilldelat',
'hasassigned'             => 'har tilldelat dig följade Flysprayärende:',
'taskupdated'             => 'Ärendet är uppdaterat.',
'hasclosedassigned'       => 'har stängt följade Flysprayärende vilket du var tilldelad:',
'unassigned'              => 'Ej tilldelat',
'hasclosed'               => 'har stängt följande ärende.',
'youonnotify'             => 'Du får detta för att du är på aviseringlistan.',
'taskclosedmsg'           => 'Ärendet stängt.',
'returntotask'            => 'Gå tillbaka till ärendedetaljer',
'backtoindex'             => 'Gå tillbaka till ärendelistan',
'noclosereason'           => 'Du angav ingen anledning till att stänga ärendet.',
'hasreopened'             => 'har återöppnat följande Flysprayärende som du har stängt:',
'taskreopenedmsg'         => 'Ärendet har återöppnats.',
'backtotask'              => 'Gå tillbaka till ärendet.',
'commentaddedmsg'         => 'Kommentaren tillagd.',
'commenttoassigned'       => 'har lagt till en kommentar till ett ärende som du är tilldelad:',
'commenttotask'           => 'har lagt till följande kommentar till ärendet.',
'nocommententered'        => 'Du borde ange en kommentar innan du klickar på skickaknappen.',
'fillinfields'            => 'Du fyllde inte i alla fält.',
'notcurrentpass'          => 'Det är inte ditt nuvarande lösenord!',
'passchanged'             => 'Ditt lösenord är ändrat.',
'closewindow'             => 'Du kan nu stänga detta fönster.',
'passnomatch'             => 'Dina nya lösenord matchade inte varandra!',
'usernametaken'           => 'Användarnamnet används redan. Du måste välja ett nytt.',
'newusercreated'          => 'Ett nytt användarkonto har skapats.',
'accountcreated'          => 'Ditt konto är nu skapat.',
'newuserwarning'          => 'Ditt konto kan behöva godkännas av en administratör. Om du inte kann logga in så beror det antagligen på det.',
'nomatchpass'             => 'Lösenorden är inte lika.',
'confirmwrong'            => 'Fel bekräftelsekod!',
'formnotcomplete'         => 'Formuläret är inte fullständigt ifyllt.',
'formnotnumeric'          => 'Texten måste vara siffror!',
'groupnametaken'          => 'Gruppnamnet används redan.',
'newgroupadded'           => 'Ny grupp tillagd.',
'optionssaved'            => 'Inställningar för Flyspray sparade.',
'hasuploaded'             => 'har bifogat en fil till ett ärende som du är tilldelad:',
'hasattached'             => 'har bifogat en fil till följande ärende.',
'fileuploaded'            => 'Filen har bifogats.',
'fileerror'               => 'Kunde inte bifoga filen. Kanske behörigheterna för <i>attachments/</i>-katalogen är felaktiga.',
'contactadmin'            => 'Kontakta administratören för detta projekt.',
'selectfileerror'         => 'Du valde ingen fil.',
'userupdated'             => 'Användardetaljer har uppdaterats',
'realandemail'            => 'Du måste fylla i både fullständigt namn och epost!',
'groupupdated'            => 'Gruppinställningar uppdaterades.',
'groupanddesc'            => 'Du måste ange gruppnamn.',
'fillallfields'           => 'Fyll i alla fält.',
'listPmustN'              => '"Sorteringsordning" måste vara siffror.',
'listupdated'             => 'Listan är uppdaterad.',
'listitemadded'           => 'Ny post är tillagt till listan.',
'relatedaddedmsg'         => 'Besläktat ärende lagt till listan.',
'relatederror'            => 'Det ärendet finns redan i listan.',
'relatedremoved'          => 'Besläktat ärende borttaget från listan.',
'notifyadded'             => 'Användare tillagd till aviseringlistan.',
'notifyerror'             => 'Användaren finns redan i aviseringlistan för det ärendet.',
'notifyremoved'           => 'Användare borttagen från aviseringslistan.',
'editcommentsaved'        => 'Ändrad kommentar är sparad.',
'commentdeletedmsg'       => 'Kommentaren är borttagen.',
'gotonewtask'             => 'Gå till ärendet du just öppnat',
'projectcreated'          => 'Ditt nya projekt är skapat. Följ länken nedan för att ändra kategori-, operativsystem- och versionslistorna.',
'customiseproject'        => 'Skräddarsy projektet',
'projectupdated'          => 'Projektinställningar uppdaterade',
'emptytitle'              => 'Du lämnade projektnamnet tomt. Gå tillbaka och justera det.',
'loginbelow'              => 'Du kan nu försöka att logga in.',
'attachmentdeletedmsg'    => 'Den bifogade filen är borttagen',
'reminderaddedmsg'        => 'Din påminnelse är tillagd.',
'reminderdeletedmsg'      => 'Vald påminnelse är borttagen.',
'flyspraytask'            => 'Ärende i Flyspray',
'fieldsmissing'           => 'Några fält hade felaktiga eller inga data.',
'relatedinvalid'          => 'Det finns inget sådant ärende.',
'relatedproject'          => 'Ärendet är kopplat till ett annat projekt. Lägg till släktskap ändå?',
'addanyway'               => 'Lägg till ändå',
'cancel'                  => 'Avbryt',
'alreadyedited'           => 'Ärendet ändrades av någon anna innan du hann spara. Vill du fortarande spara dina ändringar?',
'saveanyway'              => 'Spara ändringar ändå',
'nouserselected'          => 'Ingen användare vald.  Välj åtminstonde en användare innan du fortsätter.',
'groupswitchupdated'      => 'Lyckades ändra användargrupper',
'takenownershipmsg'       => 'Ärendet är nu tilldelat dig.',
'adminrequestmade'        => 'Din efterfrågan har skickats till en projektadministratör.',
'newdepnotify'            => 'Ett nytt beroende har skapats för följande ärende:',
'dependadded'             => 'Beroende har skapats',
'dependaddfailed'         => 'Kunde inte skapa beroende. Kontrollera att ärendet finns och att det inte blir ett ömsesidigt beroende.',
'depremovedmsg'           => 'Beroende borttaget',
'newdepis'                => 'Det nya beroendet är',
'magicurlsent'            => 'Ett meddelande är skickat till din adress.  Följ länken i meddelandet för att slutföra ärendet.',
'changefspass'            => 'Ändra lösenord i Flyspray',
'magicurlmessage'         => 'Följ denna länk för att ändra ditt lösenord i Flyspray:',
'erroronform'             => 'Det blev fel när formuläret skickades.',
'addressused'             => 'Den här adressen har använts för att registrera ett Flyspraykonto. Om inte det här meddelandet var väntat så kan du ignorera och ta bort det. Gå till denna adress för att slutföra din registrering:',
'confirmcodeis'           => 'Din bekräftelsekod är:',
'codesent'                => 'Vi har skickat din bekräftelsekod. Följ instruktionerna i meddelandet.',
'codenotsent'             => 'Kan inte skicka din kod. Försök igen senare.',
'taskmadeprivatemsg'      => 'Ärendet har gjorts privat.',
'taskmadepublicmsg'       => 'Ärendet har gjorts publikt igen',
'realandnotify'           => 'Du måste fylla i fullständigt namn och endera epostadress eller Jabber-id.',
'pmreqdeniedmsg'          => 'Begäran till projektansvarig nekades',
'massopsuccess'           => 'Alla åtgärder lyckades - där behörigheterna tillät.',
'usernotexist'            => 'Användaren finns inte i denna installation av Flyspray',
'commentattachperms'      => 'Du får kan inte ta bort kommentaren eftersom du inte har behörighet att ta bort bifogade filer.',
'voterecorded'            => 'Din röst är registrerad',
'votefailed'              => 'Din röst kunde inte registreras nu.',
'createnewgroup'          => 'Skapa ny grupp',
'requiredfields'          => 'Obligatoriska fält markeras med',
'addthisgroup'            => 'Skapa gruppen',
'createnewproject'        => 'Skapa ett nytt projekt',
'addnewproject'           => 'Nytt projekt',
'htmlallowed'             => 'HTML-kod är tillåten',
'createthisproject'       => 'Skapa projektet',
'inlineimages'            => 'Visa bifogade bilder i meddelandet',
'createnewtask'           => 'Skapa nytt ärende i projektet:',
'addanother'              => 'Lägg till ett till ärende efter detta',
'addthistask'             => 'Lägg till ärendet',
'notifyme'                => 'Avisera mig när ärendet ändras',
'newtask'                 => 'Nytt ärende',
'attachafile'             => 'Bifoga en fil',
'registernewuser'         => 'Registrera ny användare',
'none'                    => 'Ingen',
'registeraccount'         => 'Registrera kontot',
'both'                    => 'Båda',
'notifyfrom'              => 'Avisering från ',
'donotreply'              => 'DETTA ÄR ETT AUTOMATGENERERAT MEDDELANDE. SVARA INTE PÅ DET.',
'disclaimer'              => 'Du får detta meddelande eftersom du har begärt det från bugghanteringssystemet Flyspray. Om du inte förväntade dig att få det eller inte vill få meddelanden i framtiden så kan du ändra dina aviseringsinställningar via adressen som visas ovan.',
'userwho'                 => 'Användare som gjorde detta',
'moreinfo'                => 'Mer information kan du hitta på denna adress:',
'newtaskopened'           => 'Ett nytt ärende i Flyspray har öppnats. Detaljer nedan.',
'notify.taskclosed'       => 'Följande ärenden är nu stängda:',
'notify.taskreopened'     => 'Följande ärenden är nu återöppnade:',
'newdep'                  => 'Följande ärenden har nu nytt beroende:',
'notify.depremoved'       => 'Följande ärende har ett beroende borttaget:',
'olddepwas'               => 'Det gamla beroendet var',
'notify.commentadded'     => 'Följande ärende har en ny kommentar:',
'commentis'               => 'Kommentaren finns nedan.',
'newattachment'           => 'En ny fil har bifogats till ärende:',
'detailsbelow'            => 'Detaljer nedan.',
'notify.relatedadded'     => 'Ett nytt besläktat ärende har lagts till detta ärende:',
'relatedis'               => 'Det besläktade ärendet är',
'assignedtoyou'           => 'Du har tilldelats ärende:',
'takenownership'          => 'äger nu följande ärende:',
'requiresaction'          => 'Ärende som måste åtgärdas av en projektadministratör:',
'requiresactionnotify'    => 'Ärendet måste åtgärdas av en projektadministratör',
'pmdeny'                  => 'En projektadministratör har avslagit avvaktande begäran för ärende:',
'pmdenynotify'            => 'En projektadministratör har avslagit begäran',
'fileaddedtoo'            => 'Det fanns bifogade filer till denna kommentar.',
'taskwatching'            => 'Ärenden som du har aviseringar från',
'isdepfor'                => 'är ett nytt beroende av',
'denialreason'            => 'Anledning för avlsag',
'taskchanged'             => 'Ärendet har ändrats. Ändringarna visas nedan. För mer information om vad som ändrats, gå till adressen för ärendet och klicka på historikfliken.',
'useraddedtoassignees'    => 'En användare har lagt till sig till tilldelningslistan för detta ärende.',
'removeddepis'            => 'Det borttagna beroendet är',
'isnodepfor'              => 'är inte längre beroende av',
'usergroups'              => 'Användargrupper',
'pmtoolbox'               => 'Projektadministratörsverktyg',
'groupmanage'             => 'Gruppadministrering',
'pendingrequests'         => 'Avvaktande begäran',
'reasongiven'             => 'Angiven anledning',
'nopendingreq'            => 'Det finns inga avvaktande begäran.',
'givereason'              => 'Ange en anledning',
'catlisted'               => 'Redigera kategorier',
'oslisted'                => 'Redigera operativsystem',
'verlisted'               => 'Redigera versioner',
'tasktypeed'              => 'Redigera ärendetyper',
'resed'                   => 'Redigera lösningar',
'deny'                    => 'Neka',
'notifiedwhen'            => 'Aviserad när',
'onlynewtasks'            => 'Ärenden öppnas',
'allevents'               => 'Någon händelse i något ärende',
'feeds'                   => 'Feeds',
'feeddescription'         => 'Beskrivning av feed',
'feedimgurl'              => 'Bild URL för feed (lämna tom för ingen bild)',
'notifysubject'           => 'Ärende för aviseringar',
'notifysubjectinfo'       => '(%p = projektnamn, %s = ärendesummering, %t = ärendenummer, %a = action, %u = användarnamn)',
'priority6'               => 'Blixtsnabbt',
'priority5'               => 'Omedelbar',
'priority4'               => 'Brådskande',
'priority3'               => 'Hög',
'priority2'               => 'Normal',
'priority1'               => 'Låg',
'sendcode'                => 'Skicka kod!',
'entercode'               => 'Ange den bekräftelsekod som du fick i ditt meddelande. Ange även önskat lösenord.',
'confirmationcode'        => 'Bekräftelsekod',
'registererror'           => 'Kontrollera så att du har skrivit in alla obligatoriska fält och att du har korrekta uppgifter för dina aviseringssätt.',
'validusername'           => '(endast bokstäver, siffror och - _ . tillåts)',
'emailtaken'              => 'Den epostadressen eller Jabber-ID används redan. Du måste välja något annat.',
'note'                    => '<strong>Observera:</strong> Vi skickar en bekräftelsekod innan kontot skapas. Koden skickas till dig via det aviseringssätt du har valt ovan.<br />Om du anger felaktiga uppgifter så kommer du <strong>inte få din kod</strong>.',
'changelog'               => 'Ändringslogg',
'changeloggen'            => 'Ändringsloggsgenerator',
'listfrom'                => 'Visa ändringslogg från',
'to'                      => 'till',
'oldestfirst'             => 'Äldst först',
'recentfirst'             => 'Senaste först',
'severityrep'             => 'Allvarsrapport',
'totalopen'               => 'Antal öppna ärenden',
'age'                     => 'Ålder',
'agerep'                  => 'Åldersrapport',
'eventsrep'               => 'Händelserapport',
'events'                  => 'Händelser',
'Tasks'                   => 'Ärenden',
'opened'                  => 'Öppnad',
'edited'                  => 'Ändrad',
'assigned'                => 'Tilldelad',
'within'                  => 'Inom',
'pastday'                 => 'Senaste dagen',
'pastweek'                => 'Senaste veckan',
'pastmonth'               => 'Senaste månaden',
'pastyear'                => 'Senaste året',
'nolimit'                 => 'Ingen begränsning',
'from'                    => 'Från',
'duein'                   => 'Färdig den',
'selectfromdate'          => 'Välj fråndatum',
'selecttodate'            => 'Välj tilldatum',
'showvoters'              => 'Visa/göm röstare',
'roadmap'                 => 'Arbetsplan',
'roadmapfor'              => 'Arbetsplan för version',
'tasks'                   => 'ärenden',
'completed'               => 'klar.',
'opentasks'               => 'öppna ärenden',
'of'                      => '% av',
'severity5'               => 'Kritisk',
'severity4'               => 'Hög',
'severity3'               => 'Medium',
'severity2'               => 'Låg',
'severity1'               => 'Mycket låg',
'Redirect'                => 'Omdirigera',
'redirectmsg'             => 'Om din webbläsare inte stödjer omdirigeringar så klicka %sHÄR%s för att komma dit.',
'allowclosedcomments'     => 'Tillåt kommentarer på stängda ärenden',
'comment'                 => 'Kommentar',
'editowncomments'         => 'Ändra egna kommentarer',
'reopened'                => 'Återöppnad',
'loading'                 => 'Laddar...',
'notifyown'               => 'Avisera egna ändringar',
'youremail'               => 'Din epostadress',
'thankyouforbug'          => 'Tack för att rapporterar ditt problem. Du kan se ärendet och hur det fortlöper när som helst via denna länk:',
'anonuser'                => 'Anonym användare',
'conflict'                => 'Konflikt',
'file'                    => 'Fil',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Storlek',
'projectgroup'            => 'Projektgroup',
'profile'                 => 'Profil:',
'viewprofile'             => 'Visa profile',
'regdate'                 => 'Registrerad sedan',
'tasksopened'             => 'Ärende öppnat',
'replyto'                 => 'Svar till',
'notifytypes'             => 'Aviseringssätt',
'pm.taskchanged'          => 'Ärende ändrat',
'pm.taskreopened'         => 'Ärende återöppnat',
'pm.depadded'             => 'Beroende tillagt',
'pm.depremoved'           => 'Beroende borttaget',
'pmrequest'               => 'Efterfrågan, projektadm.',
'pmrequestdenied'         => 'Efterfrågan, projektadm. avslagen',
'newassignee'             => 'Ny tilldelare',
'revdepadded'             => 'Beroende av tillagd',
'revdepaddedremoved'      => 'Beroende av borttagen',
'assigneeadded'           => 'Tilldelare tillagd',
'addusergroup'            => 'Lägg användare till denna grupp',
'groupmembers'            => 'Gruppmedlemmar',
'deleteuser'              => 'Ta bort användare',
'userdeleted'             => 'Användare borttagen',
'autoassign'              => 'Tilldela ärendet till kategoriägaren automatiskt',
'ssl'                     => 'SSL',
'updatewrong'             => "Du har automatisk uppdateringskontroll aktiverat, men ett fel uppstod\n                             när uppdateringsservern skulle kontaktas. Endera så tillåter inte din server\n                             utgående trafik eller så blev det ett nätverksfel.\n                             Du kan gå till Flysprays webbsida för att se till att du kör senaste versionen.",
'deleteproject'           => 'Ta bort detta projekt och flytta allt innehåll till',
'projectdeleted'          => 'Lyckades ta bort projektet',
'feedforall'              => 'Feed för alla projekt',
'usercreated'             => 'Användare skapad',
'created'                 => 'Skapad',
'deleted'                 => 'Borttagen',
'userid'                  => 'Användar-id',
'editassignments'         => 'Ändra tilldelningar',
'preview'                 => 'Förhandsgranska',
'anyprogress'             => 'Något framsteg',
'tasksrelated'            => 'Ärenden besläktade med detta',
'duplicatetasks'          => 'Dubletter av detta ärende',
'databasemodfailed'       => 'Kunde inte ändra databasen. Möjlig anledning är otillräckliga behörigheter.',
'frequency'               => 'Frekvens',
'newuserregistered'       => 'En ny användare är registrerad i Flyspray. Användarinformation:',
'newuserregisterednotify' => 'En ny användare är registrerad',
'notify_registration'     => 'Avisera administratörer när en ny användare registreras',
'textversion'             => 'Textversion',
'onlyprimary'             => 'Ärenden som blockerar andra',
'switch'                  => 'Byt',
'max'                     => 'max.',
'dates'                   => 'Datum',
'selectduedatefrom'       => 'Färdigdatum från',
'selectduedateto'         => 'till',
'selectsincedatefrom'     => 'Ändrad från',
'selectsincedateto'       => 'till',
'selectdate'              => 'Välj datum',
'selectopenedfrom'        => 'Öppnad från',
'selectopenedto'          => 'till',
'selectclosedfrom'        => 'Stängd från',
'selectclosedto'          => 'till',
'startat'                 => 'Börja den',
'hasattachment'           => 'Har bifogade filer',
'private'                 => 'Privat',
'watching'                => 'Aviseras',
'alreadyvotedthistask'    => 'du har röstat',
'alreadyvotedthisday'     => 'redan röstat idag',
'visibility'              => 'Synlighet',
'public'                  => 'Publik',
'leaveemptyauto'          => 'Lämna lösenord tomt om du vill ha ett automatgenererat lösenord.',
'novalidemail'            => 'Du angav inte en giltig epostadress.',
'novalidjabber'           => 'Du angav inte en giltig Jabberadress.',
'missingrequired'         => 'Du fyllde inte i alla obligatoriska fält.',
'entervalidusername'      => 'Skriv in ett giltigt användarnamn och fullständigt namn.',
'couldnotaddusernotif'    => 'Kunde inte lägga in denna användare i aviseringslistan.',
'defaulttask'             => 'Förvald ärendebeskrivning',
'all'                     => 'alla',
'events.useraddedtoassignees'=> 'Användare satt som tilldelare',
'vote(s)'                 => 'röst(er)',
'eventlog'                => 'Händelselogg',
'assignmentchanged'       => 'Tilldelning ändrad',
'detailedinfo'            => 'Detaljerad information',
'All'                     => 'Alla',
'tasksireported'          => 'Ärenden jag rapporterat',
'recentlyopened'          => 'Nyligen öppnade',
'stats'                   => 'Statistik',
'totaltasks'              => 'totalt antal ärenden',
'mostwanted'              => 'Mest efterfrågade ärenden',
'defaultentry'            => 'Förvald startsida',
'toplevel'                => 'Top level view',
'overview'                => 'Översikt',
'error#'                  => 'Felnr.',
'error1'                  => 'Du har inte tillräckliga behörigheter för att se den bifogade filen.',
'error3'                  => 'Upprepad händelse, styr om till huvudsidan.',
'error4'                  => 'Du har inga administratörsbehörigheter.',
'error5'                  => 'Användaren finns inte i denna Flyspray.',
'error6'                  => 'Felaktig administratörsarea.',
'error7'                  => 'Inloggning misslyckades (fel användarnamn eller lösenord)!',
'error71'                 => 'Användarkontot är låst i %d minuter på grund av för många misslyckade inloggningsförsök!',
'error8'                  => 'Du måste ange både användarnamn och lösenord.',
'error9'                  => 'Ärendet finns inte eller så har du inte behörighet att se det.',
'error10'                 => 'Ärendet finns inte eller så har du inte behörighet att se det.',
'error101'                => 'Du har inga rättigheter av visa detta ärende.',
'error102'                => 'Du har inga rättigheter av visa detta ärende, försök att logga in.',
'error11'                 => 'Ingen behörighet att ändra denna kommentar.',
'error12'                 => 'Inte en giltig kod! Är du säker på att det är den du fick från registreringsmeddelandet?',
'error13'                 => 'Anonyma användare har ingen profil.',
'error14'                 => 'Du har inte behörighet att skapa en ny grupp.',
'error15'                 => 'Du har inte behörighet att öppna ett ärende.',
'error16'                 => 'Du är inte projektadministratör.',
'error17'                 => 'Felatkig projektadministratörsarea.',
'error18'                 => 'Felaktig URL.',
'error19'                 => 'Den användaren finns inte i denna Flyspray.',
'error20'                 => 'Felaktig databasändring.',
'error21'                 => 'Ett eller flera epostmeddelanden kunde inte skickas. Kontrollera dina inställningar.',
'error22'                 => 'Nyregistreringar av användare tillåts inte.',
'error23'                 => 'Användare eller grupp får inte logga in.',
'error24'                 => 'Varken dot-programmet eller en dot-server har angivits i inställningarna.',
'error25'                 => 'Arbetsplaner är bara tillgängliga från ett specifikt projekt.',
'done'                    => 'klar',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projektet kunde inte tas bort.',
'GMT'                     => 'GMT',
'timezone'                => 'Tidzon',
'accept'                  => 'Acceptera',
'reasonfordeinal'         => 'Anledning för avslag',
'pruneclosedlinks'        => 'Beskär kopplingar till stängda länkar',
'pruneclosedtasks'        => 'Beskär kopplingar till stängda ärenden',
'pagegenerated'           => 'Sida och bild genererad på %d sekunder.',
'pruninglevel'            => 'Beskärningsnivå',
'lastuser'                => 'Sista användaren kan inte tas bort.',
'allprivate'              => 'Alla projekt är privata.',
'deletegroup'             => 'Ta bort denna grupp och flytta användare till',
'parent'                  => 'Förälder',
'ordertip'                => 'Ordningen som de kommer visas i listan',
'showtip'                 => 'Visa denna i listan',
'deletetip'               => 'Ta bort denna från listan',
'del'                     => 'bort',
'request1'                => 'En ärendestängning är begärd.',
'request2'                => 'En återöppning av ärendet är begärd.',
'allpriorities'           => 'Alla prioriteringar',
'noroadmap'               => 'Ingen arbetsplan finns (ingen projektspecifik "framtids"-version finns).',
'expand'                  => 'Fäll ut',
'collapse'                => 'Fäll in',
'expandall'               => 'Fäll ut alla',
'collapseall'             => 'Fäll in alla',
'minpwsize'               => 'Minsta lösenordslängd är 5 tecken',
'passwordtoosmall'        => 'Lösenordslängden är för kort.',
'accountwaslocked'        => 'Ditt användarkonto har blivit låst på grund av för många misslyckade inloggningsförsök.',
'failedattempts'          => 'Det var %d misslyckade inloggningsförsök.',
'groupnotexist'           => 'Den valda gruppen finns inte i detta projekt.',
'searchindetails'         => 'Sök i beskrivning',
);

//
// Translated by Mikael Silfver, mikael dot silfver gmail com.
//
?>
