<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Modifica utente',
'accountenabled'          => 'Utenza abilitata',
'editallusers'            => 'Visualizza tutti gli Utenti',
'username'                => 'Nome Utente',
'usersupdated'            => 'Utenti aggiornati correttamente',
'realname'                => 'Nome Reale',
'emailaddress'            => 'Indirizzo e-mail ',
'jabberid'                => 'Jabber ID',
'profileimage'            => 'Immagine del Profilo',
'notifytype'              => 'Tipo di notifica',
'group'                   => 'Gruppo',
'enableaccounts'          => 'Abilita Account',
'disableaccounts'         => 'Disabilita Account',
'deleteaccounts'          => 'Elimina Account',
'updatedetails'           => 'Aggiorna le informazioni',
'setglobally'             => 'Questa opzione è stata impostata a livello globale.',
'usergroupmanage'         => 'Gestione Utenti e Gruppi',
'newuser'                 => 'Registra un nuovo Utente',
'newuserbulk'             => 'Registra Nuovi Utenti',
'bulkuserstoadd'          => 'Elenco dei Nuovi Utenti',
'optionsforallusers'      => 'Opzioni per tutti i Nuovi Utenti',
'newgroup'                => 'Crea un nuovo Gruppo',
'yes'                     => 'Si',
'no'                      => 'No',
'editgroup'               => 'Modifica il Gruppo',
'groupname'               => 'Nome del Gruppo',
'description'             => 'Descrizione',
'admin'                   => 'Amministra Gruppo',
'opennewtasks'            => 'Apri nuovo Task',
'modifytasks'             => 'Modifica Task esistenti',
'addcomments'             => 'Aggiungi commenti',
'attachfiles'             => 'Allega file',
'vote'                    => 'I membri possono votare',
'groupenabled'            => 'I membri possono collegarsi',
'groupopen'               => 'I membri possono collegarsi',
'tasktypelist'            => 'Lista dei tipi di Task',
'categorylist'            => 'Lista delle Categorie',
'oslist'                  => 'Lista dei Sistemi Operativi',
'resolutionlist'          => 'Lista delle Soluzioni',
'versionlist'             => 'Lista delle Versioni',
'severitylist'            => 'Lista delle Gravità',
'listnote'                => 'Nota: Disabilitare il box "Mostra" potrebbe alterare alcuni task quando in modalità modifica.  La modifica del campo "Nome" cambierà tutti i task con quel nome.',
'name'                    => 'Nome',
'order'                   => 'Ordinamento',
'back'                    => 'Indietro',
'text'                    => 'Testo',
'highlight'               => 'In evidenza',
'show'                    => 'Mostra',
'owner'                   => 'Proprietario',
'selectowner'             => 'Seleziona il proprietario',
'update'                  => 'Aggiorna',
'addnew'                  => 'Aggiungi nuovo',
'flysprayprefs'           => 'Preferenze di Flyspray',
'projecttitle'            => 'Titolo del Progetto',
'baseurl'                 => 'URL base per questa installazione',
'replyaddress'            => 'Indirizzo e-mail di risposta per le notifiche',
'themestyle'              => 'Tema / Stile',
'customstyle'             => 'personalizzato',
'language'                => 'Lingua',
'anonview'                => 'Consenti agli utenti anonimi di visualizzare i task',
'allowanon'               => 'Consenti agli utenti anonimi di creare nuovi task',
'never'                   => 'Mai',
'anonymously'             => 'In modo anonimo',
'afterregister'           => 'Solo dopo essere stati registrati',
'spamproof'               => 'Abilita il codice di conferma per i nuovi Utenti registrati',
'anongroup'               => 'Gruppo per i nuovi Utenti',
'groupassigned'           => 'Ai Membri di questo Gruppo possono essere assegnati dei Task',
'forcenotify'             => 'Forza la notifica dei Task come',
'neversend'               => 'Non inviare mai',
'userchoose'              => 'Lascia scegliere l\'Utente',
'email'                   => 'E-mail',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Proprietario predefinito della categoria',
'noone'                   => 'Nessuno',
'jabbernotify'            => 'Notifiche Jabber',
'jabberserver'            => 'Server',
'jabberport'              => 'Porta',
'jabberuser'              => 'Nome Utente',
'jabberpass'              => 'Password',
'saveoptions'             => 'Salva le opzioni',
'editcomment'             => 'Modifica il Commento',
'commentby'               => 'Commento a cura di',
'saveeditedcomment'       => 'Salva il commento modificato',
'projectprefs'            => 'Preferenze del Progetto',
'pagetitle'               => 'Titolo Pagina',
'defaultproject'          => 'Progetto predefinito',
'projectlists'            => 'Lista dei Progetti',
'showlogo'                => 'Mostra mmagine del logo',
'showgravatars'           => 'Mostra i Gravatar',
'emailNoHTML'             => 'Disabilita HTML nelle E-Mail',
'intromessage'            => 'Messaggio Introduttivo',
'active'                  => 'attivo',
'inactive'                => 'inattivo',
'isactive'                => 'Il progetto è attivo',
'showinactive'            => 'Mostra progetti inattivi',
'hideinactive'            => 'Nascondi progetti inattivi',
'createproject'           => 'Crea un nuovo Progetto',
'nopermission'            => 'Non hai il permesso di usare questa pagina',
'listordertip'            => 'l\'ordine con cui questi dati appariranno nella lista',
'listshowtip'             => 'Mostra questo dato nella lista',
'categoryownertip'        => 'Questa persona riceverà una notifica quando verrà aperto un Task in questa Categoria',
'categoryparenttip'       => 'La Categoria padre sotto cui cadrà questa nuova',
'notsubcategory'          => 'Nessuna - è una categoria primaria',
'showinlineimages'        => 'Mostra le immagini allegate inline',
'dateformat'              => 'Formato date',
'dateformat_extended'     => 'Formato date esteso',
'cache_feeds'             => 'Cache feeds',
'no_cache'                => 'Niente caching',
'cache_disk'              => 'Cache su disco',
'cache_db'                => 'Cache nel DB',
'subcategoryof'           => 'Sottocategoria di',
'visiblecolumns'          => 'Colonne mostrate nella lista Task',
'visiblefields'           => 'Campi quando si aggiungono/modificano/visualizzano i Task',
'tense'                   => 'Tempo',
'listtensetip'            => 'Passato, presente o futuro',
'past'                    => 'Passato',
'present'                 => 'Presente',
'future'                  => 'Futuro',
'oldpass'                 => 'Vecchia Password',
'nooldpass'               => 'Nessuna Password precedente impostata',
'oldpasswrong'            => 'Password precedente errata',
'changepass'              => 'Cambia password',
'confirmpass'             => 'Conferma Password',
'projectmanager'          => 'Amministratore del Progetto',
'viewtasks'               => 'Visualizza Task',
'modifyowntasks'          => 'Modifica un proprio Task',
'modifyalltasks'          => 'Modifica Task che non sono propri dell\'Utente',
'viewcomments'            => 'Visualizza commenti',
'editcomments'            => 'Modifica commenti',
'deletecomments'          => 'Cancella commenti',
'viewattachments'         => 'Visualizza allegati',
'createattachments'       => 'Crea allegati',
'deleteattachments'       => 'Cancella allegati',
'viewhistory'             => 'Visualizza lo storico',
'closeowntasks'           => 'Chiudi un Task che ti appartiene',
'closeothertasks'         => 'Chiudi Task che non sono propri dell\'utente',
'assigntoself'            => 'Assegnati i Task se non sono già assegnati',
'assignotherstoself'      => 'Assegnati i Task degli altri',
'viewreports'             => 'Visualizza i Report',
'othersview'              => 'Permetti a chiunque di visualizzare il Progetto',
'othersviewroadmap'       => 'Permetti a chiunque di visualizzare la roadmap del progetto',
'usersandgroups'          => 'Utenti e Gruppi',
'globalgroup'             => 'Gruppo globale',
'globalgroups'            => 'Gruppi globali',
'defaultglobalgroup'      => 'Gruppo globale predefinito per i nuovi utenti',
'addtogroup'              => 'Aggiungi al Gruppo',
'moveuserstogroup'        => 'Sposta gli utenti nel Gruppo',
'nogroup'                 => 'Nessun Gruppo - elimina dal Progetto',
'eventdesc'               => 'Descrizione dell\'evento',
'requestedby'             => 'Richiesto da',
'daterequested'           => 'Data della richiesta',
'closetask'               => 'Chiudi Task',
'reopentask'              => 'Riapri Task',
'applymember'             => 'Richiedi l\'accesso al Progetto',
'forcurrentproj'          => 'Per il Progetto corrente',
'lostpw'                  => 'Recupero Password perse',
'lostpwexplain'           => 'Inserisci il nome utente e ti verrà inviato un link per il cambio della password. Il link sarà inviato all\'indirizzo di notifica configurato nel tuo profilo.',
'sendlink'                => 'Invia link',
'savenewpass'             => 'Memorizza la nuova Password',
'anonreg'                 => 'Permetti la registrazione di nuovi utenti',
'allowanonopentask'       => 'Permetti agli utenti anonimi di aprire dei task',
'editglobalgroup'         => 'Modifica i gruppi globali',
'editgroupforproj'        => 'Modifica i gruppi per progetto',
'notshownforadmin'        => 'I permessi del Gruppo Admin non vengono mostrati.  Non hai bisogno di modificarli.',
'general'                 => 'Generale',
'userregistration'        => 'Registrazione utenti',
'notifications'           => 'Notifiche',
'resetoptions'            => 'Annulla Opzioni',
'preferences'             => 'Preferenze',
'tasktypes'               => 'Tipi di Task',
'resolutions'             => 'Soluzioni',
'categories'              => 'Categorie',
'categoriesglobal'        => 'Categorie Globali',
'categoriesproject'       => 'Categorie specifiche del Progetto',
'categoriestarget'        => 'Categorie destinazione',
'operatingsystems'        => 'Sistemi Operativi',
'versions'                => 'Versioni',
'admintoolboxlong'        => 'Strumenti di Amministrazione',
'newproject'              => 'Nuovo Progetto',
'delete'                  => 'Cancella',
'link'                    => 'Collegamento',
'referencelinks'          => 'Riferimento Collegamenti',
'listdeletetip'           => 'Cancella questa voce dalla lista',
'lookandfeel'             => 'Aspetto Grafico',
'globaltheme'             => 'Tema Principale',
'emailnotify'             => 'Notifiche per Email',
'fromaddress'             => 'Indirizzo Da',
'smtpserver'              => 'Server SMTP',
'smtpuser'                => 'Nome Utente SMTP',
'smtppass'                => 'Password SMTP',
'addrewrite'              => 'Usa address rewriting',
'usereminderdaemon'       => 'Abilita il daemon per notifiche in background',
'tasksperpage'            => 'Task per pagina nella Task list',
'addtoassignees'          => 'Aggiungi me stesso tra gli assegnatari',
'taskstatuses'            => 'Stato Task',
'canvote'                 => 'Può votare i Task',
'loginsuccessful'         => 'Login corretto.',
'youareloggedout'         => 'Sei stato disconnesso.',
'waitwhiletransfer'       => 'Aspetta mentre vieni trasferito...',
'clicknowait'             => 'Clicca qui se non vuoi aspettare.',
'accountdisabled'         => 'Il tuo account è disabilitato, Contatta un Amministratore.',
'task'                    => 'Task',
'edittask'                => 'Modifica questo Task',
'openedby'                => 'Aperto da',
'editedby'                => 'Ultima modifica da parte di',
'tasktype'                => 'Tipo di Task',
'category'                => 'Categoria',
'status'                  => 'Stato',
'assignedto'              => 'Assegnato a',
'operatingsystem'         => 'Sistema Operativo',
'severity'                => 'Gravità',
'reportedversion'         => 'Segnalato nella Versione',
'dueinversion'            => 'Previsto nella Versione',
'defaultdueinversion'     => 'Versione Prevista di default per i Task',
'undecided'               => 'Non precisata',
'percentcomplete'         => 'Percentuale di Completamento:',
'details'                 => 'Dettagli',
'savedetails'             => 'Salva Dettagli',
'canceledit'              => 'Cancella Modifiche',
'anonymous'               => 'Origine anonima',
'complete'                => 'completati',
'closedby'                => 'Chiuso da',
'reasonforclosing'        => 'Il motivo della chiusura è:',
'reopenthistask'          => 'Riapri questo task',
'comments'                => 'Commenti',
'attachments'             => 'Allegati',
'relatedtasks'            => 'Task correlati',
'edit'                    => 'Modifica',
'addcomment'              => 'Aggiungi commento',
'fileuploadedby'          => 'File caricato da',
'uploadafile'             => 'Carica un file come allegato',
'addalink'                => 'Aggiungi un collegamento',
'addanotherlink'          => 'Aggiungi un altro collegamento',
'uploadnow'               => 'Carica ora!',
'thesearerelated'         => 'Questi task sono correlati a questo task',
'remove'                  => 'Rimuovi',
'addnewrelated'           => 'Aggiungi un nuovo Task correlato',
'add'                     => 'Aggiungi!',
'otherrelated'            => 'Altri Task correlati',
'receivenotify'           => 'Questi Utenti riceveranno una notifica dettagliata quando questo Task viene modificato.',
'addusertolist'           => 'Aggiungi un Utente a questa lista',
'addtolist'               => 'Aggiungi alla lista',
'addmyself'               => 'Aggiungi me stesso a questa lista',
'removemyself'            => 'Rimuovi me stesso da questa lista',
'theseusersnotify'        => 'Questi utenti riceveranno una notifica dettagliata quando questo Task viene modificato.',
'attachedtoproject'       => 'Allegato al progetto',
'reminders'               => 'Promemoria',
'system'                  => 'Sistema',
'systemvalues'            => 'Elenco valori per tutto il Sistema',
'projectvalues'           => 'Elenco valori per il progetto specifico',
'remindthisuser'          => 'Manda un promemoria a questo utente',
'thisoften'               => 'Quanto spesso',
'startafter'              => 'Aspetta prima di inviare promemoria',
'hour'                    => 'ora',
'hours'                   => 'Ora(e)',
'day'                     => 'giorno',
'days'                    => 'Giorno(i)',
'week'                    => 'settimana',
'weeks'                   => 'Settimana(e)',
'addreminder'             => 'Aggiungi promemoria',
'defaultreminder'         => 'Questo è un promemoria per controllare il seguente task di Flyspray:',
'message'                 => 'Messaggio',
'closed'                  => 'Chiusi',
'filename'                => 'Nome file:',
'date'                    => 'Data',
'filesize'                => 'Dimensione File:',
'closurecomment'          => 'Commenti addizionali sulla chiusura:',
'history'                 => 'Storico',
'nohistory'               => 'Lo storico non è disponibile',
'eventdate'               => 'Data',
'user'                    => 'Utente',
'event'                   => 'Evento',
'fieldchanged'            => 'Campo cambiato',
'taskopened'              => 'Task aperto',
'taskreopened'            => 'Il Task è stato riaperto.',
'taskclosed'              => 'Il Task è stato chiuso.',
'commentadded'            => 'Il Commento è stato aggiunto.',
'commentedited'           => 'Commento modificato',
'commentdeleted'          => 'Il commento è stato cancellato.',
'attachmentadded'         => 'Aggiunto allegato',
'attachmentdeleted'       => 'l\'allegato è stato rimosso',
'taskedited'              => 'Modificati i dettagli del Task',
'notificationadded'       => 'Aggiunto utente alla lista di notifica',
'notificationdeleted'     => 'Rimosso utente dalla lista di notifica',
'relatedadded'            => 'Task correlato aggiunto alla lista.',
'relateddeleted'          => 'Rimosso Task correlato',
'taskassigned'            => 'Task assegnato a',
'taskreassigned'          => 'Task riassegnato a',
'assignmentremoved'       => 'Assegnazione rimossa',
'summary'                 => 'Riepilogo',
'addedasrelated'          => 'Aggiunto Task alla lista correlata a',
'deletedasrelated'        => 'Rimosso Task dalla lista correlata a',
'reminderadded'           => 'Il tuo promemoria è stato aggiunto.',
'reminderdeleted'         => 'Il promemoria selezionato è stato eliminato.',
'priority'                => 'Priorità',
'previousvalue'           => 'Valore precedente',
'newvalue'                => 'Nuovo valore',
'selectareason'           => 'Seleziona un motivo',
'assigntome'              => 'Assegna a me stesso',
'reopenrequest'           => 'Richiedi la riapertura',
'requestclose'            => 'Richiedi la chiusura',
'ownershiptaken'          => 'l\'utente ha preso possesso',
'closerequestmade'        => 'Richiesta di chiusura del Task effettuata',
'reopenrequestmade'       => 'Richiesta di riapertura del Task effettuata',
'taskdependson'           => 'Questo Task dipende da',
'taskdependsontask'       => 'Il task dipende da',
'taskdependsontasks'      => 'Il task dipende da',
'taskblock'               => 'Il task blocca impedisce la chiusura',
'taskblocks'              => 'Questo Task impedisce di chiudere questi altri',
'depadded'                => 'Dipendenza inserita',
'depaddedother'           => 'Questo Task aggiunto come dipendenza',
'depremoved'              => 'La dipendenza è stata eliminata',
'depremovedother'         => 'Questo Task è stato rimosso dalla lista di dipendenze dei Task',
'showdetailserror'        => 'Il Task non esiste o non hai i permessi per visualizzarlo.',
'makeprivate'             => 'Rendi privato',
'makepublic'              => 'Rendi pubblico',
'taskmadeprivate'         => 'Questo Task è stato reso privato',
'taskmadepublic'          => 'Questo Task è stato reso pubblico',
'confirmdeletecomment'    => 'Cancellare questo commento? %s',
'attachementswilldeleted' => 'Verranno eliminati anche tutti gli allegati!',
'confirmdeleteattach'     => 'Cancellare questo allegato?',
'selectedhistory'         => 'Mostra i dettagli dello storico selezionati',
'showallhistory'          => 'Mostra tutto lo storico',
'hidethis'                => 'Nascondi quest`area',
'mark100'                 => 'Segna il Task come Completo al 100%',
'watchtask'               => 'controlla Task',
'stopwatching'            => 'disabilita controllo',
'commentlink'             => 'Link a questo commento',
'submitreq'               => 'Invia richiesta',
'reasonforreq'            => 'Motivo della richiesta',
'pmreqdenied'             => 'l\'Amministratore del Progetto ha rifiutato la richiesta',
'taskpendingreq'          => 'In attesa di azione da parte dell\'Amministratore del Progetto. Visualizza lo Storico per i dettagli.',
'previoustask'            => 'Task precedente',
'nexttask'                => 'Prossimo task',
'duedate'                 => 'Data prevista',
'attachnoperms'           => 'Questo commento contiene degli allegati ma non hai l\'autorizzazione a visualizzarli.',
'linknoperms'             => 'Sono presenti collegamenti in questo commento anche se non si hanno i permessi per vederli.',
'open'                    => 'Aperti',
'depgraph'                => 'Visualizza il Grafico delle Dipendenze',
'reset'                   => 'Reset',
'selectusers'             => 'Seleziona Utenti...',
'addmetoassignees'        => 'Aggiungimi agli assegnatari',
'addedtoassignees'        => 'Utente aggiunto alla lista degli assegnatari',
'dependencygraph'         => 'Grafico delle Dipendenze',
'attachanotherfile'       => 'Allega un altro file',
'OK'                      => 'OK',
'addvote'                 => 'Aggiungi Voto',
'disable_lostpw'          => 'Disabilita il recupero della password',
'disable_changepw'        => 'Disabilita la creazione/modifica password',
'notifyfromfs'            => 'Notifica da Flyspray',
'autogenerated'           => 'QUESTO è UN MESSAGGIO GENERATO AUTOMATICAMENTE, NON RISPONDERE',
'forward'                 => 'Avanti',
'previous'                => 'Precedente',
'next'                    => 'Successivo',
'first'                   => 'Primo',
'last'                    => 'Ultimo',
'page'                    => 'Pagina %d di %d',
'search'                  => 'Cerca',
'alltasktypes'            => 'Qualsiasi tipo di Task',
'allseverities'           => 'Qualsiasi Gravità',
'alldevelopers'           => 'Tutti gli Sviluppatori',
'notyetassigned'          => 'Non ancora assegnato',
'allcategories'           => 'Qualsiasi Categoria',
'allstatuses'             => 'Qualsiasi Stato',
'allopentasks'            => 'Tutti i Task aperti',
'sortthiscolumn'          => 'Ordina in base a questa colonna',
'id'                      => 'ID',
'project'                 => 'Progetto:',
'dateopened'              => 'Data di apertura',
'progress'                => 'Progresso',
'searchthisproject'       => 'Cerca in questo Progetto',
'dueanyversion'           => 'Previsto in ogni Versione',
'anyversion'              => 'Segnalato in Tutte le Versioni',
'dueversion'              => 'Previsto nella Versione',
'lastedit'                => 'Ultima modifica',
'os'                      => 'Sistema Operativo',
'reportedin'              => 'Segnalato nella',
'taskrange'               => 'Visualizzazione Task %d - %d di %d',
'noresults'               => 'La ricerca non ha prodotto risultati.',
'takeaction'              => 'Esegui',
'watchtasks'              => 'Controlla i Task selezionati',
'stopwatchingtasks'       => 'Disabilita controllo sui Task selezionati',
'assigntaskstome'         => 'Assegna Task a me stesso',
'dueby'                   => 'Previsto il',
'dueanytime'              => 'Nessuna data prevista',
'selectduedate'           => 'Seleziona scadenza',
'toggleselected'          => 'Inverti selezione',
'due'                     => 'Scadenza',
'assignedtome'            => 'Assegnati a me stesso',
'tasklist'                => 'Elenco Task',
'dateclosed'              => 'Data chiusura',
'advanced'                => 'Avanzate',
'searchcomments'          => 'Cerca nei commenti',
'searchforall'            => 'Cerca tutte le parole',
'anonusers'               => 'Utenti Anonimi',
'miscellaneous'           => 'Varie',
'users'                   => 'Utenti',
'taskproperties'          => 'Proprietà del Task',
'selectsincedate'         => 'Seleziona Modificato dal',
'changedsince'            => 'Modificato dal',
'updatefs'                => 'Per favore aggiorna Flyspray.',
'currentversion'          => 'La tua versione è',
'latestversion'           => 'la versione piu` recente è',
'hidemessage'             => '(ricordamelo piu` tardi)',
'saveas'                  => 'Salva ricerca come',
'nosearches'              => 'Nessuna ricerca salvata',
'saving'                  => 'Salvataggio in corso...',
'votes'                   => 'Voti',
'tovote'                  => 'Vota',
'allclosedtasks'          => 'Tutti i Task Chiusi',
'password'                => 'Password',
'login'                   => 'Login!',
'rememberme'              => 'Ricordami',
'lostpassword'            => 'Hai perso la Password?',
'lostpwforfs'             => 'Smarrita la password per Flyspray',
'lostpwmsg1'              => "Salve.\nHo perso la mia password per Flyspray il ",
'lostpwmsg2'              => ", per favore inviatemene un'altra.\nNome Utente: ",
'regards'                 => 'Saluti,',
'yourusername'            => ' il tuo Nome Utente ',
'locale'                  => 'it-IT',
'filenotexist'            => 'Il file non esiste.  Contatta l\'Amministratore di Flyspray per questo Progetto.',
'showtask'                => 'Mostra il Task',
'now'                     => 'Ora',
'go'                      => 'Vai!',
'opentaskanon'            => 'Apri un nuovo Task come anonimo',
'register'                => 'Registra come nuovo Utente',
'addnewtask'              => 'Aggiungi un nuovo Task',
'reports'                 => 'Rapporti',
'editmydetails'           => 'Modifica i miei dati',
'logout'                  => 'Logout',
'disabledaccount'         => 'La tua utenza è stata disabilitata!<br>Disconnessione immediata...',
'poweredby'               => 'Powered by Flyspray',
'sponsoredby'             => 'Flyspray è sponsorizzato da',
'projects'                => 'Progetti',
'allprojects'             => 'Tutti i Progetti',
'selectproject'           => 'per il Progetto:',
'tasksall'                => 'Tutti i Task',
'tasksassigned'           => 'Task a me assegnati',
'tasksreported'           => 'Task da me riportati',
'taskswatched'            => 'Task che controllo',
'mysearch'                => 'Le mie Ricerche',
'admintoolbox'            => 'Strumenti di Amministrazione',
'manageproject'           => 'Gestione Progetto',
'permissions'             => 'Visualizza Autorizzazioni',
'hide'                    => 'Nascondi',
'pendingreq'              => 'Invia richieste in attesa come Messaggio Privato',
'errorpage'               => "Flyspray non puo' fornire la pagina richiesta.\n                                 Forse hai richiesto un task inesistente oppure non hai\n                                 l'autorizzazione per visualizzare la pagina richiesta.\n\n                                 Potresti aver provato ad usare una URL modificata a mano per interagire col\n                                 database e tentare un attacco SQL injection. Se questo e' il caso, vai all'angolino\n                                 e rifletti sulle tue azioni.  Quando torni, per favore, non farlo piu'!",
'permissionsforproject'   => 'Autorizzazioni per ',
'switchto'                => 'Passa a',
'lastsearch'              => 'Ultima ricerca',
'modify'                  => 'Modifica',
'noticefrom'              => 'Informazione da',
'hasopened'               => 'ha aperto un nuovo Task su Flyspray, e l\'ha assegnato a te:',
'moreinfonew'             => 'Puoi trovare più informazioni su questo bug alla pagina FlySpray:',
'newtaskcategory'         => 'Un nuovo task è stato aperto in questa categoria',
'categoryowner'           => 'Stai ricevendo questo messaggio perchè sei il gestore della categoria.',
'tasksummary'             => 'Riassunto del Task:',
'newtaskadded'            => 'Il tuo nuovo Task è stato aggiunto.',
'summaryanddetails'       => 'Devi inserire sia il riassunto che i dettagli.',
'summaryrequired'         => 'Devi ',
'goback'                  => 'Torna indietro.',
'messagefrom'             => 'Questo è un messaggio dal sistema di bug tracking Flyspray a',
'hasjustmodified'         => 'ha appena modificato il seguente task.',
'changedfields'           => 'I campi modificati sono contraddistinti da due asterischi (**)',
'moreinfomodify'          => 'Puoi avere maggiori informazioni su questo Task all\'URL seguente:',
'nolongerassigned'        => 'Il Task seguente non è piu` assegnato a te. Ora è assegnato a',
'hasassigned'             => 'ti ha assegnato il seguente task Flyspray:',
'taskupdated'             => 'Il task è stato aggiornato.',
'tasksupdated'            => 'I Task sono stati aggiornati.',
'hasclosedassigned'       => 'ha chiuso il seguente Task Flyspray che era assegnato a te:',
'unassigned'              => 'Non assegnato',
'hasclosed'               => 'ha chiuso il seguente Task.',
'youonnotify'             => 'Ricevi questo messaggio perchè sei sulla lista di notifica.',
'taskclosedmsg'           => 'Il Task è stato chiuso.',
'returntotask'            => 'Ritorna ai dettagli del Task',
'backtoindex'             => 'Torna alla lista dei Task',
'noclosereason'           => 'Non hai selezionato un motivo per chiudere questo Task.',
'hasreopened'             => 'ha riaperto il seguente Task Flyspray che avevi chiuso:',
'taskreopenedmsg'         => 'Il Task è stato riaperto.',
'backtotask'              => 'Torna indietro al Task.',
'commentaddedmsg'         => 'Il Commento è stato aggiunto.',
'commenttoassigned'       => 'ha aggiunto un commento a un Task che era stato assegnato:',
'commenttotask'           => 'ha aggiunto il seguente commento a questo Task.',
'nocommententered'        => 'Devi inserire un commento prima di cliccare il pulsante di invio.',
'fillinfields'            => 'Non hai riempito tutti i campi.',
'notcurrentpass'          => 'Non è la tua Password attuale!',
'passchanged'             => 'La tua Password è cambiata.',
'closewindow'             => 'Adesso puoi chiudere la finestra.',
'passnomatch'             => 'Le tue nuove password non coincidono!',
'usernametaken'           => 'Questo Nome Utente è già in uso. Devi sceglierne un altro.',
'usernametakenbulk'       => 'Nome Utente non disponibile',
'newusercreated'          => 'Un nuovo Utente è stato creato.',
'accountcreated'          => 'I tuo Utente è stato creato.',
'newuserwarning'          => 'Rircorda che l\'impostazione dell\'applicazione potrebbe richiedere che il tuo Utente venga approvato da un Amministratore. Se non riesci a collegarti, questa potrebbe essere la causa.',
'nomatchpass'             => 'Le Password non corrispondono.',
'confirmwrong'            => 'Il codice di conferma non è corretto!',
'formnotcomplete'         => 'Il modulo non è completo.',
'formnotnumeric'          => 'Il dato inserito non è numerico!',
'groupnametaken'          => 'Questo nome di Gruppo è già in uso.',
'newgroupadded'           => 'Aggiunto nuovo Gruppo.',
'optionssaved'            => 'Opzioni Flyspray salvate.',
'hasuploaded'             => 'ha caricato un allegato ad un Task che ti è assegnato a te:',
'hasattached'             => 'ha caricato un allegato al seguente Task.',
'fileuploaded'            => 'Il file è stato caricato.',
'fileerror'               => 'C`è stato un errore nel caricamento del file.  Forse i permessi sulla directory degli allegati sono sbagliati.',
'contactadmin'            => 'Contatta l\'Amministratore di questo Progetto.',
'selectfileerror'         => 'Non hai selezionato alcun file.',
'userupdated'             => 'I dettagli Utente sono stati aggiornati',
'realandemail'            => 'Non hai riempito i campi Nome Reale e Indirizzo E-mail.',
'groupupdated'            => 'Definizione del Gruppo aggiornata.',
'groupanddesc'            => 'Non hai riempito i campi Nome Gruppo e Descrizione.',
'fillallfields'           => 'I campi vanno tutti inseriti tutti.',
'listPmustN'              => 'l\'"Ordine" deve essere numerico.',
'listupdated'             => 'La Lista è stata modificata.',
'listitemadded'           => 'Nuovo elemento aggiunto alla lista.',
'relatedaddedmsg'         => 'Task collegato aggiunto alla lista.',
'relatederror'            => 'Questo Task è gia nella lista dei Task correlati.',
'relatedremoved'          => 'Task correlato rimosso dalla lista.',
'notifyadded'             => 'Utente aggiunto alla lista di notifica.',
'notifyerror'             => 'l\'utente è gia nella lista di notifica di questo Task.',
'notifyremoved'           => 'Utente rimosso dalla lista di notifica.',
'editcommentsaved'        => 'Il commento è stato modificato.',
'commentdeletedmsg'       => 'Il Commento è stato eliminato.',
'gotonewtask'             => 'Vai al nuovo Task appena creato',
'projectcreated'          => 'Il tuo nuovo Progetto è stato creato. Segui il link sotto per definire le liste di Categorie, Versioni e Sistema Operativo',
'customiseproject'        => 'Personalizza questo Progetto',
'projectupdated'          => 'Le preferenze del Progetto sono state aggiornate',
'emptytitle'              => 'Hai lasciato vuoto il titolo del Progetto. Torna indietro e completa.',
'loginbelow'              => 'Prova a collegarti ora.',
'attachmentdeletedmsg'    => 'l\'Allegato è stato eliminato',
'reminderaddedmsg'        => 'Il tuo Promemoria è stato inserito.',
'reminderdeletedmsg'      => 'Il Promemoria selezionato è stato eliminato.',
'flyspraytask'            => 'Task Flyspray',
'fieldsmissing'           => 'Alcuni campi contenevano dati errati o mancanti.',
'relatedinvalid'          => 'Non c`è questo Task.',
'relatedproject'          => 'Il Task appartiene ad un Progetto differente.',
'addanyway'               => 'Aggiungi comunque',
'cancel'                  => 'Cancella',
'alreadyedited'           => 'Il Task è stato modificato da qualcun altro prima che lo salvassi.',
'saveanyway'              => 'Salva comunque le mie modifiche',
'nouserselected'          => 'Nessun Utente selezionato. Seleziona almeno un Utente prima di riprovare.',
'groupswitchupdated'      => 'Gruppi utenti modificati con successo.',
'takenownershipmsg'       => 'Questo Task è ora assegnato a te.',
'adminrequestmade'        => 'La tua richiesta è stata trasmessa ad un Amministratore del Progetto.',
'newdepnotify'            => 'Una nuova dipendenza è stata aggiunta al seguente Task:',
'dependadded'             => 'La dipendenza èstata aggiunta',
'dependaddfailed'         => 'Non puoi aggiungere il Task come dipendenza in questo momento',
'depremovedmsg'           => 'La dipendenza del Task è stata eliminata',
'newdepis'                => 'La nuova dipendenza è',
'magicurlsent'            => 'Un messaggio è stato inviato al tuo indirizzo di notifica. Contiene un link che ti porterà ad una pagina per completare questo Task.',
'changefspass'            => 'Cambia la Password di Flyspray',
'magicurlmessage'         => 'Segui questo link per cambiare la tua password Flyspray:',
'erroronform'             => 'C`è stato un problema su questo modulo',
'addressused'             => 'Questo indirizzo è stato usato per registrare un account Flyspray. Se non stavi aspettando questo messaggio, ti prego di ignorarlo e di cancellarlo. Il tuo codice di conferma è:',
'confirmcodeis'           => 'Il tuo codice di conferma è:',
'codesent'                => 'Il tuo codice di conferma è stato inviato. Prego segui le istruzioni contenute nel messaggio.',
'codenotsent'             => 'Non posso inviarti il codice, per favore riprova piu` tardi',
'taskmadeprivatemsg'      => 'Questo Task è stato reso privato',
'taskmadepublicmsg'       => 'Questo Task è stato reso pubblico',
'realandnotify'           => 'Devi riempire il campo Nome Reale, ed uno tra i campi Indirizzo Email o Jabber ID.',
'pmreqdeniedmsg'          => 'Richiesta all\'Amministratore del Progetto rifiutata',
'massopsenable'           => 'Abilita la possibilità di modificare più task con una singola operazione.',
'massopsuccess'           => 'Operazione globale terminata con successo - ove consentito dalle autorizzazioni',
'usernotexist'            => 'l\'Utente non esiste in questa installazione di Flyspray',
'commentattachperms'      => 'Non puoi cancellare il commento - non hai l\'autorizzazione per cancellare gli allegati',
'voterecorded'            => 'Il tuo Voto è stato registrato',
'votefailed'              => 'Il tuo Voto non può essere inserito in questo momento.',
'createnewgroup'          => 'Crea un nuovo Gruppo',
'requiredfields'          => 'I campi obbligatori sono identificati con un',
'addthisgroup'            => 'Aggiungi questo Gruppo',
'createnewproject'        => 'Crea un nuovo Progetto',
'addnewproject'           => 'Aggiungi un nuovo Progetto',
'htmlallowed'             => 'è possibile inserire codice HTML',
'createthisproject'       => 'Crea questo Progetto',
'inlineimages'            => 'Mostra le immagini allegate inline',
'createnewtask'           => 'Crea un nuovo Task',
'addanother'              => 'Aggiungi un altro Task dopo questo',
'addthistask'             => 'Aggiungi questo Task',
'notifyme'                => 'Avvisami quando questo Task cambia',
'newtask'                 => 'Nuovo Task:',
'attachafile'             => 'Allega un file',
'registernewuser'         => 'Registra nuovo Utente',
'none'                    => 'Nessuna',
'registeraccount'         => 'Registra questo Account',
'registerbulkaccount'     => 'Registrati',
'both'                    => 'Entrambi',
'notifyfrom'              => 'Notifica da',
'donotreply'              => 'QUESTO è UN MESSAGGIO AUTOMATICO, NON RISPONDERE.',
'disclaimer'              => 'Hai ricevuto questo messaggio perché lo hai richiesto al sistema di bugtracking Flyspray. Puoi disabilitare le notifiche future visitando l\'indirizzo qui sopra.',
'userwho'                 => 'Utente che ha effettuato l\'operazione',
'moreinfo'                => 'Maggiori informazioni disponibili all\'indirizzo:',
'newtaskopened'           => 'Un nuovo Task è stato aperto su Flyspray. Maggiori dettagli di seguito.',
'notify.taskclosed'       => 'Il Task seguente è stato chiuso:',
'notify.taskreopened'     => 'Il Task seguente è stato riaperto:',
'newdep'                  => 'Il Task seguente ha una nuova dipendenza:',
'notify.depremoved'       => 'Al Task seguente è stata rimossa una dipendenza:',
'olddepwas'               => 'La vecchia dipendenza era',
'notify.commentadded'     => 'Al Task seguente è stato aggiunto un commento:',
'commentis'               => 'Il commento è indicato di seguito.',
'newattachment'           => 'Un nuovo file è stato allegato al seguente Task:',
'detailsbelow'            => 'Di seguito i dettagli.',
'notify.relatedadded'     => 'Un nuovo Task collegato è stato aggiunto al seguente Task:',
'relatedis'               => 'Il Task collegato è',
'assignedtoyou'           => 'Ti è stato assegnato il seguente Task:',
'takenownership'          => 'Questo task non è assegnato a te.',
'requiresaction'          => 'Il seguente Task richiede l\'intervento di un Amministratore del Progetto:',
'requiresactionnotify'    => 'Il Task richiede l\'intervento di un Amministratore del Progetto',
'pmdeny'                  => 'Un Amministratore del Progetto ha rifiutato la richiesta sottomessa per il seguente Task:',
'pmdenynotify'            => 'Un Amministratore del Progetto ha rifiutato la richiesta',
'fileaddedtoo'            => 'C`erano già uno o piu` file allegati a questo commento.',
'taskwatching'            => 'Il seguente Task che stai controllando',
'isdepfor'                => 'è una nuova dipendenza per',
'denialreason'            => 'Motivo del rifiuto',
'taskchanged'             => 'Il seguente Task è stato modificato. Le modifiche sono elencate qui` sotto. Per informazioni piu` dettagliate sulle modifiche visita l\'indirizzo seguente e clicca sullo Storico.',
'useraddedtoassignees'    => 'Un Utente ha aggiunto sè stesso alla lista degli utenti assegnati a questo Task.',
'removeddepis'            => 'La dipendenza rimossa è',
'isnodepfor'              => 'non è piu` una dipendenza per',
'usergroups'              => 'Utenti e Gruppi',
'pmtoolbox'               => 'Strumenti dell\'Amministratore Progetto',
'groupmanage'             => 'Gestione del Gruppo',
'pendingrequests'         => 'Richieste amministrative incomplete',
'reasongiven'             => 'Motivazione inserita',
'nopendingreq'            => 'Non ci sono richieste per l\'Amministratore del Progetto in sospeso.',
'givereason'              => 'Inserisci una motivazione',
'catlisted'               => 'Editor delle Categorie',
'oslisted'                => 'Editor dei Sistemi Operativi',
'verlisted'               => 'Editor delle Versioni',
'tasktypeed'              => 'Editor delle Tipologie di Task',
'resed'                   => 'Editor delle Soluzioni',
'deny'                    => 'Nega',
'notifiedwhen'            => 'Notificato quando',
'onlynewtasks'            => 'Vengono aperti nuovi Task',
'allevents'               => 'Un evento qualsiasi su qualsiasi Task',
'feeds'                   => 'Feeds',
'feeddescription'         => 'Descrizione Feed',
'feedimgurl'              => 'Indirizzo dell\'immagine per il Feed (lasciare vuoto per selezionare nessuna immagine)',
'notifysubject'           => 'Oggetto delle notifiche',
'notifysubjectinfo'       => '(%p = titolo del Progetto, %s = riassunto del Task, %t = id del Task, %a = azione, %u = nome utente)',
'priority6'               => 'Molto Alta',
'priority5'               => 'Alta',
'priority4'               => 'Media',
'priority3'               => 'Bassa',
'priority2'               => 'Molto Bassa',
'priority1'               => 'Rinviare',
'sendcode'                => 'Invia il codice!',
'entercode'               => 'Il tuo codice di conferma è stato inviato usando il tuo metodo di notifica preferenziale. Quando lo ricevi, inseriscilo qui sotto.  Inserisci anche la Password dell\'Account.',
'confirmationcode'        => 'Codice di conferma',
'registererror'           => 'Accertati di avere riempito tutti i campi obbligatori, e di aver inserito i giusti dettagli per il metodo di notifica preferenziale richiesto.',
'validusername'           => '(sono consentiti solo caratteri alfanumerici e - _ .)',
'validemail'              => '(utilizzare ; per separare più indirizzi email)',
'emailtakenbulk'          => 'Indirizzo email già utilizzato',
'emailtaken'              => 'l\'indirizzo Email o lo Jabber-ID sono già in uso. Devi selezionarne un altro.',
'note'                    => "<b>Nota:</b>  Ti sara' inviato un codice di conferma prima che il tuo account venga\ncreato. Il codice ti sara' inviato usando il tuo metodo di notifica preferenziale sopra indicato.<br>SE INSERISCI INFORMAZIONI FALSE, NON RICEVERAI IL CODICE.",
'changelog'               => 'Changelog',
'changeloggen'            => 'Generatore di Changelog',
'listfrom'                => 'Crea una lista di changelog da',
'to'                      => 'a',
'oldestfirst'             => 'Prima i piu` vecchi',
'recentfirst'             => 'Prima i piu` nuovi',
'severityrep'             => 'Rapporto per Gravità',
'totalopen'               => 'totale Task aperti',
'age'                     => 'Età',
'agerep'                  => 'Rapporto per età',
'eventsrep'               => 'Rapporto eventi',
'events'                  => 'Eventi',
'Tasks'                   => 'Task',
'opened'                  => 'Aperti',
'edited'                  => 'Modificati',
'assigned'                => 'Assegnati',
'within'                  => 'Entro',
'pastday'                 => 'Ieri',
'pastweek'                => 'La scorsa settimana',
'pastmonth'               => 'Il mese scorso',
'pastyear'                => 'l\'anno scorso',
'nolimit'                 => 'Nessun limite',
'from'                    => 'Da',
'duein'                   => 'Previsto entro',
'selectfromdate'          => 'Seleziona Data a Partire Da',
'selecttodate'            => 'Seleziona Data Fino A',
'showvoters'              => 'Mostra/nascondi votanti',
'roadmap'                 => 'Roadmap',
'roadmapfor'              => 'Roadmap per la Versione',
'tasks'                   => 'Task',
'completed'               => 'completato.',
'opentasks'               => 'Task aperti',
'of'                      => '% di',
'severity5'               => 'Critica',
'severity4'               => 'Alta',
'severity3'               => 'Media',
'severity2'               => 'Bassa',
'severity1'               => 'Molto Bassa',
'Redirect'                => 'Redireziona',
'redirectmsg'             => 'Se il tuo browser non supporta la meta-redirezione per favore clicca qui %sHERE%s per essere rediretto',
'allowclosedcomments'     => 'Consenti commenti sui Task chiusi',
'comment'                 => 'Commento',
'editowncomments'         => 'Modifica i propri commenti',
'reopened'                => 'Riaperto',
'loading'                 => 'Caricamento in corso...',
'notifyown'               => 'Notifica per le modifiche fatte da me stesso',
'youremail'               => 'Il tuo indirizzo E-mail',
'thankyouforbug'          => 'Grazie per aver segnalato i problemi che hai riscontrato. Puoi vedere il task e seguirne l\'avanzamento in ogni momento tramite il seguente indirizzo:',
'anonuser'                => 'Utente anonimo',
'conflict'                => 'Conflitto',
'file'                    => 'File',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Dimensioni',
'projectgroup'            => 'Gruppo',
'profile'                 => 'Profilo:',
'viewprofile'             => 'Visualizza Profilo',
'regdate'                 => 'Registrato dal',
'tasksopened'             => 'Task aperti',
'replyto'                 => 'Rispondi a',
'notifytypes'             => 'Tipi di notifica',
'pm.taskchanged'          => 'Task modificato',
'pm.taskreopened'         => 'Task riaperto',
'pm.depadded'             => 'Dipendenza inserita',
'pm.depremoved'           => 'Dipendenza eliminata',
'pmrequest'               => 'Richiesta PM',
'pmrequestdenied'         => 'Richiesta PM respinta',
'newassignee'             => 'Nuovo assegnatario',
'revdepadded'             => 'Dipendenza inversa aggiunta',
'revdepaddedremoved'      => 'Dipendenza inversa eliminata',
'assigneeadded'           => 'Assegnatario aggiunto',
'addusergroup'            => 'Aggiungi Utente a questo Gruppo',
'groupmembers'            => 'Membri del Gruppo',
'deleteuser'              => 'Elimina questo Utente',
'userdeleted'             => 'Utente eliminato',
'autoassign'              => 'Assegna automaticamente un Task al proprietario della Categoria',
'ssl'                     => 'SSL',
'updatewrong'             => "Hai selezionato l'opzione di aggiornamento ma si e' verificato un errore nel\n                             collegamento al server, il tuo host non consente connessioni all'esterno\n                             oppure c'e' un problema di rete.\n                             Per favore visita il sito di Flyspray e assicurati di avere installata la versione piu' recente.",
'deleteproject'           => 'Elimina questo Progetto e sposta il contenuto in',
'projectdeleted'          => 'Progetto eliminato con successo',
'feedforall'              => 'Feed per tutti i progetti',
'usercreated'             => 'Utente creato',
'created'                 => 'Creato',
'deleted'                 => 'Eliminato',
'userid'                  => 'ID Utente',
'editassignments'         => 'Modifica assegnazioni',
'preview'                 => 'Anteprima',
'anyprogress'             => 'Qualsiasi Avanzamento',
'tasksrelated'            => 'Task collegati a questo Task',
'duplicatetasks'          => 'Task duplicati di questo Task',
'databasemodfailed'       => 'Modifica al Database fallita. Una delle possibili cause sono autorizzazioni insufficienti.',
'frequency'               => 'Frequenza',
'newuserregistered'       => 'Un nuovo Utente si è registrato. Di seguito i dettagli:',
'newuserregisterednotify' => 'Un nuovo Utente si è registrato',
'notify_registration'     => 'Avvisa gli Amministratori sui nuovi utenti registrati',
'textversion'             => 'Versione solo testo',
'onlyprimary'             => 'Task che non bloccano altri Task',
'onlyblocker'             => 'Task che bloccano altri Task',
'blockerornoblocker'      => 'Bloccante o non-bloccante. Scegliere entrambi non ha senso.',
'switch'                  => 'Vai a',
'max'                     => 'massimo',
'dates'                   => 'Date',
'selectduedatefrom'       => 'Data Scadenza dal',
'selectduedateto'         => 'al',
'selectsincedatefrom'     => 'Modificato dal',
'selectsincedateto'       => 'al',
'selectdate'              => 'Seleziona Data',
'selectopenedfrom'        => 'Aperto dal',
'selectopenedto'          => 'al',
'selectclosedfrom'        => 'Chiuso dal',
'selectclosedto'          => 'al',
'startat'                 => 'Inizia dal',
'hasattachment'           => 'Con allegati',
'private'                 => 'Privato',
'watching'                => 'In osservazione',
'alreadyvotedthistask'    => 'hai già votato per questo Task',
'alreadyvotedthisday'     => 'hai già votato oggi',
'visibility'              => 'Visibilità',
'public'                  => 'Pubblico',
'leaveemptyauto'          => 'Lascia vuoti i campi della password se vuoi che una password sia generata automaticamente per te.',
'novalidemail'            => 'l\'indirizzo Email inserito non è valido.',
'novalidjabber'           => 'l\'ID Jabber inserito non è valido.',
'missingrequired'         => 'Non hai inserito tutti i campi richiesti.',
'entervalidusername'      => 'Inserisci un Utente valido ed un Nome Reale.',
'couldnotaddusernotif'    => 'Impossibile aggiungere questo Utente alla lista delle notifiche.',
'defaulttask'             => 'Descrizione di default dei Task',
'all'                     => 'tutti',
'events.useraddedtoassignees'=> 'Utente aggiunto agli assegnatari',
'eventlog'                => 'Log degli eventi',
'assignmentchanged'       => 'Modificata assegnazione',
'detailedinfo'            => 'Informazioni dettagliate',
'All'                     => 'Tutti',
'tasksireported'          => 'Task riportati da me',
'recentlyopened'          => 'Aperti recentemente',
'stats'                   => 'Statistiche',
'totaltasks'              => 'task totali',
'mostwanted'              => 'Task piu` cercati',
'defaultentry'            => 'Pagina iniziale predefinita',
'toplevel'                => 'Vista superiore',
'overview'                => 'Riepilogo',
'error#'                  => 'Errore #',
'error1'                  => 'Non hai privilegi sufficienti per vedere questo allegato.',
'error3'                  => 'Azione ripetuta, redirezione alla pagina principale.',
'error4'                  => 'Non hai i privilegi di amministrazione.',
'error5'                  => 'Utente sconosciuto a questa installazione di Flyspray.',
'error6'                  => 'Area di amministrazione non valida.',
'error7'                  => 'Login fallito (Nome Utente o Password errati)!',
'error71'                 => 'Account bloccato per %d minuto a causa dei troppi tentativi falliti!',
'error8'                  => 'Non hai inserito il Nome Utente o la Password.',
'error9'                  => 'Il Task non esiste o non sei autorizzato a vederlo.',
'error10'                 => 'Il Task non esiste o non sei autorizzato a vederlo.',
'error101'                => 'Non hai i permessi per guardare questo task.',
'error102'                => 'Non hai i permessi per guardare questo task, fare il login potrebbe aiutare.',
'error11'                 => 'Non hai l\'autorizzazione per modificare questo commento.',
'error12'                 => 'Magic key non valida! Sicuro di averla ricevuta dal tuo messaggio di notifica?',
'error13'                 => 'Gli utenti anonimi non hanno un profilo.',
'error14'                 => 'Non hai privilegi sufficienti per creare nuovi Gruppi.',
'error15'                 => 'Non hai privilegi sufficienti per arprie nuovi Task.',
'error16'                 => 'Non sei un Amministratore del Progetto.',
'error17'                 => 'Area PM non valida.',
'error18'                 => 'Indirizzo non valido.',
'error19'                 => 'Utente sconosciuto a questa installazione di Flyspray.',
'error20'                 => 'Modifica al database non valida.',
'error21'                 => 'Errore nell\'invio di una o piu` Email. Verifica la tua configurazione.',
'error22'                 => 'Non è possibile registrare nuovi Utenti.',
'error23'                 => 'Utente o Gruppo non abilitato.',
'error24'                 => 'Un eseguibile di Dot o un server pubblico Dot non sono stati configurati.',
'error25'                 => 'La Roadmap è disponibile solo per un Progetto specifico.',
'error26'                 => 'Provider OAuth non supportato.',
'error27'                 => 'Impossibile collegarsi. Autorizzaci a visualizzare il tuo indirizzo email.',
'error28'                 => 'Non si hanno i permessi per accedere a questa area.',
'done'                    => 'completato',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Il Progetto non può essere eliminato.',
'GMT'                     => 'GMT',
'timezone'                => 'Fuso Orario',
'accept'                  => 'Accetto',
'reasonfordeinal'         => 'Ragione del rifiuto',
'pruneclosedlinks'        => 'Ripulisci i Link Chiusi',
'pruneclosedtasks'        => 'Ripulisci i Task Chiusi',
'pagegenerated'           => 'Pagina e immagine generate in %d secondi.',
'pruninglevel'            => 'Livello di Pulizia',
'lastuser'                => 'l\'ultimo Utente non può essere eliminato.',
'allprivate'              => 'Tutti i Progetti sono privati.',
'deletegroup'             => 'Elimina questo Gruppo e sposta gli Utenti in',
'parent'                  => 'Categoria superiore',
'ordertip'                => 'Ordine in cui queste voci compariranno nella lista',
'showtip'                 => 'Mostra questa voce nella lsita',
'deletetip'               => 'Cancella questa voce dalla lista',
'del'                     => 'cancella',
'request1'                => 'è stata richiesta la chiusura di un task',
'request2'                => 'è stata richiesta la riapertura del task',
'allpriorities'           => 'Tutte le Priorità',
'noroadmap'               => 'Nessuna roadmap disponibile (non ci sono versioni "future" previste per questo progetto).',
'expand'                  => 'Espandi',
'collapse'                => 'Contrai',
'expandall'               => 'Espandi tutto',
'collapseall'             => 'Contrai tutto',
'minpwsize'               => 'La lunghezza minima della password è di 5 caratteri',
'passwordtoosmall'        => 'La password è troppo corta.',
'accountwaslocked'        => 'Il tuo account è stato bloccato a causa di troppi tentativi di login falliti.',
'failedattempts'          => 'Ci sono stati %d tentativi di login falliti.',
'groupnotexist'           => 'Il gruppo selezionato non esiste in questo progetto.',
'searchindetails'         => 'Cerca nei dettagli',
'showasassignees'         => 'Mostra come Assegnato',
'find'                    => 'Trova',
'tls'                     => 'TLS',
'isadmin'                 => 'È admin',
'addvotes'                => 'Aggiungi Voti',
'removevote'              => 'Rimuovi Voto',
'voteremoved'             => 'Il tuo voto è stato rimosso',
'voteremovefailed'        => 'Il voto non può essere rimosso in questo momento.',
'novotes'                 => 'Non hai voti su nessun task.',
'connectedtasks'          => 'Task connessi',
'taskdependencies'        => 'Dipendenze task',
'viewgraph'               => 'Vedi Grafico',
'notaskdependencies'      => 'Questo task non dipende su nessun task',
'dependson'               => 'Dipende da',
'blocks'                  => 'Blocchi',
'newdependency'           => 'Nuove dipendenze',
'nouserstoadd'            => 'Nessun utente da aggiungere. Assicurarsi che Nome, Cognome e Email siano definite per ogni utente.',
'dispintro'               => 'Mostra messaggio introduttivo principale',
'mainmessage'             => 'Messaggio introduttivo principale',
'setsupertask'            => 'Imposta ID Super-Task:',
'supertaskmodified'       => 'ID Super-Task è stato modificato',
'set'                     => 'Imposta',
'supertask'               => 'Super-Task',
'setparent'               => 'Imposta id del task genitore per questo task',
'selfsupertasknotallowed' => 'L\'ID del super-task non può essere uguale all\'ID dell\'attuale Task',
'quickaction'             => 'Azioni veloci',
'updateselectedtasks'     => 'Aggiorna i Task Selezionati',
'notspecified'            => 'Non specificato',
'editselectedtasks'       => 'Modifica i Task Specificati',
'information'             => 'Informazione',
'taskclosedisabled'       => 'La Chiusura Task è attualmente disabilitata in quanto i seguenti task dipendenti sono ancora aperti:-',
'daysleft'                => 'Giorni mancanti',
'dayoverdue'              => 'Giorni di Ritardo',
'duetoday'                => 'Da fare oggi.',
'daysbeforealert'         => 'Giorni prima dell\'avviso',
'associatedsubtask'       => 'Sotto-task associato correttamente',
'associatesubtask'        => 'Associa l\'ID task con questo task',
'subtaskid'               => 'ID Sotto-task',
'subtaskalreadyhasparent' => 'Il sotto task inserito ha già un task genitore. Si prega di correggere prima di associare.',
'subtaskisparent'         => 'Il sotto-task inserito è il task genitore di questo task. Sotto-task non associato.',
'subtasknotexist'         => 'Il sotto task inserito non esiste.',
'subtaskremovedmsg'       => 'Il sotto task è stato rimosso con successo',
'subtaskadded'            => 'Sotto task aggiunto',
'subtaskremoved'          => 'Sotto task rimosso',
'addnewsubtask'           => 'Aggiungi un sotto-task',
'hidesubtasks'            => 'Nascondi Sotto-task',
'voteforthistask'         => 'Vota per questo task',
'watchthistask'           => 'Visualizza questo task',
'privatethistask'         => 'Rendi il task privato',
'adddependenttask'        => 'Associa task dipendente',
'associatetaskid'         => 'ID Sotto-task',
'parenttaskid'            => 'ID Task Genitore',
'invalidsupertaskid'      => 'L\'id del Task genitore non è valido',
'supertaskadded'          => 'Supertask aggiunto',
'supertaskremoved'        => 'Supertask rimosso',
'effort'                  => 'Impegno',
'efforttracking'          => 'Tracciamento Impegno',
'useeffort'               => 'Il progetto utilizza il Tracciamento dell\'Impegno',
'estimatedeffort'         => 'Impegno Stimato',
'totalestimatedeffort'    => 'Totale impegno stimato',
'currenteffortdone'       => 'Attuale impegno impiegato',
'starteffort'             => 'Avvia Tracciamento',
'endeffort'               => 'Ferma Tracciamento',
'cleareffort'             => 'Pulisci Tracciamento',
'addeffort'               => 'Aggiungi Impegno',
'manualeffort'            => 'Aggiungi manualmente Impegno (H:M)',
'efforttrackingstarted'   => 'Monitoraggio impegno avviato per questo task ',
'efforttrackingnotstarted'=> 'Impossibile iniziare a monitorare su di un problema già in monitoraggio.',
'efforttrackingstopped'   => 'Monitoraggio Impegno terminato per questo task',
'efforttrackingcancelled' => 'Monitoraggio Impegno cancellato per questo task',
'efforttrackingadded'     => 'Impegno registrato manualmente per il task',
'trackinginprogress'      => 'Monitoraggio in corso',
'viewestimatedeffort'     => 'Può visualizzare il monitoraggio dell\'Impegno',
'viewcurrenteffortdone'   => 'Può visualizzare l\'attuale Impegno impiegato',
'trackeffort'             => 'Può monitorare l\'Impegno',
'invalideffort'           => 'L\'Impegno inserito non è valido. Devono essere solo numeri',
'showpass'                => 'Mostra Password',
'chooseafile'             => 'Si prega di scegliere un file!',
'incorrectfiletype'       => 'Tipo di file non corretto. Sono permessi: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Impossibile richiedere la password. Ti sei registrato tramite %s',
'addmultipletasks'        => 'Aggiungi più task',
'pendingnewuserrequest'   => 'Richieste di Nuovi Utenti in Attesa',
'adminrequestswaiting'    => 'Richieste admin in attesa',
'clicktoedit'             => 'Clicca su un campo per modificarlo velocemente',
'confirmedit'             => 'Conferma',
'regapprovedbyadmin'      => 'Registrazioni approvate dagli admin (disabilita codice di conferma)',
'activity'                => 'Attività',
'myactivity'              => 'Le mie attività',
'emailverificationwrong'  => 'L\'email di conferma non corrisponde con l\'indirizzo email fornito',
'verifyemailaddress'      => 'Conferma indirizzo email',
'hideemails'              => 'Nascondi l\'indirizzo email degli utenti',
'hidemyemail'             => 'Nascondi il mio indirizzo email',
'exporttasklist'          => 'Esporta elenco Task',
'onedecimal'              => 'Un decimale',
'manday'                  => 'uomo-giornata',
'mandays'                 => 'uomo-giornate',
'mandayabbrev'            => 'md',
'hourspermanday'          => 'Ore per Uomo a Giornata (HH:mm)',
'itemexists'              => 'L\'elemento %s già esiste nel database.',
'categoryitemexists'      => 'L\'elemento %s già esiste nella categoria %s nel database.',
'pageswelcomemsg'         => 'Pagine dove mostrare il messaggio introduttivo principale',
'pagesintromsg'           => 'Pagine dove mostrare il messaggio introduttivo',
'activeoauths'            => 'Provider OAuth attivi',
'onlyoauthreg'            => 'Permetti solo registrazioni tramite OAuth',
'estimatedeffortformat'   => 'Formato di visualizzazione Impegno stimato',
'currenteffortdoneformat' => 'Formato di visualizzazione Impegno attuale',
'minute'                  => 'minuto',
'minutes'                 => 'minuti',
'minuteplural'            => 'minuti',
'minutesingular'          => 'minuto',
'minuteabbrev'            => 'min',
'hourplural'              => 'ore',
'hoursingular'            => 'ora',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'Impegno stimato per i task aperti',
'currenteffortdoneopen'   => 'Impegno speso nei task aperti',
'signinwith'              => 'Accedi con %s',
'canviewroadmap'          => 'Può vedere la roadmap',
'enableavatars'           => 'Abilita gli avatar',
'maxavatarsize'           => 'Dimensione massima avatar in pixel',
'taskhassubtask'          => 'Questo task presenta il seguente sotto-task',
'taskhassubtasks'         => 'Questo task presenta i seguenti sotto-task',
'translations'            => 'Traduzioni',
'translate'               => 'Traduci',
'taskdescription'         => 'Descrizione Task',
'notaskdescription'       => 'Nessuna descrizione per il Task',
'pleaseselect'            => 'Scegliere',
'closeselectedtasks'      => 'Chiudi i task selezionati',
'closetasks'              => 'Chiudi Task',
'hintforbulkimport'       => "<b>Consigli per l'importazione in blocco:</b>\n<ol>\n<li>Copia e incolla da un file Excel o CSV un'intera colonna.</li>\n<li>Attualmente è possibile incollare solo Riepilogo e Dettagli.</li>\n<li>Ci sono suggerimenti quando assegni a qualcuno e a \"nessuno\" se non vengono trovate corrispondenze.</li>\n</ol>",
'taskissubtaskof'         => 'Questo task è un Sotto-task di',
'applyfirstline'          => 'Applica la prima linea',
'addmorerows'             => 'Aggiungi più righe',
'addtasks'                => 'Aggiungi Task',
'massopsdisabled'         => 'Spiacenti ma la modifica multipla è attualmente disabilitata, abbiamo pianificato l\'implementazione in una versione successiva ma nel frattempo puoi abilitarla dal codice sorgente a tuo rischio. Ti consigliamo comunque di leggere i commenti nel codice prima di farlo.',
'viewroadmap'             => 'Può visualizzare la roadmap',
'nosuicide'               => "Gentile utente, il programma non permette di disabilitare il tuo account o il tuo gruppo.\nIl fratello empatico di HAL9000.",
'movingtodifferentproject'=> 'Non è permesso spostare task che hanno un task padre o sotto-task in un altro progetto. E\' necessario slegarli dai relativi task nel progetto originario.',
'musthavesameproject'     => 'I task genitore e sotto-task devono appartenere allo stesso progetto',
'defaultorderby'          => 'Ordina l\'elenco dei task per',
'defaultorderby2'         => 'e poi per',
'viewowntasks'            => 'Visualizza i tuoi task',
'viewgroupstasks'         => 'Visualizza i task dei gruppi',
'urlrewriting'            => 'Riscrittura URL',
'enablehtaccess'          => 'Abilita il tuo file .htaccess nella cartella principale prima di abilitare l\'url rewriting',
'nomodrewrite'            => 'Mod rewrite non sembra essere disponibile su questo server. Impossibile abilitare url rewriting.',
'on'                      => 'Abilita',
'off'                     => 'Disabilita',
'defaultorderbydirection' => 'Ordine predefinito',
'ascending'               => 'Ascendente',
'descending'              => 'Discendente',
'myassignedtasks'         => 'I miei task',
'commentedon'             => 'Commentato il',
'maxvoteperday'           => 'Numero Massimo di voti per giorno',
'votesperproject'         => 'Limite di voti utente per progetto',
'votelimitreached'        => "Hai raggiunto il tuo limite di voti per questo progetto. Verifica la pagina del tuo profilo per vedere per quali task stai votando attuanlmente.\n",
'myvotes'                 => 'I miei voti',
'tag'                     => 'Tag',
'tags'                    => 'Tag',
'tagsinfo'                => 'Inserisci liberamente tag per i task. Separa i tag con ; (punto e virgola). Non vengono attualmente usati per ricerca, ordinamento o filtro.',
'novalues'                => 'Nessun elemento',
'youhaveregistered'       => "Ti seri registrato.\nLe tue informazioni sono le seguenti:",
'youhaveregisterednotify' => 'La tua registrazione è stata accettata dagli amministratori.',
'usedintasks'             => 'Utilizzo',
'freetagging'             => 'Permetti agli utenti di definire i tag',
'keyboardshortcuts'       => 'Scorciatoie da tastiera',
'testmailsettings'        => 'Prova le impostazioni email',
'test'                    => 'Prova',
'testmailsettingsnotice'  => 'Verifica anche di aver ricevuto l\'email di prova all\'indirizzo dell\'account corrente (indirizzo impostato nel profilo)',
'invalidinput'            => 'Ci sono alcuni valori mancanti o erroneamente inviati',
'invalidprogress'         => 'Seleziona un valore valido per il Progresso',
'invalidpriority'         => 'Seleziona un valore valido per la Priorità',
'invalidseverity'         => 'Seleziona un valore valido per la Gravità',
'invalidstatus'           => 'Seleziona uno stato valido per il Task',
'invalidtasktype'         => 'Seleziona un tipo di task valido',
'invalidcategory'         => 'Seleziona una Categoria valida',
'invalidreportedversion'  => 'Seleziona una versione valida per il Report',
'invaliddueversion'       => 'Seleziona una Versione valida come versione prevista',
'invalidos'               => 'Seleziona un Sistema Operativo valido',
'invalidtags'             => 'Seleziona solo i tag consentiti',
'invalidassignees'        => 'Seleziona solo Assegnatari validi',
'invalidtargetproject'    => 'Seleziona un progetto di destinazione valido',
'customize'               => 'Personalizza',
'hidesubs'                => 'Nascondi task collegati',
'hideprivate'             => 'Nascondi task privati',
'hideclosed'              => 'Nascondi task chiusi',
'globaloptions'           => 'opzioni globali',
'currentproject'          => 'Progetto corrente',
'targetproject'           => 'Progetto destinazione',
'availablekeybshortcuts'  => 'Combinazioni disponibili',
'logindialoglogout'       => 'Dialog di Login / Logout',
'focustaskidsearch'       => 'Attiva campo ricerca Task ID',
'openselectedtask'        => 'Apri il Task selezionato',
'movecursorup'            => 'Muovi il cursore giù',
'movecursordown'          => 'Muovi il cursore su',
'taskdetails'             => 'Dettagli Task',
'taskediting'             => 'Modifiche Task',
'savetask'                => 'Salva Task',
'generalintegration'      => 'Stringhe da integrare',
'generalintegrationdesc'  => 'Il contenuto viene inserito nel body dal tema di default, sotto il contenuto principale e prima del footer. Dove sarà effettivamente visualizzato sullo schermo dipende dal CSS. Usa un tema personalizzato custom_*.css per il posizionamento.',
'footerintegration'       => 'Stringhe da integrare nel footer',
'footerintegrationdesc'   => 'Il contenuto viene inserito nel footer dal tema di default. Dove sarà effettivamente visualizzato sullo schermo dipende dal CSS. Usa un tema personalizzato custom_*.css per il posizionamento.',
'editorbold'              => 'G',
'editorboldhint'          => 'Grassetto',
'editoritalic'            => 'C',
'editoritalichint'        => 'Corsivo',
'editorunderline'         => 'S',
'editorunderlinehint'     => 'Sottolineato',
'editorstrikethrough'     => 'B',
'editorstrikethroughhint' => 'Barrato',
'captchaerror'            => 'CAPTCHA errato. Riprova.',
'registercaptcha'         => 'Risolvi il CAPTCHA.',
'regcaptcha'              => 'Visualizza il CAPTCHA per le nuove registrazioni utente.',
'invalidsecurimage'       => 'CAPTCHA non valido.',
'invalidrecaptcha'        => 'Google reCAPTCHA non valido.',
'antispam'                => 'Prevenzione SPAM',
'antispamprefsinfo'       => 'Impostazioni per le contromisure anti spambots. Attualmente vengono utilizzati Securimage e Google reCAPTCHA per le nuove registrazioni utente.',
'securimageprefsinfo'     => 'Un CAPTCHA di tipo classico dove gli utenti devono riconoscere una sequenza di testo per dimostrare di essere umani.',
'securimageenable'        => 'Attiva Securimage.',
'recaptchaprefsinfo'      => "Google reCAPTCHA è un'alternativa al classico CAPTCHA.\nIn base ai dati registrati, al comportamento e altre tipologie di domande basate su immagini, Google decide se sei un umano o un bot.\nPer usarlo hai bisogno di un account Google e di configurare reCAPTCHA per il tuo dominio all'indirizzo https://www.google.com/recaptcha\ndopodiché inserire \"sitekey\" e \"secret\".\nIn base alla configurazione su Google (\"reCAPTCHA V2\" oppure \"Invisible reCAPTCHA\") potresti dover informare i tuoi utenti sulle policy di protezione dati.",
'recaptchaenable'         => 'Abilita Google reCAPTCHA',
'adminchecks'             => 'Verifiche',
'adminchecksinfo'         => 'Informazioni e verifiche sulla tua installazione',
'repeatpassword'          => 'Ripeti Password',
'repeatemailaddress'      => 'Ripeti Indirizzo Email',
'tooltipshorttasktitle'   => 'Scrivi un titolo che sintetizzi il problema e lo renda comprensibile a colpo d\'occhio',
'lastlogin'               => 'Ultimo Accesso',
);

?>
