<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'ערוך משתמש',
'accountenabled'          => 'חשבון פעיל',
'editallusers'            => 'הצג את כל המשתמשים',
'username'                => 'שם משתמש',
'usersupdated'            => 'המשתמש עודכן בהצלחה',
'realname'                => 'שם מלא',
'emailaddress'            => 'כתובת דואל',
'jabberid'                => 'שם ג\'אבר',
'profileimage'            => 'תמונת פרופיל',
'notifytype'              => 'שיטת הודעה',
'group'                   => 'קבוצה',
'enableaccounts'          => 'הפעל חשבונות',
'disableaccounts'         => 'בטל חשבונות',
'deleteaccounts'          => 'מחק חשבונות',
'updatedetails'           => 'עדכן פרטים',
'setglobally'             => 'העדפה זו הוגדרה בכל המערכת.',
'usergroupmanage'         => 'ניהול קבוצות ומשתמשים',
'newuser'                 => 'רישום משתמש חדש',
'newuserbulk'             => 'רישום מספר משתמשים',
'bulkuserstoadd'          => 'רשימת משתמשים חדשים',
'optionsforallusers'      => 'אפשרויות לכל המשתמשים החדשים',
'newgroup'                => 'יצירת קבוצה חדשה',
'yes'                     => 'כן',
'no'                      => 'לא',
'editgroup'               => 'עריכת קבוצה',
'groupname'               => 'שם קבוצה',
'description'             => 'תיאור',
'admin'                   => 'קבוצת ניהול',
'opennewtasks'            => 'פתח משימות חדשות',
'modifytasks'             => 'עדכן משימות קיימות',
'addcomments'             => 'הוסף תגובות',
'attachfiles'             => 'הצמד קבצים',
'vote'                    => 'הצבע',
'groupenabled'            => 'חברים יכולים להכנס',
'tasktypelist'            => 'רשימת סוגי משימות',
'categorylist'            => 'רשימת קטגוריות',
'oslist'                  => 'רשימת מערכות הפעלה',
'resolutionlist'          => 'רשימת החלטות',
'versionlist'             => 'רשימת גרסאות',
'severitylist'            => 'רשימת חומרות',
'listnote'                => 'הערה: הורדת סימון ״הצג״ עלולה לשנות חלק מהמשימות כשנמצאים במצב עריכה. שינוי השדה ״שם״ ישנה את כל המשימות בשם זה. משימות שלא יכולות להמחק הן מוגנות כיוון שהן נדרשות לתפקוד תקין או בשימוש במשימות.',
'name'                    => 'שם',
'order'                   => 'סדר',
'back'                    => 'חזרה',
'text'                    => 'טקסט',
'highlight'               => 'הדגשה',
'show'                    => 'הצג',
'owner'                   => 'בעלים',
'selectowner'             => 'בחר בעלים',
'update'                  => 'עדכן',
'addnew'                  => 'הוסף חדש',
'flysprayprefs'           => 'הגדרות מערכת',
'projecttitle'            => 'כותרת פרויקט',
'baseurl'                 => 'כתובת בסיס להתקנה זו',
'replyaddress'            => 'כתובת תשובה להודעות',
'themestyle'              => 'סגנון \\ עיצוב',
'language'                => 'שפה',
'anonview'                => 'אפשר למשתמשים אנונימיים לראות משימות',
'allowanon'               => 'אפשר למשתמשים אנונימיים לפתוח משימות חדשות',
'never'                   => 'אף פעם',
'anonymously'             => 'באופן אנונימי',
'afterregister'           => 'רק לאחר הרשמה',
'spamproof'               => 'אפשר קוד אישור לרישום משתמשים חדשים',
'anongroup'               => 'קבוצה לרישום משתמשים חדשים',
'groupassigned'           => 'ניתן להגדיר משימות לחברי הקבוצות הבאות',
'forcenotify'             => 'הכרח הודעות על משימות',
'neversend'               => 'לעולם לא לשלוח',
'userchoose'              => 'אפשר לכל משתמש לבחור',
'email'                   => 'דואר אלקטרוני',
'jabber'                  => 'ג\'אבר מסרים מיידיים',
'defaultcatowner'         => 'ברירת מחדל של בעל קטגוריה',
'noone'                   => 'אף אחד',
'jabbernotify'            => 'מסרים מידיים ג\'אבר',
'jabberserver'            => 'שרת',
'jabberport'              => 'פורט',
'jabberuser'              => 'משתמש',
'jabberpass'              => 'סיסמה',
'saveoptions'             => 'שמור הגדרות',
'editcomment'             => 'עריכת הערה',
'commentby'               => 'הערה על ידי',
'saveeditedcomment'       => 'שמור הערה שנערכה',
'projectprefs'            => 'העדפות פרויקט',
'pagetitle'               => 'כותרת עמוד',
'defaultproject'          => 'פרויקט ברירת מחדל',
'projectlists'            => 'רשימות פרויקטים',
'showlogo'                => 'הצג תמונת לוגו כותרת',
'showgravatars'           => 'הצג גראוואטרים',
'emailNoHTML'             => 'דואלים ללא HTML',
'intromessage'            => 'הודעת פתיחה',
'isactive'                => 'הפרויקט פעיל',
'createproject'           => 'צור פרויקט חדש',
'nopermission'            => 'אין לך הרשאה לשימוש בעמוד זה.',
'listordertip'            => 'הסדר בו פריטים אלו יופיעו ברשימה',
'listshowtip'             => 'הצג פריט זה ברשימה',
'categoryownertip'        => 'משתמש זה יקבל הודעה כאשר נפתחת משימה בקטגוריה זו',
'categoryparenttip'       => 'קטגוריית אב שהחדשה הזו תהיה תחתיה',
'notsubcategory'          => 'ללא (קטגוריה ראשית)',
'showinlineimages'        => 'הצג תמונות מצורפות בפנים',
'dateformat'              => 'מבנה תאריך',
'dateformat_extended'     => 'מבנה תאריך מפורט',
'cache_feeds'             => 'מטמון פידים',
'no_cache'                => 'ללא מטמון',
'cache_disk'              => 'מטמון בדיסק',
'cache_db'                => 'מטמון בבסיס הנתונים',
'subcategoryof'           => 'תת קטגוריה של',
'visiblecolumns'          => 'עמודות להצגה ברשימת משימות',
'visiblefields'           => 'שדות בזמן הוספה/עריכה/צפייה במשימה',
'tense'                   => 'זמן',
'listtensetip'            => 'עבר, הווה או עתיד',
'past'                    => 'עבר',
'present'                 => 'הווה',
'future'                  => 'עתיד',
'oldpass'                 => 'סיסמא ישנה',
'nooldpass'               => 'לא הוגדרה סיסמא ישנה',
'oldpasswrong'            => 'סיסמא ישנה שגויה',
'changepass'              => 'שינוי סיסמא',
'confirmpass'             => 'אישור שינוי',
'projectmanager'          => 'מנהל פרויקט',
'viewtasks'               => 'הצג משימות',
'modifyowntasks'          => 'עדכן את משימותיך',
'modifyalltasks'          => 'עדכן משימות שאינן בבעלות המשתמש',
'viewcomments'            => 'הצג הערות',
'editcomments'            => 'ערוך הערות',
'deletecomments'          => 'מחק הערות',
'viewattachments'         => 'הצג קבצים מצורפים',
'createattachments'       => 'צור קבצים מצורפים',
'deleteattachments'       => 'מחק קבצים מצורפים',
'viewhistory'             => 'הצג היסטוריה',
'closeowntasks'           => 'סגור משימות בבעלותך',
'closeothertasks'         => 'סגירת משימות שאינן בבעלות המשתמש',
'assigntoself'            => 'הקצה משימות לעצמי אם עדיין לא הוקצו',
'assignotherstoself'      => 'הקצה משימות של אחרים לעצמי',
'viewreports'             => 'הצגת רשימת אירועים',
'othersview'              => 'אפשר לכולם לראות פרויקט זה',
'usersandgroups'          => 'משתמשים וקבוצות',
'globalgroup'             => 'קבוצה גלובלית',
'globalgroups'            => 'קבוצות גלובליות',
'defaultglobalgroup'      => 'קבוצת ברירת מחדל גלובלית למשתמשים חדשים',
'addtogroup'              => 'הוסף לקבוצה',
'moveuserstogroup'        => 'העבר משתמשים לקבוצה',
'nogroup'                 => 'ללא קבוצה - הסר מהפרויקט',
'eventdesc'               => 'תיאור אירוע',
'requestedby'             => 'נתבקש על ידי',
'daterequested'           => 'תאריך בקשה',
'closetask'               => 'סגור משימה',
'reopentask'              => 'פתח מחדש משימה',
'applymember'             => 'הגש בקשה לחברות בפרויקט',
'forcurrentproj'          => 'לפרויקט הקיים',
'lostpw'                  => 'שחזור סיסמא שאבדה',
'lostpwexplain'           => 'הזן את שם המשתמש לשליחת קישור לשינוי הסיסמא. ההודעה תשלח לכתובת ההודעות שהוגדרה בפרופילך.',
'sendlink'                => 'שלח קישור',
'savenewpass'             => ' שמור סיסמה חדשה',
'anonreg'                 => 'אפשר רישום משתמשים חדשים',
'allowanonopentask'       => 'אפשר למשתמשים אנונימיים לפתוח משימות',
'editglobalgroup'         => 'ערוך קבוצה גלובלית',
'editgroupforproj'        => 'ערוך קבוצה לפרויקט',
'notshownforadmin'        => 'הרשאות לקבוצת ניהול לא מוצגות. אין צורך לערוך אותן.',
'general'                 => 'כללי',
'userregistration'        => 'רישום משתמש',
'notifications'           => 'הודעות',
'resetoptions'            => 'אפס הגדרות',
'preferences'             => 'העדפות',
'tasktypes'               => 'סוגי משימות',
'resolutions'             => 'החלטות',
'categories'              => 'קטגוריות',
'operatingsystems'        => 'מערכות הפעלה',
'versions'                => 'גרסאות',
'admintoolboxlong'        => 'תיבת כלים לניהול',
'newproject'              => 'פרויקט חדש',
'delete'                  => 'מחק',
'link'                    => 'קשר',
'referencelinks'          => 'קישורי סימוכין:',
'listdeletetip'           => 'מחק פריט זה מהרשימה',
'lookandfeel'             => 'מראה ואינטראקציה',
'globaltheme'             => 'תערכת נושא גלובלי',
'emailnotify'             => 'הודעות דואל',
'fromaddress'             => 'מכתובת',
'smtpserver'              => 'שרת SMTP',
'smtpuser'                => 'שם משתמש SMTP',
'smtppass'                => 'סיסמת SMTP',
'addrewrite'              => 'השתמש בשכתוב כתובת',
'usereminderdaemon'       => 'הפעל שירות תזכורות ברקע',
'tasksperpage'            => 'משימות לעמוד ברשימת המשימות',
'addtoassignees'          => 'הוסף אותי להקצאות',
'taskstatuses'            => 'מצבי משימה',
'canvote'                 => 'יכול להצביע עבור משימות',
'loginsuccessful'         => 'כניסה הצליחה.',
'youareloggedout'         => 'יצאת מהמערכת.',
'waitwhiletransfer'       => 'נא להמתין בעת ההעברה...',
'clicknowait'             => 'לחץ כאן אם אין ברצונך להמתין.',
'accountdisabled'         => 'חשבונך הושהה, יש ליצור קשר עם מנהל המערכת.',
'task'                    => 'משימה',
'edittask'                => 'ערוך משימה זו',
'openedby'                => 'נפתחה על ידי',
'editedby'                => 'נערכה לאחרונה על ידי',
'tasktype'                => 'סוג משימה',
'category'                => 'קטגוריה',
'status'                  => 'סטטוס',
'assignedto'              => 'הוקצתה עבור',
'operatingsystem'         => 'מערכת הפעלה',
'severity'                => 'חומרה',
'reportedversion'         => 'דווח בגרסה',
'dueinversion'            => 'לביצוע בגרסה',
'defaultdueinversion'     => 'ברירת מחדל של ביצוע בגירסה למשימות חדשות',
'undecided'               => 'לא הוחלט',
'percentcomplete'         => 'אחוז השלמה',
'details'                 => 'פרטים',
'savedetails'             => 'שמור פרטים',
'canceledit'              => 'ביטול',
'anonymous'               => 'תורם אנונימי',
'complete'                => 'הושלם',
'closedby'                => 'נסגרה על ידי',
'reasonforclosing'        => 'סיבת סגירה:',
'reopenthistask'          => 'פתח מחדש משימה זו',
'comments'                => 'הערות',
'attachments'             => 'קבצים מצורפים',
'relatedtasks'            => 'משימות קשורות',
'edit'                    => 'ערוך',
'addcomment'              => 'הוסף הערה',
'fileuploadedby'          => 'הקובץ הועלה על ידי',
'uploadafile'             => 'צרף קובץ',
'addalink'                => 'הוסף קישור',
'addanotherlink'          => 'הוסף קישור נוסף',
'uploadnow'               => 'העלה עכשיו!',
'thesearerelated'         => 'משימות אלו קשורות למשימה זו',
'remove'                  => 'הסר',
'addnewrelated'           => 'הוסף משימה קשורה חדשה',
'add'                     => 'הוסף',
'otherrelated'            => 'משימות אחרות שמשימה זו קשורה אליהן',
'receivenotify'           => 'משתמשים אלו יקבלו הודעות מפורטות כאשר משימה זו מתעדכנת.',
'addusertolist'           => 'הוסף משתמש לרשימה זו',
'addtolist'               => 'הוסף לרשימה',
'addmyself'               => 'הוסף את עצמי לרשימה זו',
'removemyself'            => 'הסר את עצמי מרשימה זו',
'theseusersnotify'        => 'משתמשים אלו יקבלו הודעות מפורטות כאשר משימה זו מתעדכנת.',
'attachedtoproject'       => 'צורף לפרויקט',
'reminders'               => 'תזכורות',
'system'                  => 'מערכת',
'remindthisuser'          => 'הזכר למשתמש זה',
'thisoften'               => 'בתדירות זו',
'startafter'              => 'המתן לפני הפעלת תזכורות',
'hour'                    => 'שעה',
'hours'                   => 'שעות',
'day'                     => 'יום',
'days'                    => 'ימים',
'week'                    => 'שבוע',
'weeks'                   => 'שבועות',
'addreminder'             => 'הוסף תזכורת',
'defaultreminder'         => 'זוהי תזכורת להציץ במשימה הבאה:',
'message'                 => 'הודעה',
'closed'                  => 'נסגרה',
'filename'                => 'שם קובץ:',
'date'                    => 'תאריך',
'filesize'                => 'גודל קובץ:',
'closurecomment'          => 'הערות נוספות לסגירה:',
'history'                 => 'היסטוריה',
'nohistory'               => 'אין היסטוריה.',
'eventdate'               => 'תאריך',
'user'                    => 'משתמש',
'event'                   => 'אירוע',
'fieldchanged'            => 'שדה שונה',
'taskopened'              => 'משימה נפתחה',
'taskreopened'            => 'משימה נפתחה מחדש',
'taskclosed'              => 'משימה נסגרה',
'commentadded'            => 'הערה נוספה',
'commentedited'           => 'הערה נערכה',
'commentdeleted'          => 'הערה נמחקה',
'attachmentadded'         => 'קובץ צורף',
'attachmentdeleted'       => 'צירוף קובץ נמחק',
'taskedited'              => 'פרטי משימה נערכו',
'notificationadded'       => 'משתמש התווסף לרשימת היידוע',
'notificationdeleted'     => 'משתמש הוסר מרשימת היידוע',
'relatedadded'            => 'משימה קשורה נוספה',
'relateddeleted'          => 'משימה קשורה הוסרה',
'taskassigned'            => 'משימה הוקצתה עבור',
'taskreassigned'          => 'משימה הוקצתה מחדש עבור',
'assignmentremoved'       => 'הקצאה הוסרה',
'summary'                 => 'סיכום',
'addedasrelated'          => 'משימה התווספה לרשימת משימות קשורות של',
'deletedasrelated'        => 'משימה הוסרה מרשימת משימות קשורות של',
'reminderadded'           => 'תזכורת התווספה',
'reminderdeleted'         => 'תזכורת הוסרה',
'priority'                => 'עדיפות',
'previousvalue'           => 'ערך קודם',
'newvalue'                => 'ערך חדש',
'selectareason'           => 'בחר סיבה',
'assigntome'              => 'הקצה לעצמי',
'reopenrequest'           => 'בקש פתיחה מחדש',
'requestclose'            => 'בקש סגירה',
'ownershiptaken'          => 'משתמש לקח בעלות',
'closerequestmade'        => 'בקשה הגיעה לסגירת המשימה',
'reopenrequestmade'       => 'בקשה הגיעה לפתיחה מחדש של המשימה',
'taskdependson'           => 'משימה זו תלויה במשימות',
'taskblocks'              => 'משימה זו חוסמת משימות אלו מלהסגר',
'depadded'                => 'תלות נוספה',
'depaddedother'           => 'משימה זו הוגדרה כתלות',
'depremoved'              => 'תלות הוסרה',
'depremovedother'         => 'משימה זו הוסרה מרשימת התלויות של משימה אחרת',
'showdetailserror'        => 'משימה זו אינה קיימת, או שאין לך הרשאות לצפות בה.',
'makeprivate'             => 'הגדר כפרטי',
'makepublic'              => 'הגדר כציבורי',
'taskmadeprivate'         => 'המשימה הוגדרה כפרטית',
'taskmadepublic'          => 'הפרטיות הוסרה - משימה הוגדרה כפומבית',
'confirmdeletecomment'    => 'אתה משוכנע שברצונך למחוק הערה זו? %s',
'attachementswilldeleted' => 'כל הקבצים הצורפים יימחקו גם כן!',
'confirmdeleteattach'     => 'אתה משוכנע שברצונך למחוק קובץ מצורף זה?',
'selectedhistory'         => 'מציגים פרטי היסטוריה שנבחרה',
'showallhistory'          => 'הצג לשונית היסטוריה מלאה שוב',
'hidethis'                => 'הסתר שטח זה שוב',
'mark100'                 => 'סמן משימה כמושלמת ב-100%',
'watchtask'               => 'עקוב אחר משימה',
'stopwatching'            => 'הפסק מעקב',
'commentlink'             => 'קשר לתגובה זו',
'submitreq'               => 'שלח בקשה',
'reasonforreq'            => 'סיבת הבקשה',
'pmreqdenied'             => 'מנהל פרויקט דחה את הבקשה',
'taskpendingreq'          => 'ממתינים לפעולת מנהל פרויקט. הבט בלשונית ההיסטוריה לפרטים.',
'previoustask'            => 'המשימה הקודמת',
'nexttask'                => 'המשימה הבאה',
'duedate'                 => 'תאריך יעד',
'attachnoperms'           => 'ישנם קבצים מצורפים להערה זו, אבל אין לך הרשאות לצפות בהם.',
'linknoperms'             => 'ישנם קישורים בהערה זו, אבל אין לך הרשאות לצפות בהם.',
'open'                    => 'פתח',
'depgraph'                => 'הצג גרף תלויות',
'reset'                   => 'אפס',
'selectusers'             => 'בחר משתמשים...',
'addmetoassignees'        => 'הוסף אותי להקצאות',
'addedtoassignees'        => 'משתמש התווסף לרשימת ההקצאות',
'dependencygraph'         => 'גרף תלויות',
'attachanotherfile'       => 'צרף קובץ אחר',
'OK'                      => 'אוקי',
'addvote'                 => 'הוסף הצבעה',
'disable_lostpw'          => 'בטל איחזור סיסמא שאבדה',
'disable_changepw'        => 'בטל יצירת/עריכת סיסמא',
'notifyfromfs'            => 'הודעה ממערכת Flyspray',
'autogenerated'           => 'זוהי הודעה המיוצרת אוטומטית. אין להשיב!',
'forward'                 => 'קדימה',
'previous'                => 'הקודם',
'next'                    => 'הבא',
'first'                   => 'ראשון',
'last'                    => 'אחרון',
'page'                    => 'עמוד %d מתוך %d',
'search'                  => 'חפש',
'alltasktypes'            => 'כל סוגי המשימות',
'allseverities'           => 'כל החומרות',
'alldevelopers'           => 'כל המפתחים',
'notyetassigned'          => 'לא הוקצתה עדיין',
'allcategories'           => 'כל הקטגוריות',
'allstatuses'             => 'כל הסטטוסים',
'allopentasks'            => 'כל המשימות הפתוחות',
'sortthiscolumn'          => 'מיין לפי עמודה זו',
'id'                      => 'מזהה',
'project'                 => 'פרויקט',
'dateopened'              => 'נפתח',
'progress'                => 'התקדמות',
'searchthisproject'       => 'חפש בפרויקט זה',
'dueanyversion'           => 'יעד בכל גרסה',
'anyversion'              => 'מדווח בכל גרסה',
'dueversion'              => 'יעד בגרסה',
'lastedit'                => 'נערך לאחרונה',
'os'                      => 'מערכת הפעלה',
'reportedin'              => 'דווח ב',
'taskrange'               => 'מציג משימות %d - %d מתוך %d',
'noresults'               => 'החיפוש לא החזיר תוצאות.',
'takeaction'              => 'בצע פעולה',
'watchtasks'              => 'עקוב אחר משימות נבחרות',
'stopwatchingtasks'       => 'הפסק מעקב אחר משימות נבחרות',
'assigntaskstome'         => 'הקצה משימות נבחרות עבורי',
'dueby'                   => 'יעד',
'dueanytime'              => 'יעד בכל רגע',
'selectduedate'           => 'בחר תאריך יעד',
'toggleselected'          => 'הפוך בחירה',
'due'                     => 'יעד',
'assignedtome'            => 'הוקצתה לעצמי',
'tasklist'                => 'רשימת משימות',
'dateclosed'              => 'תאריך סגירה',
'advanced'                => 'מתקדם',
'searchcomments'          => 'חפש בהערות',
'searchforall'            => 'חפש את כל המילים',
'anonusers'               => 'משתמשים אנונימיים',
'miscellaneous'           => 'שונות',
'users'                   => 'משתמשים',
'taskproperties'          => 'הגדרות משימה',
'selectsincedate'         => 'בחר השתנתה מאז',
'changedsince'            => 'השתנתה מאז',
'updatefs'                => 'אנא עדכן את Flyspray.',
'currentversion'          => 'הגרסה הנוכחית היא',
'latestversion'           => 'הגרסה החדשה ביותר היא',
'hidemessage'             => '(הזכירו לי בהמשך)',
'saveas'                  => 'שמור חיפוש בשם',
'nosearches'              => 'אין חיפושים שמורים',
'saving'                  => 'שומר...',
'votes'                   => 'הצבעות',
'tovote'                  => 'הצבע',
'allclosedtasks'          => 'כל המשימות הסגורות',
'password'                => 'סיסמא',
'login'                   => 'התחברות!',
'rememberme'              => 'זכור אותי',
'lostpassword'            => 'שכחת סיסמא?',
'lostpwforfs'             => 'סיסמא אבודה עבור Flyspray',
'lostpwmsg1'              => "שלום.\n\nשכחתי את סיסמתי ",
'lostpwmsg2'              => ",אנא הנפיקו לי סיסמה חדשה.\n\nשם משתמש: ",
'regards'                 => 'בתודה,',
'yourusername'            => ' שם המשתמש שלך ',
'locale'                  => 'he-IL',
'filenotexist'            => 'קובץ לא קיים, או שאין לך הרשאות גישה עבורו.',
'showtask'                => 'הצג משימה',
'now'                     => 'עכשיו',
'go'                      => 'בצע!',
'opentaskanon'            => 'פתח משימה חדשה כאנונימי',
'register'                => 'הרשמה',
'addnewtask'              => 'הוסף משימה חדשה',
'reports'                 => 'יומן אירועים',
'editmydetails'           => 'ערוך את הפרטים שלי',
'logout'                  => 'התנתקות',
'disabledaccount'         => 'החשבון שלך הושהה! מנתק אותך מהמערכת...',
'poweredby'               => 'Powered by Flyspray',
'sponsoredby'             => 'Flyspray is proudly sponsored by',
'projects'                => 'פרויקטים',
'allprojects'             => 'כל הפרויקטים',
'selectproject'           => 'עבור פרויקט:',
'tasksall'                => 'כל המשימות',
'tasksassigned'           => 'משימות המוקצות לי',
'tasksreported'           => 'משימות שדיווחתי',
'taskswatched'            => 'משימות שאני עוקב אחריהן',
'mysearch'                => 'החיפושים שלי',
'admintoolbox'            => 'תיבת כלים לניהול',
'manageproject'           => 'ניהול פרויקט',
'permissions'             => 'הצג הרשאות',
'hide'                    => 'הסתר',
'pendingreq'              => 'מנהל פרוייקט מבקש המתנה',
'errorpage'               => 'הדף לא נמצא. אולי חיפשת משימה לא קיימת, או שאין לך הרשאות לצפות בדף שרצית.',
'permissionsforproject'   => 'הרשאות עבור ',
'switchto'                => 'עבור ל',
'lastsearch'              => 'חיפוש אחרון',
'modify'                  => 'עדכן',
'noticefrom'              => 'הודעה מאת',
'hasopened'               => 'פתח משימת Fltspray חדשה והיא הוקצתה עבורך:',
'moreinfonew'             => 'ניתן לקבל עוד פרטים על הבאג הזה בעמוד Flyspray:',
'newtaskcategory'         => 'נפתחה משימת Flyspray חדשה בקטגוריה זו',
'categoryowner'           => 'אתה מקבל את זה כי אתה רשום כמנהל הקטגוריה.',
'tasksummary'             => 'סיכום משימה:',
'newtaskadded'            => 'המשימה שלך התווספה.',
'summaryanddetails'       => 'יש למלא גם סיכום וגם פרטים.',
'goback'                  => 'חזור.',
'messagefrom'             => 'זו הודעה ממערכת מעקב באגים Flyspray ב ',
'hasjustmodified'         => 'עדכן כרגע את המשימה הבאה.',
'changedfields'           => 'שדות ששונו מסומנים בכוכביות (**)',
'moreinfomodify'          => 'ניתן לקבל עוד מידע על המשימה הזו בקישור הבא:',
'nolongerassigned'        => 'משימה זו כבר לא מוקצית עבורך. היא מוקצית כעת עבור',
'hasassigned'             => 'הקצה עבורך את משימת Flyspray הבאה: ',
'taskupdated'             => 'המשימה עודכנה.',
'tasksupdated'            => 'המשימות עודכנו.',
'hasclosedassigned'       => 'סגר את משימת Flyspray הבאה שהוקצתה עבורך:',
'unassigned'              => 'לא מוקצה',
'hasclosed'               => 'סגר את המשימה הבאה.',
'youonnotify'             => 'אתה מקבל זאת משום שאתה ברשימת המיודעים.',
'taskclosedmsg'           => 'משימה נסגרה.',
'returntotask'            => 'חזרה לפרטי המשימה',
'backtoindex'             => 'חזרה לרשימת המשימות',
'noclosereason'           => 'לא בחרת סיבה לסגירת המשימה.',
'hasreopened'             => 'פתח מחדש את המשימה הבאה שאתה סגרת:',
'taskreopenedmsg'         => 'משימה נפתחה מחדש.',
'backtotask'              => 'חזרה למשימה.',
'commentaddedmsg'         => 'הערה התווספה.',
'commenttoassigned'       => 'הוסיף הודעה למשימה שהוקצתה אליך:',
'commenttotask'           => 'הוסיף את ההערה הבאה למשימה.',
'nocommententered'        => 'באמת חובה להוסיף הערה לפני שלוחצים על כפתור השליחה.',
'fillinfields'            => 'לא מילאת את כל השדות.',
'notcurrentpass'          => 'זו לא הסיסמא הנוכחית שלך!',
'passchanged'             => 'ססמתך שונתה.',
'closewindow'             => 'ניתן לסגור את החלון.',
'passnomatch'             => 'הסיסמאות אינן זהות!',
'usernametaken'           => 'שם משתמש זה כבר תפוס, יש לבחור שם אחר.',
'usernametakenbulk'       => 'שם משתמש כבר תפוס',
'newusercreated'          => 'חשבון משתמש חדש נוצר.',
'accountcreated'          => 'חשבונך נוצר.',
'newuserwarning'          => 'שים לב שההגדרות הגלובליות יכולות להזדקק לכך שחשבונך יאושר על ידי מנהל. אם אינך יכול להרשם, זו כנראה הסיבה.',
'nomatchpass'             => 'הסיסמאות לא תואמות.',
'confirmwrong'            => 'קוד אישור לא נכון!',
'formnotcomplete'         => 'הטופס לא הוזן במלואו.',
'formnotnumeric'          => 'הנתונים שהוכנסו אינם מספריים!',
'groupnametaken'          => 'שם קבוצה זה כבר תפוס.',
'newgroupadded'           => 'קבוצה חדשה נוספה.',
'optionssaved'            => 'הגדרות נשמרו.',
'hasuploaded'             => 'צירף קובץ חדש למשימה שהוקצתה:',
'hasattached'             => 'צירף קובץ למשימה הבאה.',
'fileuploaded'            => 'הקובץ הועלה לשרת.',
'fileerror'               => 'הייתה בעייה בהעלאת הקובץ לשרת. אולי ההרשאות על ספרית attachments אינן נכונות.',
'contactadmin'            => 'צור קשר עם המנהל לפרויקט זה.',
'selectfileerror'         => 'לא בחרת קובץ.',
'userupdated'             => 'פרטי משתמש עודכנו',
'realandemail'            => 'לא הזנת את הפרטים בשדות שם וכתובת דואל.',
'groupupdated'            => 'הגדרת קבוצה עודכנה.',
'groupanddesc'            => 'לא הזנת את שם הקבוצה.',
'fillallfields'           => 'אנא הזן את כל השדות.',
'listPmustN'              => '"סדר" חיב להיות מספרי.',
'listupdated'             => 'הרשימה עודכנה.',
'listitemadded'           => 'פריט חדש התווסף לרשימה.',
'relatedaddedmsg'         => 'משימה קשורה התווספה לרשימה.',
'relatederror'            => 'משימה זו כבר נמצאת ברשימת המשימות הקשורות.',
'relatedremoved'          => 'משימה קשורה נמחקה מהרשימה.',
'notifyadded'             => 'משתמש התווסף לרשימת היידוע.',
'notifyerror'             => 'משתמש זה כבר נמצא ברשימת היידוע עבור משימה זו.',
'notifyremoved'           => 'משתמש הוסר מרשימת היידוע.',
'editcommentsaved'        => 'הערה מעודכנת נשמרה.',
'commentdeletedmsg'       => 'הערה נמחקה.',
'gotonewtask'             => 'עבור למשימה החדשה שיצרת',
'projectcreated'          => 'הפרויקט החדש שלך נוצר. ניתן לערוך אותו באזור ניהול הפרויקטים',
'customiseproject'        => 'התאמה אישית של הפרוייקט',
'projectupdated'          => 'העדפות הפרויקט עודכנו',
'emptytitle'              => 'השארת את שדה כותרת הפרויקט ריק. אנא חזור ותקן זאת.',
'loginbelow'              => 'ניתן לנסות להתחבר עכשיו.',
'attachmentdeletedmsg'    => 'קובץ מצורף זה נמחקה',
'reminderaddedmsg'        => 'התזכורת שלך נוספה.',
'reminderdeletedmsg'      => 'התזכורת שנבחרה נמחקה.',
'flyspraytask'            => 'משימת Flyspray',
'fieldsmissing'           => 'שדות מסויימים אינם מכילים ערך או מכילים ערך לא תקין.',
'relatedinvalid'          => 'אין כזו משימה.',
'relatedproject'          => 'משימה זו קשורה לפרויקט אחר. להוסיף בכל מקרה?',
'addanyway'               => 'הוסף בכל זאת',
'cancel'                  => 'ביטול',
'alreadyedited'           => 'משימה זו נערכה על ידי מישהו אחר לפני ששמרת. האם לשמור בכל זאת את השינויים?',
'saveanyway'              => 'שמור את השינויים בכל זאת',
'nouserselected'          => 'לא נבחר משתמש. יש לבחור לפחות משתמש אחד לפני ניסיון נוסף.',
'groupswitchupdated'      => 'קבוצות משתמשים עודכנו בהצלחה.',
'takenownershipmsg'       => 'משימה זו מוקצית אליך כעת.',
'adminrequestmade'        => 'בקשתך נשלחה למנהל פרויקט.',
'newdepnotify'            => 'תלות חדשה נוספה למשימה הבאה:',
'dependadded'             => 'תלות משימה נוספה',
'dependaddfailed'         => ' ארעה שגיאה בזמן הוספת התלות. אנא בדוק שהמשימה קיימת ואין חסימה הדדית.',
'depremovedmsg'           => 'תלות משימה הוסרה',
'newdepis'                => 'התלות החדשה היא',
'magicurlsent'            => 'הודעה נשלחה לכתובת ההתראות שלך. היא כוללת קישור שיוביל אותך לדף בו תשלים משימה זו.',
'changefspass'            => 'שינוי סיסמה',
'magicurlmessage'         => 'יש ללחוץ על הקישור הבא לשינוי הסיסמה:',
'erroronform'             => 'ארעה שגיאה בשליחת הקובץ',
'addressused'             => 'This address has been used to register a Flyspray account.  If you were not expecting this message, please ignore and delete it.  Go to the following URL to complete your registration:',
'confirmcodeis'           => 'קוד האישור שלך הוא:',
'codesent'                => 'קוד האישור שלך נשלח. אנא מלא אחר ההוראות בהודעה זו.',
'codenotsent'             => 'לא מצליח לשלוח את הקוד, אנא נסה שוב מאוחר יותר.',
'taskmadeprivatemsg'      => 'משימה זו הוגדרה כפרטית',
'taskmadepublicmsg'       => 'משימה זו הוגדרה שוב כפומבית.',
'realandnotify'           => 'עליך למלא את שדה השם המלא, ואת שדה כתובת הדואל טו ה-Jabber ID.',
'pmreqdeniedmsg'          => 'בקשת מנהל פרוייקט נדחתה',
'massopsuccess'           => 'קבוצת פעולות הצליחה - היכן שההרשאות אפשרו',
'usernotexist'            => 'משתמש זה לא קיים',
'commentattachperms'      => 'אין באפשרותך למחוק הערה זו - אין הרשאות למחיקת קבצים מצורפים',
'voterecorded'            => 'הצבעתך נרשמה',
'votefailed'              => 'הצבעתך לא יכולה להתווסף כרגע.',
'createnewgroup'          => 'צור קבוצה חדשה',
'requiredfields'          => 'שדות חובה מסומנים עם',
'addthisgroup'            => 'הוסף קבוצה זו',
'createnewproject'        => 'צור פרוייקט חדש',
'addnewproject'           => 'הוס,ף פרוייקט חדש',
'htmlallowed'             => 'אין להשתמש ב HTML',
'createthisproject'       => 'צור פרוייקט זה',
'inlineimages'            => 'הצג תמונות מצורפות בתוך ההודעה',
'createnewtask'           => 'צור משימה חדשה בפרויקט:',
'addanother'              => 'הוסף עוד משימה אחרי זו',
'addthistask'             => 'הוסף משימה זו',
'notifyme'                => 'יידע אותי בכל פעם שמשימה זו מתעדכנת',
'newtask'                 => 'משימה חדשה',
'attachafile'             => 'צרף קובץ',
'registernewuser'         => 'רישום משתמש חדש',
'none'                    => 'ללא',
'registeraccount'         => 'רשום חשבון זה',
'registerbulkaccount'     => 'רשום חשבונות',
'both'                    => 'שניהם',
'notifyfrom'              => 'הודעות מ',
'donotreply'              => 'זוהי הודעה אוטומטית, אין להשיב!',
'disclaimer'              => 'קיבלת הודעה זו מכייון שביקשת כך ממערכת מעקב באגים Flyspray. אם לא ציפית להודעה זו או אינך מעוניין לקבל דואל בעתיד, יש באפשרותך לשנות את הגדרות היידוע בקישור המופיע למעלה.',
'userwho'                 => 'משתמש שביצע זאת',
'moreinfo'                => 'עוד מידע ניתן למצוא בקישור הבא:',
'newtaskopened'           => 'משימת Flyspray חדשה נפתחה, פרטים למטה.',
'notify.taskclosed'       => 'המשימה הבאה כעת סגורה:',
'notify.taskreopened'     => 'המשימה הבאה נפתחה מחדש:',
'newdep'                  => 'למשימה הבאה יש תלות חדשה:',
'notify.depremoved'       => 'הורדה תלות עבור המשימה הבאה:',
'olddepwas'               => 'התלות הקודמת הייתה',
'notify.commentadded'     => 'נוספה הערה למשימה הבאה:',
'commentis'               => 'תוכן ההערה בהמשך.',
'newattachment'           => 'קובץ חדש צורף למשימה הבאה:',
'detailsbelow'            => 'הפרטים בהמשך.',
'notify.relatedadded'     => 'משימה קשורה חדשה נוספה למשימה הבאה:',
'relatedis'               => 'המשימה הקשורה היא',
'assignedtoyou'           => 'המשימה הבאה הוקצתה אליך:',
'takenownership'          => 'קיבלת בעלות על המשימה הבאה:',
'requiresaction'          => 'המשימה הבאה דורשת פעולה של מנהל פרויקט:',
'requiresactionnotify'    => 'המשימה דורשת פעולה של מנהל פרויקט',
'pmdeny'                  => 'מנהל פרוייקט סירב לבקשה שהמתינה עבור המשימה הבאה:',
'pmdenynotify'            => 'מנהל פרוייקט סירב לבקשה',
'fileaddedtoo'            => 'קובץ אחד או יותר צורפו.',
'taskwatching'            => 'המשימה הזו בה אתה צופה',
'isdepfor'                => 'זו תלות חדשה עבור',
'denialreason'            => 'סיבת הסירוב',
'taskchanged'             => 'המשימה הבאה שונתה. השינויים מפורטים בהמשך. למידע מלא על כל מה שהשתנה, בקר בקישור ולחץ על לשונית ההיסטוריה.',
'useraddedtoassignees'    => 'משתמש הוסיף עצמו לרשימת המשתמשים שמשימה זו מוקצית אליהם.',
'removeddepis'            => 'התלות שהוסרה היא',
'isnodepfor'              => 'אינה תלות יותר עבור',
'usergroups'              => 'קבוצות משתמשים',
'pmtoolbox'               => 'תיבת כלים של מנהל פרויקט',
'groupmanage'             => 'ניהול קבוצה',
'pendingrequests'         => 'בקשות ממתינות',
'reasongiven'             => 'סיבה שניתנה',
'nopendingreq'            => 'אין בקשות מנהל פרוייקט ממתינות',
'givereason'              => 'תן סיבה',
'catlisted'               => 'עורך רשימת קטגוריות',
'oslisted'                => 'עורך רשימת מערכות הפעלה',
'verlisted'               => 'עורך רשימת גרסאות',
'tasktypeed'              => 'עורך רשימת סוגי משימות',
'resed'                   => 'עורך רשימת החלטות',
'deny'                    => 'דחה',
'notifiedwhen'            => 'ייודע כאשר',
'onlynewtasks'            => 'משימות חדשות נפתחו',
'allevents'               => 'כל אירוע בכל משימה',
'feeds'                   => 'פידים',
'feeddescription'         => 'תיאור פיד',
'feedimgurl'              => 'קישור לתמונה עבור פיד (השאר ריק ללא תמונה)',
'notifysubject'           => 'נושא להודעות',
'notifysubjectinfo'       => '(%p = כותרת פרויקט, %s = סיכום הודעה, %t = מספר משימה, %a = פעולה, %u = משתמש)',
'priority6'               => 'גובה מאד',
'priority5'               => 'גבוה',
'priority4'               => 'בינוני',
'priority3'               => 'נמוך',
'priority2'               => 'נמוך מאד',
'priority1'               => 'לא יבוצע',
'sendcode'                => 'שלח קוד!',
'entercode'               => 'אנא הזן את קוד האישור שהתקבל בהודעת המייל. כמו כן הזן את הסיסמא הרצויה.',
'confirmationcode'        => 'קוד אישור',
'registererror'           => 'וודא שמילאת את כל שדות החובה, וכן שמילאת מידע מדוייקים לגבי סוג ההודעות שברצונך לקבל.',
'validusername'           => '(רק תוים אלפנומריים ו- _ מותרים)',
'validemail'              => '(השתמש ב-; להפריד בין מספר כתובות דואל)',
'emailtakenbulk'          => 'כתובת דואל תפוסה',
'emailtaken'              => 'כתובת זו כבר כבר תפוסה, נא לבחור אחרת.',
'note'                    => '<strong>הערה:</strong>  לפני יצירת החשבון, קוד אישור יישלח בהתאם לצורת היידוע שבחרת למעלה.</br>אם אתה מזין מידע שגוי, לא תקבל את הקוד.',
'changelog'               => 'יומן שינויים',
'changeloggen'            => 'מחולל יומן שינויים',
'listfrom'                => 'הצג רשומות יומן שינויים החל מ-',
'to'                      => 'עד',
'oldestfirst'             => 'הישן ביותר קודם',
'recentfirst'             => 'העדכני ביותר קודם',
'severityrep'             => 'דו״ח חומרה',
'totalopen'               => 'סך משימות פתוחות',
'age'                     => 'גיל',
'agerep'                  => 'דו״ח גיל',
'eventsrep'               => 'דו״ח אירועים',
'events'                  => 'אירועים',
'Tasks'                   => 'משימות',
'opened'                  => 'פתוחות',
'edited'                  => 'ערוכות',
'assigned'                => 'מוקצות',
'within'                  => 'בתוך',
'pastday'                 => 'היום האחרון',
'pastweek'                => 'השבוע האחרון',
'pastmonth'               => 'החודש האחרון',
'pastyear'                => 'השנה האחרונה',
'nolimit'                 => 'ללא הגבלה',
'from'                    => 'מ-',
'duein'                   => 'יעד',
'selectfromdate'          => 'בחר מתאריך',
'selecttodate'            => 'בחר עד תאריך',
'showvoters'              => 'הצג/הסתר מצביעים',
'roadmap'                 => 'מפת דרכים',
'roadmapfor'              => 'מפת דרכים לגרסה',
'tasks'                   => 'משימות',
'completed'               => 'הושלמו.',
'opentasks'               => 'משימות פתוחות',
'of'                      => '% מתוך',
'severity5'               => 'קריטי',
'severity4'               => 'גבוה',
'severity3'               => 'בינוני',
'severity2'               => 'נמוך',
'severity1'               => 'נמוך מאד',
'Redirect'                => 'להעביר ל',
'redirectmsg'             => 'If your browser does not support meta redirection please click %sHERE%s to be redirected',
'allowclosedcomments'     => 'אפשר הערות על משימות סגורות',
'comment'                 => 'הערה',
'editowncomments'         => 'עריכת הערות של עצמי',
'reopened'                => 'נפתחה מחדש',
'loading'                 => 'טוען...',
'notifyown'               => 'יידוע על שינויים עצמיים',
'youremail'               => 'כתובת הדואל שלך',
'thankyouforbug'          => 'תודה על הדיווח. ניתן לראות את המשימה ולעקוב אחר ביצועה בקישור הבא:',
'anonuser'                => 'משתמש אנונימי',
'conflict'                => 'התנגשות',
'file'                    => 'קובץ',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'גודל',
'projectgroup'            => 'קבוצת פרויקט',
'profile'                 => 'פרופיל:',
'viewprofile'             => 'הצג פרופיל',
'regdate'                 => 'נרשם מתאריך',
'tasksopened'             => 'משימות פתוחות',
'replyto'                 => 'השב אל',
'notifytypes'             => 'סוגי הודעות',
'pm.taskchanged'          => 'משימה שונתה',
'pm.taskreopened'         => 'משימה נפתחה מחדש',
'pm.depadded'             => 'תלות נוספה',
'pm.depremoved'           => 'תלות הוסרה',
'pmrequest'               => 'בקשת PM',
'pmrequestdenied'         => 'בקשת PM נדחתה',
'newassignee'             => 'הקצאה חדשה',
'revdepadded'             => 'תלות לכיוון השני התווספה',
'revdepaddedremoved'      => 'תלות לכיוון השני הוסרה',
'assigneeadded'           => 'הקצאה התווספה',
'addusergroup'            => 'הוסף משתמש לקבוצה זו',
'groupmembers'            => 'חברי הקבוצה',
'deleteuser'              => 'מחק משתמש זה',
'userdeleted'             => 'משתמש נמחק',
'autoassign'              => 'הקצאת משימה אוטומטית לבעל הקטגוריה',
'ssl'                     => 'SSL',
'updatewrong'             => "You have the update check feature enabled, but an error ocurred while trying\n                             to contact the update server, either your host do not allow outbound connections\n                             or the error was caused by a network problem.\n                             Please visit the flyspray website to make sure you are running the latest version.",
'deleteproject'           => 'מחק את הפרויקט והעבר את תוכנו ל',
'projectdeleted'          => 'הפרויקט נמחק בהצלחה',
'feedforall'              => 'פיד עבור כל הפרויקטים',
'usercreated'             => 'משתמש נוצר',
'created'                 => 'נוצר',
'deleted'                 => 'נמחק',
'userid'                  => 'מזהה משתמש',
'editassignments'         => 'עריכת הקצאות',
'preview'                 => 'תצוגה מוקדמת',
'anyprogress'             => 'התקדמות כלשהי',
'tasksrelated'            => 'משימות קשורות למשימה זו',
'duplicatetasks'          => 'כפילויות של משימה זו',
'databasemodfailed'       => 'עדכון בסיס נתונים נכשל. סיבות אפשריות הן הרשאות לא מספקות.',
'frequency'               => 'תדירות',
'newuserregistered'       => 'משתמש חדש נרשם במערכת Flyspray. פרטי המשתמש הם:',
'newuserregisterednotify' => 'משתמש חדש נרשם',
'notify_registration'     => 'הודע למנהלים על רישום משתמש חדש',
'textversion'             => 'גרסה טקסטואלית',
'onlyprimary'             => 'משימות שאינן חוסמות משימות אחרות',
'switch'                  => 'מעבר',
'max'                     => 'לכל היותר',
'dates'                   => 'תאריכים',
'selectduedatefrom'       => 'יעד מ-',
'selectduedateto'         => 'עד',
'selectsincedatefrom'     => 'השתנה מ-',
'selectsincedateto'       => 'עד',
'selectdate'              => 'בחר תאריך',
'selectopenedfrom'        => 'נפתח מ-',
'selectopenedto'          => 'עד',
'selectclosedfrom'        => 'נסגר מ-',
'selectclosedto'          => 'עד',
'startat'                 => 'התחיל ב-',
'hasattachment'           => 'מכיל קבצים מצורפים',
'private'                 => 'פרטי',
'watching'                => 'עוקב',
'alreadyvotedthistask'    => 'הצבעת עבור המשימה',
'alreadyvotedthisday'     => 'כבר הצבעת היום',
'visibility'              => 'נראות',
'public'                  => 'פומבי',
'leaveemptyauto'          => 'השאר את שדות הסיסמא ריקים אם ברצונך שהססמא תייוצר אוטומטית.',
'novalidemail'            => 'לא הזנת כתובת דואל תקינה.',
'novalidjabber'           => 'לא הזנת כתובת Jabber תקינה.',
'missingrequired'         => 'לא מולאו כל שדות החובה.',
'entervalidusername'      => 'אנא הזן שם משתמש ושם מלא תקינים.',
'couldnotaddusernotif'    => 'לא ניתן להוסיף משתמש זה לרשימת היידוע.',
'defaulttask'             => 'תיאור משימה ברירת מחדל',
'all'                     => 'הכל',
'events.useraddedtoassignees'=> 'משתמש התווסף להקצאות',
'eventlog'                => 'יומן אירועים',
'assignmentchanged'       => 'הקצאה שונתה',
'detailedinfo'            => 'מידע מפורט',
'All'                     => 'הכל',
'tasksireported'          => 'משימות שדיווחתי',
'recentlyopened'          => 'נפתחו לאחרונה',
'stats'                   => 'סטטיסטיקות',
'totaltasks'              => 'סך כל המשימות',
'mostwanted'              => 'משימות מועדפות',
'defaultentry'            => 'עמוד נחיתה ברירת מחדל',
'toplevel'                => 'תצוגה עילית',
'overview'                => 'מבט כללי',
'error#'                  => 'שגיאה #',
'error1'                  => 'אין לך מספיק הרשאות לראות את הקובץ המצורף.',
'error3'                  => 'פעולה חוזרת, מנווט לדף הבית.',
'error4'                  => 'אין לך הרשאות מנהל.',
'error5'                  => 'משתמש זה לא קיים בהתקנה.',
'error6'                  => 'איזור ניהול לא תקין.',
'error7'                  => 'כניסה נכשלה, סיסמא שגויה!',
'error71'                 => 'החשבון ננעל למשך %d דקות בגלל נסיונות כניסה רבים מדי!',
'error8'                  => 'לא הזנת גם שם משתמש וגם סיסמא.',
'error9'                  => 'משימה לא קיימת או שאין הרשאות לראות אותה.',
'error10'                 => 'משימה זו לא קיימת.',
'error101'                => 'אין לך הרשאות לראות משימה זו.',
'error102'                => 'אין לך הרשאות לראות משימה זו, כניסה למערכת יכולה לעזור.',
'error11'                 => 'אין הרשאות לערוך הערה זו.',
'error12'                 => 'מפתח קסמים לא תקין! אתה משוכנע שקיבלת אותו מהודעת האישור שלך?',
'error13'                 => 'למשתמשים אנונימים אין פרופיל.',
'error14'                 => 'אין לך מספיק הרשאות ליצור קבוצה חדשה.',
'error15'                 => 'אין לך מספיק הרשאות לפתוח משימה.',
'error16'                 => 'אינך מנהל פרויקט.',
'error17'                 => 'איזור PM לא תקין.',
'error18'                 => 'קישור קסם שגוי.',
'error19'                 => 'משתמש זה לא קיים בהתקנה.',
'error20'                 => 'עדכון מסד נתונים לא תקין.',
'error21'                 => 'דואל אחד או יותר נכשלו בשליחה. בדוק את ההגדרות שלך.',
'error22'                 => 'הרשמת משתמש חדש אינה מאופשרת.',
'error23'                 => 'משתמש או קבוצה לא מאופשרים לכניסה למערכת.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'מפת דרכים זמינה רק לפרוייקט מסויים.',
'error26'                 => 'ספק oauth לא נתמך.',
'error27'                 => 'כניסה למערכת נכשלה. אפשר לנו לראות את כתובת הדואל שלך.',
'error28'                 => 'אין לך הרשאות להכנס לאיזור הזה.',
'done'                    => 'בוצע',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'לא ניתן למחוק את הפרויקט.',
'GMT'                     => 'GMT',
'timezone'                => 'אזור זמן',
'accept'                  => 'אשר',
'reasonfordeinal'         => 'סיבת דחיה',
'pruneclosedlinks'        => 'נפה קישורים סגורים',
'pruneclosedtasks'        => 'נפה משימות סגורות',
'pagegenerated'           => 'דף ותמונה מיוצרים תוך %d שניות',
'pruninglevel'            => 'מנפה רמה',
'lastuser'                => 'לא ניתן למחוק את המשתמש האחרון.',
'allprivate'              => 'כל הפרוייקטים פרטיים.',
'deletegroup'             => 'מחק קבוצה זו והעבר משתמשים אל',
'parent'                  => 'אב',
'ordertip'                => 'הסדר בו יופיעו פריטים אלו ברשימה',
'showtip'                 => 'הצג פריט זה ברשימה',
'deletetip'               => 'מחק פריט זה מהרשימה',
'del'                     => 'מחק',
'request1'                => 'הוגשה בקשה לסגירת משימה.',
'request2'                => 'הוגשה בקשה לפתיחת המשימה מחדש.',
'allpriorities'           => 'כל הקדימויות',
'noroadmap'               => 'לא קיימות מפות דרכים (אין גרסאות ״עתיד״ לפרוייקט)',
'expand'                  => 'הרחב',
'collapse'                => 'סגור',
'expandall'               => 'הרחב הכל',
'collapseall'             => 'סגור הכל',
'minpwsize'               => 'אורך סיסמא לפחות 5 תוים',
'passwordtoosmall'        => 'סיסמא קצרה מדי.',
'accountwaslocked'        => 'חשבונך ננעל עקב נסיונות כניסה כושלים למערכת רבים מדי.',
'failedattempts'          => 'היו %d נסיונות כניסה כושלים.',
'groupnotexist'           => 'קבוצה שנבחרה לא קיימת בפרוייק זה.',
'searchindetails'         => 'פרטי חיפוש',
'showasassignees'         => 'הצג כהקצאות',
'find'                    => 'חפש',
'tls'                     => 'TLS',
'isadmin'                 => 'האם מנהל',
'addvotes'                => 'הוסף הצבעות',
'removevote'              => 'הסר הצבעה',
'voteremoved'             => 'הצבעתך הוסרה',
'voteremovefailed'        => 'לא ניתן להסיר הצבעתך כעת.',
'connectedtasks'          => 'משימות מקושרות:',
'taskdependencies'        => 'תלויות במשימה',
'viewgraph'               => 'הצגת גרף',
'notaskdependencies'      => 'משימה זו אינה תלויה במשימות אחרות.',
'dependson'               => 'תלויה ב-',
'blocks'                  => 'חוסמת',
'newdependency'           => 'תלות חדשה:',
'nouserstoadd'            => 'אין משתמשים להוספה. אנא וודא ששם, שם משצמש ודואל מוזנים לכל משתמש.',
'dispintro'               => 'הצג הודעת פתיחה עיקרית',
'mainmessage'             => 'הודעת פתיחה עיקרית',
'setsupertask'            => 'הגדר מאפיין של משימת-על:',
'supertaskmodified'       => 'מאפיין של משימת-על עודכן',
'set'                     => 'הגדר',
'supertask'               => 'משימת-על',
'setparent'               => 'הגדר מאפיין משימת אב של משימה זו',
'selfsupertasknotallowed' => 'מאפיין משימת-על לא יכול להיות זהה למאפיין משימה עצמית',
'quickaction'             => 'פעולות מהירות',
'updateselectedtasks'     => 'עדכן משימות בחורות',
'notspecified'            => 'לא מצויין',
'editselectedtasks'       => 'ערוך משימות בחורות',
'information'             => 'מידע',
'taskclosedisabled'       => 'סגירת משימה כרגע לא ניתנת בגלל שהמשימות התלויות הבאות עדיין פתוחות:-',
'daysleft'                => 'ימים נותרו',
'dayoverdue'              => 'ימים מעבר ליעד',
'duetoday'                => 'מיועד להיום.',
'daysbeforealert'         => 'ימים לפני התראה.',
'associatedsubtask'       => 'קישר תת-משימה #FS בהצלחה',
'associatesubtask'        => 'קשר מאפיין תת-משימה למשימה זו',
'subtaskid'               => 'מאפיין תת-משימה',
'subtaskalreadyhasparent' => 'לתת-המשימה שהזנת כבר יש משימת אב, אנא בטל קישור זה לפני הקישור החדש.',
'subtaskisparent'         => 'תת-המשימה שהזנת היא משימת האב של משימה זו. תת-משימה לא מקושרת.',
'subtasknotexist'         => 'תת-המשימה שהזנת לא קיימת.',
'subtaskremovedmsg'       => 'תת-המשימה הוסרה בהצלחה',
'subtaskadded'            => 'תת-משימה התווספה',
'subtaskremoved'          => 'תת-משימה הוסרה',
'addnewsubtask'           => 'הוסף תת-משימה חדשה',
'hidesubtasks'            => 'החבא תתי-משימות',
'voteforthistask'         => 'הצבע למשימה זו',
'watchthistask'           => 'עקוב אחר משימה זו',
'privatethistask'         => 'הפוך משימה זו לפרטית',
'adddependenttask'        => 'קשר משימה תלויה',
'associatetaskid'         => 'מאפיין תת-משימה',
'parenttaskid'            => 'מאפיין משימת אב',
'invalidsupertaskid'      => 'מאפיין משימת אב לא תקין',
'supertaskadded'          => 'משימת-על התווספה',
'supertaskremoved'        => 'משימת-על הוסרה',
'effort'                  => 'מאמץ',
'efforttracking'          => 'מעקב מאמץ',
'useeffort'               => 'הפרוייקט משתמש במעקב מאמץ',
'estimatedeffort'         => 'הערכת מאמץ',
'totalestimatedeffort'    => 'סך כל מאמץ מוערך',
'currenteffortdone'       => 'מאמץ עכשווי הושלם',
'starteffort'             => 'התחל מעקב',
'endeffort'               => 'הפסק מעקב',
'cleareffort'             => 'נקה מעקב',
'addeffort'               => 'הוסף מאמץ',
'manualeffort'            => 'הוסף מאמץ ידנית (H:M)',
'efforttrackingstarted'   => 'מעקב מאמץ הומשך עבור משימה זו.',
'efforttrackingnotstarted'=> 'לא מסוגל להתחיל מעקב על משימה שכבר יש בה מעקב.',
'efforttrackingstopped'   => 'מעקב מאמץ הסתיים למשימה זו.',
'efforttrackingcancelled' => 'מעקב מאמץ התבטל למשימה זו.',
'efforttrackingadded'     => 'מאמץ ידני נרשם למשימה זו.',
'trackinginprogress'      => 'מעקב בתהליך',
'viewestimatedeffort'     => 'יכול לראות מעקב מאמץ',
'viewcurrenteffortdone'   => 'יכול לראות מאמץ שהושלם עד כה',
'trackeffort'             => 'יכול לעקוב אחר מאמץ.',
'invalideffort'           => 'המאמץ שהוזן לא תקין. חייב להיות מספרי.',
'showpass'                => 'הצג סיסמ',
'chooseafile'             => 'אנא בחר קובץ!',
'incorrectfiletype'       => 'סוג קובץ לא תקין. סיומות מותרות: jpg, jpeg, gif, png.',
'addmultipletasks'        => 'הוסף מספר משימות',
'pendingnewuserrequest'   => 'בקשת משתמש חדש ממתינה',
'adminrequestswaiting'    => 'בקשות מנהל ממתינות',
'clicktoedit'             => 'הקלק על כל שדה לעריכה מהירה',
'confirmedit'             => 'אשר',
'regapprovedbyadmin'      => 'הרשמות מאושרים על ידי מנהלים (ביטול קוד אישור)',
'activity'                => 'פעילות',
'myactivity'              => 'פעילות שלי',
'emailverificationwrong'  => 'אישור הדואל אינו תואם לכתובת הדואל הרשומה',
'verifyemailaddress'      => 'אשר כתובת דואל',
'hideemails'              => 'החבא כתובות דואל של משתמשים',
'hidemyemail'             => 'החבא את כתובת הדואל שלי',
'exporttasklist'          => 'ייצא רשימת משימות',
'onedecimal'              => 'נקודה עשרונית אחת',
'manday'                  => 'יום אדם',
'mandays'                 => 'ימי אדם',
'mandayabbrev'            => 'י״א',
'hourspermanday'          => 'שעות ליום אדם אחד (HH:mm)',
'itemexists'              => 'פריט %s כבר קיים במסד הנתונים.',
'categoryitemexists'      => 'פריט %s כבר קיים במסד הנתונים תחת קטגוריה %s.',
'pageswelcomemsg'         => 'דפים בהם יש להראות הודעת פתיחה ראשית',
'pagesintromsg'           => 'דפים בהם יש להראות הודעת פיחה',
'activeoauths'            => 'ספקי oauth פעילים',
'onlyoauthreg'            => 'אשר רק הרשמות Oauth',
'estimatedeffortformat'   => 'פורמט תצוגת הערכת מאמץ',
'currenteffortdoneformat' => 'פורמט תצוגת מאמץ שהושלם',
'minute'                  => 'דקה',
'minutes'                 => 'דקות',
'minuteplural'            => 'דקות',
'minutesingular'          => 'דקה',
'minuteabbrev'            => 'ד',
'hourplural'              => 'שעות',
'hoursingular'            => 'שעה',
'hourabbrev'              => 'ש',
'estimatedeffortopen'     => 'הערכת מאמץ למשימות פתוחות',
'currenteffortdoneopen'   => 'מאמץ שהושקע במשימות פתוחות',
'signinwith'              => 'הכנס עם %s',
'canviewroadmap'          => 'יכול לראות מפת דרכים',
'enableavatars'           => 'אפשר אוואטרים',
'maxavatarsize'           => 'גודל אוואטר מירבי בפיקסלים',
'taskhassubtask'          => 'למשימה זו יש את תת-המשימה הבאה',
'taskhassubtasks'         => 'למשימה זו יש את תת-המשימות הבאות',
'translations'            => 'תרגומים',
'translate'               => 'תרגם',
'taskdescription'         => 'תיאור משימה',
'notaskdescription'       => 'אין תיאור משימה',
'pleaseselect'            => 'אנא בחר',
'closeselectedtasks'      => 'סגור משימות בחורות',
'closetasks'              => 'סגור משימות',
'hintforbulkimport'       => "<b>Tips for bulk importing:</b>\n<ol>\n<li>Copy and paste from an excel spreadsheet or CSV by pasting one entire column.</li>\n<li>Currently you can only paste Summary and Details.</li>\n<li>There are suggestions when you assign to someone, and to no-one if there is no matched name.</li>\n</ol>",
'taskissubtaskof'         => 'משימה זו היא תת-משימה של',
'applyfirstline'          => 'הפעל על שורה ראשונה',
'addmorerows'             => 'הוסף עוד שורות',
'addtasks'                => 'הוסף משימות',
'massopsdisabled'         => 'Sorry, bulk editing is currently disabled for Flyspray 1.0. We plan to finish implementation for a later release of Flyspray. You can enable them in source code again at your own risk, but read the comments there before doing it.	',
'viewroadmap'             => 'יכול לראות את מפת הדרכים',
'nosuicide'               => 'Dear user, my program doesn\'t allow you to destroy your access to Flyspray by disabling your own account or switching your own group. The empathic brother of HAL9000	',
'movingtodifferentproject'=> 'Moving a task that has either a parent or subtasks to a different project is not allowed. You must break the connection between them first.	',
'musthavesameproject'     => 'אב ותת-משימה חייבים להשתייך לאותו פרוייקט.',
'defaultorderby'          => 'מיין את רשימת המשימות בברירת מחדל לפי',
'viewowntasks'            => 'ראה את המשימות שלך',
'viewgroupstasks'         => 'ראה משימות קבוצות',
'urlrewriting'            => 'שיכתוב הכתובת',
'enablehtaccess'          => 'Please enable your .htaccess file at Flyspray root before turning url rewriting on	',
'nomodrewrite'            => 'Mod rewrite doesn\'t seem to be available on this server, sorry but I can\'t turn url rewriting on	',
'on'                      => 'מופעל',
'off'                     => 'מכובה',
'defaultorderbydirection' => 'מיון ברירת מחדל לפי כיוון',
'ascending'               => 'עולה',
'descending'              => 'יורד',
'myassignedtasks'         => 'המשימות המוקצות לי',
'commentedon'             => 'העיר על',
);

?>
