<?php
/**
*  Adaptado do pt_br para pt_pt por André Nunes - andre.garcia.nunes at gmail dot com
*  Respeita o novo Acordo Ortográfico de 1990.
*  Não esquecer: Editar e gravar em utf-8...
*/

$translation = array(
'edituser'                => 'Editar Utilizador',
'accountenabled'          => 'Conta ativa',
'editallusers'            => 'Ver todos os utilizadores',
'username'                => 'Nome de Utilizador',
'usersupdated'            => 'Utilizadores atualizados com sucesso',
'realname'                => 'Nome Verdadeiro',
'emailaddress'            => 'Endereço de Email',
'jabberid'                => 'Jabber ID',
'profileimage'            => 'Imagem de perfil',
'notifytype'              => 'Tipo de Notificação',
'group'                   => 'Grupo',
'enableaccounts'          => 'Ativar Contas',
'disableaccounts'         => 'Desativar Contas',
'deleteaccounts'          => 'Apagar Contas',
'updatedetails'           => 'Atualizar detalhes',
'setglobally'             => 'Esta preferência foi estabelecida globalmente.',
'usergroupmanage'         => 'Gestão de Grupos e Utilizadores',
'newuser'                 => 'Registar Novo Utilizador',
'newuserbulk'             => 'Registar múltiplos Novos Utilizadores',
'bulkuserstoadd'          => 'Lista de Novos Utilizadores',
'optionsforallusers'      => 'Opções para todos os Novos Utilizadores',
'newgroup'                => 'Criar Novo Grupo',
'yes'                     => 'Sim',
'no'                      => 'Não',
'editgroup'               => 'Editar Grupo',
'groupname'               => 'Nome do Grupo',
'description'             => 'Descrição',
'admin'                   => 'Grupo Admin',
'opennewtasks'            => 'Abrir novas tarefas',
'modifytasks'             => 'Modificar tarefas existentes',
'addcomments'             => 'Adicionar comentários',
'attachfiles'             => 'Anexar ficheiros',
'vote'                    => 'Votar',
'groupenabled'            => 'Membros podem-se conectar',
'groupopen'               => 'Membros podem-se conectar',
'tasktypelist'            => 'Lista de Tipos de Tarefas',
'categorylist'            => 'Lista de Categorias',
'oslist'                  => 'Lista de Sistemas Operativos',
'resolutionlist'          => 'Lista de Resoluções',
'versionlist'             => 'Lista de Versões',
'severitylist'            => 'Lista de Gravidades',
'listnote'                => 'Nota:  Desmarcar a caixa "exibir" pode modificar algumas tarefas quando no modo de edição.  Alterar o campo "Nome" modificará todas as tarefas com esse nome. Itens que não podem ser apagados ou estão protegidos para garantir o funcionamento correto ou estão a ser usados em tarefas.',
'name'                    => 'Nome',
'order'                   => 'Ordem',
'back'                    => 'Retroceder',
'text'                    => 'Texto',
'highlight'               => 'Destacar',
'show'                    => 'Exibir',
'owner'                   => 'Proprietário',
'selectowner'             => 'Selecionar Proprietário',
'update'                  => 'Atualizar',
'addnew'                  => 'Adicionar novo',
'flysprayprefs'           => 'Preferências do Flyspray',
'projecttitle'            => 'Título do Projeto',
'baseurl'                 => 'URL base da instalação',
'replyaddress'            => 'Responder ao endereço de e-mail para notificações',
'themestyle'              => 'Tema / Estilo',
'language'                => 'Idioma',
'anonview'                => 'Permitir que utilizadores anónimos vejam as tarefas',
'allowanon'               => 'Permitir que utilizadores anónimos criem novas tarefas',
'never'                   => 'Nunca',
'anonymously'             => 'Anonimamente',
'afterregister'           => 'Somente após registo',
'spamproof'               => 'Ativar código de confirmação em registos de novos utilizadores',
'anongroup'               => 'Grupo para registo de novos utilizadores',
'groupassigned'           => 'Membros destes grupos podem receber tarefas',
'forcenotify'             => 'Forçar notificações de tarefa como',
'neversend'               => 'Nunca enviar',
'userchoose'              => 'Deixar cada utilizador escolher',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Proprietário padrão da categoria',
'noone'                   => 'Ninguém',
'jabbernotify'            => 'Notificações do Jabber',
'jabberserver'            => 'Servidor',
'jabberport'              => 'Port',
'jabberuser'              => 'Nome de utilizador da conta',
'jabberpass'              => 'Password da conta',
'saveoptions'             => 'Guardar opções',
'editcomment'             => 'Editar Comentário',
'commentby'               => 'Comentário por',
'saveeditedcomment'       => 'Guardar comentário editado',
'projectprefs'            => 'Preferências do Projeto',
'pagetitle'               => 'Título da Página',
'defaultproject'          => 'Projeto Padrão',
'projectlists'            => 'Listas de Projeto',
'showlogo'                => 'Exibir a imagem do logo do título',
'showgravatars'		  => 'Mostrar Gravatars',
'emailNoHTML'             => 'não íncluir HTML nos E-Mails',
'intromessage'            => 'Mensagem introdutória',
'active'                  => 'ativo',
'inactive'                => 'inativo',
'isactive'                => 'Projeto está ativo',
'showinactive'            => 'Mostrar projetos inativos',
'hideinactive'            => 'Esconder projetos inativos',
'createproject'           => 'Criar um novo Projeto',
'nopermission'            => 'Não tem permissão para usar essa página.',
'listordertip'            => 'A ordem em que estes itens irão aparecer na lista',
'listshowtip'             => 'Exibir este item na lista',
'categoryownertip'        => 'Esta pessoa irá receber notificações quando uma tarefa nesta categoria abrir',
'categoryparenttip'       => 'Categoria pai a qual esta nova irá pertencer',
'notsubcategory'          => 'Nenhuma (categoria principal)',
'showinlineimages'        => 'Exibir imagens anexadas na mesma página',
'dateformat'              => 'Formato da Data',
'dateformat_extended'     => 'Formato da Data por extenso',
'cache_feeds'             => 'Cache de feeds',
'no_cache'                => 'Sem fazer cache',
'cache_disk'              => 'Cache no disco',
'cache_db'                => 'Cache na BD',
'subcategoryof'           => 'Subcategoria de',
'visiblecolumns'          => 'Colunas exibidas na lista de tarefas',
'visiblefields'           => 'Campos enquanto se adiciona/edita/vê uma tarefa',
'tense'                   => 'Tempo',
'listtensetip'            => 'Passado, Presente ou Futuro',
'past'                    => 'Passado',
'present'                 => 'Presente',
'future'                  => 'Futuro',
'oldpass'                 => 'Password antiga',
'nooldpass'               => 'Não foi definida uma password antiga',
'oldpasswrong'            => 'Passowrd antiga está errada',
'changepass'              => 'Alterar password',
'confirmpass'             => 'Confirmar password',
'projectmanager'          => 'Gerente do Projeto',
'viewtasks'               => 'Ver tarefas',
'modifyowntasks'          => 'Modificar suas tarefas',
'modifyalltasks'          => 'Modificar tarefas que não são do utilizador',
'viewcomments'            => 'Ver comentários',
'editcomments'            => 'Editar comentários',
'deletecomments'          => 'Apagar comentários',
'viewattachments'         => 'Ver anexos',
'createattachments'       => 'Criar anexos',
'deleteattachments'       => 'Apagar anexos',
'viewhistory'             => 'Ver histórico',
'closeowntasks'           => 'Fechar suas tarefas',
'closeothertasks'         => 'Fechar tarefas que não são do utilizador',
'assigntoself'            => 'Atribuir as tarefas a si caso ainda não tenham sido atribuidas',
'assignotherstoself'      => 'Atribuir outras tarefas a si',
'viewreports'             => 'Ver log de eventos',
'othersview'              => 'Permitir a qualquer um ver este projeto',
'othersviewroadmap'       => 'Permitir a qualquer um ver o roteiro deste projeto',
'usersandgroups'          => 'Utlizadores e Grupos',
'globalgroup'             => 'Grupo Global',
'globalgroups'            => 'Grupos Globais',
'defaultglobalgroup'      => 'Grupo global padrão para novos utilizadores',
'addtogroup'              => 'Adicionar ao grupo',
'moveuserstogroup'        => 'Mover utilizador para o grupo',
'nogroup'                 => 'Nenhum Grupo - Remover do projeto',
'eventdesc'               => 'Descrição do Evento',
'requestedby'             => 'Pedido por',
'daterequested'           => 'Data do Pedido',
'closetask'               => 'Fechar Tarefa',
'reopentask'              => 'Re-abrir Tarefa',
'applymember'             => 'Candidatar-se a membro do Projeto',
'forcurrentproj'          => 'Para o projeto atual',
'lostpw'                  => 'Recuperar password perdida',
'lostpwexplain'           => 'Escreva o seu nome de utilizador para receber um link para recuperação da password perdida. Será enviado para o endereço de notificação do seu perfil.',
'sendlink'                => 'Enviar link',
'savenewpass'             => 'Guardar nova password',
'anonreg'                 => 'Permitir registo de novos utilizadores',
'allowanonopentask'       => 'Permitir quem utilizadores anónimos abram novas tarefas',
'editglobalgroup'         => 'Editar Grupo Global',
'editgroupforproj'        => 'Editar grupo para o Projeto',
'notshownforadmin'        => 'Permissões não são exibidas para o grupo admin. Não precisa de as editar.',
'general'                 => 'Geral',
'userregistration'        => 'Registode utilizador',
'notifications'           => 'Notificações',
'resetoptions'            => 'Redefinir Opções',
'preferences'             => 'Preferências',
'tasktypes'               => 'Tipos de Tarefa',
'resolutions'             => 'Resoluções',
'categories'              => 'Categorias',
'operatingsystems'        => 'Sistemas Operativos',
'versions'                => 'Versões',
'admintoolboxlong'        => 'Ferramentas administrativas',
'newproject'              => 'Novo Projeto',
'delete'                  => 'Apagar',
'link'                    => 'Link',
'referencelinks'          => 'Links de referência:',
'listdeletetip'           => 'Apagar este item da lista',
'lookandfeel'             => 'Aparência',
'globaltheme'             => 'Tema Global',
'emailnotify'             => 'Notificações por Email',
'fromaddress'             => 'Endereço de origem',
'smtpserver'              => 'Servidor SMTP',
'smtpuser'                => 'Utilizador SMTP',
'smtppass'                => 'Password SMTP',
'addrewrite'              => 'Usar reescrita do endereço',
'usereminderdaemon'       => 'Ativar avisos',
'tasksperpage'            => 'Tarefas por página da lista de tarefas',
'addtoassignees'          => 'Atribuir-me',
'taskstatuses'            => 'Estados das Tarefas',
'canvote'                 => 'Pode votar',
'loginsuccessful'         => 'Ligado com sucesso.',
'youareloggedout'         => 'Foi desligado.',
'waitwhiletransfer'       => 'Por favor espere enquanto é transferido...',
'clicknowait'             => 'Clique aqui se não quiser esperar.',
'accountdisabled'         => 'Sua conta está desativada. Contate um administrador.',
'task'                    => 'Tarefa',
'edittask'                => 'Editar esta tarefa',
'openedby'                => 'Aberto por',
'editedby'                => 'Editado por',
'tasktype'                => 'Tipo de Tarefa',
'category'                => 'Categoria',
'status'                  => 'Estado',
'assignedto'              => 'Atribuido a',
'operatingsystem'         => 'Sistema Operativo',
'severity'                => 'Gravidade',
'reportedversion'         => 'Reportado na Versão',
'dueinversion'            => 'Conclusão esperada na versão',
'defaultdueinversion'     => 'Conclusão esperada por defeito para novas tarefas',
'undecided'               => 'Não decidido',
'percentcomplete'         => 'Percentagem Completa',
'details'                 => 'Detalhes',
'savedetails'             => 'Guardar Detalhes',
'canceledit'              => 'Cancelar Edição',
'anonymous'               => 'Envio Anónimo',
'complete'                => 'Completo',
'closedby'                => 'Fechado por',
'reasonforclosing'        => 'Motivo de fecho:',
'reopenthistask'          => 'Re-abrir esta tarefa',
'comments'                => 'Comentários',
'attachments'             => 'Anexos',
'relatedtasks'            => 'Tarefas Relacionadas',
'edit'                    => 'Editar',
'addcomment'              => 'Adicionar comentário',
'fileuploadedby'          => 'Arquivo enviado por',
'uploadafile'             => 'Anexar arquivo',
'addalink'                => 'Adicionar um link',
'addanotherlink'          => 'Adicionar outro link',
'uploadnow'               => 'Enviar agora!',
'thesearerelated'         => 'Estas tarefas estão relacionadas com esta tarefa',
'remove'                  => 'Remover',
'addnewrelated'           => 'Adicionar uma nova tarefa relacionada',
'add'                     => 'Adicionar!',
'otherrelated'            => 'Outras tarefas que estão relacionadas com esta',
'receivenotify'           => 'Estes utilizadores receberão informações detalhadas quando esta tarefa for alterada.',
'addusertolist'           => 'Adicionar utilizador a esta lista',
'addtolist'               => 'Adicionar à lista',
'addmyself'               => 'Adicionar-me à lista',
'removemyself'            => 'Remover-me da lista',
'theseusersnotify'        => 'Estes utilizadores receberão informações detalhadas quando esta tarefa for alterada.',
'attachedtoproject'       => 'Anexado ao Projeto',
'reminders'               => 'Avisos',
'system'                  => 'Sistema',
'systemvalues'            => 'Valores de todo o sistema',
'projectvalues'           => 'Valores específicos ao projeto',
'remindthisuser'          => 'Lembrar este utilizador',
'thisoften'               => 'Frequência',
'startafter'              => 'Esperar antes de iniciar os avisos',
'hour'                    => 'hora',
'hours'                   => 'horas',
'day'                     => 'dia',
'days'                    => 'dias',
'week'                    => 'semana',
'weeks'                   => 'semanas',
'addreminder'             => 'Adicionar Aviso',
'defaultreminder'         => 'Este é um aviso da seguinte tarefa do Flyspray:',
'message'                 => 'Mensagem',
'closed'                  => 'Fechado',
'filename'                => 'Nome do ficheiro:',
'date'                    => 'Data',
'filesize'                => 'Tamanho do ficheiro:',
'closurecomment'          => 'Comentários adicionais sobre o fecho:',
'history'                 => 'Histórico',
'nohistory'               => 'Sem histórico disponível.',
'eventdate'               => 'Data',
'user'                    => 'Utilizador',
'event'                   => 'Evento',
'fieldchanged'            => 'Campo foi modificado',
'taskopened'              => 'Tarefa aberta',
'taskreopened'            => 'Tarefa re-aberta',
'taskclosed'              => 'Tarefa fechada',
'commentadded'            => 'Comentário adicionado',
'commentedited'           => 'Comentário editado',
'commentdeleted'          => 'Comentário apagado',
'attachmentadded'         => 'Anexo adicionado',
'attachmentdeleted'       => 'Anexo apagado',
'taskedited'              => 'Detalhes da tarefa editados',
'notificationadded'       => 'Utilizador adicionado a lista de notificação',
'notificationdeleted'     => 'Utilizador removido da lista de notificação',
'relatedadded'            => 'Tarefa relacionada adicionada',
'relateddeleted'          => 'Tarefa relacionada removida',
'taskassigned'            => 'Tarefa atribuida a',
'taskreassigned'          => 'Tarefa reatribuida a',
'assignmentremoved'       => 'Atribuição removida',
'summary'                 => 'Resumo',
'addedasrelated'          => 'Tarefa adicionada à lista relacionada com',
'deletedasrelated'        => 'Tarefa removida da lista relacionada com',
'reminderadded'           => 'Aviso adicionado',
'reminderdeleted'         => 'Aviso removido',
'priority'                => 'Prioridade',
'previousvalue'           => 'Valor anterior',
'newvalue'                => 'Novo valor',
'selectareason'           => 'Selecionar um motivo',
'assigntome'              => 'Atribuir a mim',
'reopenrequest'           => 'Pedir re-abertura',
'requestclose'            => 'Pedir fecho',
'ownershiptaken'          => 'Utilizador apropriou-se',
'closerequestmade'        => 'Requisitado fecho da tarefa',
'reopenrequestmade'       => 'Requisitado re-abertura da tarefa',
'taskdependson'           => 'Esta tarefa depende de',
'taskdependsontask'       => 'Esta tarefa depende de',
'taskdependsontasks'      => 'Esta tarefa depende de',
'taskblock'               => 'Esta tarefa impede esta de fechar',
'taskblocks'              => 'Esta tarefa impede estas de fechar',
'depadded'                => 'Adicionada dependência',
'depaddedother'           => 'Esta tarefa foi adicionada como dependência de',
'depremoved'              => 'Dependência removida',
'depremovedother'         => 'Esta tarefa foi removida da lista de dependências de outra tarefa',
'showdetailserror'        => 'Esta tarefa não existe ou não tem permissão para vê-la.',
'makeprivate'             => 'tornar privado',
'makepublic'              => 'tornar publico',
'taskmadeprivate'         => 'Tarefa foi tornada privada',
'taskmadepublic'          => 'Privacidade removida - tarefa tornada pública',
'confirmdeletecomment'    => 'Quer mesmo apagar este comentário? %s',
'attachementswilldeleted' => 'Os ficheiros anexados também serão apagados!',
'confirmdeleteattach'     => 'Quer mesmo apagar este anexo?',
'selectedhistory'         => 'A exibir os detalhes do histórico selecionado',
'showallhistory'          => 'Exibir aba de histórico completo novamente',
'hidethis'                => 'Esconder novamente',
'mark100'                 => 'Marcar tarefa como 100% completa',
'watchtask'               => 'Seguir tarefa',
'stopwatching'            => 'Parar de seguir',
'commentlink'             => 'Link para este comentário',
'submitreq'               => 'Enviar pedido',
'reasonforreq'            => 'Motivo para o pedido',
'pmreqdenied'             => 'Pedido de Gerência de Projeto negado',
'taskpendingreq'          => 'Ação pendente ao Gerente de Projeto.  Veja a aba Histórico para detalhes.',
'previoustask'            => 'Tarefa Anterior',
'nexttask'                => 'Próxima tarefa',
'duedate'                 => 'Prazo limite',
'attachnoperms'           => 'Há anexos com este comentário, mas não tem permissão para vê-los.',
'linknoperms'             => 'Há links neste comentário mas não tem permissões para os ver.',
'open'                    => 'Abrir',
'depgraph'                => 'Ver gráfico de Dependência',
'reset'                   => 'Desfazer',
'selectusers'             => 'Selecionar utilizadores...',
'addmetoassignees'        => 'Adicionar-me à lista de atribuidos',
'addedtoassignees'        => 'utilizador adicionado à lista de atribuidos',
'dependencygraph'         => 'Gráfico de Dependência',
'attachanotherfile'       => 'Anexar outro ficheiro',
'OK'                      => 'OK',
'addvote'                 => 'Adicionar Voto',
'disable_lostpw'          => 'Desativar recuperação da password',
'disable_changepw'        => 'Desativar criar/modificar password',
'notifyfromfs'            => 'Notificação do Flyspray',
'autogenerated'           => 'ESTA É UMA MENSAGEM AUTOMÁTICA, NÃO RESPONDA',
'forward'                 => 'Reencaminhar',
'previous'                => 'Anterior',
'next'                    => 'Próximo',
'first'                   => 'Primeiro',
'last'                    => 'Último',
'page'                    => 'Página %d de %d',
'search'                  => 'Procurar',
'alltasktypes'            => 'Todos os tipos de tarefas',
'allseverities'           => 'Todas as Gravidades',
'alldevelopers'           => 'Todos Developers',
'notyetassigned'          => 'Ainda não atribuido',
'allcategories'           => 'Todas Categorias',
'allstatuses'             => 'Todos Estados',
'allopentasks'            => 'Todas as tarefas abertas',
'sortthiscolumn'          => 'Ordenar por esta coluna',
'id'                      => 'ID',
'project'                 => 'Projeto',
'dateopened'              => 'Aberto',
'progress'                => 'Progresso',
'searchthisproject'       => 'Pesquisar no projeto por',
'dueanyversion'           => 'Terminar em qualquer Versão',
'anyversion'              => 'Reportado em qualquer Versão',
'dueversion'              => 'Terminar na Versão',
'lastedit'                => 'Última Edição',
'os'                      => 'Sistema Operativo',
'reportedin'              => 'Reportado Em',
'taskrange'               => 'Exibindo tarefas %d - %d de %d',
'noresults'               => 'Sua pesquisa não retornou resultados.',
'takeaction'              => 'Agir',
'watchtasks'              => 'Acompanhar as tarefas selecionadas',
'stopwatchingtasks'       => 'Parar de acompanhar as tarefas selecionadas',
'assigntaskstome'         => 'Atribuir a tarefa selecionada para mim',
'dueby'                   => 'Terminado por',
'dueanytime'              => 'Terminado qualquer hora',
'selectduedate'           => 'Seleciona Data de Término',
'toggleselected'          => 'Selecionar',
'due'                     => 'Terminado',
'assignedtome'            => 'Atribuido a mim',
'tasklist'                => 'Lista de tarefas',
'dateclosed'              => 'Fechado Data',
'advanced'                => 'Avançado',
'searchcomments'          => 'Procurar nos comentários',
'searchforall'            => 'Procurar por todas palavras',
'anonusers'               => 'Utilizadores anónimos',
'miscellaneous'           => 'Variados',
'users'                   => 'Utilizadores',
'taskproperties'          => 'Propriedades da Tarefa',
'selectsincedate'         => 'Selecionar Alterado desde',
'changedsince'            => 'Alterado desde',
'updatefs'                => 'Por favor atualize o Flyspray.',
'currentversion'          => 'Sua versão atual é',
'latestversion'           => 'e a última versão é',
'hidemessage'             => '(lembrar mais tarde)',
'saveas'                  => 'Guardar pesquisa como',
'nosearches'              => 'Sem pesquisas guardadas',
'saving'                   => 'A guardar...',
'votes'                   => 'Votos',
'tovote'                  => 'Votar',
'allclosedtasks'          => 'Todas as Tarefas Fechadas',
'password'                => 'Password',
'login'                   => 'Conectar-se!',
'rememberme'              => 'Lembrar-me',
'lostpassword'            => 'Esqueceu a password?',
'lostpwforfs'             => 'Senha esquecida para o Flyspray',
'lostpwmsg1'              => 'Olá.

Eu perdi minha senha do Flyspray em ',
'lostpwmsg2'              => ', por favor envie-me uma nova password.

utilizador: ',
'regards'                 => '

Atenciosamente,',
'yourusername'            => ' seu nome de utilizador ',
'locale'                  => 'pt-PT',
'filenotexist'            => 'Ficheiro não existe, ou não tem permissão para o ver.',
'showtask'                => 'Exibir Tarefa',
'now'                     => 'Agora',
'go'                      => 'Vai!',
'opentaskanon'            => 'Abrir uma nova Tarefa anonimamente',
'register'                => 'Registar',
'addnewtask'              => 'Adicionar nova tarefa',
'reports'                 => 'Log de Eventos',
'editmydetails'           => 'Editar meus detalhes',
'logout'                  => 'Sair',
'disabledaccount'         => 'Sua conta foi desativada!<br>A desligar...',
'poweredby'               => 'Powered by Flyspray',
'sponsoredby'             => 'Flyspray é orgulhosamente patrocinado por',
'projects'                => 'Projetos',
'allprojects'             => 'Todos Projetos',
'selectproject'           => 'para Projeto:',
'tasksall'                => 'Todas as tarefas',
'tasksassigned'           => 'Tarefas atribuidas a mim',
'tasksreported'           => 'Tarefas reportadas a mim',
'taskswatched'            => 'Tarefas acompanhadas',
'mysearch'                => 'Minhas Procuras',
'admintoolbox'            => 'Opções administrativas',
'manageproject'           => 'Gerir Projeto',
'permissions'             => 'Ver Permissões',
'hide'                    => 'Esconder',
'pendingreq'              => 'Pedidos em espera',
'errorpage'               => 'Erro a tentar aceder à página.
                                 Talvez tenha pedido uma tarefa que não existe,
                                 ou não tem permissão para ver esta página.<br /><br />
                                 Pode estar a tentar usar um URL inválido
                                 ou a fazer o que não devia.',

'permissionsforproject'   => 'Permissiões para ',
'switchto'                => 'Alternar para',
'lastsearch'              => 'Ultima Procura',
'modify'                  => 'Alterar',
'noticefrom'              => 'Notificação de',
'hasopened'               => 'ABRIU uma tarefa NOVA e esta foi atribuída a si:',
'moreinfonew'             => 'Pode encontrar mais informações na página do FlySpray:',
'newtaskcategory'         => 'Uma nova Tarefa do FlySpray foi aberta nesta categoria',
'categoryowner'           => 'Recebeu esta mensagem porque está listado como dono da categoria.',
'tasksummary'             => 'Descrição da tarefa:',
'newtaskadded'            => 'Sua nova Tarefa foi adicionada.',
'summaryanddetails'       => 'Precisa de preencher a descrição e os detalhes.',
'summaryrequired'         => 'Precisa de preencher uma pequena descrição da tarefa.',
'goback'                  => 'Voltar.',
'messagefrom'             => 'Esta é uma mensagem do sistema de bug tracking FlySpray',
'hasjustmodified'         => 'modificou a seguinte Tarefa.',
'changedfields'           => 'campos alterados estão precedidos por asteriscos (**)',
'moreinfomodify'          => 'Mais informações sobre esta Tarefa no URL:',
'nolongerassigned'        => 'A seguinte Tarefa não está mais atribuida a si.  Ela agora está atribuida a',
'hasassigned'             => 'Atribuiu a si a seguinte Tarefa do FlySpray:',
'taskupdated'             => 'Tarefa atualizada.',
'tasksupdated'            => 'Tarefas atualizadas.',
'hasclosedassigned'       => 'fechou a seguinte tarefa Flyspray que foi atribuida a si:',
'unassigned'              => 'não atribuida',
'hasclosed'               => 'fechou a seguinte tarefa.',
'youonnotify'             => 'Recebeu isto porque está na lista de notificação.',
'taskclosedmsg'           => 'Tarefa foi fechada.',
'returntotask'            => 'Voltar para detalhes da tarefa',
'backtoindex'             => 'Voltar para a lista de tarefas',
'noclosereason'           => 'Não selecionou nenhum motivo para fechar esta tarefa.',
'hasreopened'             => 'reabriu a seguinte tarefa do Notes que fechou:',
'taskreopenedmsg'         => 'Tarefa foi reaberta.',
'backtotask'              => 'Voltar para a tarefa.',
'commentaddedmsg'         => 'O comentario foi adicionado.',
'commenttoassigned'       => 'adicionou um comentário a uma tarefa que foi atribuído:',
'commenttotask'           => 'adicionou o seguinte comentário a esta tarefa.',
'nocommententered'        => 'Deve inserir um comentário antes de clicar a tecla enviar.',
'fillinfields'            => 'Não preencheu todos os campos.',
'notcurrentpass'          => 'Esta não é sua password atual!',
'passchanged'             => 'Sua senha foi alterada.',
'closewindow'             => 'Agora já pode fechar esta janela.',
'passnomatch'             => 'As suas novas passwords não eram as mesmas!',
'usernametaken'           => 'Este utilizador já está registadoo. Precisa de escolher outro nome para acesso.',
'usernametakenbulk'       => 'Nome de Utilizador já utilizado',
'newusercreated'          => 'Foi criada uma nova conta de utilizador.',
'accountcreated'          => 'Sua conta foi criada.',
'newuserwarning'          => 'Algumas funções são desabilitadas para utilizadores comuns e as mesmas, requerem que seu utilizador seja aprovado por um dos administradores. Se não puder iníciar uma sessão, provavelmente é por que ainda não possui estes direitos de acesso dados por um dos administradores.',
'nomatchpass'             => 'As passwords não combinam.',
'confirmwrong'            => 'Código de confirmação está incorreto!',
'formnotcomplete'         => 'O formulário não foi preenchido completamente.',
'formnotnumeric'          => 'O dado inserido não é numérico!',
'groupnametaken'          => 'O Nome do grupo já está em uso.',
'newgroupadded'           => 'Novo grupo adicionado.',
'optionssaved'            => 'Opções do Flyspray guardadas.',
'hasuploaded'             => 'enviou um ficheiro em anexo a uma tarefa que lhe foi atribuída:',
'hasattached'             => 'enviou um ficheiro à seguinte tarefa.',
'fileuploaded'            => 'Ficheiro foi carregado.',
'fileerror'               => 'Houve um erro no carregamento do ficheiro.  Talvez as permissões na pasta <i>attachments/</i> estão incorrectas.',
'contactadmin'            => 'Contacte o Administrador deste projeto.',
'selectfileerror'         => 'Não selecionou um ficheiro e/ou não incorporou uma descrição.',
'userupdated'             => 'Detalhes do utilizador foram atualizados',
'realandemail'            => 'Não preencheu os campos do Nome Real e do Endereço de Email.',
'groupupdated'            => 'Definição de grupo atualizada.',
'groupanddesc'            => 'Não preencheu os campos de nome e de descrição de grupo.',
'fillallfields'           => 'Preencha todos os campos.',
'listPmustN'              => 'O campo "Ordem" deve ser numérico.',
'listupdated'             => 'A lista foi atualizada.',
'listitemadded'           => 'O artigo novo da lista adicionou.',
'relatedaddedmsg'         => 'Tarefa relacionada adicionada à lista.',
'relatederror'            => 'Esse utilizador está já na lista da notificação para essa tarefa.',
'relatedremoved'          => 'Tarefa relacionada removida da lista.',
'notifyadded'             => 'utilizador adicionado para lista de notificações.',
'notifyerror'             => 'Este utilizador está já na lista da notificação para essa tarefa.',
'notifyremoved'           => 'utilizador removido da lista de notificação.',
'editcommentsaved'        => 'O comentário foi guardado e atualizado.',
'commentdeletedmsg'       => 'O comentário foi apagado.',
'gotonewtask'             => 'Ir para a nova tarefa que acabou de criar',
'projectcreated'          => 'nosso novo Projeto foi criado. Siga o link abaixo para configurar categoria, sistema operativo e listas de versões.',
'customiseproject'        => 'Customisar este projeto',
'projectupdated'          => 'Preferências do projeto atualizadas',
'emptytitle'              => 'VDeixou em branco o campo do título do projeto. Volte e adicione um título para este projeto.',
'loginbelow'              => 'Seu registo foi concluido com sucesso. Agora, já pode aceder o site usando o formulário abaixo.',
'attachmentdeletedmsg'    => 'O ficheiro foi excluído',
'reminderaddedmsg'        => 'Seu aviso foi adicionado.',
'reminderdeletedmsg'      => 'O aviso selecionado foi apagado.',
'flyspraytask'            => 'Tarefa do Flyspray',
'fieldsmissing'           => 'Alguns campos estão vazios ou possuem dados inválidos.',
'relatedinvalid'          => 'Esta tarefa não existe.',
'relatedproject'          => 'Esta tarefa pertence a outro projeto. Relacioná-las mesmo assim?',
'addanyway'               => 'Adicionar de qualquer jeito',
'cancel'                  => 'Cancelar',
'alreadyedited'           => 'Esta tarefa foi editada por outra pessoa antes de a tentar guardar. Deseja sobreescrever as alterações?',
'saveanyway'              => 'Guardar minhas alterações mesmo assim',
'nouserselected'          => 'Nenhum utilizador selecionado.  Selecione pelo menos um utilizador antes de tentar novamente.',
'groupswitchupdated'      => 'Grupos de utilizadores alterados com sucesso.',
'takenownershipmsg'       => 'Esta tarefa está agora atribuida a si.',
'adminrequestmade'        => 'Seu pedido foi enviado para um Gerente de Projeto.',
'newdepnotify'            => 'Uma nova dependência foi adicionada à seguinte tarefa:',
'dependadded'             => 'Dependência entre tarefas adicionada.',
'dependaddfailed'         => 'Ocorreu um erro ao tentar adicionar a dependência. Verifique se a tarefa existe e não há bloqueio mútuo.',
'depremovedmsg'           => 'Dependência entre tarefas removida',
'newdepis'                => 'A nova dependência é',
'magicurlsent'            => 'Uma mensagem foi enviada para seu endereço de notificação.  Ela contém um link que o levará à pagina que completa esta tarefa.',
'changefspass'            => 'Alterar password do Flyspray',
'magicurlmessage'         => 'Por favor abra o seguinte link para alterar a sua password do Flyspray:',
'erroronform'             => 'Ocorreu um problema com o envio do seu formulário',
'addressused'             => 'Este endereço foi usado para registo numa conta no Flyspray.  Se não esperava esta mensagem, por favor ignore e apague.  Vá para o seguinte endereço para completar seu registo:',
'confirmcodeis'           => 'Seu código de confirmação é:',
'codesent'                => 'Seu código de confirmação foi enviado.  Por favor siga as instruções na mensagem.',
'codenotsent'             => 'Não foi possível enviar seu código, por favor tente novamente',
'taskmadeprivatemsg'      => 'Esta tarefa tornou-se privada',
'taskmadepublicmsg'       => 'Esta tarefa tornou-se publica novamente',
'realandnotify'           => 'Precisa de preencher seu nome verdadeiro, e o endereço de E-mail ou seu Jabber ID.',
'pmreqdeniedmsg'          => 'Gerência de Projeto negada',
'massopsuccess'           => 'Operações executadas com sucesso - onde havia permissão',
'usernotexist'            => 'Este utilizador não existe neste Flyspray',
'commentattachperms'      => 'Não pode apagar este comentário - sem permissão para apagar anexos',
'voterecorded'            => 'Seu voto foi registado',
'votefailed'              => 'Seu voto não pode ser registado neste momento.',
'createnewgroup'          => 'Criar novo grupo',
'requiredfields'          => 'Todos os campos assinalados são requeridos',
'addthisgroup'            => 'Adicionar ao grupo',
'createnewproject'        => 'Criar um projeto novo',
'addnewproject'           => 'Adicionar um novo projeto',
'htmlallowed'             => 'Código do HTML é reservado',
'createthisproject'       => 'Criar este projeto',
'inlineimages'            => 'Mostrar as imagens em anexo na mesma janela',
'createnewtask'           => 'Criar uma nova tarefa no projeto:',
'addanother'              => 'Adicionar outra tarefa depois desta',
'addthistask'             => 'Adicionar esta tarefa',
'notifyme'                => 'Notificar-me sempre que esta tarefa mudar',
'newtask'                 => 'Nova Tarefa',
'attachafile'             => 'Anexar arquivo',
'registernewuser'         => 'Registar novo utilizador',
'none'                    => 'Nenhum',
'registeraccount'         => 'Registar esta conta',
'registerbulkaccount'     => 'Registar contas',
'both'                    => 'Ambos',
'notifyfrom'              => 'Notificação de ',
'donotreply'              => 'ESTA é UMA MENSAGEM AUTOMáTICA, NãO RESPONDA.',
'disclaimer'              => 'Está recebendo esta mensagem porque o pediu do Sistema de Bugtracking Flyspray.  Se não esperava esta mensagem ou não quer receber e-mails no futuro, pode alterar suas definições de notificação no URL abaixo.',
'userwho'                 => 'utilizador que fez isso',
'moreinfo'                => 'Mais informações podem ser encontradas no seguinte URL:',
'newtaskopened'           => 'Uma nova tarefa do Flyspray foi aberta.  Detalhes abaixo.',
'notify.taskclosed'       => 'A seguinte tarefa foi fechada:',
'notify.taskreopened'     => 'A seguinte tarefa foi re-aberta:',
'newdep'                  => 'A seguinte tarefa tem uma nova dependência:',
'notify.depremoved'       => 'A seguinte tarefa teve uma dependência removida:',
'olddepwas'               => 'A antiga dependência era',
'notify.commentadded'     => 'A seguinte tarefa tem um novo comentário:',
'commentis'               => 'O comentário está abaixo.',
'newattachment'           => 'Um novo ficheiro foi anexado para a seguinte tarefa:',
'detailsbelow'            => 'Os detalhes estão abaixo.',
'notify.relatedadded'     => 'Uma nova relação entre tarefas foi adicionada a seguinte tarefa:',
'relatedis'               => 'A tarefa relacionada é',
'assignedtoyou'           => 'A seguinte tarefa foi atribuida a si:',
'takenownership'          => 'foi designado para a seguinte tarefa:',
'requiresaction'          => 'A seguinte tarefa precisa da moderação do Gerente de Projeto:',
'requiresactionnotify'    => 'A tarefa precisa ser moderada por um Gerente de Projeto',
'pmdeny'                  => 'Um Gerente de Projeto negou o pedido pendente para a seguinte tarefa:',
'pmdenynotify'            => 'Um Gerente de Projeto negou o pedido',
'fileaddedtoo'            => 'Há um ou mais ficheiros anexados a este comentário.',
'taskwatching'            => 'A seguinte tarefa que estava acompanhando',
'isdepfor'                => 'é uma nova dependência para',
'denialreason'            => 'Motivo da negação',
'taskchanged'             => 'A seguinte tarefa foi alterada.  As alterações estão listadas abaixo.  Para ver sobre tudo que foi alterado, visite o seguinte URL e clique na aba Histórico.',
'useraddedtoassignees'    => 'Um utilizador adicionou-se à lista de utilizadores atribuidos para esta tarefa.',
'removeddepis'            => 'A dependência removida foi',
'isnodepfor'              => 'não há mais dependência para',
'usergroups'              => 'Grupos de utilizador',
'pmtoolbox'               => 'Ferramentas do Gerente de Projeto',
'groupmanage'             => 'Gerir os Grupos',
'pendingrequests'         => 'Pedidos Pendentes',
'reasongiven'             => 'Motivos dadas',
'nopendingreq'            => 'Não há pedidos pendentes para Gestores de Projeto.',
'givereason'              => 'Dê uma motivo',
'catlisted'               => 'Editor da Lista de Categorias',
'oslisted'                => 'Editor da Lista de Sistemas Operativos',
'verlisted'               => 'Editor da Lista de Versões',
'tasktypeed'              => 'Editor da Lista de Tipos de Tarefa',
'resed'                   => 'Editor da Lista de Resoluções',
'deny'                    => 'Negar',
'notifiedwhen'            => 'Notificar quando',
'onlynewtasks'            => 'Novas tarefas estão abertas',
'allevents'               => 'Qualquer evento ocorrido em qualquer tarefa',
'feeds'                   => 'Feeds',
'feeddescription'         => 'Descrição de Feed',
'feedimgurl'              => 'Imagem do URL do Feed (deixe em branco para nenhuma imagem)',
'notifysubject'           => 'Assunto para notificações',
'notifysubjectinfo'       => '(%p = título do projeto, %s = resumo da tarefa, %t = id da tarefa, %a = ação, %u = Nome de Utilizador)',
'priority6'               => 'Altíssima',
'priority5'               => 'Imediatamente',
'priority4'               => 'Urgente',
'priority3'               => 'Alta',
'priority2'               => 'Normal',
'priority1'               => 'Baixa',
'sendcode'                => 'Envie o código!',
'entercode'               => 'Digite o código de confirmação que recebeu na mensagem de notificação. Também digite a password que deseja.',
'confirmationcode'        => 'Código de confirmação',
'registererror'           => 'Certifique-se de que preencheu todos os campos obrigatórios e de que specificou os detalhes corretos para o tipo de notificação desejada.',
'validusername'           => '(apenas caracteres alfanuméricos e - _ . são permitidos)',
'validemail'              => '(use ; para separar vários endereços de email)',
'emailtakenbulk'          => 'Endereço de Email já foi utilizado',
'emailtaken'              => 'O email ou ID Jabber já estão em uso. Terá que escolher um outro.',
'note'                    => '<strong>Nota:</strong>  Receberá um código de confirmação antes da criação da sua conta. O código será enviado através do seu método de notificação especificado acima. <br />Se fornecer dados falso, <strong>não receberá o seu código</strong>.',
'changelog'               => 'Registo de mudanças',
'changeloggen'            => 'Gerador de registo de mudanças',
'listfrom'                => 'Listar registo de mudanças de',
'to'                      => 'para',
'oldestfirst'             => 'Mais antigos antes',
'recentfirst'             => 'Mais novos antes',
'severityrep'             => 'Relatório de gravidade',
'totalopen'               => 'Total de tarefas a realizar',
'age'                     => 'Idade',
'agerep'                  => 'Relatório de idade',
'eventsrep'               => 'Relatório de eventos',
'events'                  => 'Eventos',
'Tasks'                   => 'Tarefas',
'opened'                  => 'Aberto',
'edited'                  => 'Modificado',
'assigned'                => 'Atribuído',
'within'                  => 'Dentro de',
'pastday'                 => 'Ontem',
'pastweek'                => 'Semana passada',
'pastmonth'               => 'Mês passado',
'pastyear'                => 'Ano passado',
'nolimit'                 => 'Sem limite',
'from'                    => 'Início',
'duein'                   => 'Término',
'selectfromdate'          => 'Selecione a data de início',
'selecttodate'            => 'Selecione a data de término',
'showvoters'              => 'Mostrar/esconder votantes',
'roadmap'                 => 'Plano de execução',
'roadmapfor'              => 'Plano de execução para a versão',
'tasks'                   => 'tarefas',
'completed'               => 'completas.',
'opentasks'               => 'tarefas em aberto',
'of'                      => '% de',
'severity5'               => 'Crítica',
'severity4'               => 'Alta',
'severity3'               => 'Média',
'severity2'               => 'Baixa',
'severity1'               => 'Muito baixa',
'Redirect'                => 'Redirecionar',
'redirectmsg'             => 'Se o seu browser não suporta redirecionamento, clique %sAQUI%s para ser redirecionado.',
'allowclosedcomments'     => 'Permitir comentários em tarefas já executadas',
'comment'                 => 'Comentar',
'editowncomments'         => 'Editar os seus comentários',
'reopened'                => 'Reabertos',
'loading'                 => 'A caregar...',
'notifyown'               => 'Notificar sobre as suas modificações',
'youremail'               => 'O seu email',
'thankyouforbug'          => 'Obrigado por reportar o seu problema. Pode ver a tarefa e observer o seu progresso a qualquer hora através do seguinte URL:',
'anonuser'                => 'utilizador anónimo',
'conflict'                => 'Conflito',
'file'                    => 'Ficheiro',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Tamanho',
'projectgroup'            => 'Grupo do projeto',
'profile'                 => 'Perfil:',
'viewprofile'             => 'Ver perfil',
'regdate'                 => 'Registado desde',
'tasksopened'             => 'Tarefas em aberto',
'replyto'                 => 'Responder para',
'notifytypes'             => 'Tipos de notificação',
'pm.taskchanged'          => 'Tarefa modificada',
'pm.taskreopened'         => 'Tarefa reaberta',
'pm.depadded'             => 'Dependência adicionada',
'pm.depremoved'           => 'Dependência removida',
'pmrequest'               => 'Requisição de Gestão do Projeto',
'pmrequestdenied'         => 'Requisição de Gestão de Projeto negada',
'newassignee'             => 'Nova atribuição',
'revdepadded'             => 'Dependência reversa adicionada',
'revdepaddedremoved'      => 'Dependência reversa removida',
'assigneeadded'           => 'Atribuição adicionada',
'addusergroup'            => 'Adicionar utilizador a este grupo',
'groupmembers'            => 'Membros do grupo',
'deleteuser'              => 'Apagar este utilizador',
'userdeleted'             => 'utilizador apagado',
'autoassign'              => 'Auto atribuir uma tarefa ao dono da categoria',
'ssl'                     => 'SSL',
'updatewrong'             => 'Tem a verificação de atualizações habilitada, mas um erro ocorreu ao tentar
                             acessar o servidor de atualizações, ou o seu host não permite acesso a conexões externas,
                             ou o erro foi causado por uma falha na rede.
                             Por gentileza, visite o site do FlySpray para assegurar-se de que está utilizando a última versão.',
'deleteproject'           => 'Apagar este projeto e mover seus dados para',
'projectdeleted'          => 'Projeto apagado com sucesso',
'feedforall'              => 'Fornecido para todos os projetos',
'usercreated'             => 'Utilizador criado',
'userdeleted'             => 'Utilizador apagado',
'created'                 => 'Criado',
'deleted'                 => 'Apagado',
'userid'                  => 'Identificador do utilizador',
'editassignments'         => 'Editar atribuições',
'preview'                 => 'Pré-visualizar',
'anyprogress'             => 'Qualquer progresso',
'tasksrelated'            => 'Tarefas relacionadas a esta',
'duplicatetasks'          => 'Tarefas duplicadas desta',
'databasemodfailed'       => 'A modificação na base de dados falhou. Uma das possíveis razões é falta de permissões.',
'frequency'               => 'Frequência',
'newuserregistered'       => 'Um novo utilizador se registou na instalação do FlySpray. O detalhes do utilizador são os seguintes:',
'newuserregisterednotify' => 'Um novo utilizador se registou',
'notify_registration'     => 'Notificar administradores sobre o registo de novos utilizadores',
'textversion'             => 'Versão texto',
'onlyprimary'             => 'Tarefas não bloqueiam outras tarefas',
'onlyblocker'             => 'Tarefas bloqueando outras tarefas',
'blockerornoblocker'      => 'Tarefas que bloqueiam ou não bloqueiam, não faz sentido selecionar ambas opções',
'switch'                  => 'Trocar',
'max'                     => 'máx.',
'dates'                   => 'Datas',
'selectduedatefrom'       => 'Terminam a partir de',
'selectduedateto'         => 'até',
'selectsincedatefrom'     => 'Modificadas a partir de',
'selectsincedateto'       => 'até',
'selectdate'              => 'Selecione a data',
'selectopenedfrom'        => 'Abertas a partir de',
'selectopenedto'          => 'até',
'selectclosedfrom'        => 'Fechadas a partir de',
'selectclosedto'          => 'até',
'startat'                 => 'Inicia-se em',
'hasattachment'           => 'Possui anexo',
'private'                 => 'Privada',
'watching'                => 'Acompanhando',
'alreadyvotedthistask'    => 'votou para esta tarefa',
'alreadyvotedthisday'     => 'já votada hoje',
'visibility'              => 'Visibilidade',
'public'                  => 'Pública',
'leaveemptyauto'          => 'Deixe os campos de senha em branco se desejar que a senha seja gerada automaticamente.',
'novalidemail'            => 'Não forneceu um email válido.',
'novalidjabber'           => 'Não forneceu um endereço Jabber válido.',
'missingrequired'         => 'Não preencheu todos os campos obrigatórios.',
'entervalidusername'      => 'Por gentileza, especifique um utilizador válido com um nome real.',
'couldnotaddusernotif'    => 'Não foi possível adicionar este utilizador à lista de notificações.',
'defaulttask'             => 'Descrição de tarefa padrão',
'all'                     => 'todas',
'events.useraddedtoassignees' => 'utilizador adicionado aos atribuidos',
'eventlog'                => 'Histórico de eventos',
'assignmentchanged'       => 'Atribuição modificada',
'detailedinfo'            => 'Informações detalhadas',
'All'                     => 'Todas',
'tasksireported'          => 'Tarefas que reportou',
'recentlyopened'          => 'Abertas recentemente',
'stats'                   => 'Estatísticas',
'totaltasks'              => 'total de tarefas',
'mostwanted'              => 'Tarefas mais requisitadas',
'defaultentry'            => 'Página de entrada padrão',
'toplevel'                => 'Visão do nível mais alto',
'overview'                => 'Resumo',
'error#'                  => 'Erro #',
'error1'                  => 'Não possui permissões suficientes para visualizar este anexo.',
'error3'                  => 'Ação repetida, redirecionando para a página principal.',
'error4'                  => 'Não possui privilégios administrativos.',
'error5'                  => 'O utilizador não existe nesta instalação do FlySpray.',
'error6'                  => 'área de administração inválida.',
'error7'                  => 'Autenticação falhou (Nome de utilizador ou senha incorreto)!',
'error71'                 => 'Conta travada por %d minutos devido a muitas tentativas de login!',
'error8'                  => 'Não especificou o seu nome de utilizador e sua senha.',
'error9'                  => 'A tarefa não existe ou não tem permissão para ver esta tarefa.',
'error10'                 => 'A tarefa não existe ou não tem permissão para ver esta tarefa.',
'error101'                => 'Não tem permissão para ver esta tarefa.',
'error102'                => 'Não tem permissão para ver esta tarefa, autenticar-se pode ajudar.',
'error11'                 => 'Sem permissões para editar este documento.',
'error12'                 => 'Sem chave mágica! Tem a certeza que recebeu a mensagem de notificação?',
'error13'                 => 'Utilizadores anónimos não possuem perfil',
'error14'                 => 'Não possui permissões suficientes para criar um grupo novo.',
'error15'                 => 'Não possui permissões para criar uma tarefa.',
'error16'                 => 'Não é um administrador de projeto.',
'error17'                 => 'Inválido, área de PM.',
'error18'                 => 'URL inválido.',
'error19'                 => 'O utilizador não existe nesta instalação do FlySpray.',
'error20'                 => 'Modificação na base de dados inválida.',
'error21'                 => 'Um ou mais emails não puderam ser enviados. Verifique a sua configuração.',
'error22'                 => 'Não é permitida a criação de novos utilizadores.',
'error23'                 => 'utilizador ou grupo não habilitados para autenticar-se.',
'error24'                 => 'Nem o ponto executável, nem um ponto público foi definido.',
'error25'                 => 'Plano de execução disponível apenas para um projeto específico.',
'error26'                 => 'Fornecedor de "oauth" não suportado.',
'error27'                 => 'Impossível fazer login. Autorize-nos a ver o seu email.',
'error28'                 => 'Não tem permissões para aceder a esta área.',
'done'                    => 'feito',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projeto não pode ser apagado.',
'GMT'                     => 'GMT',
'timezone'                => 'Fuso horário',
'accept'                  => 'Aceitar',
'reasonfordeinal'         => 'Motivo para recusar',
'pruneclosedlinks'        => 'Remover links fechados',
'pruneclosedtasks'        => 'Remover tarefas concluídas',
'pagegenerated'           => 'Página e imagem geradas em %d segundos.',
'pruninglevel'            => 'Nível de ramificação',
'lastuser'                => 'O último utilizador não pode ser apagado.',
'allprivate'              => 'Todos os projetos são privados.',
'deletegroup'             => 'Apagar este grupo e mover usuários para',
'parent'                  => 'Pai',
'ordertip'                => 'A ordem em que estes itens irão aparecer na lista',
'showtip'                 => 'Mostrar este item na lista',
'deletetip'               => 'Apagar este item da lista',
'del'                     => 'apagar',
'request1'                => 'O fecho de uma tarefa foi solicitado.',
'request2'                => 'Um pedido para reabertura da tarefa foi feito.',
'allpriorities'           => 'Todas Prioridades',
'noroadmap'               => 'Não há um roadmap disponível (não existem versões "futuras" específicas do projeto).',
'expand'                  => 'Expandir',
'collapse'                => 'Recolher',
'expandall'               => 'Expandir Tudo',
'collapseall'             => 'Recolher Tudo',
'minpwsize'               => 'O tamanho mínimo para a password é de 5 caracteres',
'passwordtoosmall'        => 'O tamanho da password é muito pequeno.',
'accountwaslocked'        => 'Sua conta foi bloqueada devido a muitas tentativas sem sucesso de entrar.',
'failedattempts'          => 'Foram %d tentativas de entrar sem sucesso.',
'groupnotexist'           => 'Grupo selecionado não existe neste projeto.',
'searchindetails'         => 'Detalhes da Procura',
'showasassignees'         => 'Exibir como atribuido',
'find'                    => 'Encontrar',
'tls'                     => 'TLS',
'isadmin'                 => 'É administrador',
'addvotes'                => 'Adiciona votos',
'removevote'              => 'Remove voto',
'voteremoved'             => 'O seu voto foi removido',
'voteremovefailed'        => 'O seu voto não pode ser removido neste momento.',
'novotes'                 => 'Não há votações.',
'connectedtasks'          => 'Tarefas relacionadas:',
'taskdependencies'        => 'Dependências',
'viewgraph'               => 'ver gráfico',
'notaskdependencies'      => 'Esta tarefa não depende de outras.',
'dependson'               => 'Depende de',
'blocks'                  => 'Bloqueia',
'newdependency'           => 'Nova dependência:',
'nouserstoadd'            => 'Não há utilizadores para adicionar. Por favor confirme que o Nome, o Nome de Utilizador e o Email estão definidos para cada utilizador.',
'dispintro'               => 'Mostrar mensagem introdutória',
'mainmessage'             => 'Mensagem introdutória principal',
/* note only the English version for 'dispintro' is supported
 * other languages should also be taken cared of in the future*/

'setsupertask'            => 'Mudar ID da Super-Tarefa:',
'supertaskmodified'       => 'ID da Super-Tarefa foi modificado',
'set'                     => 'Modificar',
'supertask'               => 'Super-Tarefa',
'setparent'               => 'Modificar o id da tarefa mãe desta tarefa',
'selfsupertasknotallowed' => 'ID da Super-Tarefa não pode ser igual ao ID da própria tarefa',
'quickaction'             => 'Acções rápidas',
'updateselectedtasks'     => 'Atualizar tarefas selecionadas',
'notspecified'            => 'Não especificado',
'editselectedtasks'       => 'Editar tarefas selecionadas',
'information'             => 'Informação',
'taskclosedisabled'       => 'Não é possível fechar Tarefa pois ainda existem tarefas abertas que dependem desta:-',
'daysleft'                => 'dias que faltam',
'dayoverdue'              => 'dias de atraso',
'duetoday'                => 'Prazo termina hoje.',
'daysbeforealert'         => 'Dias antes do alerta',
'associatedsubtask'       => 'Associada com sucesso à subtarefa #FS',
'associatesubtask'        => 'Associar ID da sub tarefa com esta tarefa',
'subtaskid'               => 'ID da sub tarefa',
'subtaskalreadyhasparent' => 'A sub tarefa que inseriu já tem uma tarefa mãe, por favor corrija isto antes de associar.',
'subtaskisparent'         => 'A sub tarefa que inseriu é a tarefa mãe desta tarefa. Sub tarefa não associada.',
'subtasknotexist'         => 'A sub tarefa que inseriu não existe.',
'subtaskremovedmsg'       => 'A sub tarefa foi removida com sucesso',
'subtaskadded'            => 'Adicionada sub tarefa',
'subtaskremoved'          => 'Removida sub tarefa',
'addnewsubtask'           => 'Adicionada nova sub tarefa',
'hidesubtasks'            => 'Esconder sub tarefas',
'voteforthistask'         => 'Votar nesta tarefa',
'watchthistask'           => 'Seguir esta tarefa',
'privatethistask'         => 'Tornar esta tarefa privada',
'adddependenttask'        => 'Associar dependência',
'associatetaskid'         => 'ID da sub tarefa',
'parenttaskid'            => 'ID da tarefa mãe',
'invalidsupertaskid'      => 'ID da tarefa mãe é inválido.',
'supertaskadded'          => 'Adicionada Super-tarefa',
'supertaskremoved'        => 'Removida Super-tarefa',
'effort'                  => 'Esforço',
'efforttracking'          => 'Seguir Esforço',
'useeffort'               => 'Projeto usa controlo de Esforço',
'estimatedeffort'         => 'Esforço estimado',
'totalestimatedeffort'    => 'Total de Esforço estimado',
'actualeffort'            => 'Esforço realizado',
'starteffort'             => 'Começar a seguir',
'endeffort'               => 'Parar de seguir',
'cleareffort'             => 'Limpar',
'addeffort'               => 'Adicionar esforço',
'manualeffort'            => 'Adicionar esforço manualmente(H:M)',
'efforttrackingstarted'   => 'Começou a seguir Esforço nesta tarefa.',
'efforttrackingnotstarted'=> 'Não é possível seguir esforço de uma tarefa que já está a ser seguida',
'efforttrackingstopped'   => 'Seguir Esforço terminado.',
'efforttrackingcancelled' => 'Seguir Esforço cancelado para esta tarefa.',
'efforttrackingadded'     => 'Esforço  manual guardado.',
'trackinginprogress'      => 'A seguir esforço',
'viewestimatedeffort'     => 'Pode seguir esforço',
'viewcurrenteffortdone'   => 'Pode ver esforço despendido',
'trackeffort'             => 'Pode ver esforço',
'invalideffort'           => 'O Esforço é inválido. Tem de inserir um número.',
'showpass'                => 'Mostrar password',
'chooseafile'             => 'Por favor escolha um ficheiro!',
'incorrectfiletype'       => 'Formato de ficheiro incorreto. Permitidos: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Não há password a pedir. Registou-se através de %s',
'addmultipletasks'        => 'Adicionar tarefas múltiplas',
'pendingnewuserrequest'   => 'Pedido de Novo Utilizador pendente',
'adminrequestswaiting'    => 'Administrador pede que espere',
'clicktoedit'             => 'Clique em cada campo para editar rapidamente',
'confirmedit'             => 'confirmar',
'canceledit'              => 'cancelar',
'regapprovedbyadmin'      => 'Registos aprovados por admins (desligar código de confirmação)',
'activity'                => 'Atividade',
'myactivity'              => 'A minha Atividade',
'emailverificationwrong'  => 'A confirmação de email não coincide com o email dado',
'verifyemailaddress'      => 'Confirmar endereço de email',
'hideemails'              => 'Esconder endereço de email dos utilizadores',
'hidemyemail'             => 'Esconder o meu endereço de email',
'exporttasklist'          => 'Exportar lista de Tarefas',
'onedecimal'              => 'um décimal',
'manday'                  => 'dia por pessoa',
'mandays'                 => 'dias por pessoa',
'mandayabbrev'            => 'dpp',
'hourspermanday'          => 'Horas por dia por pessoa (HH:mm)',
'itemexists'              => 'Item %s já existe na base de dados.',
'categoryitemexists'      => 'Item %s já existe na categoria %s da base de dados.',
'pageswelcomemsg'         => 'Páginas onde mostrar mensagem principal de boas vindas',
'pagesintromsg'           => 'Páginas onde mostrar mensagem de boas vindas',
'activeoauths'            => 'Provedores Oauth ativos',
'onlyoauthreg'            => 'Apenas permitir registos por Oauths',
'estimatedeffortformat'   => 'Formato para mostrar esforço estimado',
'currenteffortdoneformat' => 'Formato para mostrar esforço atual',
'minute'                  => 'minuto',
'minutes'                 => 'minutos',
'minuteplural'            => 'minutos',
'minutesingular'          => 'minuto',
'minuteabbrev'            => 'min',
'hourplural'              => 'horas',
'hoursingular'            => 'hora',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'Esforço estimado para tarefas abertas',
'currenteffortdoneopen'   => 'Esforço dispendido em tarefas abertas',
'signinwith'              => 'Entrar com %s',
'canviewroadmap'          => 'Pode ver roteiro',
'enableavatars'           => 'Permitir avatars',
'maxavatarsize'           => 'Tamanho máximo de avatar em pixeis',
'taskhassubtask'          => 'Esta tarefa tem as seguintes sub-tarefa',
'taskhassubtasks'         => 'Esta tarefa tem as seguintes sub-tarefas',
'translations'            => 'Traduções',
'translate'               => 'Traduzir',
'taskdescription'         => 'Descrição da Tarefa',
'notaskdescription'       => 'sem descrição',
'pleaseselect'            => 'Por favor selecionar',
'closeselectedtasks'      => 'Fechar tarefas selecionadas',
'closetasks'              => 'fechar tarefas',
'hintforbulkimport'       => '<b>Dicas de importação:</b>
  <ol>
  <li>Copiar e colar a partir de uma folha de cálculo excel ou CSV colando uma coluna inteira.</li>
  <li>Atualmente só pode colar Descrição e Detalhes.</li>
  <li>Há sugestões quando nomeia alguém, e ninguém quando os nomes não batem certo.</li>
  </ol>',
'taskissubtaskof'         => 'Esta tarefa é sub-tarefa de',
'applyfirstline'          => 'Aplicar primeira linha',
'addmorerows'             => 'Adicionar mais linhas',
'addtasks'                => 'Adicionar tarefas',
'massopsdisabled'         => 'Pedimos desculpa, edião em massa está desabilidata no Flyspray 1.0. Planeamos acabar a implementação para uma versão posterior do Flyspray. Pode ativar no condigo fonte por sua conta e risco, mas leia os comentários lá antes de o fazer.',
'viewroadmap'             => 'Pode ver rodeito',
'nosuicide'               => 'Estimado utilizado, o meu programa não permite que destrua o seu acesso ao Flyspray desativando a sua conta ou mudando o seu grupo',
'movingtodifferentproject' => 'Mover uma tarefa que não tem parente nem sub-taregas para um projeto diferente não é permitido. Primeiro tem de apagar a ligação entre eles.',
'musthavesameproject'     => 'Parente e sub-tarefa devem pertencer ao mesmo projeto.',
'defaultorderby'          => 'Ordenar tarefas por',
'viewowntasks'            => 'Ver próprias tarefas',
'viewgroupstasks'         => 'Ver tarefas do grupo',
'urlrewriting'            => 'Reescrever Url',
'enablehtaccess'          => 'Ative o ficheiro .htaccess na raiz da sua instalação Flyspray antes de permitir que urls sejam reescritos',
'nomodrewrite'            => 'Parece que neste momento não dá para reescrever urls deste servidor',
'on'                      => 'Ligado',
'off'                     => 'Desligado',
'defaultorderbydirection' => 'Ordem por defeito',
'ascending'               => 'Ordem crescente',
'descending'              => 'Ordem decrescente',
'myassignedtasks'         => 'Tarefas atribuídas a mim',
'commentedon'             => 'comentou em',
'maxvoteperday'           => 'Máximo de votos por dia',
'votesperproject'         => 'Limite de votos do utilizador por projeto',
'votelimitreached'        => 'Chegou ao limite de votos para este projeto. Veja na sua página de perfil em que tarefas está a votar. Lá pode também retirar votos. Veja quais as suas tarefas mais importantes no momento. Tarefas resolvidas não contam para o limite de votos.',
'myvotes'                 => 'Meus votos',
'tag'                     => 'Etiquetas',
'tags'                    => 'Etiquetas',
'tagsinfo'                => 'Etiquetar tarefas no Flyspray: Separar etiquetas por ; Neste momento ainda não são usadas para pesquisar, ordenar e filtrar.',
'novalues'                => 'sem entradas',
'youhaveregistered'       => 'Registou-se no Flyspray. Os seus detalhes são os seguintes:',
'youhaveregisterednotify' => 'O seu registo no Flyspray foi aprovada pelos Administradores.',
'usedintasks'             => 'Utilização',
'freetagging'             => 'permitir etiquetas definidas por utilizadores',
);
?>
