<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Uredi uporabnika',
'username'                => 'Uporabniško ime',
'realname'                => 'Naziv (ime, priimek)',
'emailaddress'            => 'E-pošta',
'profileimage'            => 'Slika profila',
'notifytype'              => 'Način obveščanja',
'updatedetails'           => 'Posodobite podrobnosti',
'newuser'                 => 'Registracija novega uporabnika',
'yes'                     => 'Da',
'no'                      => 'Ne',
'addcomments'             => 'Dodaj komentar',
'attachfiles'             => 'Pripni datoteke',
'vote'                    => 'oddan glas',
'back'                    => 'Nazaj',
'show'                    => 'Prikaži',
'update'                  => 'Posodobi',
'addnew'                  => 'Dodaj novo',
'flysprayprefs'           => 'Flyspray nastavitve',
'language'                => 'Jezik',
'never'                   => 'Nikoli',
'email'                   => 'E-pošta',
'noone'                   => 'Vsem',
'editcomment'             => 'Uredi komentar',
'commentby'               => 'Komentiral',
'saveeditedcomment'       => 'Shrani urejan komentar',
'dateformat'              => 'Format datuma',
'dateformat_extended'     => 'Podroben format datuma',
'oldpass'                 => 'Staro geslo',
'changepass'              => 'Spremenite geslo',
'confirmpass'             => 'Potrdite geslo',
'viewtasks'               => 'Pregled poročil',
'editcomments'            => 'Uredi komentarje',
'closeowntasks'           => 'Zapri lastno poročilo',
'closeothertasks'         => 'Zapri poročilo katere niste lastnik',
'viewreports'             => 'Oglej poročil',
'globalgroup'             => 'Pravice portala',
'closetask'               => 'Zapri poročilo',
'lostpw'                  => 'Pridobitev izgubljenega gesla',
'lostpwexplain'           => 'Vpišite vaše uporabniško ime in poslali vam bomo povezavo za spremembo obstoječega gesla.  E-pošta bo poslana na naslov kot je naveden v vašem uporabniškem profilu.',
'sendlink'                => 'Pošlji povezavo',
'savenewpass'             => 'Shrani novo geslo',
'notifications'           => 'Obveščanje',
'resetoptions'            => 'Ponastavi nastavitve',
'operatingsystems'        => 'Operacijski sistemi',
'delete'                  => 'Izbriši',
'link'                    => 'Povezava',
'tasksperpage'            => 'Število poročil na eno stran',
'loginsuccessful'         => 'Prijava uspešna.',
'task'                    => 'Poročilo',
'edittask'                => 'Uredi poročilo',
'openedby'                => 'Poročilo kreiral',
'editedby'                => 'Zadnje urejanje',
'tasktype'                => 'Tip sporočila',
'category'                => 'Kategorija',
'status'                  => 'Status',
'assignedto'              => 'Dodeljeno',
'operatingsystem'         => 'Operacijski sistem',
'severity'                => 'Pogostost',
'reportedversion'         => 'Verzija programa',
'dueinversion'            => 'Do verzije',
'undecided'               => 'Nedoločeno',
'percentcomplete'         => 'Končano',
'details'                 => 'Podrobnosti',
'savedetails'             => 'Shrani spremembe',
'canceledit'              => 'Prekliči urejanje',
'anonymous'               => 'Anonimni uporabnik',
'complete'                => 'končano',
'closedby'                => 'Zaprl uporabnik',
'reasonforclosing'        => 'Razlog:',
'reopenthistask'          => 'Ponovno odpri poročilo',
'comments'                => 'Komentar',
'attachments'             => 'Priponka',
'relatedtasks'            => 'Sorodna poročila',
'edit'                    => 'Uredi',
'addcomment'              => 'Dodaj komentar',
'fileuploadedby'          => 'Datoteko naložil',
'uploadafile'             => 'Priponka',
'addalink'                => 'Dodaj povezavo',
'addanotherlink'          => 'Dodaj novo povezave',
'uploadnow'               => 'Naloži zdaj!',
'remove'                  => 'Odstrani',
'addnewrelated'           => 'Dodaj novo odvisno poročilo',
'add'                     => 'Dodaj',
'addusertolist'           => 'Dodaj uporabnika k seznamu',
'theseusersnotify'        => 'Ti uporabniki bodo prejemali podrobna obvestila o vsakršnih spremembah sporočila.',
'attachedtoproject'       => 'Dodano k projektu',
'reminders'               => 'Opomniki',
'system'                  => 'Sistem',
'remindthisuser'          => 'Opomni uporabnika',
'thisoften'               => 'Obvesti na vsakih',
'hour'                    => 'ura',
'hours'                   => 'ura (ure)',
'day'                     => 'dan',
'days'                    => 'dan (dni)',
'week'                    => 'teden',
'weeks'                   => 'teden (tednov)',
'addreminder'             => 'Dodaj opomnik',
'defaultreminder'         => 'To je opomnik za poročilo:',
'message'                 => 'Sporočilo',
'closed'                  => 'Zaprto',
'filename'                => 'Ime datoteke:',
'date'                    => 'Datum',
'closurecomment'          => 'Dodatni komentar:',
'history'                 => 'Zgodovina',
'nohistory'               => 'Ni zgodovine.',
'eventdate'               => 'Datum',
'user'                    => 'Uporabnik',
'event'                   => 'Dogodek',
'fieldchanged'            => 'Sprememba polja',
'taskopened'              => 'Kreirano poročilo',
'taskreopened'            => 'Ponovno kreiranje poročila',
'taskclosed'              => 'Poročilo zaprto',
'commentadded'            => 'Dodan komentar',
'commentedited'           => 'Urejanje komentarja',
'commentdeleted'          => 'Komentar izbrisan',
'attachmentadded'         => 'Dodana priponka',
'attachmentdeleted'       => 'Priponka izbrisana',
'notificationadded'       => 'Uporabnik dodan na seznam obveščanja',
'notificationdeleted'     => 'Uporabnik odstranil iz seznama obveščanja',
'taskassigned'            => 'Poročilo dodeljeno',
'taskreassigned'          => 'Poročilo dodeljeno uporabniku',
'summary'                 => 'Povzetek',
'priority'                => 'Prednost',
'selectareason'           => 'Izberite razlog',
'assigntome'              => 'Dodeli meni',
'ownershiptaken'          => 'Poročilo prevzel uporabnik',
'depadded'                => 'Dodana odvisnost',
'depaddedother'           => 'To poročilo je dodano v odvisnost',
'makeprivate'             => 'naredi zasebno',
'makepublic'              => 'naredi javno',
'mark100'                 => 'Označi poročilo kot 100% končano',
'watchtask'               => 'prični slediti',
'stopwatching'            => 'prenehaj slediti',
'commentlink'             => 'Povezava k komentarju',
'reasonforreq'            => 'Razlog zahtevka',
'previoustask'            => 'Prejšnje poročilo',
'nexttask'                => 'Naslednje poročilo',
'duedate'                 => 'Do datuma',
'open'                    => 'Odprta',
'depgraph'                => 'Ogled grafa odvisnosti',
'reset'                   => 'Ponastavi',
'selectusers'             => 'Izberi uporabnika...',
'dependencygraph'         => 'Odvisnostni graf',
'attachanotherfile'       => 'Dodaj novo priponko',
'OK'                      => 'Vredu',
'addvote'                 => 'Dodaj glas',
'notifyfromfs'            => 'Sporočilo od Flyspray',
'autogenerated'           => 'TO JE SAMODEJNO SPOROČILO, PROSIMO NE ODGOVARJAJTE NANJ',
'forward'                 => 'Naprej',
'previous'                => 'Prešnja',
'next'                    => 'Naslednja',
'first'                   => 'Prva',
'last'                    => 'Zadnja',
'page'                    => 'Stran %d od %d',
'search'                  => 'Iskanje',
'alltasktypes'            => 'Vsi tipi poročil',
'allseverities'           => 'Vsaka pogostost',
'alldevelopers'           => 'Vsi razvijalci',
'notyetassigned'          => 'Še ni dodeljeno',
'allcategories'           => 'Vse kategorije',
'allstatuses'             => 'Vsi statusi',
'allopentasks'            => 'Vsa odprta poročila',
'sortthiscolumn'          => 'Uredite po tem stolpcu',
'id'                      => 'ID',
'project'                 => 'Projekt',
'dateopened'              => 'Odprto',
'progress'                => 'Napredovanje',
'searchthisproject'       => 'Iskanje po tem projektu',
'dueanyversion'           => 'Do vsake verzije',
'anyversion'              => 'Poročano v vsaki verziji',
'dueversion'              => 'Do verzije',
'os'                      => 'Operacijski sistem',
'taskrange'               => 'Prikazovanje poročila %d - %d od %d',
'takeaction'              => 'Izvedi dejanje',
'watchtasks'              => 'Spremljal izbrano poročilo',
'stopwatchingtasks'       => 'Prenehaj opazovati izbrano poročilo',
'assigntaskstome'         => 'Dodeli izbrana poročila meni',
'selectduedate'           => 'Izberite do datuma',
'assignedtome'            => 'Dodeljeno meni',
'tasklist'                => 'Seznam poročil',
'dateclosed'              => 'Datum zaprtja',
'advanced'                => 'Napredno',
'searchcomments'          => 'Iskanje po komentarjih',
'searchforall'            => 'Iskanje po vseh besedah',
'anonusers'               => 'Anonimni uporabniki',
'miscellaneous'           => 'Razno',
'users'                   => 'Uporabniki',
'taskproperties'          => 'Podrobnosti poročila',
'currentversion'          => 'Tvoja trenutna verzija je',
'hidemessage'             => '(opomni me kasneje)',
'saveas'                  => 'Shrani iskanje kot',
'nosearches'              => 'Ni shranjenih iskanj',
'saving'                  => 'Shranjevanje...',
'votes'                   => 'oddani glasovi',
'tovote'                  => 'Oddaj glas',
'allclosedtasks'          => 'Vsa zaprta poročila',
'password'                => 'Geslo',
'login'                   => 'PRIJAVA',
'rememberme'              => 'Zapomni si me',
'lostpassword'            => 'Izgubljeno geslo?',
'lostpwforfs'             => 'Izgubljeno geslo za Flyspray',
'lostpwmsg1'              => "Živjo.\n\nIzgubil sem geslo za Flyspray na ",
'locale'                  => 'sl-SI',
'showtask'                => 'Prikaži poročilo',
'now'                     => 'Sedaj',
'go'                      => 'Pojdi!',
'opentaskanon'            => 'Dodaj novo poročilo (anonimno)',
'register'                => 'Registracija',
'addnewtask'              => 'Dodaj novo poročilo',
'reports'                 => 'Pregled poročil',
'editmydetails'           => 'Uredi moje podrobnosti',
'logout'                  => 'ODJAVA',
'poweredby'               => 'Flyspray',
'sponsoredby'             => 'Flyspray sponzorira',
'projects'                => 'Projekti',
'allprojects'             => 'Vsi projekti',
'tasksall'                => 'Vsa poročila',
'taskswatched'            => 'Opazovana poročila',
'mysearch'                => 'Moja iskanja',
'manageproject'           => 'Upravljanje projekta',
'permissions'             => 'Ogled pravic',
'hide'                    => 'Skrij',
'errorpage'               => "Flyspray cannot provide the page you requested.\nPerhaps you requested a task that does not exist, or you\ndo not have permission to view the page you wanted.<br /><br />\nYou may have tried to use a naughty URL to interact with the database\nbackend using SQL injection. If this is true, go to the corner and think\nabout your actions. When you return, please do not do it again!",
'permissionsforproject'   => 'Dodeljene pravice za ',
'lastsearch'              => 'Zadnje iskanje',
'modify'                  => 'Spremenite',
'noticefrom'              => 'Sporočilo od',
'summaryrequired'         => 'Vpisati morate jedro poročanega poročila.',
'goback'                  => 'Nazaj',
'taskupdated'             => 'Poročilo je bilo posodobljeno.',
'tasksupdated'            => 'Poročila so bila posodobljena.',
'unassigned'              => 'Nedoločeno',
'taskclosedmsg'           => 'Poročilo je bilo zaprto.',
'noclosereason'           => 'Za zaprtje poročila je potrebno izbrati razlog.',
'hasreopened'             => 'je ponovno odprl že zaprto Flyspray poročilo, katero ste zaprli vi.',
'taskreopenedmsg'         => 'Opravilo je bilo ponovno odprto.',
'backtotask'              => 'Nazaj na poročilo.',
'commentaddedmsg'         => 'Komentar uspešno dodan.',
'closewindow'             => 'Lahko zaprete to okno.',
'usernametakenbulk'       => 'Uporabniško ime že zasedeno',
'newuserwarning'          => 'V vednost, da je možno da mora pred prvo prijavo skrbnik potrdi vaš račun. Če se ne morete prijaviti je lahko to vzrok.',
'optionssaved'            => 'Flyspray nastavitve shranjene.',
'loginbelow'              => 'Sedaj se lahko prijavite (desno zgoraj -> PRIJAVA).',
'flyspraytask'            => 'Flyspray poročilo',
'addanyway'               => 'Vseeno dodaj',
'cancel'                  => 'Prekliči',
'changefspass'            => 'Spremenite Flyspray geslo',
'addressused'             => 'Vaš naslov je bil uporabljen za registracijo na Flyspray portalu.  Če niste pričakovali tega sporočila ga prosimo spreglejte in izbrišite.  Za registracijo sledite spodnji povezavi:',
'confirmcodeis'           => 'Vaša potrditvena koda:',
'addthistask'             => 'Oddaj poročilo',
'notifyme'                => 'Obvestite me o spremembi',
'newtask'                 => 'Novo poročilo',
'attachafile'             => 'Priponka',
'registernewuser'         => 'Registracija novega uporabnika',
'none'                    => 'Brez',
'registeraccount'         => 'Registracija računa',
'disclaimer'              => 'To sporočilo ste prejeli ker je bila oddana zahteva na Flyspray portalu.  Če niste pričakovali tega sporočila ali če ne želite prejemati podobnih sporočil v bodoče lahko spremenite način obveščanja v zgoraj navedeni povezavi.',
'userwho'                 => 'Poročilo kreiral',
'moreinfo'                => 'Več informacij na spletni povezavi:',
'newtaskopened'           => 'Odprto je novo poročilo na Flyspray portalu.',
'fileaddedtoo'            => 'Poročilo vsebuje eno ali več priponk.',
'feeds'                   => 'Poročanje',
'priority6'               => 'Kritično',
'priority5'               => 'Takoj',
'priority4'               => 'Urgentno',
'priority3'               => 'Visoka',
'priority2'               => 'Normalno',
'priority1'               => 'Nizka',
'sendcode'                => 'Registracija uporabnika',
'entercode'               => 'Vpišite potrditveno kodo, katero ste prejeli v sporočilu.  Prav tako vpišite željeno uporabniško geslo.',
'note'                    => '<strong>Opomba:</strong>  Pred kreiranjem novega računa vam bo na e-pošto poslana aktivacijska povezava.  Aktivacijska povezava bo poslana na zgoraj vpisan e-poštni naslov.<br />Če so vpisani neresnični podatki <strong>ne boste prejeli aktivacijske povezave</strong>.',
'to'                      => 'do',
'events'                  => 'Poročila',
'opened'                  => 'Odprto',
'edited'                  => 'Urejano',
'assigned'                => 'Dodeljeno',
'pastweek'                => 'Pretekli teden',
'from'                    => 'Od',
'roadmap'                 => 'Razvojni načrt',
'opentasks'               => 'odprtih poročil',
'severity5'               => 'Vedno',
'severity4'               => 'Skoraj vedno',
'severity3'               => 'Pogosto',
'severity2'               => 'Včasih',
'severity1'               => 'Skoraj nikoli',
'reopened'                => 'Ponovno odprto',
'loading'                 => 'Nalaganje...',
'notifyown'               => 'Obvesti o lastnih spremembah',
'youremail'               => 'Vaš e-poštni naslov ',
'file'                    => 'Datoteka',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => 'Velikost',
'projectgroup'            => 'Pravice projekta',
'profile'                 => 'Profil',
'viewprofile'             => 'Ogled profila',
'regdate'                 => 'Uporabnik od',
'tasksopened'             => 'Kreiral poročila',
'pm.taskreopened'         => 'Opravilo ponovno odprto',
'anyprogress'             => 'Vsi napredki',
'tasksrelated'            => 'Poročilo sorodno temu poročilu',
'duplicatetasks'          => 'Podvojite poročilo tega poročila',
'newuserregistered'       => 'Na Flyspray se je registriral nov uporabnik. Podatki so sledeči:',
'onlyprimary'             => 'Poročila ki ne zavirajo drugih poročil',
'onlyblocker'             => 'Poročila, ki onemogočajo druga poročila',
'switch'                  => 'Prikaži',
'max'                     => 'največ',
'dates'                   => 'Datumi',
'selectduedatefrom'       => 'Od',
'selectduedateto'         => 'do',
'selectsincedatefrom'     => 'Spremenjeno od',
'selectsincedateto'       => 'do',
'selectopenedfrom'        => 'Odprto od',
'selectopenedto'          => 'do',
'selectclosedfrom'        => 'Zaprto od',
'selectclosedto'          => 'do',
'startat'                 => 'Začni',
'hasattachment'           => 'Ima priponko',
'private'                 => 'Zasebno',
'watching'                => 'Opazujem',
'alreadyvotedthistask'    => 'glasovali ste za to poročilo',
'alreadyvotedthisday'     => 'danes ste že glasovali',
'visibility'              => 'Vidljivost',
'public'                  => 'Javno',
'defaulttask'             => 'Privzeti opis poročila',
'all'                     => 'vsi',
'eventlog'                => 'Pregled poročil',
'All'                     => 'Vsi',
'tasksireported'          => 'Poročila ki sem jih poročal',
'recentlyopened'          => 'Nedavno odprta poročila',
'stats'                   => 'Statistika',
'totaltasks'              => 'vseh poročil',
'mostwanted'              => 'Najbolj zaželjena poročila',
'overview'                => 'Pregled',
'error#'                  => 'Napaka #',
'error7'                  => 'Napaka pri prijavi, nepravilno geslo!',
'done'                    => 'končano',
'timezone'                => 'Časovni pas',
'accept'                  => 'Sprejmi',
'pruneclosedlinks'        => 'Zaprte odvisnosti povezave',
'pruneclosedtasks'        => 'Zaprte odvisnosti poročil',
'pruninglevel'            => 'Stopnja odvisnosti',
'request1'                => 'Zahtevano je zaprtje poročila.',
'allpriorities'           => 'Vse prioritete',
'noroadmap'               => 'Trenutno ni javno objavljenega razvojnega načrta.',
'minpwsize'               => 'Najmanjša dolžina gesla je 5 znakov',
'searchindetails'         => 'Podrobnosti iskanja',
'find'                    => 'Najdi',
'addvotes'                => 'Dodaj glas',
'removevote'              => 'Odstrani glas',
'novotes'                 => 'Ni veljavnih glasov.',
'taskdependencies'        => 'Odvisnost poročila',
'viewgraph'               => 'ogled grafa',
'notaskdependencies'      => 'To poročilo nima povezave z nobenim predhodnim poročilom.',
'dependson'               => 'Odvisen od',
'newdependency'           => 'Nova odvisnost:',
'setparent'               => 'Nastavite ID matičnega poročila za to poročilo',
'quickaction'             => 'Hitra dejanja',
'associatesubtask'        => 'Nastavitev ID podporočila za to poročilo',
'addnewsubtask'           => 'Dodajte novo podporočilo',
'hidesubtasks'            => 'Skrij podporočila',
'voteforthistask'         => 'Glasujte za to poročilo',
'watchthistask'           => 'Opazujte to poročilo',
'privatethistask'         => 'Nastavite poročilo kot zasebno',
'adddependenttask'        => 'Povežite soodvisno poročilo',
'incorrectfiletype'       => 'Nepravilen tip datoteke. Dovoljeno: jpg, jpeg, gif, png.',
'addmultipletasks'        => 'Dodaj množična poročila',
'clicktoedit'             => 'Za hitro urejanje kliknite na polje',
'confirmedit'             => 'Potrdi',
'activity'                => 'Dejavnost',
'myactivity'              => 'Moja dejavnost',
'verifyemailaddress'      => 'Potrdite e-poštni naslov',
'hidemyemail'             => 'Skrij moj e-poštni naslov',
'exporttasklist'          => 'Izvozi seznam poročil',
'hourplural'              => 'ure',
'hoursingular'            => 'ura',
'hourabbrev'              => 'h',
'taskdescription'         => 'Opis poročila',
'notaskdescription'       => 'Ni opisa',
'closeselectedtasks'      => 'Zapri izbrana poročila',
'closetasks'              => 'Zapri poročila',
'hintforbulkimport'       => "<b>Navodila za množično poročanje:</b>\n<ol>\n<li>Kopiranje in lepljenje iz Excel ali CSV datoteke.</li>\n<li>Prilepite lahko Povzetek in Podrobnosti.</li>\n</ol>",
'applyfirstline'          => 'Shrani prvo vrstico',
'addmorerows'             => 'Dodaj novo vrstico',
'addtasks'                => 'Dodaj poročila',
'myassignedtasks'         => 'Poročila dodeljena meni',
'commentedon'             => 'komentiral dne',
'myvotes'                 => 'Moje glasovanje',
'tags'                    => 'Oznake',
'youhaveregistered'       => 'Registrirali ste se na Flyspray. Vaši podatki so:',
'youhaveregisterednotify' => 'Vaša registracija na Flyspray je bila sprejeta.',
'keyboardshortcuts'       => 'Bližnjice na tipkovnici',
'availablekeybshortcuts'  => 'Na voljo bližnjice na tipkovnici',
'logindialoglogout'       => 'Prijava / Odjava',
'focustaskidsearch'       => 'Iskanje po ID oznaki',
'openselectedtask'        => 'Odpri izbrano poročilo',
'movecursorup'            => 'Premakne kurzor gor',
'movecursordown'          => 'Premakne kurzor dol',
'taskdetails'             => 'Podrobnosti opravila',
'taskediting'             => 'Urejanje opravila',
'savetask'                => 'Shrani opravilo',
'taskhassubtask'          => 'To opravilo ima sledeče podopravilo',
'taskhassubtasks'         => 'To opravilo ima sledeča podopravila',
'taskissubtaskof'         => 'To opravilo je podopravilo od opravila',
'supertaskadded'          => 'Dodano glavno opravilo',
'supertaskremoved'        => 'Odstranjeno glavno opravilo',
'subtaskadded'            => 'Dodano podopravilo',
'subtaskremoved'          => 'Odstranjeno podopravilo',
);

?>
