<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Benutzer bearbeiten',
'accountenabled'          => 'Konto aktiviert',
'editallusers'            => 'alle Nutzer anzeigen',
'username'                => 'Benutzername',
'usersupdated'            => 'Nutzer erfolgreich aktualisiert',
'realname'                => 'vollständiger Name',
'emailaddress'            => 'E-Mail',
'jabberid'                => 'Jabber-ID',
'profileimage'            => 'Profilbild',
'notifytype'              => 'Benachrichtigungsweg',
'group'                   => 'Gruppe',
'enableaccounts'          => 'Zugänge aktivieren',
'disableaccounts'         => 'Zugänge sperren',
'deleteaccounts'          => 'Zugänge löschen',
'updatedetails'           => 'speichern',
'setglobally'             => 'Diese Einstellung ist global gesetzt.',
'usergroupmanage'         => 'Benutzer- und Gruppenmanagement',
'newuser'                 => 'Neuen Benutzer registrieren',
'newuserbulk'             => 'mehrere neue Benutzer anlegen',
'bulkuserstoadd'          => 'Liste neuer Nutzer',
'optionsforallusers'      => 'Einstellungen für alle neuen Nutzer',
'newgroup'                => 'Neue Gruppe erstellen',
'yes'                     => 'ja',
'no'                      => 'nein',
'editgroup'               => 'Gruppe bearbeiten',
'groupname'               => 'Gruppenname',
'description'             => 'Beschreibung',
'admin'                   => 'Administratorengruppe',
'opennewtasks'            => 'neue Aufgaben anlegen',
'modifytasks'             => 'vorhandene Aufgaben ändern',
'addcomments'             => 'Kommentare hinzufügen',
'attachfiles'             => 'Dateien anhängen',
'vote'                    => 'Stimme',
'groupenabled'            => 'Mitglieder können sich anmelden (Gruppe aktiv)',
'groupopen'               => 'Mitglieder können sich anmelden (Gruppe aktiv)',
'tasktypelist'            => 'Aufgabentypen',
'categorylist'            => 'Kategorien',
'oslist'                  => 'Betriebssysteme',
'resolutionlist'          => 'Erledigungsstatus',
'versionlist'             => 'Versionen',
'severitylist'            => 'Schweregrad',
'listnote'                => 'Hinweis: Wenn Sie "Anzeigen" deaktivieren, können einige Aufgaben beim Bearbeiten anders dargestellt werden. Änderungen des Namens wirken sich automatisch auf alle zugehörigen Aufgaben aus. Einträge, die Aufgaben zugeordnet sind oder die zum Funktionieren der Anwendung erforderlich sind, können nicht gelöscht werden.',
'name'                    => 'Name',
'order'                   => 'Reihenfolge',
'back'                    => 'zurück',
'text'                    => 'Text',
'highlight'               => 'hervorheben',
'show'                    => 'anzeigen',
'owner'                   => 'Zuständiger',
'selectowner'             => 'Zuständigen auswählen',
'update'                  => 'aktualisieren',
'addnew'                  => 'hinzufügen',
'flysprayprefs'           => 'Flyspray Optionen',
'projecttitle'            => 'Projektname',
'baseurl'                 => 'Basis-URL für diese Installation',
'replyaddress'            => 'Antwortadresse für E-Mail-Benachrichtigungen',
'themestyle'              => 'Design',
'customstyle'             => 'angepasst',
'language'                => 'Sprache',
'anonview'                => 'Anonyme Benutzer dürfen Aufgaben sehen',
'allowanon'               => 'Anonyme Benutzer dürfen neue Aufgaben anlegen',
'never'                   => 'niemals',
'anonymously'             => 'anonym',
'afterregister'           => 'nach Registrierung',
'spamproof'               => 'Bestätigungscode für das Registrieren neuer Benutzer aktivieren',
'anongroup'               => 'Gruppe für anonyme Registrierungen',
'groupassigned'           => 'Mitglieder dieser Gruppen können Aufgaben übertragen werden',
'forcenotify'             => 'Benachrichtigungsweg erzwingen',
'neversend'               => 'niemals senden',
'userchoose'              => 'Benutzerauswahl',
'email'                   => 'E-Mail',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Standard-Kategorie-Inhaber',
'noone'                   => 'niemand',
'jabbernotify'            => 'Jabber-Benachrichtigungen',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Benutzername',
'jabberpass'              => 'Passwort',
'saveoptions'             => 'speichern',
'editcomment'             => 'Kommentar bearbeiten',
'commentby'               => 'Kommentar von',
'saveeditedcomment'       => 'Bearbeiteten Kommentar speichern',
'projectprefs'            => 'Projekteinstellungen',
'pagetitle'               => 'Seitentitel',
'defaultproject'          => 'Standard-Projekt',
'projectlists'            => 'Projekt-Listen',
'showlogo'                => 'Logografik im Titel anzeigen',
'showgravatars'           => 'Gravatare anzeigen',
'emailNoHTML'             => 'kein HTML in E-Mails',
'intromessage'            => 'Begrüßungstext',
'active'                  => 'aktiv',
'inactive'                => 'inaktiv',
'isactive'                => 'Projekt ist aktiv',
'showinactive'            => 'Zeige inaktive Projekte',
'hideinactive'            => 'inaktive Projekte ausblenden',
'createproject'           => 'Neues Projekt erstellen',
'nopermission'            => 'Sie sind nicht zum Zugriff auf diese Seite berechtigt.',
'listordertip'            => 'Reihenfolge der Einträge in der Liste',
'listshowtip'             => 'Diesen Eintrag in der Liste anzeigen',
'categoryownertip'        => 'Dieser Benutzer erhält eine Benachrichtigung, wenn eine Aufgabe in dieser Kategorie angelegt wird: ',
'categoryparenttip'       => 'Kategorie, die durch die neue Kategorie untergliedert wird',
'notsubcategory'          => 'keine - (oberste Ebene)',
'showinlineimages'        => 'Angehängte Bilder als Vorschau direkt anzeigen',
'dateformat'              => 'Datumsformat',
'dateformat_extended'     => 'erweitertes Datumsformat',
'cache_feeds'             => 'Cache für Newsfeeds aktivieren',
'no_cache'                => 'ohne Cache',
'cache_disk'              => 'Cache als Datei',
'cache_db'                => 'Cache in Datenbank',
'subcategoryof'           => 'Unterkategorie von',
'visiblecolumns'          => 'Spalten in der Aufgabenliste',
'visiblefields'           => 'sichtbare Felder, wenn Aufgaben hinzugefügt,bearbeitet oder angeschaut werden',
'tense'                   => 'zeitliche Einordnung',
'listtensetip'            => 'abgeschlossen, aktuell oder zukünftig',
'past'                    => 'abgeschlossen',
'present'                 => 'aktuell',
'future'                  => 'zukünftig',
'oldpass'                 => 'altes Passwort',
'nooldpass'               => 'kein altes Passwort gesetzt',
'oldpasswrong'            => 'Altes Passwort war falsch',
'changepass'              => 'neues Passwort',
'confirmpass'             => 'neues Passwort bestätigen',
'projectmanager'          => 'Projektmanager',
'viewtasks'               => 'Aufgaben anzeigen',
'modifyowntasks'          => 'eigene Aufgaben bearbeiten',
'modifyalltasks'          => 'jemand anderem übertragene Aufgaben bearbeiten',
'viewcomments'            => 'Kommentare anzeigen',
'editcomments'            => 'Kommentare bearbeiten',
'deletecomments'          => 'Kommentare löschen',
'viewattachments'         => 'Anhänge anzeigen',
'createattachments'       => 'Anhänge erstellen',
'deleteattachments'       => 'Anhänge löschen',
'viewhistory'             => 'Verlauf anzeigen',
'closeowntasks'           => 'eigene Aufgaben schließen',
'closeothertasks'         => 'jemand anderem übertragene Aufgaben schließen',
'assigntoself'            => 'niemandem übertragene Aufgaben selbst übernehmen',
'assignotherstoself'      => 'jemand anderem übertragene Aufgaben selbst übernehmen',
'viewreports'             => 'Berichte anzeigen',
'othersview'              => 'Jeder darf die Aufgaben dieses Projektes anzeigen',
'othersviewroadmap'       => 'Jeder darf die Planung dieses Projektes anzeigen',
'usersandgroups'          => 'Benutzer & Gruppen',
'globalgroup'             => 'Globale Gruppe',
'globalgroups'            => 'Globale Gruppen',
'defaultglobalgroup'      => 'Standardgruppe für neue Benutzer',
'addtogroup'              => 'Zur Gruppe hinzufügen',
'moveuserstogroup'        => 'In Gruppe verschieben',
'nogroup'                 => 'keine Gruppe (aus Projekt entfernen)',
'eventdesc'               => 'Ereignisbeschreibung',
'requestedby'             => 'angefragt von',
'daterequested'           => 'Datum der Anfrage',
'closetask'               => 'Aufgabe schließen',
'reopentask'              => 'Aufgabe wieder öffnen',
'applymember'             => 'Bitte um Projektmitgliedschaft',
'forcurrentproj'          => 'Für das aktuelle Projekt',
'lostpw'                  => 'neues Passwort anfordern',
'lostpwexplain'           => 'Geben Sie Ihren Benutzernamen ein, um einen Link zum Ändern Ihres Passwortes an die in Ihrem Profil eingestellte Benachrichtigungsadresse zu senden.',
'sendlink'                => 'Link senden',
'savenewpass'             => 'neues Passwort speichern',
'anonreg'                 => 'neue Benutzerregistrierungen zulassen',
'allowanonopentask'       => 'Jeder darf neue Aufgaben zu diesem Projekt hinzufügen',
'editglobalgroup'         => 'Globale Gruppe bearbeiten',
'editgroupforproj'        => 'Gruppe für dieses Projekt bearbeiten',
'notshownforadmin'        => 'Berechtigungen der Administratorengruppe können nicht geändert werden.',
'general'                 => 'allgemein',
'userregistration'        => 'Benutzerregistrierung',
'notifications'           => 'Benachrichtigungen',
'resetoptions'            => 'rückgängig',
'preferences'             => 'Einstellungen',
'tasktypes'               => 'Aufgabentypen',
'resolutions'             => 'Lösungen',
'categories'              => 'Kategorien',
'categoriesglobal'        => 'Kategorien systemweit',
'categoriesproject'       => 'Kategorien projekteigen',
'categoriestarget'        => 'Kategorien Zielprojekt',
'operatingsystems'        => 'Betriebssysteme',
'versions'                => 'Versionen',
'admintoolboxlong'        => 'Verwaltungswerkzeuge',
'newproject'              => 'neues Projekt',
'delete'                  => 'löschen',
'link'                    => 'Verknüpfung',
'referencelinks'          => 'Referenzverbindung',
'listdeletetip'           => 'Dieses Element von der Liste löschen',
'lookandfeel'             => 'Erscheinungsbild',
'globaltheme'             => 'globales Design',
'emailnotify'             => 'E-Mail-Benachrichtigungen',
'fromaddress'             => 'Absender-Adresse',
'smtpserver'              => 'SMTP-Server',
'smtpuser'                => 'SMTP-Benutzername',
'smtppass'                => 'SMTP-Passwort',
'addrewrite'              => 'E-Mail-Adresse umschreiben (address rewriting)',
'usereminderdaemon'       => 'Erinnerungsnachrichten aktivieren (benötigt konfigurierten cronjob, der periodisch schedule.php aufruft)',
'tasksperpage'            => 'Aufgaben pro Seite',
'addtoassignees'          => 'Selbst mit übernehmen',
'taskstatuses'            => 'Aufgabenstatus',
'canvote'                 => 'Stimme abgeben',
'loginsuccessful'         => 'Login erfolgreich.',
'youareloggedout'         => 'Sie wurden abgemeldet.',
'waitwhiletransfer'       => 'Sie werden weitergeleitet...',
'clicknowait'             => 'weiter',
'accountdisabled'         => 'Ihr Benutzerkonto wurde deaktiviert. Wenden Sie sich an einen Administrator.',
'task'                    => 'Aufgabe',
'edittask'                => 'Aufgabe bearbeiten',
'openedby'                => 'angelegt von',
'editedby'                => 'zuletzt bearbeitet von',
'tasktype'                => 'Aufgabentyp',
'category'                => 'Kategorie',
'status'                  => 'Status',
'assignedto'              => 'zuständig',
'operatingsystem'         => 'Betriebssystem',
'severity'                => 'Schweregrad',
'reportedversion'         => 'betrifft Version',
'dueinversion'            => 'fällig in Version',
'defaultdueinversion'     => 'Voreinstellung fällig in Version',
'undecided'               => 'unbestimmt',
'percentcomplete'         => 'Prozent erledigt',
'details'                 => 'Beschreibung',
'savedetails'             => 'speichern',
'canceledit'              => 'abbrechen',
'anonymous'               => 'Anonymer Reporter',
'complete'                => 'erledigt',
'closedby'                => 'geschlossen von',
'reasonforclosing'        => 'Grund für das Schließen:',
'reopenthistask'          => 'Aufgabe wieder öffnen',
'comments'                => 'Kommentare',
'attachments'             => 'Dateianhänge',
'relatedtasks'            => 'Verknüpfte Aufgaben',
'edit'                    => 'bearbeiten',
'addcomment'              => 'Kommentar hinzufügen',
'fileuploadedby'          => 'Datei hochgeladen von',
'uploadafile'             => 'Datei zum Anhängen hochladen',
'addalink'                => 'Verknüpfung hinzufügen',
'addanotherlink'          => 'weitere Verknüpfung hinzufügen',
'uploadnow'               => 'hochladen',
'thesearerelated'         => 'Folgende Aufgaben sind mit dieser verknüpft: ',
'remove'                  => 'entfernen',
'addnewrelated'           => 'mit einer Aufgabe verbinden',
'add'                     => 'hinzufügen',
'otherrelated'            => 'Aufgaben, mit denen diese verknüpft ist',
'receivenotify'           => 'Diese Benutzer werden detaillierte Benachrichtigungen erhalten, wenn sich diese Aufgabe ändert.',
'addusertolist'           => 'Benutzer zu dieser Liste hinzufügen',
'addtolist'               => 'zu Liste hinzufügen',
'addmyself'               => 'mich selbst zu dieser Liste hinzufügen',
'removemyself'            => 'mich selbst von dieser Liste entfernen',
'theseusersnotify'        => 'Folgende Benutzer erhalten detaillierte Benachrichtigungen, sobald sich die Aufgabe ändert: ',
'attachedtoproject'       => 'gehört zu Projekt',
'reminders'               => 'Erinnerungen',
'system'                  => 'System',
'systemvalues'            => 'Systemweite Listenwerte',
'projectvalues'           => 'Projektspezifische Listenwerte',
'remindthisuser'          => 'diesen Benutzer',
'thisoften'               => 'alle',
'startafter'              => 'Zeit bis zur ersten Erinnerung',
'hour'                    => 'Stunde',
'hours'                   => 'Stunden',
'day'                     => 'Tag',
'days'                    => 'Tage',
'week'                    => 'Woche',
'weeks'                   => 'Wochen',
'addreminder'             => 'Erinnerung hinzufügen',
'defaultreminder'         => 'Erinnerung: Bitte sehen Sie sich die folgende Flyspray-Aufgabe an:',
'message'                 => 'Nachricht',
'closed'                  => 'geschlossen',
'filename'                => 'Dateiname:',
'date'                    => 'Zeitraum',
'filesize'                => 'Dateigröße:',
'closurecomment'          => 'Kommentar zum Schließen:',
'history'                 => 'Verlauf',
'nohistory'               => 'Keine Daten verfügbar.',
'eventdate'               => 'Datum',
'user'                    => 'Benutzer',
'event'                   => 'Ereignis',
'fieldchanged'            => 'Feld geändert',
'taskopened'              => 'Aufgabe angelegt',
'taskreopened'            => 'Aufgabe wieder geöffnet',
'taskclosed'              => 'Aufgabe geschlossen',
'commentadded'            => 'Kommentar hinzugefügt',
'commentedited'           => 'Kommentar geändert',
'commentdeleted'          => 'Kommentar gelöscht',
'attachmentadded'         => 'Anhang hinzugefügt',
'attachmentdeleted'       => 'Anhang gelöscht',
'taskedited'              => 'Aufgabendetails geändert',
'notificationadded'       => 'Benutzer zur Benachrichtigungsliste hinzugefügt',
'notificationdeleted'     => 'Benutzer von der Benachrichtigungsliste entfernt',
'relatedadded'            => 'Verknüpfung zur Aufgabe hinzugefügt',
'relateddeleted'          => 'Verknüpfung zur Aufgabe entfernt',
'taskassigned'            => 'Aufgabe übertragen an: ',
'taskreassigned'          => 'Aufgabe neu übertragen an: ',
'assignmentremoved'       => 'Zuständigkeit entfernt: ',
'summary'                 => 'Zusammenfassung',
'addedasrelated'          => 'Aufgabe zur Liste verknüpfter Aufgaben hinzugefügt von',
'deletedasrelated'        => 'Aufgabe aus der Liste verknüpfter Aufgaben entfernt von',
'reminderadded'           => 'Erinnerung erstellt',
'reminderdeleted'         => 'Erinnerung gelöscht',
'priority'                => 'Dringlichkeit',
'previousvalue'           => 'vorheriger Wert',
'newvalue'                => 'neuer Wert',
'selectareason'           => 'Begründung wählen...',
'assigntome'              => 'Aufgabe allein übernehmen',
'reopenrequest'           => 'Wiederöffnung angefragt',
'requestclose'            => 'Schließen angefragt',
'ownershiptaken'          => 'Benutzer hat die Aufgabe übernommen',
'closerequestmade'        => 'Schließen einer Aufgabe angefragt',
'reopenrequestmade'       => 'Wiederöffnung einer Aufgabe angefragt',
'taskdependson'           => 'Diese Aufgabe ist abhängig von',
'taskdependsontask'       => 'Diese Aufgabe ist abhängig von',
'taskdependsontasks'      => 'Diese Aufgabe ist abhängig von',
'taskblock'               => 'Diese Aufgabe verhindert das Schließen von',
'taskblocks'              => 'Diese Aufgabe verhindert das Schließen von',
'depadded'                => 'Abhängigkeit hinzugefügt',
'depaddedother'           => 'abhängige Aufgabe hinzugefügt',
'depremoved'              => 'Abhängigkeit entfernt',
'depremovedother'         => 'abhängige Aufgabe entfernt',
'showdetailserror'        => 'Die Aufgabe ist nicht vorhanden oder Sie sind nicht zur Anzeige berechtigt.',
'makeprivate'             => 'verstecken',
'makepublic'              => 'veröffentlichen',
'taskmadeprivate'         => 'Diese Aufgabe wurde versteckt',
'taskmadepublic'          => 'Diese Aufgabe wurde wieder veröffentlicht',
'confirmdeletecomment'    => 'Diesen Kommentar wirklich löschen? %s',
'attachementswilldeleted' => 'Alle Anhänge werden ebenfalls gelöscht!',
'confirmdeleteattach'     => 'Diesen Anhang wirklich löschen?',
'selectedhistory'         => 'Verlauf für markierten Eintrag anzeigen',
'showallhistory'          => 'Kompletten "Verlauf"-Tab wieder anzeigen',
'hidethis'                => 'Diesen Bereich wieder ausblenden',
'mark100'                 => 'Aufgabe als 100% erledigt markieren',
'watchtask'               => 'Aufgabe beobachten',
'stopwatching'            => 'Aufgabe nicht mehr beobachten',
'commentlink'             => 'Diesen Kommentar verlinken',
'submitreq'               => 'Anfrage abschicken',
'reasonforreq'            => 'Grund für die Anfrage',
'pmreqdenied'             => 'Projektmanager hat die Anfrage abgelehnt',
'taskpendingreq'          => 'Warte auf Bearbeitung durch den Projektmanager. Einzelheiten siehe "Verlauf"-Tab.',
'previoustask'            => 'vorherige Aufgabe',
'nexttask'                => 'nächste Aufgabe',
'duedate'                 => 'fällig am',
'attachnoperms'           => 'Dieser Kommentar hat Anhänge, aber Ihnen fehlt die Berechtigung diese anzuzeigen.',
'linknoperms'             => 'Es gibt Verknüpfungen mit diesem Kommentar, aber Ihnen fehlt die Berechtigung diese anzuzeigen.',
'open'                    => 'offene',
'depgraph'                => 'Abhängigkeitsdiagramm anzeigen',
'reset'                   => 'rückgängig',
'selectusers'             => 'Benutzer wählen...',
'addmetoassignees'        => 'Aufgabe mit übernehmen',
'addedtoassignees'        => 'Benutzer als Zuständigen hinzugefügt',
'dependencygraph'         => 'Abhängigkeitsdiagramm ',
'attachanotherfile'       => 'weitere Datei anfügen',
'OK'                      => 'OK',
'addvote'                 => 'Stimme hinzufügen',
'disable_lostpw'          => 'vergessene Passwortfunktion abschalten',
'disable_changepw'        => 'erstellen oder ändern des Passwortes abschalten',
'notifyfromfs'            => 'Flyspray Benachrichtigung',
'autogenerated'           => 'Dies ist eine automatisch erstellte Nachricht. Bitte antworten Sie nicht darauf.',
'forward'                 => 'vorwärts',
'previous'                => 'vorige',
'next'                    => 'nächste',
'first'                   => 'erste',
'last'                    => 'letzte',
'page'                    => 'Seite %d von %d',
'search'                  => 'suchen',
'alltasktypes'            => 'alle Aufgabentypen',
'allseverities'           => 'alle Schweregrade',
'alldevelopers'           => 'alle Entwickler',
'notyetassigned'          => 'niemandem übertragen',
'allcategories'           => 'alle Kategorien',
'allstatuses'             => 'alle Status',
'allopentasks'            => 'alle offenen Aufgaben',
'sortthiscolumn'          => 'Nach dieser Spalte sortieren',
'id'                      => 'ID',
'project'                 => 'Projekt',
'dateopened'              => 'angelegt',
'progress'                => 'Fortschritt',
'searchthisproject'       => 'suchen',
'dueanyversion'           => 'fällig in beliebiger Version',
'anyversion'              => 'in beliebiger Version geöffnet',
'dueversion'              => 'fällig in Version',
'lastedit'                => 'zuletzt geändert',
'os'                      => 'Betriebssystem',
'reportedin'              => 'betrifft Version',
'taskrange'               => 'zeige Aufgaben %d - %d von %d',
'noresults'               => 'Ihre Suche ergab keine Treffer.',
'takeaction'              => 'ausführen',
'watchtasks'              => 'markierte Aufgaben beobachten',
'stopwatchingtasks'       => 'markierte Aufgaben nicht mehr beobachten',
'assigntaskstome'         => 'markierte Aufgaben mir übertragen',
'dueby'                   => 'fällig bis',
'dueanytime'              => 'unbestimmt',
'selectduedate'           => 'Fälligkeit auswählen',
'toggleselected'          => 'Auswahl umkehren',
'due'                     => 'fällig',
'assignedtome'            => 'mir übertragene Aufgaben',
'tasklist'                => 'Aufgabenliste',
'dateclosed'              => 'geschlossen am',
'advanced'                => 'erweitert',
'searchcomments'          => 'Suche in Kommentaren',
'searchforall'            => 'Suche nach allen Wörtern',
'anonusers'               => 'anonyme Benutzer',
'miscellaneous'           => 'Sonstiges',
'users'                   => 'Benutzer',
'taskproperties'          => 'Eigenschaften der Aufgabe',
'selectsincedate'         => 'Wähle nach Datum der Änderung',
'changedsince'            => 'geändert seit',
'updatefs'                => 'Bitte aktualisieren Sie Ihre Flyspray-Installation.',
'currentversion'          => 'Die installierte Version ist',
'latestversion'           => 'und die aktuellste Version ist',
'hidemessage'             => '(später erinnern)',
'saveas'                  => 'Suche speichern als',
'nosearches'              => 'Keine Suchprofile vorhanden',
'saving'                  => 'Speichern...',
'votes'                   => 'Stimmen',
'tovote'                  => 'abstimmen',
'allclosedtasks'          => 'alle geschlossenen ',
'password'                => 'Passwort',
'login'                   => 'Login',
'rememberme'              => 'Bei jedem Besuch automatisch anmelden',
'lostpassword'            => 'Passwort vergessen?',
'lostpwforfs'             => 'Hat das Passwort für Flyspray vergessen',
'lostpwmsg1'              => "Hallo,\n\nich habe mein Passwort für Flyspray auf ",
'lostpwmsg2'              => "vergessen. Bitte senden Sie mir ein neues Passwort.\n\nBenutzername: ",
'regards'                 => "Vielen Dank,\n",
'yourusername'            => ' Ihr Benutzername ',
'locale'                  => 'de-DE',
'filenotexist'            => "Die Datei ist nicht vorhanden oder Sie sind nicht zum Zugriff berechtigt.\n",
'showtask'                => 'Zeige Aufgabe',
'now'                     => 'jetzt',
'go'                      => 'Los!',
'opentaskanon'            => 'neue Aufgabe anonym anlegen',
'register'                => 'als neuer Benutzer registrieren',
'addnewtask'              => 'neue Aufgabe anlegen',
'reports'                 => 'Berichte',
'editmydetails'           => 'meine Benutzerdaten bearbeiten',
'logout'                  => 'Logout',
'disabledaccount'         => "Ihr Konto wurde deaktiviert!\n\nSie werden jetzt abgemeldet...",
'poweredby'               => 'Powered by Flyspray',
'sponsoredby'             => 'Flyspray wird finanziert durch ',
'projects'                => 'Projekte',
'allprojects'             => 'Alle Projekte',
'selectproject'           => 'im Projekt:',
'tasksall'                => 'Alle Aufgaben',
'tasksassigned'           => 'mir übertragene Aufgaben',
'tasksreported'           => 'Aufgaben, die ich angelegt habe',
'taskswatched'            => 'von mir beobachtete',
'mysearch'                => 'meine Suchprofile',
'admintoolbox'            => 'Verwaltungswerkzeuge',
'manageproject'           => 'Projektverwaltung',
'permissions'             => 'Berechtigungen',
'hide'                    => 'verstecken',
'pendingreq'              => 'Anstehende Anfragen an den Projektmanager',
'errorpage'               => "Die angeforderte Seite kann nicht angezeigt werden.\n\nMöglicherweise haben Sie eine nicht vorhandene Aufgabe ausgewählt oder Sie besitzen keine Berechtigung, um die aufgerufene Seite anzuzeigen. \n\nFalls Sie versucht haben eine Sicherheitslücke wie beispielsweise SQL-Injection auszunutzen, gehen Sie in die Ecke und schämen sich! Bitte versuchen Sie es nicht noch einmal.",
'permissionsforproject'   => 'Berechtigungen für ',
'switchto'                => 'auswählen',
'lastsearch'              => 'meine letzte Suche',
'modify'                  => 'ändern',
'noticefrom'              => 'Nachricht von',
'hasopened'               => 'hat eine neue Flyspray-Aufgabe angelegt und Ihnen übertragen:',
'moreinfonew'             => 'Einzelheiten zu dieser Aufgabe erfahren Sie auf folgender Flyspray-Seite:',
'newtaskcategory'         => 'Eine neue Flyspray-Aufgabe wurde in dieser Kategorie angelegt',
'categoryowner'           => 'Sie erhalten diese Nachricht, weil Sie für diese Kategorie zuständig sind.',
'tasksummary'             => 'Zusammenfassung:',
'newtaskadded'            => 'Ihre neue Aufgabe wurde hinzugefügt.',
'summaryanddetails'       => 'Sie müssen sowohl eine Zusammenfassung als auch eine Beschreibung angeben.',
'summaryrequired'         => 'Bitte geben Sie eine kurze Aufgabenbeschreibung an.',
'goback'                  => 'zurück',
'messagefrom'             => 'Dies ist eine Nachricht vom Flyspray Bugtracking-System auf ',
'hasjustmodified'         => 'hat soeben folgende Aufgabe geändert:',
'changedfields'           => 'Veränderte Felder sind mit Sternchen gekennzeichnet (**)',
'moreinfomodify'          => 'Weitere Informationen zu dieser Aufgabe auf',
'nolongerassigned'        => 'Für die nachstehende Aufgabe sind Sie nicht mehr zuständig. Die Aufgabe wurde übertragen an ',
'hasassigned'             => 'hat Ihnen die folgende Flyspray-Aufgabe übertragen:',
'taskupdated'             => 'Aufgabe wurde aktualisiert.',
'tasksupdated'            => 'Die Aufgabe wurde aktualisiert.',
'hasclosedassigned'       => 'hat die folgende Flyspray-Aufgabe geschlossen, die Ihnen übertragen war:',
'unassigned'              => 'niemandem übertragen',
'hasclosed'               => 'hat die folgende Aufgabe geschlossen:',
'youonnotify'             => 'Sie erhalten diese Nachricht, weil Sie auf der Benachrichtigungsliste geführt sind.',
'taskclosedmsg'           => 'Die Aufgabe wurde geschlossen.',
'returntotask'            => 'zurück zu den Aufgabendetails',
'backtoindex'             => 'zurück zur Aufgabenliste',
'noclosereason'           => 'Sie haben keinen Grund für das Schließen der Aufgabe angegeben.',
'hasreopened'             => 'hat folgende Flyspray-Aufgabe wieder geöffnet, die Sie bereits geschlossen hatten:',
'taskreopenedmsg'         => 'Die Aufgabe wurde wieder geöffnet.',
'backtotask'              => 'zurück zur Aufgabe.',
'commentaddedmsg'         => 'Der Kommentar wurde hinzugefügt',
'commenttoassigned'       => 'hat einen Kommentar zu einer Aufgabe hinzugefügt, die Ihnen übertragen ist: ',
'commenttotask'           => 'hat folgenden Kommentar zur Aufgabe abgegeben: ',
'nocommententered'        => 'Schreiben Sie einen Kommentar bevor Sie das Formular abschicken.',
'fillinfields'            => 'Sie haben nicht alle Felder ausgefüllt.',
'notcurrentpass'          => 'Das ist nicht Ihr aktuelles Passwort!',
'passchanged'             => 'Ihr Passwort wurde geändert.',
'closewindow'             => 'Sie können dieses Fenster jetzt schließen.',
'passnomatch'             => 'Neues Passwort und Bestätigung stimmen nicht überein!',
'usernametaken'           => 'Dieser Benutzername wurde bereits vergeben. Wählen Sie bitte einen anderen Namen.',
'usernametakenbulk'       => 'Benutzername schon vorhanden',
'newusercreated'          => 'Neues Benutzerkonto wurde angelegt.',
'accountcreated'          => 'Ihr Konto wurde angelegt.',
'newuserwarning'          => 'Ihr Konto muss möglicherweise von einem Administrator aktiviert werden, bevor Sie sich das erste Mal anmelden können.',
'nomatchpass'             => 'Ihre Passwörter stimmen nicht überein!',
'confirmwrong'            => 'Bestätigungscode ungültig!',
'formnotcomplete'         => 'Formular wurde nicht vollständig ausgefüllt.',
'formnotnumeric'          => 'Die Eingabe war nicht numerisch!',
'groupnametaken'          => 'Dieser Gruppenname ist bereits vorhanden.',
'newgroupadded'           => 'Neue Gruppe hinzugefügt.',
'optionssaved'            => 'Flyspray-Optionen gespeichert.',
'hasuploaded'             => 'hat eine Datei an eine Aufgabe angehängt, die Ihnen übertragen ist: ',
'hasattached'             => 'hat eine Datei an folgende Aufgabe angehängt: ',
'fileuploaded'            => 'Datei wurde hochgeladen.',
'fileerror'               => 'Fehler beim Hochladen der Datei. Vielleicht stimmen die Berechtigungen für das <code>attachments</code> Verzeichnis nicht.',
'contactadmin'            => 'Wenden Sie sich an den Administrator des Projekts.',
'selectfileerror'         => 'Sie haben keine Datei ausgewählt.',
'userupdated'             => 'Benutzerdetails wurden aktualisiert',
'realandemail'            => 'Sie müssen beide Felder "vollständiger Name" und "E-Mail" ausfüllen.',
'groupupdated'            => 'Gruppendefinition aktualisiert.',
'groupanddesc'            => 'Sie haben keinen Gruppennamen und/oder keine Beschreibung eingegeben.',
'fillallfields'           => 'Bitte füllen Sie alle Felder aus.',
'listPmustN'              => 'Der Wert für die Reihenfolge muss numerisch sein.',
'listupdated'             => 'Die Liste wurde aktualisiert.',
'listitemadded'           => 'Neues Listenelement hinzugefügt.',
'relatedaddedmsg'         => 'Verknüpfte Aufgabe zur Liste hinzugefügt.',
'relatederror'            => 'Zu dieser Aufgabe besteht bereits eine Verbindung.',
'relatedremoved'          => 'Die Verbindung zu der Aufgabe wurde entfernt.',
'notifyadded'             => 'Der Benutzer wird ab jetzt benachrichtigt.',
'notifyerror'             => 'Dieser Benutzer erhält bereits Benachrichtigungen zu dieser Aufgabe.',
'notifyremoved'           => 'Der Benutzer wird ab jetzt nicht mehr benachrichtigt.',
'editcommentsaved'        => 'Geänderten Kommentar gespeichert.',
'commentdeletedmsg'       => 'Der Kommentar wurde gelöscht.',
'gotonewtask'             => 'Zu den Details der soeben erstellten Aufgabe',
'projectcreated'          => 'Ihr neues Projekt wurde erstellt. Sie können das Projekt jetzt unter "Projektverwaltung" einrichten.',
'customiseproject'        => 'Dieses Projekt anpassen',
'projectupdated'          => 'Projekteinstellungen gespeichert.',
'emptytitle'              => 'Bitte geben Sie einen Projektnamen an.',
'loginbelow'              => 'Sie können sich nun anmelden.',
'attachmentdeletedmsg'    => 'Der Anhang wurde gelöscht',
'reminderaddedmsg'        => 'Ihre Erinnerung wurde eingerichtet.',
'reminderdeletedmsg'      => 'Die ausgewählte Erinnerung wurde gelöscht.',
'flyspraytask'            => 'Flyspray-Aufgabe',
'fieldsmissing'           => 'Felder ohne oder mit ungültigen Werten wurden ignoriert.',
'relatedinvalid'          => 'Aufgabe nicht vorhanden.',
'relatedproject'          => 'Die gewählte Aufgabe gehört zu einem anderen Projekt.',
'addanyway'               => 'Dennoch hinzufügen',
'cancel'                  => 'abbrechen',
'alreadyedited'           => 'Die Aufgabe wurde von einem anderen Benutzer bearbeitet, während Sie Ihre Änderungen vorgenommen haben. Wollen Sie dennoch speichern und die Bearbeitung des anderen Benutzers damit überschreiben?',
'saveanyway'              => 'Meine Änderungen speichern',
'nouserselected'          => 'Keinen Benutzer ausgewählt. Markieren Sie mindestens einen Benutzer und versuchen Sie es erneut.',
'groupswitchupdated'      => 'Benutzergruppen erfolgreich geändert.',
'takenownershipmsg'       => 'Jetzt wurde Ihnen die Aufgabe übertragen.',
'adminrequestmade'        => 'Ein Projektmanager wurde über Ihre Anfrage informiert.',
'newdepnotify'            => 'Eine neue Abhängigkeit wurde zur folgenden Aufgabe hinzugefügt: ',
'dependadded'             => 'Abhängigkeit wurde hinzugefügt',
'dependaddfailed'         => 'Sie können diese Aufgabe im Moment nicht als Abhängigkeit hinzufügen',
'depremovedmsg'           => 'Die Abhängigkeit von der anderen Aufgabe wurde entfernt.',
'newdepis'                => 'Die neue Abhängigkeit ist',
'magicurlsent'            => 'Eine Nachricht mit einem Link auf die Seite zum Vervollständigen der Aufgabe wurde an Ihre Benachrichtigungsadresse geschickt.',
'changefspass'            => 'Flyspray-Passwort ändern',
'magicurlmessage'         => 'Bitte folgen Sie diesem Link, um Ihr Passwort zu ändern: ',
'erroronform'             => 'Bei der Verarbeitung der Formulareingaben ist ein Problem aufgetreten',
'addressused'             => "Diese Adresse wurde verwendet, um ein Flyspray-Benutzerkonto anzulegen. Wenn Sie diese Nachricht nicht erwartet haben, ignorieren und löschen Sie diese bitte. \n\n(This address has been used to register a Flyspray account. If you were not expecting this message, please ignore and delete it.)\n\nBenutzen Sie folgenden Aktivierungslink um die Registrierung abzuschließen: ",
'confirmcodeis'           => 'Ihr Bestätigungscode:',
'codesent'                => 'Ihr Bestätigungscode wurde versandt. Folgen Sie bitte den Anweisungen in der Nachricht.',
'codenotsent'             => 'Ihr Bestätigungscode konnte nicht versandt werden. Bitte versuchen Sie es später erneut.',
'taskmadeprivatemsg'      => 'Diese Aufgabe ist nun versteckt',
'taskmadepublicmsg'       => 'Diese Aufgabe ist nun wieder öffentlich sichtbar',
'realandnotify'           => 'Sie müssen die Felder "vollständiger Name" und entweder "E-Mail" oder "Jabber-ID" ausfüllen.',
'pmreqdeniedmsg'          => 'Der Projektmanager hat die Anfrage abgelehnt.',
'massopsenable'           => 'Erlaube Massenänderungen',
'massopsuccess'           => 'Vorgang auf allen Elementen erfolgreich, bei denen die Berechtigungen ausreichend waren',
'usernotexist'            => 'Dieser Benutzer ist in dieser Flyspray-Instanz nicht vorhanden.',
'commentattachperms'      => 'Sie können diesen Kommentar nicht löschen - Sie haben keine Berechtigung zum Löschen von Anhängen.',
'voterecorded'            => 'Ihre Stimme wurde registriert.',
'votefailed'              => 'Ihre Stimme kann momentan nicht hinzugefügt werden.',
'createnewgroup'          => 'Neue Gruppe erstellen',
'requiredfields'          => 'Notwendige Felder sind gekennzeichnet:',
'addthisgroup'            => 'Gruppe hinzufügen',
'createnewproject'        => 'neues Projekt',
'addnewproject'           => 'neues Projekt hinzufügen',
'htmlallowed'             => 'HTML-Code zulassen',
'createthisproject'       => 'Projekt erstellen',
'inlineimages'            => 'angehängte Bilder als Vorschau anzeigen',
'createnewtask'           => 'Neue Aufgabe in diesem Projekt anlegen:',
'addanother'              => 'weitere Aufgabe nach dieser hinzufügen',
'addthistask'             => 'Aufgabe hinzufügen',
'notifyme'                => 'Automatische Benachrichtigung bei Änderungen an dieser Aufgabe',
'newtask'                 => 'neue Aufgabe',
'attachafile'             => 'Datei anhängen',
'registernewuser'         => 'neuen Benutzer registrieren',
'none'                    => 'nichts',
'registeraccount'         => 'Konto registrieren',
'registerbulkaccount'     => 'Nutzer registrieren',
'both'                    => 'E-Mail und Jabber',
'notifyfrom'              => 'Benachrichtigung von ',
'donotreply'              => 'DIES IST EINE AUTOMATISCH ERSTELLTE NACHRICHT, BITTE NICHT ANTWORTEN.',
'disclaimer'              => 'Sie erhalten diese Nachricht, weil Sie in Flyspray Benachrichtigungen aktiviert haben. Wenn Sie zukünftig keine solchen Benachrichtigungen mehr erhalten wollen, können Sie die Einstellungen für Benachrichtigungen über die obenstehende URL ändern.',
'userwho'                 => 'Benutzer der dies getan hat',
'moreinfo'                => 'Mehr Informationen können unter der folgenden URL abgerufen werden: ',
'newtaskopened'           => 'Eine neue Flyspray Aufgabe wurde angelegt. Details siehe unten.',
'notify.taskclosed'       => 'Diese Aufgabe ist nun geschlossen:',
'notify.taskreopened'     => 'Diese Aufgabe wurde wieder geöffnet:',
'newdep'                  => 'Diese Aufgabe besitzt eine neue Abhängigkeit:',
'notify.depremoved'       => 'Von dieser Aufgabe wurde die Abhängigkeit entfernt:',
'olddepwas'               => 'Die alte Abhängigkeit war',
'notify.commentadded'     => 'Dieser Aufgabe wurde ein neuer Kommentar hinzugefügt:',
'commentis'               => 'Der Kommentartext folgt.',
'newattachment'           => 'Dieser Aufgabe wurde eine Datei angehängt:',
'detailsbelow'            => 'Details siehe unten.',
'notify.relatedadded'     => 'Dieser Aufgabe wurde eine Beziehung zu einer anderen Aufgabe zugeordnet:',
'relatedis'               => 'Die abhängige Aufgabe ist',
'assignedtoyou'           => 'Die folgende Aufgabe wurde Ihnen übertragen: ',
'takenownership'          => 'ist jetzt Eigentümer der folgenden Aufgabe: ',
'requiresaction'          => 'Diese Aufgabe benötigt die Bearbeitung durch einen Projektmanager:',
'requiresactionnotify'    => 'Die Aufgabe benötigt die Bearbeitung durch einen Projektmanager.',
'pmdeny'                  => 'Ein Projektmanager hat die für folgende Aufgabe anstehende Anfrage abgelehnt: ',
'pmdenynotify'            => 'Ein Projektmanager hat die Anfrage abgelehnt',
'fileaddedtoo'            => 'Eine oder mehrere Dateien wurden hinzugefügt.',
'taskwatching'            => 'Diese Aufgabe beobachten Sie',
'isdepfor'                => 'bildet eine neue Abhängigkeit für Aufgabe ',
'denialreason'            => 'Grund der Ablehnung',
'taskchanged'             => 'Die nachstehende Aufgabe wurde geändert (Details siehe unten). Vollständige Informationen über Änderungen erreichen Sie über die angegebene URL unter dem Tab "Verlauf".',
'useraddedtoassignees'    => 'Ein Benutzer hat die Aufgabe selbst übernommen.',
'removeddepis'            => 'Die gelöschte Abhängigkeit ist',
'isnodepfor'              => 'ist nicht mehr abhängig von',
'usergroups'              => 'Benutzergruppen',
'pmtoolbox'               => 'Projektverwaltung',
'groupmanage'             => 'Benutzer und Gruppen',
'pendingrequests'         => 'anliegende Anfragen',
'reasongiven'             => 'Begründung',
'nopendingreq'            => 'Es gibt zur Zeit keine offenen Anfragen an den Projektmanager',
'givereason'              => 'Geben Sie eine Begründung',
'catlisted'               => 'Kategorien-Editor',
'oslisted'                => 'Betriebssystems-Editor',
'verlisted'               => 'Versions-Editor',
'tasktypeed'              => 'Aufgabentypen-Editor',
'resed'                   => 'Lösungen-Editor',
'deny'                    => 'ablehnen',
'notifiedwhen'            => 'Benachrichtigen wenn',
'onlynewtasks'            => 'neu angelegte Aufgaben',
'allevents'               => 'Bei allen Ereignissen in einer beliebigen Aufgabe',
'feeds'                   => 'Newsfeeds',
'feeddescription'         => 'Newsfeed Beschreibung',
'feedimgurl'              => 'Newsfeed Bild URL (leer zeigt kein Bild an)',
'notifysubject'           => 'Betreff',
'notifysubjectinfo'       => '(%p = Projektname, %s = Zusammenfassung, %t = Aufgaben-ID, %a = Aktion, %u = Benutzer)',
'priority6'               => 'sofort',
'priority5'               => 'eilig',
'priority4'               => 'hoch',
'priority3'               => 'normal',
'priority2'               => 'gering',
'priority1'               => 'verschoben',
'sendcode'                => 'Code senden!',
'entercode'               => 'Ihr Bestätigungscode wurde versandt. Geben Sie ihn nach Erhalt zusammen mit Ihrem gewünschten Passwort in untenstehendem Formular ein.',
'confirmationcode'        => 'Bestätigungscode',
'registererror'           => 'Stellen Sie sicher, dass Sie alle notwendigen Felder ausgefüllt und korrekte Angaben zu Ihrem gewählten Benachrichtigungsweg gemacht haben.',
'validusername'           => '(nur alphanumerische Zeichen und - _ . sind erlaubt)',
'validemail'              => '( Semikolon ; nutzen, um mehrere Emailadressen anzugeben)',
'emailtakenbulk'          => 'Emailadresse schon vergeben',
'emailtaken'              => 'Diese E-Mail Adresse oder Jabber-ID wird bereits benutzt. Bitte wählen Sie eine andere.',
'note'                    => '<em>Hinweis:</em> Ihnen wird auf dem gewählten Weg ein Bestätigungscode zugesandt, bevor Ihr Konto eröffnet wird. <strong>Wenn Sie falsche Angaben machen, werden Sie den Code nicht erhalten!</strong>',
'changelog'               => 'Verlauf',
'changeloggen'            => 'Verlauf Generator',
'listfrom'                => 'Liste der Änderungen von',
'to'                      => 'bis',
'oldestfirst'             => 'Älteste zuerst',
'recentfirst'             => 'Aktuellste zuerst',
'severityrep'             => 'Bericht nach Schweregrad',
'totalopen'               => 'Offene Aufgaben insgesamt',
'age'                     => 'Alter',
'agerep'                  => 'Bericht nach Alter',
'eventsrep'               => 'Ereignisbericht',
'events'                  => 'Ereignisse',
'Tasks'                   => 'Aufgaben',
'opened'                  => 'angelegt',
'edited'                  => 'geändert',
'assigned'                => 'Übertragen',
'within'                  => 'innerhalb',
'pastday'                 => 'des letzten Tages',
'pastweek'                => 'der letzten Woche',
'pastmonth'               => 'des letzten Monats',
'pastyear'                => 'des letzten Jahres',
'nolimit'                 => 'unbegrenzt',
'from'                    => 'von',
'duein'                   => 'fällig in',
'selectfromdate'          => 'Startdatum',
'selecttodate'            => 'Enddatum',
'showvoters'              => 'Anzeigen/Ausblenden der Wähler',
'roadmap'                 => 'Planung',
'roadmapfor'              => 'Planung für',
'tasks'                   => 'Aufgaben',
'completed'               => 'erledigt.',
'opentasks'               => 'offene Aufgaben',
'of'                      => '% von',
'severity5'               => 'kritisch',
'severity4'               => 'hoch',
'severity3'               => 'mittel',
'severity2'               => 'niedrig',
'severity1'               => 'sehr niedrig',
'Redirect'                => 'weiterleiten',
'redirectmsg'             => 'Falls Ihr Browser Sie nicht automatisch weiterleitet, klicken Sie bitte %sHERE%s.',
'allowclosedcomments'     => 'Kommentare zu geschlossenen Aufgaben erlauben',
'comment'                 => 'Kommentar',
'editowncomments'         => 'eigene Kommentare bearbeiten',
'reopened'                => 'wieder geöffnet',
'loading'                 => 'Lade...',
'notifyown'               => 'bei eigenen Änderungen benachrichtigen',
'youremail'               => 'Ihre E-Mail Adresse',
'thankyouforbug'          => 'Vielen Dank für den Problembericht. Sie können Ihren Bericht und seine Bearbeitung jederzeit unter folgender URL verfolgen: ',
'anonuser'                => 'Anonymer Benutzer',
'conflict'                => 'Widerspruch',
'file'                    => 'Datei',
'KiB'                     => 'KB',
'MiB'                     => 'MB',
'size'                    => 'Größe',
'projectgroup'            => 'Projektgruppe',
'profile'                 => 'Profil',
'viewprofile'             => 'Profil anzeigen',
'regdate'                 => 'registriert seit',
'tasksopened'             => 'angelegte Aufgaben',
'replyto'                 => 'Antwort an',
'notifytypes'             => 'Benachrichtigungsanlässe',
'pm.taskchanged'          => 'Aufgabe geändert',
'pm.taskreopened'         => 'Aufgabe wieder geöffnet',
'pm.depadded'             => 'Abhängigkeit hinzugefügt',
'pm.depremoved'           => 'Abhängigkeit entfernt',
'pmrequest'               => 'Anfrage an den Projektmanager',
'pmrequestdenied'         => 'Anfrage an den Projektmanager abgelehnt',
'newassignee'             => 'neue Zuständigkeit',
'revdepadded'             => 'Umgekehrte Abhängigkeit hinzugefügt',
'revdepaddedremoved'      => 'Umgekehrte Abhängigkeit entfernt',
'assigneeadded'           => 'Zuständigen hinzugefügt',
'addusergroup'            => 'Benutzer zur Gruppe hinzufügen',
'groupmembers'            => 'Gruppenmitglieder',
'deleteuser'              => 'Benutzer löschen',
'userdeleted'             => 'Benutzer gelöscht',
'autoassign'              => 'Aufgabe automatisch dem Kategorie-Inhaber übertragen',
'ssl'                     => 'SSL',
'updatewrong'             => 'Die Update-Prüfung ist aktiviert. Allerdings gab es Probleme, auf den Update-Server zuzugreifen. Entweder sind ausgehende Verbindungen nicht möglich oder es gab ein Netzwerk-Problem. Bitte besuchen Sie die Flyspray Website (http://flyspray.org), um die Aktualität Ihrer Version zu überprüfen.',
'deleteproject'           => 'Projekt löschen und Inhalte verschieben nach',
'projectdeleted'          => 'Das Projekt wurde gelöscht',
'feedforall'              => 'Newsfeed für alle Projekte',
'usercreated'             => 'Benutzer hinzugefügt',
'created'                 => 'erzeugt',
'deleted'                 => 'gelöscht',
'userid'                  => 'Benutzer-ID',
'editassignments'         => 'Zuständigkeit bearbeiten',
'preview'                 => 'Vorschau',
'anyprogress'             => 'beliebiger Fortschritt',
'tasksrelated'            => 'Aufgaben, die mit dieser verknüpft sind',
'duplicatetasks'          => 'Andere Aufgaben für dasselbe Problem',
'databasemodfailed'       => 'Änderungen an der Datenbank nicht möglich. Wahrscheinlich besitzen Sie nicht die notwendigen Rechte.',
'frequency'               => 'Häufigkeit',
'newuserregistered'       => 'Ein neuer Benutzer hat sich an Ihrer Flyspray-Instanz mit folgenden Benutzerdaten registriert: ',
'newuserregisterednotify' => 'Ein neuer Benutzer hat sich registriert',
'notify_registration'     => 'Administrator über neue Registrierungen informieren',
'textversion'             => 'Textversion',
'onlyprimary'             => 'Aufgaben, die keine anderen Aufgaben blockieren',
'onlyblocker'             => 'Aufgaben, die andere Aufgaben blockieren',
'blockerornoblocker'      => 'Entweder Blockierer oder Nichtblockierer wählen, beides zusammen bringt nix.',
'switch'                  => 'auswählen',
'max'                     => 'max.',
'dates'                   => 'Datum',
'selectduedatefrom'       => 'Fälligkeit von',
'selectduedateto'         => 'bis',
'selectsincedatefrom'     => 'verändert von',
'selectsincedateto'       => 'bis',
'selectdate'              => 'Datum wählen',
'selectopenedfrom'        => 'angelegt seit',
'selectopenedto'          => 'bis',
'selectclosedfrom'        => 'geschlossen von',
'selectclosedto'          => 'bis',
'startat'                 => 'begonnen von',
'hasattachment'           => 'mit Anhängen',
'private'                 => 'versteckt',
'watching'                => 'beobachtet',
'alreadyvotedthistask'    => 'Sie haben für diese Aufgabe gestimmt',
'alreadyvotedthisday'     => 'Sie haben heute schon abgestimmt',
'visibility'              => 'Sichtbarkeit',
'public'                  => 'Öffentlich sichtbar',
'leaveemptyauto'          => 'Lassen Sie das Passwort-Feld leer, um automatisch ein Passwort zu erzeugen.',
'novalidemail'            => 'Sie haben keine gültige E-Mail Adresse eingegeben.',
'novalidjabber'           => 'Sie haben keine gültige Jabber-Adresse eingegeben.',
'missingrequired'         => 'Sie haben nicht alle erforderlichen Felder ausgefüllt.',
'entervalidusername'      => 'Bitte geben Sie einen gültigen Benutzernamen und den vollständigen Namen an.',
'couldnotaddusernotif'    => 'Für den Benutzer konnte keine Benachrichtigung eingerichtet werden.',
'defaulttask'             => 'Standard Aufgabenbeschreibung',
'all'                     => 'alles',
'events.useraddedtoassignees'=> 'Zuständigen hinzugefügt',
'eventlog'                => 'Berichte',
'assignmentchanged'       => 'Zuständigkeit geändert',
'detailedinfo'            => 'Details',
'All'                     => 'alle',
'tasksireported'          => 'von mir angelegte',
'recentlyopened'          => 'kürzlich angelegte',
'stats'                   => 'Statistik',
'totaltasks'              => 'Aufgaben insgesamt',
'mostwanted'              => 'häufig angefragte Aufgaben',
'defaultentry'            => 'Zeige auf der Startseite',
'toplevel'                => 'Top Level Ansicht',
'overview'                => 'Überblick',
'error#'                  => 'FEHLER #',
'error1'                  => 'Sie sind nicht zur Anzeige dieses Anhangs berechtigt!',
'error3'                  => 'Wiederholte Aktion, zur Hauptseite umgeleitet!',
'error4'                  => 'Sie haben keine Administrator-Rechte!',
'error5'                  => 'Dieser Benutzer ist in dieser Flyspray-Instanz nicht vorhanden!',
'error6'                  => 'Ungültiger Administrator-Bereich!',
'error7'                  => 'Anmeldung nicht möglich (Benutzername oder Passwort falsch)!',
'error71'                 => 'Zugang wurde für %d Minuten gesperrt wegen zu vieler fehlerhafter Loginversuche.',
'error8'                  => 'Sie müssen einen Benutzernamen UND ein Passwort eingeben.',
'error9'                  => 'Die Aufgabe ist nicht vorhanden oder Sie sind nicht zur Anzeige berechtigt!',
'error10'                 => 'Die Aufgabe ist nicht vorhanden oder Sie sind zur Anzeige nicht berechtigt!',
'error101'                => 'Sie haben keine Berechtigung diese Aufgabe anzuschauen.',
'error102'                => 'Sie haben keine Berechtigung diese Aufgabe anzuschauen, vielleicht hilft sich anzumelden.',
'error11'                 => 'Sie sind nicht berechtigt, diesen Kommentar zu bearbeiten!',
'error12'                 => "Ungültiger Aktivierungsschlüssel! \nHaben Sie diesen korrekt aus der Nachricht übernommen?",
'error13'                 => 'Anonyme Benutzer besitzen kein Profil!',
'error14'                 => 'Sie sind nicht berechtigt eine neue Gruppe zu erzeugen!',
'error15'                 => 'Sie sind nicht berechtigt eine Aufgabe anzulegen!',
'error16'                 => 'Sie sind kein Projektmanager!',
'error17'                 => 'Ungültiger Projektmanager-Bereich!',
'error18'                 => 'Ungültige Aktivierungs-URL!',
'error19'                 => 'Dieser Benutzer ist in dieser Flyspray-Instanz nicht vorhanden!',
'error20'                 => 'Ungültiger Schreibvorgang in der Datenbank!',
'error21'                 => "Ein oder mehrere E-Mails konnten nicht versandt werden! \nPrüfen Sie die Konfiguration.",
'error22'                 => 'Die Registrierung neuer Benutzer ist nicht erlaubt!',
'error23'                 => 'Der Benutzer oder die Gruppe wurde nicht zum Login berechtigt!',
'error24'                 => 'Das Programm "dot" ist weder lokal noch für einen öffentlichen dot-Server konfiguriert!',
'error25'                 => 'Die Planung gibt es nur jeweils für ein einzelnes Projekt!',
'error26'                 => 'derzeit nicht unterstützter OAuth-Anbieter.',
'error27'                 => 'Konnte den Nutzer nicht anmelden. Bitte erlauben Sie uns ihre Emailadresse zu sehen.',
'error28'                 => 'Sie haben keine Erlaubnis für diesen Bereich.',
'done'                    => 'erledigt',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Das Projekt konnte nicht gelöscht werden.',
'GMT'                     => 'UTC',
'timezone'                => 'Zeitzone',
'accept'                  => 'akzeptiert',
'reasonfordeinal'         => 'Grund der Ablehnung',
'pruneclosedlinks'        => 'Geschlossene Links ausblenden',
'pruneclosedtasks'        => 'Geschlossene Aufgaben ausblenden',
'pagegenerated'           => 'Seite und Bilder in %d Sekunden erzeugt.',
'pruninglevel'            => 'Darstellung',
'lastuser'                => 'Es muss mindestens ein Benutzer erhalten bleiben.',
'allprivate'              => 'Es gibt keine öffentlich sichtbaren Projekte.',
'deletegroup'             => 'Lösche diese Gruppe und verschiebe die Benutzer in',
'parent'                  => 'übergeordnetes Element',
'ordertip'                => 'Reihenfolge der Elemente',
'showtip'                 => 'Element anzeigen',
'deletetip'               => 'Element löschen',
'del'                     => 'entfernen',
'request1'                => 'Schließen einer Aufgaben wurde angefragt.',
'request2'                => 'Wiedereröffnung einer Aufgabe wurde angefragt.',
'allpriorities'           => 'Alle Prioritäten',
'noroadmap'               => 'Es ist keine Planung verfügbar, da für das Projekt keine Version für die "Zukunft" vorhanden ist.',
'expand'                  => 'aufklappen',
'collapse'                => 'zusammenklappen',
'expandall'               => 'alle aufklappen',
'collapseall'             => 'alle zusammenklappen',
'minpwsize'               => 'Das Passwort muss mindestens 5 Zeichen haben',
'passwordtoosmall'        => 'Das Passwort ist zu kurz.',
'accountwaslocked'        => 'Ihr Zugang wurde wegen zu vielen fehlerhaften Loginversuchen gesperrt.',
'failedattempts'          => 'Es gab %d fehlerhafte Loginversuche.',
'groupnotexist'           => 'Die gewählte Gruppe existiert nicht in diesem Projekt.',
'searchindetails'         => 'Suche in Aufgabentexten',
'showasassignees'         => 'Als mögliche Bearbeiter anzeigen',
'find'                    => 'finden',
'tls'                     => 'TLS',
'isadmin'                 => 'ist Admin',
'addvotes'                => 'Abstimmungen hinzufügen',
'removevote'              => 'Abstimmung entfernen',
'voteremoved'             => 'Ihre Abstimmung wurde entfernt',
'voteremovefailed'        => 'Ihre Abstimmung konnte momentan nicht entfernt werden.',
'novotes'                 => 'Du hast derzeit für keine Aufgabe abgestimmt.',
'connectedtasks'          => 'Verbundene Aufgaben:',
'taskdependencies'        => 'Abhängigkeiten',
'viewgraph'               => 'Diagramm anzeigen',
'notaskdependencies'      => 'Diese Aufgabe hängt von keiner anderen Aufgabe ab.',
'dependson'               => 'abhängig von',
'blocks'                  => 'blockiert',
'newdependency'           => 'Neue Abhängigkeit:',
'nouserstoadd'            => 'Kein Nutzer eingetragen. Name, Nutzername und Emailadresse sind notwendig für jeden Nutzer.',
'dispintro'               => 'Zeige Projektbeschreibung',
'mainmessage'             => 'Einführungstext',
'setsupertask'            => 'übergeordnete Aufgabe setzen (ID):',
'supertaskmodified'       => 'übergeordnete Aufgabe geändert',
'set'                     => 'Setzen',
'supertask'               => 'übergeordnete Aufgabe',
'setparent'               => 'Oberaufgabe für diese Aufgabe',
'selfsupertasknotallowed' => 'Aufgabe darf nicht sich selbst übergeordnete Aufgabe sein',
'quickaction'             => 'Schnellaktionen',
'updateselectedtasks'     => 'Aktualisiere ausgewählte Aufgaben',
'notspecified'            => 'nicht angegeben',
'editselectedtasks'       => 'Bearbeite ausgewählte Aufgaben',
'information'             => 'Information',
'taskclosedisabled'       => 'Das Schließen dieser Aufgabe ist derzeit aus folgenden Gründen nicht möglich:',
'daysleft'                => 'Tage verbleibend',
'dayoverdue'              => 'Tage überfällig',
'duetoday'                => 'bis heute',
'daysbeforealert'         => 'Tage vor Erinnerung',
'associatedsubtask'       => 'Erfolgreich Unteraufgabe #FS%d verknüpft',
'associatesubtask'        => 'Verknüpfe eine Unteraufgabe mit dieser Aufgabe',
'subtaskid'               => 'UnteraufgabenID',
'subtaskalreadyhasparent' => 'Diese Unteraufgabe hat bereits eine Oberaufgabe. Bitte diese Verknüpfung vorher auftrennen bevor andere Oberaufgabe.',
'subtaskisparent'         => 'Die eingegebene Unteraufgabe ist schon die Oberaufgabe der Aufgabe. Zyklische Verknüpfung nicht erlaubt.',
'subtasknotexist'         => 'Diese Unteraufgabe existiert nicht.',
'subtaskremovedmsg'       => 'Die Unteraufgabe wurde erfolgreich entfernt.',
'subtaskadded'            => 'Unteraufgabe hinzugefügt',
'subtaskremoved'          => 'Unteraufgabe entfernt',
'addnewsubtask'           => 'Neue untergeordnete Aufgabe',
'hidesubtasks'            => 'untergeordnete Aufgaben ausblenden',
'voteforthistask'         => 'Stimme für diese Aufgabe',
'watchthistask'           => 'Beobachte diese Aufgabe',
'privatethistask'         => 'Aufgabe auf privat setzen',
'adddependenttask'        => 'abhängige Aufgabe verknüpfen',
'associatetaskid'         => 'ID der Unteraufgabe',
'parenttaskid'            => 'Oberaufgaben-ID',
'invalidsupertaskid'      => 'Oberaufgaben-ID ist ungültig.',
'supertaskadded'          => 'Gruppierungsaufgabe hinzugefügt',
'supertaskremoved'        => 'übergeordnete Aufgabe gelöscht',
'effort'                  => 'Aufwand',
'efforttracking'          => 'Aufwandmessung',
'useeffort'               => 'Projekt nutzt Aufwandmessung',
'estimatedeffort'         => 'geschätzter Aufwand',
'totalestimatedeffort'    => 'geschätzter Gesamtaufwand',
'currenteffortdone'       => 'bisher erfolgter Aufwand',
'starteffort'             => 'Starte Aufwandmessung',
'endeffort'               => 'Stoppe Aufwandmessung',
'cleareffort'             => 'Entferne Aufwandmessung',
'addeffort'               => 'Aufwand hinzufügen',
'manualeffort'            => 'Aufwand eintragen (H:M)',
'efforttrackingstarted'   => 'Aufwandmessung für diese Aufgabe.',
'efforttrackingnotstarted'=> 'Die Aufwandmessung kann nicht gestarted werden, da für diese Aufgabe schon eine Messung läuft.',
'efforttrackingstopped'   => 'Aufwandsmessung für diese Aufgabe wurde gestoppt.',
'efforttrackingcancelled' => 'Aufwandsmessung abgebrochen für diese Aufgabe.',
'efforttrackingadded'     => 'Aufwandseintrag für diese Aufgabe wurde gespeichert.',
'trackinginprogress'      => 'Aufwandsmessung läuft',
'viewestimatedeffort'     => 'Kann Aufwandsmessung anschauen',
'viewcurrenteffortdone'   => 'darf erfolgten Arbeitsaufwand anschauen',
'trackeffort'             => 'kann Aufwandsmessung nutzen',
'invalideffort'           => 'Der eingegebene Aufwand ist ungültig. Es muss eine Zahl sein.',
'showpass'                => 'Zeige Passwort',
'chooseafile'             => 'Bitte eine Datei wählen.',
'incorrectfiletype'       => 'ungültiger Dateityp. Erlaubt sind jpg, jpeg, gif und png.',
'oauthreqpass'            => 'Kein Passwort vorhanden. Sie haben sich mit %s registriert.',
'addmultipletasks'        => 'mehrere Aufgaben anlegen',
'pendingnewuserrequest'   => 'wartende neue Nutzeranfrage',
'adminrequestswaiting'    => 'wartende Administratoranfragen',
'clicktoedit'             => 'Werte anklicken zur Schnellbearbeitung',
'confirmedit'             => 'speichern',
'regapprovedbyadmin'      => 'Registrierung muß durch einen Administrator bestätigt werden (Bestätigungscode ohne Bedeutung)',
'activity'                => 'Aktivität',
'myactivity'              => 'meine Aktivitäten',
'emailverificationwrong'  => 'Die beiden eingegebenen Emailadressen stimmen nicht überein',
'verifyemailaddress'      => 'Emailadresse wiederholen',
'hideemails'              => 'Emailadressen verbergen',
'hidemyemail'             => 'Emailadresse verbergen',
'exporttasklist'          => 'Aufgabenliste exportieren',
'onedecimal'              => 'eine Dezimalstelle',
'manday'                  => 'Manntag',
'mandays'                 => 'Manntage',
'mandayabbrev'            => 'Manntag',
'hourspermanday'          => 'Arbeitsstunden pro Manntag',
'itemexists'              => 'Eintrag %s existiert bereits in der Datenbank.',
'categoryitemexists'      => 'Eintrag %s existiert bereits in der Kategorie %s in der Datenbank.',
'pageswelcomemsg'         => 'Seiten, auf denen der Flysprayeinführungstext zu sehen ist',
'pagesintromsg'           => 'Seiten, auf denen der Projekteinführungstext zu sehen ist',
'activeoauths'            => 'zugelassene OAuth-Anbieter',
'onlyoauthreg'            => 'nur Anmeldung per OAuth erlauben',
'estimatedeffortformat'   => 'Anzeigeformat für geschätzten Arbeitsaufwand',
'currenteffortdoneformat' => 'Anzeigeformat für erfolgten Arbeitsaufwand',
'minute'                  => 'Minute',
'minutes'                 => 'Minuten',
'minuteplural'            => 'Minuten',
'minutesingular'          => 'Minute',
'minuteabbrev'            => 'min',
'hourplural'              => 'Stunden',
'hoursingular'            => 'Stunde',
'hourabbrev'              => 'h',
'estimatedeffortopen'     => 'geschätzter Arbeitsaufwand offener Aufgaben',
'currenteffortdoneopen'   => 'bisher erfolgter Arbeitsaufwand bei offenen Aufgaben',
'signinwith'              => 'Anmelden mit %s',
'canviewroadmap'          => 'darf Planung anschauen',
'enableavatars'           => 'Profilfotos aktivieren',
'maxavatarsize'           => 'maximale Profilfotobreite in Pixeln',
'taskhassubtask'          => 'Diese Aufgabe hat folgende Unteraufgabe',
'taskhassubtasks'         => 'Diese Aufgabe hat folgende Unteraufgaben',
'translations'            => 'Übersetzungen',
'translate'               => 'Übersetze',
'taskdescription'         => 'Aufgabenbeschreibung',
'notaskdescription'       => 'nicht vorhanden',
'pleaseselect'            => 'Bitte auswählen',
'closeselectedtasks'      => 'ausgewählte Aufgaben schließen',
'closetasks'              => 'Aufgaben schließen',
'hintforbulkimport'       => "<b>Hinweise zum Mehrfachimport</b>\n  <ol>\n  <li>Copy and paste from an excel spreadsheet or CSV by pasting one entire column.</li>\n  <li>Currently you can only paste Summary and Details.</li>\n  <li>Die Aufgabenzuweisung hat eine Autovervollständigenfunktion, einfach anfangen Namen einzutippen und Vorschläge werden angezeigt.</li>\n  </ol>",
'taskissubtaskof'         => 'Die Aufgabe ist eine Unteraufgabe von',
'applyfirstline'          => 'Erste Zeile in alle darunter kopieren',
'addmorerows'             => 'weitere Zeilen einfügen',
'addtasks'                => 'Aufgaben eintragen',
'massopsdisabled'         => 'Die Massenbearbeitung von Aufgaben ist derzeit abgeschaltet für Flyspray 1.0. Diese Fähigkeit wird wieder freigeschaltet, sobald die Überarbeitung abgeschlossen ist.',
'viewroadmap'             => 'Planung anschauen',
'nosuicide'               => 'Sehr geehrter Nutzer, es ist nicht erlaubt Ihren Zugang zu Flyspray zu zerstören in dem Sie Ihr eigenes Konto deaktivieren oder Ihre Gruppe wechseln. The empathic brother of HAL9000',
'movingtodifferentproject'=> 'Verschieben von einer Aufgabe zu einem anderen Projekt welche eine Ober- oder Unteraufgabe ist, ist nicht erlaubt. Sie müssen erst die Verbindung zwischen den Aufgaben trennen.',
'musthavesameproject'     => 'Ober- und Unteraufgabe müssen das gleiche Projekt haben.',
'defaultorderby'          => 'Aufgabenliste standardmäßig sortieren nach',
'defaultorderby2'         => '2. Sortierkriterium',
'viewowntasks'            => 'eigene Aufgaben anzeigen',
'viewgroupstasks'         => 'Gruppenaufgaben anzeigen',
'urlrewriting'            => 'hübsche URLs',
'enablehtaccess'          => 'Bitte aktivieren Sie Ihre .htaccess Datei im Flyspray Hauptverzeichnis bevor Sie "url rewriting" anwenden',
'nomodrewrite'            => 'Der "Mod rewrite" ist nicht auf Ihrem Server verfügbar, daher kann "url rewriting" nicht angewendet werden',
'on'                      => 'aktiviert',
'off'                     => 'deaktiviert',
'defaultorderbydirection' => 'Standardmäßig sortiert als',
'ascending'               => 'aufsteigend',
'descending'              => 'absteigend',
'myassignedtasks'         => 'Meine Aufgaben',
'commentedon'             => 'schrieb am',
'maxvoteperday'           => 'Stimmen pro Tag',
'votesperproject'         => 'Stimmen pro Projekt',
'votelimitreached'        => 'Sie haben die maximale Anzahl an Stimmen erreicht. Wird eine Aufgabe, für die Sie gestimmt haben geschlossen, wird ihre Stimme freigegeben. Oder Sie ziehen auf ihrer Profilseite Stimmen zurück, um wieder freie Stimmen zu bekommen.',
'myvotes'                 => 'Meine Stimmen',
'tag'                     => 'Schildchen',
'tags'                    => 'Schildchen',
'tagsavail'               => 'verfügbare Schildchen',
'tagsinfo'                => 'Trenne die Schildchen (Label/Aufkleber/Tags) durch Semikolon ; voneinander. Eine optische Gestaltung, Filterung oder Einbeziehung in die Suche ist derzeit noch nicht möglich.',
'novalues'                => 'keine Einträge',
'youhaveregistered'       => 'Sie haben sich bei Flyspray registriert. Ihre Anmeldedaten sind folgende:',
'youhaveregisterednotify' => 'Ihre Registrierung bei Flyspray wurde bestätigt.',
'usedintasks'             => 'Verwendung',
'freetagging'             => 'nutzerdefinierte Schildchen',
'keyboardshortcuts'       => 'Tastenkürzel',
'testmailsettings'        => 'Testet die aktuellen Email-Einstellungen',
'test'                    => 'Testen',
'testmailsettingsnotice'  => 'Prüfen Sie anschließend auch, ob an das Email-Konto des aktuell eingeloggten Benutzers (siehe \'Meine Benutzerdaten\') eine Test-Email eingegangen ist',
'invalidinput'            => 'Es liegen ungültige Aufgaben-Eigenschaften vor, die korrigiert werden müssen, um die Aufgabe zu einem anderen Projekt verschieben zu können',
'invalidprogress'         => 'Bitte wählen Sie einen gültigen Eintrag für \'Prozent erledigt\' aus',
'invalidpriority'         => 'Bitte wählen Sie einen gültigen Eintrag für \'Priorität\' aus',
'invalidseverity'         => 'Bitte wählen Sie einen gültigen Eintrag für \'Schweregrad\' aus',
'invalidstatus'           => 'Bitte wählen Sie einen gültigen Eintrag für \'Status\' aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidtasktype'         => 'Bitte wählen Sie einen gültigen Eintrag für \'Aufgabentyp\' aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidcategory'         => 'Bitte wählen Sie einen gültigen Eintrag für \'Kategorie\' aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidreportedversion'  => 'Bitte wählen Sie einen gültigen Eintrag für \'betrifft Version\' aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invaliddueversion'       => 'Bitte wählen Sie einen gültigen Eintrag für \'fällig in Version\' aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidos'               => 'Bitte wählen Sie einen gültigen Eintrag für \'Betriebssystem\' aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidtags'             => 'Bitte wählen Sie nur gültige Schildchen aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidassignees'        => 'Bitte wählen Sie nur gültige Zuständige aus, um die Aufgabe zu einem anderen Projekt zu verschieben',
'invalidtargetproject'    => 'Bitte wählen Sie gültiges Zielprojekt aus.',
'customize'               => 'anpassen',
'hidesubs'                => 'verstecke Unteraufgaben',
'hideprivate'             => 'verstecke private Aufgaben',
'hideclosed'              => 'verstecke geschlossene Aufgaben',
'globaloptions'           => 'allgemeine Einstellungen',
'currentproject'          => 'aktuelles Projekt',
'targetproject'           => 'Zielprojekt',
'availablekeybshortcuts'  => 'verfügbare Tastenkürzel',
'logindialoglogout'       => 'Login-Dialog / Logout',
'focustaskidsearch'       => 'fokussiere \'Zeige Aufgabe #\'',
'openselectedtask'        => 'öffne ausgewählte Aufgabe',
'movecursorup'            => 'bewege Cursor nach oben',
'movecursordown'          => 'bewege Cursor nach unten',
'taskdetails'             => 'Aufgabendetails',
'taskediting'             => 'Aufgabenbearbeitung',
'savetask'                => 'speichere Aufgabe',
'generalintegration'      => 'Integration allgemein',
'generalintegrationdesc'  => 'Der Inhalt wird innerhalb des "body"-Tags nach dem Hauptinhalt und vor dem Fußbereich eingesetzt. Wo dieser Inhalt dann wirklich auf dem Display zu sehen ist, ist durch CSS beeinflußbar. Sie können dafür eine custom_*.css nutzen.',
'footerintegration'       => 'Integration Fußbereich',
'footerintegrationdesc'   => 'Der Inhalt wird innerhalb des Fußbereiches eingesetzt. Wo dieser Inhalt dann wirklich auf dem Display zu sehen ist, ist durch CSS beeinflußbar. Sie können dafür eine custom_*.css nutzen.',
'editorbold'              => 'f',
'editorboldhint'          => 'fett',
'editoritalic'            => 'k',
'editoritalichint'        => 'kursiv',
'editorunderline'         => 'u',
'editorunderlinehint'     => 'unterstrichen',
'editorstrikethrough'     => 'd',
'editorstrikethroughhint' => 'durchgestrichen',
'editorh1'                => 'H1 Überschrift Ebene 1 - möglichst nicht verwenden, da schon für Titel der Webseite verwendet.',
'editorh2'                => 'H2 Überschrift Ebene 2 - möglichst nicht verwenden, da schon für Titel der Aufgabe verwendet.',
'editorh3'                => 'H3 Überschrift Ebene 3',
'editorh4'                => 'H4 Überschrift Ebene 4',
'editorh5'                => 'H5 Überschrift Ebene 5',
'editororderedli'         => 'geordnete Liste',
'editorunorderedli'       => 'ungeordnete Liste',
'editorhorizontalrule'    => 'Trennlinie',
'editorlink'              => 'Link zu einer Webadresse',
'editorcode'              => 'vorformatierter Text oder Programmcode mit Syntaxhervorhebung, z.B. <code php></code> für PHP',
'captchaerror'            => 'CAPTCHA nicht gelöst. Bitte erneut versuchen..',
'registercaptcha'         => 'Bitte löse das CAPTCHA-Rätsel.',
'regcaptcha'              => 'Zeige ein CAPTCHA-Rätsel bei der Nutzeregistrierung.',
'invalidsecurimage'       => 'ungültiges CAPTCHA',
'invalidrecaptcha'        => 'ungültiges Google reCAPTCHA',
'antispam'                => 'Spamschutz',
'antispamprefsinfo'       => 'Einstellungen zum Schutz vor automatisiertem Werbemüll.',
'securimageprefsinfo'     => 'Securimage ist ein klassisches CAPTCHA bei dem Nutzer eine Textfolge erkennen und eingeben müssen um ihr Menschsein zu "beweisen".',
'securimageenable'        => 'Securimage aktivieren',
'recaptchaprefsinfo'      => 'Google reCAPTCHA ist eine Alternative zum klassischen CAPTCHA.
Google entscheidet anhand von gesammelten Daten und Nutzerverhalten, ob es sich um einen menschlichen Nutzer handelt.
Um reCAPTCHA für Flyspray zu nutzen, wird ein Google Account und ein für die Domain konfiguriertes reCAPTCHA ( https://www.google.com/recaptcha ) benötigt.
Die zwei Werte "sitekey" and "secret" müssen hier dann eingetragen werden.
Abhängig von der Konfiguration bei Google - "reCAPTCHA V2" oder "Invisible reCAPTCHA" - müssen Ihre Nutzer eventuell darüber bei der Nutzerregistrierung und/oder in der Datenschutzerklärung informiert werden.
Flyspray lädt und verwendet es nur für die Seiten der Nutzerregistrierung, falls konfiguriert.',
'recaptchaenable'         => 'Google reCAPTCHA aktivieren',
'adminchecks'             => 'Checks',
'adminchecksinfo'         => 'Info and checks for your current installation',
'repeatpassword'          => 'Passwort wiederholen',
'repeatemailaddress'      => 'E-Mail-Adresse wiederholen',
'tooltipshorttasktitle'   => 'Bitte eine kurze, knackige Zusammenfassung der Aufgabe angeben.',
'lastlogin'               => 'letzte Anmeldung',
'relnofollow'             => 'rel="nofollow" bei Links hinzufügen',
'relnofollowdescription'  => 'Weist Suchmaschinen an, nutzergenerierte Verweise in Aufgaben und Kommentaren nicht für die Bewertung von Webseiten zu verwenden.',
'usetags'                 => 'Nutze Schildchen',
'usegantt'                => 'Gantt Ansicht',
'usekanban'               => 'Kanban Ansicht',
'gantt'                   => 'Gantt Ansicht',
'kanban'                  => 'Kanban Ansicht',
'accountfilter'           => 'Benutzerkontenfilter',
'accountstatus'           => 'Benutzerkontenstatus',
'showaccountsall'         => 'alle',
'showaccountsenabled'     => 'freigeschalten',
'showaccountsdisabled'    => 'gesperrt',
);
?>
