<?php

$translation = array(
'edituser'                => 'Uredi korisnika',
'username'                => 'Korisničko ime',
'realname'                => 'Stvarno ime',
'emailaddress'            => 'E-mail adresa',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Tip obaveštenja',
'group'                   => 'Grupa',
'accountenabled'          => 'Prijava dozvoljena',
'updatedetails'           => 'Ažuriraj detalje',
'setglobally'             => 'Ova povlastica postavljena je globalno.',
'usergroupmanage'         => 'Upravljanje korisnicima i grupama',
'newuser'                 => 'Registrovanje novog korisnika',
'newgroup'                => 'Kreiranje nove grupe',
'yes'                     => 'Da',
'no'                      => 'Ne',
'editgroup'               => 'Uredi grupu',
'groupname'               => 'Naziv grupe',
'description'             => 'Opis',
'admin'                   => 'Admin grupa',
'opennewtasks'            => 'Kreiraj novi zadatak',
'modifytasks'             => 'Izmeni postojeći zadatak',
'addcomments'             => 'Dodaj komentar',
'attachfiles'             => 'Pridruži fajl',
'vote'                    => 'Glasaj',
'groupenabled'            => 'Članovi se mogu prijavljivati',
'groupopen'               => 'Članovi se mogu prijavljivati',
'tasktypelist'            => 'Lista tipova zadataka',
'categorylist'            => 'Lista kategorija',
'oslist'                  => 'Lista operativnih sistema',
'resolutionlist'          => 'Resolutions list',
'versionlist'             => 'Lista verzija',
'severitylist'            => 'Lista važnosti',
'listnote'                => 'Napomena:  Dečekiranje kolone "Prikaz" može izmeniti neke zadatke kada su u režimu izmene.  Promena polja u koloni "Ime" će se odnositi na sve zadatke, gde se pominje promena. Slogovi koji se ne mogu obrisati zaštićeni su jer su potrebni za ispravno funkcionisanje zadataka.',
'name'                    => 'Ime',
'order'                   => 'Redosled',
'back'                    => 'Nazad',
'text'                    => 'Tekst',
'highlight'               => 'Naglasi',
'show'                    => 'Prikaz',
'owner'                   => 'Vlasnik',
'selectowner'             => 'Izbor vlasnika',
'update'                  => 'Ažuriraj',
'addnew'                  => 'Dodaj novi',
'flysprayprefs'           => 'Flyspray povlastice',
'projecttitle'            => 'Naslov projekta',
'baseurl'                 => 'Bazni URL za ovu instalaciju',
'replyaddress'            => 'Obaveštenja repliciraj na e-mail adresu',
'themestyle'              => 'Tema / stil',
'language'                => 'Jezik',
'anonview'                => 'Dozvoli neprijavljenim korisnicima da gledaju zadatke',
'allowanon'               => 'Dozvoli neprijavljenim korisnicima da kreiraju zadatke',
'never'                   => 'Nikad',
'anonymously'             => 'Anonimno',
'afterregister'           => 'Samo nakon registrovanja',
'spamproof'               => 'Omogući potvrdni kood za registraciju novih korisnika',
'anongroup'               => 'Grupa za novo-registrovanog korisnika',
'groupassigned'           => 'Članovi ove grupe mogu dodeljivati zadatke',
'forcenotify'             => 'Naloži obaveštenja o zadacima',
'neversend'               => 'da se nikad ne šalju',
'userchoose'              => 'da svaki korisnik može izabrati',
'email'                   => 'E-mail',
'jabber'                  => 'Jabber ID',
'defaultcatowner'         => 'Podrazumevani vlasnik kategorije',
'noone'                   => 'Nijedan',
'jabbernotify'            => 'Jabber obaveštenja',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Korisničko ime',
'jabberpass'              => 'Korisnička lozinka',
'saveoptions'             => 'Sačuvaj',
'editcomment'             => 'Uredi komentar',
'commentby'               => 'Komentarisao',
'saveeditedcomment'       => 'Snimi izmenjeni komentar',
'projectprefs'            => 'Mogućnosti nad projektima',
'pagetitle'               => 'Naslov strane',
'defaultproject'          => 'Podrazumevani projekat',
'projectlists'            => 'Lista projekata',
'showlogo'                => 'Prikaži naslov logo-a',
'intromessage'            => 'Uvodna poruka',
'isactive'                => 'Projekat je aktivan',
'createproject'           => 'Kreiraj novi projekat',
'nopermission'            => 'Nemate dozvolu da koristite ovu stranu!',
'listordertip'            => 'Redosled će biti prikazan u listi',
'listshowtip'             => 'Prikaži ovu stavku u listi',
'categoryownertip'        => 'Ovo lice će primati obaveštenja kada se otvori zadatak u ovoj kategoriji',
'categoryparenttip'       => 'The parent category this new one will fall under',
'notsubcategory'          => 'Nijedna (vrhovna kategorija!)',
'showinlineimages'        => 'Prikaži sliku priključka u liniji',
'dateformat'              => 'Format datuma (%d, %m, %y, ili %Y)',
'dateformat_extended'     => 'Detaljni format datuma',
'cache_feeds'             => 'Keširanje podataka',
'no_cache'                => 'Nema keširanja',
'cache_disk'              => 'Keširanje na disku',
'cache_db'                => 'Keširanje u DB',
'subcategoryof'           => 'Podkategorija kategorije',
'visiblecolumns'          => 'Kolone zaglavlja prikazane u task listi',
'tense'                   => 'Verzija',
'listtensetip'            => 'Prošla, sadašnja, ili buduća',
'past'                    => 'Prošla',
'present'                 => 'Sadašnja',
'future'                  => 'Buduća',
'oldpass'                 => 'Stara lozinka',
'nooldpass'               => 'Stara lozinka nije podešena',
'oldpasswrong'            => 'Stara lozinka je pogrešna',
'changepass'              => 'Nova lozinka',
'confirmpass'             => 'Potvrdi novu lozinku',
'projectmanager'          => 'Rukovodilac projekata',
'viewtasks'               => 'Uvid zadataka',
'modifyowntasks'          => 'Izmena sopstvenih zadataka',
'modifyalltasks'          => 'Izmena zadataka koji nisu u vlasništvu',
'viewcomments'            => 'Uvid komentara',
'editcomments'            => 'Izmena komentara',
'deletecomments'          => 'Brisanje komentara',
'viewattachments'         => 'Uvid priključka',
'createattachments'       => 'Napravi priključenje',
'deleteattachments'       => 'Obriši priključke',
'viewhistory'             => 'Uvid promena',
'closeowntasks'           => 'Zatvori sopstvene zadatke',
'closeothertasks'         => 'Zatvori zadatke koji nisu u vlasništvu',
'assigntoself'            => 'Dodeli zadatak sebi, ako nije već dodeljen',
'assignotherstoself'      => 'Dodeli druge zadatke sebi',
'viewreports'             => 'Uvid dnevnika događaja',
'othersview'              => 'Dozvoli svakom da gleda ovaj projekat',
'usersandgroups'          => 'Korisnici i grupe',
'globalgroup'             => 'Opšta grupa',
'globalgroups'            => 'Opšte grupe',
'defaultglobalgroup'      => 'Podrazumevana opšta grupa za nove korisnike',
'addtogroup'              => 'Dodaj u grupu',
'moveuserstogroup'        => 'Premesti korisnika u grupu',
'nogroup'                 => 'Nema grupa - Izbačene iz projekta',
'eventdesc'               => 'Opis događaja',
'requestedby'             => 'Tražen od',
'daterequested'           => 'Datum zahteva',
'closetask'               => 'Zatvor zadatak',
'reopentask'              => 'Ponovo otovori zadatak',
'applymember'             => 'Primeni za članove projekta',
'forcurrentproj'          => 'Za tekući projekat',
'lostpw'                  => 'Pronalaženje izgubljene lozinke',
'lostpwexplain'           => 'Unesite Vaše korisničko ime za slanje linka za promenu lozinke.  Ovo će biti sačuvano u Vaš profil obaveštenja.',
'sendlink'                => 'Pošalji link',
'savenewpass'             => 'Sačuvaj novu lozinku',
'anonreg'                 => 'Dozvoli registraciju novih korisnika',
'allowanonopentask'       => 'Dozvoli neprijavljenim korisnicima da otvaraju zadatke',
'editglobalgroup'         => 'Izmeni opštu grupu',
'editgroupforproj'        => 'Izmeni projektnu grupu',
'notshownforadmin'        => 'Dozvole nisu prikazane za administratorsku grupu. Nepotrebno ih je menjati.',
'general'                 => 'Opšte',
'userregistration'        => 'Korisnička registracija',
'notifications'           => 'Obaveštenja',
'resetoptions'            => 'Poništi opcije',
'preferences'             => 'Opšta podešavanja',
'tasktypes'               => 'Tipovi zadataka',
'resolutions'             => 'Razrešenja',
'categories'              => 'Kategorije',
'operatingsystems'        => 'Operativni sistemi',
'versions'                => 'Verzije',
'admintoolboxlong'        => 'Administratorske alatke',
'newproject'              => 'Novi projekat',
'delete'                  => 'Obriši',
'listdeletetip'           => 'Obriši ovu stavku iz liste',
'lookandfeel'             => 'Izgled i osećaj',
'globaltheme'             => 'Opšta tema',
'emailnotify'             => 'E-mail obaveštenja',
'fromaddress'             => 'Šalje sa adrese',
'smtpserver'              => 'SMTP servera',
'smtpuser'                => 'SMTP korisničko ime',
'smtppass'                => 'SMTP lozinka',
'addrewrite'              => 'Koristi zamenu adrese',
'usereminderdaemon'       => 'Omogući pozadinsku uslugu (daemon) za podsetnik',
'tasksperpage'            => 'Zadataka po strani liste zadataka',
'addtoassignees'          => 'Dodaj se sam listi dodeljenih',
'taskstatuses'            => 'Statusi zadataka',
'canvote'                 => 'Može glasati za zadatak',
'loginsuccessful'         => 'Prijava uspešna.',
'youareloggedout'         => 'Vi ste se odjavili.',
'waitwhiletransfer'       => 'Molim sačekajte prenos...',
'clicknowait'             => 'Klikni ovde, ako ne želiš da čekaš.',
'accountdisabled'         => 'Vaš nalog je isključen. Kontaktirajte administratora sistema.',
'task'                    => 'Zadatak',
'edittask'                => 'Izmeni ovaj zadatak',
'openedby'                => 'Otvoren od',
'editedby'                => 'Poslednji menjao',
'tasktype'                => 'Tip zadatka',
'category'                => 'Kategorija',
'status'                  => 'Status',
'assignedto'              => 'Dodeljen',
'operatingsystem'         => 'Operativni sistem',
'severity'                => 'Važnost',
'reportedversion'         => 'Prijavljena verzija',
'dueinversion'            => 'Očekuje se u verziji',
'undecided'               => 'Neodređeno',
'percentcomplete'         => '% izvršenja',
'details'                 => 'Detalji',
'savedetails'             => 'Sačuvaj detalje',
'canceledit'              => 'Otkaži izmenu',
'anonymous'               => 'Nepoznati pošiljalac',
'complete'                => 'završeno',
'closedby'                => 'Zatvoreno od strane',
'reasonforclosing'        => 'Razlog zatvaranja:',
'reopenthistask'          => 'Ponovo otovori ovaj zadatak',
'comments'                => 'Komentari',
'attachments'             => 'Priključci',
'relatedtasks'            => 'Povezani zadaci',
'edit'                    => 'Izmeni',
'addcomment'              => 'Dodaj komentar',
'fileuploadedby'          => 'Datoteka poslata od strane ',
'uploadafile'             => 'Priključi datoteku',
'uploadnow'               => 'Pošalji sada!',
'thesearerelated'         => 'Ovi zadaci su u vezi sa ovim zadatkom',
'remove'                  => 'Izbaci',
'addnewrelated'           => 'Dodaj novi zadatak koji je s ovim u vezi',
'add'                     => 'Dodaj!',
'otherrelated'            => 'Drugi zadaci s kojima je ovaj u vezi',
'receivenotify'           => 'Ovi korisnici će primati detaljna obaveštenja kada se zadatak izmeni.',
'addusertolist'           => 'Dodaj korisnika ovoj listi',
'addtolist'               => 'Dodaj u listu',
'addmyself'               => 'Sam se dodaj ovoj listi',
'removemyself'            => 'Izbaci se sam iz ove liste',
'theseusersnotify'        => 'Ovi korisnici će primati detaljna obaveštenja uvek kada se ovaj zadatak izmeni.',
'attachedtoproject'       => 'Priključen projektu',
'reminders'               => 'Podsetnik',
'system'                  => 'Sistem',
'remindthisuser'          => 'Podseti ovog korisnika',
'thisoften'               => 'To se često',
'startafter'              => 'Sačekajte pre pokretanja podsetnika',
'hours'                   => 'Sat(i)',
'days'                    => 'Dan(a)',
'weeks'                   => 'Nedelja(e)',
'addreminder'             => 'Dodaj podsetnik',
'defaultreminder'         => 'Ovo je podsetnik koji će pratiti seledeće Flyspray zadatke:',
'message'                 => 'Poruka',
'closed'                  => 'Zatvoren',
'filename'                => 'Naziv datoteke:',
'date'                    => 'Datum',
'filesize'                => 'Veličina datoteke:',
'closurecomment'          => 'Dodatno pojašnjenje o razlogu zatvaranja:',
'history'                 => 'Istorija',
'nohistory'               => 'Istorija nije dostupna.',
'eventdate'               => 'Datum',
'user'                    => 'Korisnik',
'event'                   => 'Događaj',
'fieldchanged'            => 'Promenjeno je',
'taskopened'              => 'Zadatak otvoren',
'taskreopened'            => 'Zadatak ponovo otvoren',
'taskclosed'              => 'Zadatak zatvoren',
'commentadded'            => 'Dodat komentar',
'commentedited'           => 'Komentar izmenjen',
'commentdeleted'          => 'Komentar obrisan',
'attachmentadded'         => 'Priključak dodat',
'attachmentdeleted'       => 'Priključak obrisan',
'taskedited'              => 'Detalji zadatka izmenjeni',
'notificationadded'       => 'Korisnik dodat listi obaveštenja',
'notificationdeleted'     => 'Korisnik izbačen iz liste obaveštenja',
'relatedadded'            => 'Povezani zadatak dodat',
'relateddeleted'          => 'Povezani zadatak izbačen',
'taskassigned'            => 'Zadatak dodeljen',
'taskreassigned'          => 'Zadatak preusmeren na',
'assignmentremoved'       => 'Dodela izbrisana',
'summary'                 => 'Kratak opis',
'addedasrelated'          => 'Zadatak dodat listi povezanih',
'deletedasrelated'        => 'Zadatak izbačen iz liste povezanih',
'reminderadded'           => 'Dodat podsetnik',
'reminderdeleted'         => 'Podsetnik izbačen',
'priority'                => 'Prioritet',
'previousvalue'           => 'Prethodna vrednost',
'newvalue'                => 'Nova vrednost',
'selectareason'           => 'Izbor razloga',
'assigntome'              => 'Dodeli meni',
'reopenrequest'           => 'Zahtev za ponovno otvaranje',
'requestclose'            => 'Zahtev za zatvaranje',
'ownershiptaken'          => 'Korisnikovo vlasništvo',
'closerequestmade'        => 'Zatraženo zatvaranje zadatka',
'reopenrequestmade'       => 'Zatraženo ponovno otvaranje zadatka',
'taskdependson'           => 'Ovaj zadatak zavisi od:',
'taskblocks'              => 'Ovaj zadatak blokira ove od zatvaranja',
'depadded'                => 'Dodata zavisnost',
'depaddedother'           => 'Ovaj zadatak dodaje kao zavisnost',
'depremoved'              => 'Zavisnost uklonjena',
'depremovedother'         => 'Ovaj zadatak je izbačen iz liste zavisnih zadataka',
'showdetailserror'        => 'Ovaj zadatak ne postoji, ili nemate dozovolu da ga pogledate.',
'makeprivate'             => 'napravi ga privatnim',
'makepublic'              => 'napravi ga javnim',
'taskmadeprivate'         => 'Zadatak je sada privatan',
'taskmadepublic'          => 'Privatnost uklonjena! Zadatak je sada javan',
'confirmdeletecomment'    => 'Sigurni ste da želite obrisati ovaj komntar? %s',
'confirmdeleteattach'     => 'Sigurni ste da želite obrisati ovaj priključak?',
'selectedhistory'         => 'Prikaz izabranih detalja istorije',
'showallhistory'          => 'Prikaži jezičak pune istorije ponovo',
'hidethis'                => 'Sakrij ovu zonu ponovo',
'mark100'                 => 'Označi zadatak 100% završenim',
'watchtask'               => 'prati promene',
'stopwatching'            => 'zaustavi praćenje',
'commentlink'             => 'Link ka komentaru',
'submitreq'               => 'Pošalji zahtev',
'reasonforreq'            => 'Razlog zabrane',
'pmreqdenied'             => 'Rukovodilac projektima je zabranio zahtev',
'taskpendingreq'          => 'Rukovodilac projekata trenutno nešto radi. Vidite na "Istorija" jezičku šta se događa.',
'previoustask'            => 'Prethodni zadatak',
'nexttask'                => 'Naredni zadatak',
'duedate'                 => 'Rok',
'attachnoperms'           => 'Postoje priključci za ovaj komentar, ali Vi nemate dozvolu za njihov uvid.',
'open'                    => 'Otvori',
'depgraph'                => 'Uvid grafičkog prikaza zavisnosti',
'reset'                   => 'Reset',
'selectusers'             => 'Izbor korisnika...',
'addmetoassignees'        => 'Dodaj me listi dodeljenih',
'addedtoassignees'        => 'Korisnik dodat listi dodeljenih',
'dependencygraph'         => 'Grafički prikaz zavisnosti',
'attachanotherfile'       => 'Prikači još neku datoteku',
'OK'                      => 'U redu',
'addvote'                 => 'Daj glas',
'notifyfromfs'            => 'Obaveštenje od Flyspray sistema',
'autogenerated'           => 'OVO JE AUTOMATSKI GENERISANA PORUKA! NE ODGOVARAJ!',
'forward'                 => 'Napred',
'previous'                => 'Prethodni',
'next'                    => 'Sledeći',
'first'                   => 'Prvi',
'last'                    => 'Poslednji',
'page'                    => 'Strana %d od %d',
'search'                  => 'Traži',
'alltasktypes'            => 'Svi tipovi zadataka',
'allseverities'           => 'Sve važnosti',
'alldevelopers'           => 'Svi programeri',
'notyetassigned'          => 'Nije ipak dodeljen',
'allcategories'           => 'Sve kategorije',
'allstatuses'             => 'Svi statusi',
'allopentasks'            => 'Svi otovoreni zadaci',
'sortthiscolumn'          => 'Sort po ovoj koloni',
'id'                      => 'Br.',
'project'                 => 'Projekat',
'dateopened'              => 'Otvoren',
'progress'                => 'Napredak u radu',
'searchthisproject'       => 'Pretraži ovaj projekat za',
'dueanyversion'           => 'Očekuje se u ma kojoj verziji',
'anyversion'              => 'Prijavljen u ma kojoj verziji',
'dueversion'              => 'Očekuje se u verziji',
'lastedit'                => 'Posednje izmenjen',
'os'                      => 'Operativni sistem',
'reportedin'              => 'Prijavljen u',
'taskrange'               => 'Prikaz zadataka %d - %d od %d',
'noresults'               => 'Vaša pretraga nije dala rezltate.',
'takeaction'              => 'Primeni izabrano',
'watchtasks'              => 'Praćenje izabranih zadataka',
'stopwatchingtasks'       => 'Prekini praćenje izabranih zadataka',
'assigntaskstome'         => 'Dodeli mi izabrani zadatak',
'dueby'                   => 'Dospeva',
'dueanytime'              => 'Bilo kada',
'selectduedate'           => 'Izbor datuma dospeća',
'toggleselected'          => 'Promena izbora',
'due'                     => 'Rok',
'assignedtome'            => 'Dodeljen meni',
'tasklist'                => 'Lista zadataka',
'dateclosed'              => 'Datum zatvaranja',
'advanced'                => 'Još uslova za pretragu',
'searchcomments'          => 'Traži u komentarima',
'searchforall'            => 'Traži za sve reči',
'anonusers'               => 'Nepoznati korisnik',
'miscellaneous'           => 'Razno',
'users'                   => 'Korisnici',
'taskproperties'          => 'Svojstva zadatka',
'selectsincedate'         => 'Izaberi izmene od',
'changedsince'            => 'Izmene od',
'updatefs'                => 'Molimo ažurirajte Vaš Flyspray.',
'currentversion'          => 'Vaša tranutna verzija je',
'latestversion'           => ', a poslednja verzija je',
'hidemessage'             => '(podseti me kasnije)',
'saveas'                  => 'Sačuvaj pretragu kao',
'nosearches'              => 'Nema sačuvanih pretraga',
'saving'                   => 'Snimanje...',
'votes'                   => 'Glasova',
'allclosedtasks'          => 'Svi zatvoreni zadaci',
'password'                => 'Lozinka',
'login'                   => 'Prijavi se',
'rememberme'              => 'Podseti me',
'lostpassword'            => 'Izgubili ste lozinku?',
'lostpwforfs'             => 'Izgubili ste lozinku za Flyspray',
'lostpwmsg1'              => 'Zdravo!

Izgubio/la sam moju lozinku za Flyspray na ',
'lostpwmsg2'              => ', molim Vas pošaljite mi novu lozinku.

Korisničko ime: ',
'regards'                 => '

Pozdrav od',
'yourusername'            => ' Vaše korisničko ime ',
'locale'                  => 'en-AU',
'filenotexist'            => 'Datoteka ne postoji, ili nemate dovolu da joj pristupite.',
'showtask'                => 'Prikaži zadatak',
'now'                     => 'Sada',
'go'                      => 'Idi!',
'opentaskanon'            => 'Otvori novi zadatak kao nepoznat',
'register'                => 'Registruj se',
'addnewtask'              => 'Dodaj novi zadatak',
'reports'                 => 'Dnevnik događaja',
'editmydetails'           => 'Izmeni moje detalje',
'logout'                  => 'Odjavi se',
'disabledaccount'         => 'Vaša prijava je onemogućena!<br />Odmah ćete biti odjavljeni...',
'poweredby'               => 'Powered by Flyspray',
'projects'                => 'Projekti',
'allprojects'             => 'Svi projekti',
'selectproject'           => 'za projekat:',
'tasksall'                => 'Svi zadaci',
'tasksassigned'           => 'Zadaci dodeljeni meni',
'tasksreported'           => 'Zadaci koje sam ja prijavio',
'taskswatched'            => 'Pratim zadatak',
'mysearch'                => 'Moja pretraga',
'admintoolbox'            => 'Administratorske alatke',
'manageproject'           => 'Upravljanje projektima',
'permissions'             => 'Vidi dozvole',
'hide'                    => 'Sakrij',
'pendingreq'              => 'Čeka se za PM zahtev',
'errorpage'               => 'Flyspray ne može prikazati ovu stranu.
                                 Možda ste tražili zadatak koji ne postoji, ili nemate
                                 dozvolu da vidite stranicu koju ste želeli.<br /><br />
                                 Možda ste pokušali da koristite pogrešan link u interakciji sa bazom podataka.
                                 Ako je to tačno razmislite malo o svojim postupcima i molimo Vas da to ne činite ponovo.',
'permissionsforproject'   => 'Dozvole za ',
'switchto'                => 'Pređi na',
'lastsearch'              => 'Poslednja pretraga',
'modify'                  => 'Izmeni',
'noticefrom'              => 'Obaveštenje od',
'hasopened'               => 'imate OTVOREN NOVI Flyspray zadatak i dodeljen je Vama:',
'moreinfonew'             => 'Možete naći Više informacija o ovoj greški na  Flyspray strani:',
'newtaskcategory'         => 'Novi Flyspray zadatak biće otovoren u ovoj kategoriji',
'categoryowner'           => 'Vi dobijate ovo jer ste navedeni kao vlasnik kategorije.',
'tasksummary'             => 'Rezime zadatka:',
'newtaskadded'            => 'Vaš novi zadatak je dodat.',
'summaryanddetails'       => 'Potrebno je pouniti oba polja, "Kratak opis" i "Detalji".',
'goback'                  => 'Idi nazad.',
'messagefrom'             => 'Ova poruka je od Flyspray sistema za praćenje grešaka na ',
'hasjustmodified'         => 'ste izmenili sledeći zadatak.',
'changedfields'           => 'Izmenjena polja imaju prefiks (**)',
'moreinfomodify'          => 'Možete imati više informacija o ovom zadatku sledeći ovaj URL:',
'nolongerassigned'        => 'Sledeći zadatak više nije dodeljen Vama.  Sada je dodeljen',
'hasassigned'             => 'imate dodeljen sledeći Flyspray zadatak:',
'taskupdated'             => 'Zadatak je izmenjen.',
'hasclosedassigned'       => 'je zatvoren sledeći Flyspray zadatak koji Vam je dodeljen:',
'unassigned'              => 'Nedodeljen',
'hasclosed'               => 'je zatvoren sledeći zadatak.',
'youonnotify'             => 'Vi dobijate ovo jer ste na listi za obaveštavanje.',
'taskclosedmsg'           => 'Zadatak je zatvoren.',
'returntotask'            => 'Povratak na detalje zadatka',
'backtoindex'             => 'Povraćaj na listu zadataka',
'noclosereason'           => 'Niste izabrali razlog za zatvaranje tog zadatka.',
'hasreopened'             => 'ponovo je otvoren sledeći Flyspray zadatak koji ste zatvorili:',
'taskreopenedmsg'         => 'Zadatak je ponovo otvoren.',
'backtotask'              => 'Vrati se na zadatak.',
'commentaddedmsg'         => 'Komentar je dat.',
'commenttoassigned'       => 'dodat je sledeći komentar zadatku koji Vam je dodeljen:',
'commenttotask'           => 'dat je sledeći komentar ovom zadatku.',
'nocommententered'        => 'Vi zaista treba da unesete komentar pre nago što kliknete na dugme.',
'fillinfields'            => 'Niste popunili sva polja.',
'notcurrentpass'          => 'To nije Vaša trenutna lozinka!',
'passchanged'             => 'Vaša lozinka je promenjena.',
'closewindow'             => 'Možete sada zatvoriti ovaj prozor.',
'passnomatch'             => 'Vaša nova lozinka nije ista',
'usernametaken'           => 'To korisničko ime je vać zauzeto! Moraćete da unesete drugo.',
'newusercreated'          => 'Novi korisnikčki nalog je kreiran.',
'accountcreated'          => 'Vaš nalog je kreiran.',
'newuserwarning'          => 'Imajte u vidu da Vaš nalog treba da bude odobren od strane adminiistratora sistema. Ako ne možete da se prijavite to je razlog zašto ne možete.',
'nomatchpass'             => 'Lozinka ne odgovara.',
'confirmwrong'            => 'Potvrdni kood je pogrešan!',
'formnotcomplete'         => 'Forma nije cela popunjena.',
'formnotnumeric'          => 'Unešeni podatak nije numerički!',
'groupnametaken'          => 'Ime grupe je već zauzeto.',
'newgroupadded'           => 'Nova grupa dodata.',
'optionssaved'            => 'Flyspray opcije sačuvane',
'hasuploaded'             => 'otpremili ste datoteku, kao priključak, zadatku koji je dodeljen:',
'hasattached'             => 'prikačena je datoteka sledećem zadatku.',
'fileuploaded'            => 'Datoteka je otpremljena.',
'fileerror'               => 'Došlo je do greške u otpremanju Vaše datoteke. Možda su dozvole nad <i>priključenim/</i> direktorijumima pogrešne.',
'contactadmin'            => 'Kontaktirajte administratora ovog projekta.',
'selectfileerror'         => 'Niste izabrali datoteku.',
'userupdated'             => 'Podaci o korisniku su izmenjeni',
'realandemail'            => 'Niste popunili polja "Stvarno ime" i/ili "e-mail adresa".',
'groupupdated'            => 'Definicija grupa izmenjna.',
'groupanddesc'            => 'Niste uneli ime grupe.',
'fillallfields'           => 'Molim popunite sva polja.',
'listPmustN'              => '"Poredak" će biti numerički.',
'listupdated'             => 'Lista je ažurirana!',
'listitemadded'           => 'Dodat novi slog u listi.',
'relatedaddedmsg'         => 'Povezani zadatak je dodat listi.',
'relatederror'            => 'Ovaj zadatak je već u vezi sa zadacima iz liste povezanih.',
'relatedremoved'          => 'Povezani zadatak je izbačen iz liste.',
'notifyadded'             => 'Korisnik je dodat listi obaveštavanja.',
'notifyerror'             => 'Korisnik je već u listi obaveštavanja za ovaj zadatak.',
'notifyremoved'           => 'Korisnik je izbačen iz liste obaveštavanja.',
'editcommentsaved'        => 'Izmenjeni komentar je sačuvan.',
'commentdeletedmsg'       => 'Komentar je obrisan.',
'gotonewtask'             => 'Idi na novonapravljeni zadatak',
'projectcreated'          => 'Vaš novi projekat je kreiran. Možete ga sada podesiti u zoni za upravljanje projektima.',
'customiseproject'        => 'Podesi ovaj projekat',
'projectupdated'          => 'Podešavanja projekta izmenjena',
'emptytitle'              => 'Polje za naziv projekta niste uneli!  Molimo unesite ga.',
'loginbelow'              => 'Sada možete pokušati da se prijavite.',
'attachmentdeletedmsg'    => 'Priključak je obrisan',
'reminderaddedmsg'        => 'Vaš podsetnik je dodat.',
'reminderdeletedmsg'      => 'Vaš izabrani podsetik je obrisan.',
'flyspraytask'            => 'Flyspray zadatak',
'fieldsmissing'           => 'Neka polja ne sadrže podatke, ili su podaci pogrešni.',
'relatedinvalid'          => 'Ne postoji takav zadatak.',
'relatedproject'          => 'Ovaj zadatak je priključen drugom projektu. Dodaj vezu u svakom slučaju',
'addanyway'               => 'Dodaj u svakom slučaju',
'cancel'                  => 'Otkaži',
'alreadyedited'           => 'Ovaj zadatak je izmenio neko drugi pre nego što ste sačuvali promene. Da li još želite da sačuvate promene?',
'saveanyway'              => 'Sačuvaj moje promene u svakom slučaju',
'nouserselected'          => 'Korisnik nije izabran. Izaberite najmanje jednog korisnika pre nego što pokušate ponovo.',
'groupswitchupdated'      => 'Korisnička grupa je izmenjena uspešno.',
'takenownershipmsg'       => 'Ovaj zadatak je sada dodeljen Vama.',
'adminrequestmade'        => 'Vaš zahtev je sada poslat rukovodiocu projekta.',
'newdepnotify'            => 'Nova zavisnost je dodata sledećem zadatku:',
'dependadded'             => 'Zavisnost zadatka dodata',
'dependaddfailed'         => 'Došlo je do greške pri dodavanju zavisnosti. Proverite da li zadatak postoji i da li se možda uzajamno ne blokiraju.',
'depremovedmsg'           => 'Zavisnost zadataka je uklonjena',
'newdepis'                => 'Nova zavisnost je',
'magicurlsent'            => 'Poruka je poslata na Vašu adresu za obaveštenja. Ona sadrži adresu linka koji će Vas odvesti na stranicu gde ćete dovršiti ovaj zadatak.',
'changefspass'            => 'Promena Flyspray lozinke',
'magicurlmessage'         => 'Molimo sledite sledeći link ispod za promenu Vaše Flyspray lozinke:',
'erroronform'             => 'Došlo je do problema u slanju Vaše forme',
'addressused'             => 'Ova adresa se koristi da se registruje Flyspray nalog. Ako ne očekujete ovu poruku, molimo ignorišite je i obrišite. Sledite sledeći URL da dovršite registraciju:',
'confirmcodeis'           => 'Vaš potvrdni kood je:',
'codesent'                => 'Vaš potvrdni kood je poslat. Molimo sledite instrukcije sadržane u poruci.',
'codenotsent'             => 'Ne može se poslati Vaš kood, molimo pokušajte kasnije.',
'taskmadeprivatemsg'      => 'Ovaj zadatak je načinjen privatnim',
'taskmadepublicmsg'       => 'Ovaj zadatak je načinjen ponovo javnim',
'realandnotify'           => 'Potrebno je popuniti polja "Stvarno ime", "E-mail adresa", ili "Jabber ID".',
'pmreqdeniedmsg'          => 'Zahtev odbijen od strane rukuvodioca projekta',
'massopsuccess'           => 'Masovno izvođenje operacija uspešno - dozvole su postavljene',
'usernotexist'            => 'Korisnik ne postoji u ovoj Flyspray instalaciji',
'commentattachperms'      => 'Ne možete obrisati komentar, jer nemate dozvolu za brisanje priklučenja',
'voterecorded'            => 'Vaš glas je upamćen',
'votefailed'              => 'Vaš glas neće biti dodat ovog puta.',
'createnewgroup'          => 'Kreiraj novu grupu',
'requiredfields'          => 'Obavezna polja su označena sa',
'addthisgroup'            => 'Dodaj ovu grupu',
'createnewproject'        => 'Kreiraj novi projekat',
'addnewproject'           => 'Dodaj novi projekat',
'htmlallowed'             => 'HTML kood je dozvoljen',
'createthisproject'       => 'Kreiraj ovaj projekat',
'inlineimages'            => 'Prikaži priključenu sliku u liniji',
'createnewtask'           => 'Kreiranje novog zadatka u projektu:',
'addanother'              => 'Dodavanje još jednog zadatka nakon ovog',
'addthistask'             => 'Dodaj ovaj zadatak',
'notifyme'                => 'Obavesti me o bilo kakvoj promeni ovog zadatka',
'newtask'                 => 'Novi zadatak',
'attachafile'             => 'Prikači datoteku',
'registernewuser'         => 'Registrovanje novog korisnka',
'none'                    => 'Ništa',
'registeraccount'         => 'Registrovanje ovog naloga',
'both'                    => 'Obadva',
'notifyfrom'              => 'Obaveštenje od ',
'donotreply'              => 'OVO JE AUTOMATSKA PORUKA, NE ODGOVARAJTE NA NJU!',
'disclaimer'              => 'Primili ste ovu poruku pošto je zatražena od FlySpray sistema za praćenje grešaka. Ako ne očekujete poruku, ili ne želite da primate poštu u buduće, možete promeniti podešavanja u Vašem sistemu obaveštavanja na ovom linku iznad.',
'userwho'                 => 'Korisnik koji je to uradio',
'moreinfo'                => 'Više informacija mogu se naći prateći sledeći link:',
'newtaskopened'           => 'Novi Flyspray zadatak je otvoren.  Detalji su vidljivi ispod.',
'notify.taskclosed'       => 'Sledeći zadatak je sada zatvoren:',
'notify.taskreopened'     => 'Sledeći zadatak je sada ponovo otvoren:',
'newdep'                  => 'Sledeći zadatak ima novu zavisnost:',
'notify.depremoved'       => 'Sledeći zadatak ima izbačenu zavisnost:',
'olddepwas'               => 'Stara zavisnost je',
'notify.commentadded'     => 'Sledeći zadatak ima dodat novi komentar:',
'commentis'               => 'Tekst komentara je ispod.',
'newattachment'           => 'Nova datoteka je priključena sledećem zadatku:',
'detailsbelow'            => 'Detalji su ispod.',
'notify.relatedadded'     => 'Novopovezani zadatak je dodat sledećem zadatku:',
'relatedis'               => 'Povezani zadatak je',
'assignedtoyou'           => 'Dodeljen Vam je sledeći zadatak:',
'takenownership'          => 'je preuzeo vlasništvo nad sledećim zadatkom:',
'requiresaction'          => 'Sledeći zadatak zahteva akciju rukovodioca projekta:',
'requiresactionnotify'    => 'Zadatak zahteva akciju rukovodioca projekta',
'pmdeny'                  => 'Rukovodilac projekata je odbio zahtev za sledeće zadatke:',
'pmdenynotify'            => 'Rukovodilac projekata je odbio zahtev.',
'fileaddedtoo'            => 'Jedna, ili više, datoteka su priključene.',
'taskwatching'            => 'Sledeći zadatak pratite',
'isdepfor'                => 'je nova zavisnost za',
'denialreason'            => 'Razlog zabrane',
'taskchanged'             => 'Sledeći zadatak je izmenjen. Izmene su vidljive ispod. Za više informacija o izmenama vidi na linku, kao i na jezičku "Istorija".',
'useraddedtoassignees'    => 'Korisnik se sam dodao listi korisnika kojima je dodeljen ovaj zadatak.',
'removeddepis'            => 'Uklonjena zavisnost je',
'isnodepfor'              => 'nije zavisnost više za',
'usergroups'              => 'Korisničke grupe',
'pmtoolbox'               => 'Alati rukovodioca projekata',
'groupmanage'             => 'Upravljanje grupama',
'pendingrequests'         => 'Ne rešeni zahtevi',
'reasongiven'             => 'Razlog naveden',
'nopendingreq'            => 'Nema ne rešenih zahteva za rukovodioca projekta.',
'givereason'              => 'Navedite razlog',
'catlisted'               => 'Uređivač liste kategorija',
'oslisted'                => 'Uređivač liste opretaivnih sistema',
'verlisted'               => 'Uređivač liste verzija',
'tasktypeed'              => 'Uređivač liste tipova',
'resed'                   => 'Uređivač liste razlučivanja',
'deny'                    => 'Odbij',
'notifiedwhen'            => 'obavešten kad',
'onlynewtasks'            => 'Novi zadtak otovoren',
'allevents'               => 'Novi događaj se pojavio u zadatku',
'feeds'                   => 'Feed-ovi',
'feeddescription'         => 'Opis Feed-a',
'feedimgurl'              => 'URL slike za Feed (prazno, ako nema slike)',
'notifysubject'           => 'Subjekat poruke obaveštenja',
'notifysubjectinfo'       => '(%p = naslov projekta, %s = zadatak ukratko, %t = broj zadatka, %a = akcija, %u = korisnik)',
'priority6'               => 'Trenutni',
'priority5'               => 'Skoriji',
'priority4'               => 'Urgentni',
'priority3'               => 'Visoki',
'priority2'               => 'Normalan',
'priority1'               => 'Nizak',
'sendcode'                => 'Pošalji kood!',
'entercode'               => 'Unesite potvrdni kood, koji ste primili u Vašoj poruci.  Takođe unesite Vašu traženu lozinku.',
'confirmationcode'        => 'Potvrdni kood',
'registererror'           => 'Proverite da li ste popunili sva obavezna polja i nakon toga unestite ispravne podatke za Vaš željeni način obaveštenja.',
'validusername'           => '(samo alfanumerički znaci i - _ . su dozvoljeni)',
'emailtaken'              => 'E-mail adresa, ili Jabber-ID su već navedeni. Morate izabrati drugu.',
'note'                    => '<strong>Napomena:</strong>  Biće Vam poslat kood potvrde, pre nego što se Vaš nalog kreira.  Kood će Vam biti poslat korišćenjem prethodno izabrane metode.<br />Ako unesete pogrešne podatke, <strong>nećete primiti Vaš potvrdni kood</strong>.',
'changelog'               => 'Dnevnik promena',
'changeloggen'            => 'Generator dnevnika promena',
'listfrom'                => 'Listanje stavki dnevnika od',
'to'                      => 'do',
'oldestfirst'             => 'Stariji prvo',
'recentfirst'             => 'Najnoviji prvo',
'severityrep'             => 'Izveštaj važnosti',
'totalopen'               => 'Ukupno otovorenih zadataka',
'age'                     => 'Datum',
'agerep'                  => 'Datum izveštaja',
'eventsrep'               => 'Izveštaj o odgađajima',
'events'                  => 'Događaji',
'Tasks'                   => 'Zadaci',
'opened'                  => 'Otvoreni',
'edited'                  => 'izmenjeni',
'assigned'                => 'Dodeljeni',
'within'                  => 'Unutar',
'pastday'                 => 'Juče',
'pastweek'                => 'Prošle nedelje',
'pastmonth'               => 'Prošlog meseca',
'pastyear'                => 'Prošle godine',
'nolimit'                 => 'Nema ograničenja',
'from'                    => 'Od',
'duein'                   => 'Dospeva u',
'selectfromdate'          => 'Izbor od datuma',
'selecttodate'            => 'Izbod do datuma',
'showvoters'              => 'Prikaži/sakrij glasače',
'roadmap'                 => 'Plan',
'roadmapfor'              => 'Plan za verziju',
'tasks'                   => 'zadataka',
'completed'               => 'završeno.',
'opentasks'               => 'otvorenih zadataka',
'of'                      => '% od',
'severity5'               => 'Kritična',
'severity4'               => 'Visoka',
'severity3'               => 'Srednja',
'severity2'               => 'Niska',
'severity1'               => 'Veoma niska',
'Redirect'                => 'Preusmeri',
'redirectmsg'             => 'Ako Vaš Internet pretraživač ne podržava redirekciju kliknite na %sHERE%s za redirekciju',
'allowclosedcomments'     => 'Dozvoli komentare nad zatvorenim zadacima',
'comment'                 => 'Komentar',
'editowncomments'         => 'Izmeni svoj komentar',
'reopened'                => 'Ponovo otvoren',
'loading'                 => 'Učitavanje...',
'notifyown'               => 'Obaveštenja o sopstvenim promenama',
'youremail'               => 'Vaša e-mail adresa',
'thankyouforbug'          => 'Zahvaljujemo Vam se na prijavi problema. Možete videti zadatke i pratiti napredak nad njima, bilo kada, prateći sledeći URL:',
'anonuser'                => 'Nepoznati korisnik',
'conflict'                => 'Konflikt',
'file'                    => 'Datoteka',
'KiB'                     => 'kB',
'MiB'                     => 'MB',
'size'                    => 'Veličina',
'projectgroup'            => 'Projektna grupa',
'profile'                 => 'Profil:',
'viewprofile'             => 'Uvid profila',
'regdate'                 => 'Registrovan od',
'tasksopened'             => 'Zadatak otvoren',
'replyto'                 => 'Odogovori',
'notifytypes'             => 'Tip obaveštenja',
'pm.taskchanged'          => 'Zadatak izmenjen',
'pm.taskreopened'         => 'Zadatak ponovo otvoren',
'pm.depadded'             => 'Zavsnost dodata',
'pm.depremoved'           => 'Zavisnost uklonjena',
'pmrequest'               => 'PM zahtev',
'pmrequestdenied'         => 'PM zahtev odbačen',
'newassignee'             => 'Novi ovlašćenik',
'revdepadded'             => 'Kontra-zavisnost dodata',
'revdepaddedremoved'      => 'Kontra-zavisnost ukllonjena',
'assigneeadded'           => 'Ovalšćenik dodat',
'addusergroup'            => 'Dodaj korisnika ovoj grupi',
'groupmembers'            => 'Članovi grupe',
'deleteuser'              => 'Brisanje korisnika',
'userdeleted'             => 'Korisnik obrisan',
'autoassign'              => 'Automatska dodela zadatka vlasniku kategorije',
'ssl'                     => 'SSL',
'updatewrong'             => 'Provera ažuriranja je uključena i u tom postupku se pojavila greška
                             prilikom kontaktiranja servera. Ili je problem sa spoljašnjim pristupom ovog hosta,
                             ili je problem sa mrežom.
                             Molimo posetite FlySpray sajt, radi dobavljanja najnovije verzije!',
'deleteproject'           => 'Briši ovaj projekat i premesti sadržaj u',
'projectdeleted'          => 'Projekat je uspešno obrisan',
'feedforall'              => 'Feed za sve projekte',
'usercreated'             => 'Korisnik kreiran',
'userdeleted'             => 'Korisnik obrisan',
'created'                 => 'Kreiran',
'deleted'                 => 'Obrisan',
'userid'                  => 'Korisnički broj',
'editassignments'         => 'Izmeni dodelu',
'preview'                 => 'Pregled',
'anyprogress'             => 'Ma koji napredak',
'tasksrelated'            => 'Zadaci koji su u vezi',
'duplicatetasks'          => 'Duplih zadataka',
'databasemodfailed'       => 'Promena baze podataka neuspešna. Mogući razog je nedostatak privilegija.',
'frequency'               => 'Učestalo',
'newuserregistered'       => 'Novi korisnik je registrovan u Vašoj Flyspray instalaciji. Korisnički podaci su sledeći:',
'newuserregisterednotify' => 'Novi korisnik registrovan',
'notify_registration'     => 'Obavesti administratora o novim registracijama',
'textversion'             => 'Tekst verzija',
'onlyprimary'             => 'Zadatak ne blokira druge zadatke',
'switch'                  => 'Promeni',
'max'                     => 'maks.',
'dates'                   => 'Datumi',
'selectduedatefrom'       => 'Očekuje se od',
'selectduedateto'         => 'dospeva do',
'selectsincedatefrom'     => 'Menjeno od',
'selectsincedateto'       => 'do',
'selectdate'              => 'Izaberi datum',
'selectopenedfrom'        => 'Otvoreno od',
'selectopenedto'          => 'do',
'selectclosedfrom'        => 'Zatvoreno od',
'selectclosedto'          => 'do',
'startat'                 => 'Počni na',
'hasattachment'           => 'Ima priključak (attachment)',
'private'                 => 'Privatno',
'watching'                => 'Praćenje promena',
'alreadyvotedthistask'    => 'glasali ste za ovaj zadatak',
'alreadyvotedthisday'     => 'već glasano danas',
'visibility'              => 'Vidljivost',
'public'                  => 'Javno',
'leaveemptyauto'          => 'Nemojte unosititi lozinku, ako želite da se ona automatski generiše.',
'novalidemail'            => 'Niste uneli važeću e-mail adresu.',
'novalidjabber'           => 'Niste uneli važeću Jabber adresu.',
'missingrequired'         => 'Niste popunili sva obavezna polja!',
'entervalidusername'      => 'Molimo unesite važeće korisničko i stvarno ime.',
'couldnotaddusernotif'    => 'Ovaj korisnik neće biti dodat listi obaveštenja.',
'defaulttask'             => 'Podrazumevani opis zadatka',
'all'                     => 'sve',
'events.useraddedtoassignees' => 'Korisnik dodat listi dodeljenih',
'vote(s)'                 => 'glas(ova)',
'eventlog'                => 'Dnevnik događaja',
'assignmentchanged'       => 'Dodela promenjena',
'detailedinfo'            => 'Detaljne informacije',
'All'                     => 'Sve',
'tasksireported'          => 'Zadaci i izveštaji',
'recentlyopened'          => 'Često otvarani',
'stats'                   => 'Statusi',
'totaltasks'              => 'ukupno zadataka',
'mostwanted'              => 'Najtraženiji zadaci',
'defaultentry'            => 'Podrazumevana ulazna strana',
'toplevel'                => 'Uvid najvišeg nivoa',
'overview'                => 'Pregled',
'error#'                  => 'Greška broj: ',
'error1'                  => 'Nemate dovoljno dozvola da vidite ovaj priključak!',
'error3'                  => 'Ponovljen postupak, vraćanje na glavnu stranu!',
'error4'                  => 'Nemate administratorska prava!',
'error5'                  => 'Korisnik nije registrovan u ovoj Flyspray instalaciji!',
'error6'                  => 'Pogrešna administratorska zona.',
'error7'                  => 'Prijava neuspela. Pogrešna lozinka!',
'error71'                 => 'Korisnički nalog je zaključan za narednih %d minuta zbog prevelikog broja pokušaja prijave!',
'error8'                  => 'Niste uneli korisničko ime i/ili lozinku!',
'error9'                  => 'Zadatak ne postoji, ili nemate dozvolu za uvid zadataka!',
'error10'                 => 'Ovaj zadatak ne postoji!',
'error101'                => 'Nemate dozvolu za uvid ovog zadatka!',
'error102'                => 'Nemate dozvolu za uvid ovog zadatka! Prijavite se, možda će prijava pomoći.',
'error11'                 => 'Nemate dozvolu za izmenu ovog komentara!',
'error12'                 => 'Nevažeći magični ključ! Da li ste sigurni da je ovo Vaša poruka obaveštenja?',
'error13'                 => 'Anonimni korisnik nema profil!',
'error14'                 => 'Nemate dovoljno dozvola da kreirate novu grupu!',
'error15'                 => 'Nemate dovoljno dozvola da otvorite zadatak!',
'error16'                 => 'Vi niste rukovodilac projekata!',
'error17'                 => 'Pogrešna PM zona!',
'error18'                 => 'Pogrešan magični URL!',
'error19'                 => 'Korisnik ne postoji u ovoj Flyspray instalaciji!',
'error20'                 => 'Pogrešna izmena baze podataka!',
'error21'                 => 'Jedna, ili više, elektronskih poruka (e-mail) nije poslata! Proverite Vašu konfiguraciju.',
'error22'                 => 'Zabranjena registracija novim korisnicima!',
'error23'                 => 'Korisniku, ili njegovoj grupi, je zabranjena prijava!',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Plan je raspoloživ samo za specifične projekte.',
'done'                    => 'urađeno',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projekat nije obrisan!',
'GMT'                     => 'GMT',
'timezone'                => 'Vremenska zona',
'accept'                  => 'Prihvati',
'reasonfordeinal'         => 'Razlog za zabranu',
'pruneclosedlinks'        => 'Odstrani zatvorene linkove',
'pruneclosedtasks'        => 'Odstrani zatvorene zadatke',
'pagegenerated'           => 'Strana i slika generisani u %d sekundi.',
'pruninglevel'            => 'Odstranjivanje nivoa',
'lastuser'                => 'Poslednji korisnik ne može biti obrisan!',
'allprivate'              => 'Svi projekti su privatni!',
'deletegroup'             => 'Obriši ovu grupu i premesti korisnjike u',
'parent'                  => 'Nadređen',
'ordertip'                => 'Redosled stavki biće prikazan u listi',
'showtip'                 => 'Prikaži ovu stavku u listi',
'deletetip'               => 'Briši ovu stavku iz liste',
'del'                     => 'Briši',
'request1'                => 'Zatraženo je zatvaranje zadatka.',
'request2'                => 'Postupak za ponovno otvaranje zadatka uspešno okončan.',
'allpriorities'           => 'Svi prioriteti',
'noroadmap'               => 'Ova opcija nije raspoloživa u trenutnoj verziji.',
'expand'                  => 'Raširi',
'collapse'                => 'Sažmi',
'expandall'               => 'Raširi sve',
'collapseall'             => 'Sažmi sve',
'minpwsize'               => 'Minimalna dužina lozinke je 5 znakova',
'passwordtoosmall'        => 'Dužina lozinke je prekratka',
'accountwaslocked'        => 'Vaš korisnički nalog je zaključan zbog prevelikog broja pokušaja prijave!',
'failedattempts'          => 'Ukupno %d neuspešnih pokušaja prijave!',
'groupnotexist'           => 'Izabrana grupa ne postoji u ovom projektu!',
'searchindetails'         => 'Detalji pretrage',
'showasassignees'         => 'Prikaži kao dodeljene',
'find'                    => 'Nađi',
'tls'                     => 'TLS',
'isadmin'                 => 'Da li je ovo administrator?',
'addvotes'                => 'Glasaj za',
);
