<?php
/**
* initial czech translation by Petr Stasiak
*
* @author Petr Stasiak
* @see FS#1844
*
*/

$translation = array(
'edituser'                => 'Upravit uživatele',
'username'                => 'Přihlašovací jméno',
'realname'                => 'Skutečné jméno',
'emailaddress'            => 'Emailová adresa',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Typ upozornění',
'group'                   => 'Skupina',
'accountenabled'          => 'Účet povolen',
'updatedetails'           => 'Aktualizovat detaily',
'setglobally'             => 'Tato předvolba je nastavena globálně.',
'usergroupmanage'         => 'Nastavení uživatelů a skupin',
'newuser'                 => 'Registrace uživatele',
'newgroup'                => 'Založit skupinu',
'yes'                     => 'Ano',
'no'                      => 'Ne',
'editgroup'               => 'Upravit skupinu',
'groupname'               => 'Název skupiny',
'description'             => 'Popis',
'admin'                   => 'Admin group',
'opennewtasks'            => 'Nově otevřené úkoly',
'modifytasks'             => 'Upravit existující úkol',
'addcomments'             => 'Přidat komentář',
'attachfiles'             => 'Připojit soubory',
'vote'                    => 'Hlasovat',
'groupenabled'            => 'Členové se mohou přihlásit',
'tasktypelist'            => 'Seznam typů požadavků',
'categorylist'            => 'Seznam kategorií',
'oslist'                  => 'Seznam operačních systémů',
'resolutionlist'          => 'Seznam řešení',
'versionlist'             => 'Seznam verzí',
'severitylist'            => 'Seznam priorit',
'listnote'                => 'Pozor:  Vypnutí "zobrazit" může ovlivnit některé požadavky v režimu úpravy. Změna pole "Název" změní všechny požadavky tohoto jména. Položky, které nemohou být odstraněny, jsou buď chráněny, protože jsou potřebné pro správnou funkci nebo se používají v požadavcích.',
'name'                    => 'Jméno',
'order'                   => 'Třídění',
'back'                    => 'Zpět',
'text'                    => 'Text',
'highlight'               => 'Zvýraznit',
'show'                    => 'Zobrazit',
'owner'                   => 'Vlastník',
'selectowner'             => 'Vybrat vlastníka',
'update'                  => 'Aktualizovat',
'addnew'                  => 'Přidat nový',
'flysprayprefs'           => 'Nastavení Flyspray',
'projecttitle'            => 'Nadpis projektu',
'baseurl'                 => 'Základní URL adresa této instalace',
'replyaddress'            => 'Adresa pro odpovědi na upozornění',
'themestyle'              => 'Téma / Styl',
'language'                => 'Jazyk',
'anonview'                => 'Povolit nepřihlášeným zobrazit požadavky',
'allowanon'               => 'Povolit nepřihlášeným zakládat požadavky',
'never'                   => 'Nikdy',
'anonymously'             => 'Anonymně',
'afterregister'           => 'Pouze po registraci',
'spamproof'               => 'Povolit potvrzovací kód při registraci uživatele',
'anongroup'               => 'Skupina pro nové registrace',
'groupassigned'           => 'Členové těchto skupin mohou řešit požadavky',
'forcenotify'             => 'Upozornění na změny zaslat',
'neversend'               => 'Nikdy neposílat',
'userchoose'              => 'Nechat uživatele vybrat',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Výchozí vlastník kategorie',
'noone'                   => 'Žádný',
'jabbernotify'            => 'Upozornění jabber',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Uživatelské jméno',
'jabberpass'              => 'Heslo',
'saveoptions'             => 'Uložit nastavení',
'editcomment'             => 'Upravit komentář',
'commentby'               => 'Komentoval ',
'saveeditedcomment'       => 'Uložit změněný komentář',
'projectprefs'            => 'Vlastnosti projektu',
'pagetitle'               => 'Nadpis stránky',
'defaultproject'          => 'Výchozí projekt',
'projectlists'            => 'Seznam projektů',
'showlogo'                => 'Zobrazit logo v záhlaví',
'intromessage'            => 'Úvodní zpráva - popis projektu',
'isactive'                => 'Projekt je aktivní',
'createproject'           => 'Vytvořit nový projekt',
'nopermission'            => 'Nemáte právo k použití této stránky.',
'listordertip'            => 'Vyberte položky pro zobrazení v seznamu',
'listshowtip'             => 'Zobrazit tuto položku v seznamu',
'categoryownertip'        => 'Tito uživatelé obdrží upozornění pokud bude otevřen požadavek v této kategorii',
'categoryparenttip'       => 'Nadřízená kategorie, tato nová bude spadat pod ni',
'notsubcategory'          => 'Není (nejvyžší kategorie)',
'showinlineimages'        => 'Zobrazit přiložené obrázky v textu',
'dateformat'              => 'Formát data (j.n.Y)',
'dateformat_extended'     => 'Dlouhý formát data (l j.F.Y)',
'cache_feeds'             => 'Kešovat zdroje ',
'no_cache'                => 'Žádná keš',
'cache_disk'              => 'Keš na disku',
'cache_db'                => 'Keš v databázi',
'subcategoryof'           => 'Podkategorie ',
'visiblecolumns'          => 'Sloupce zobrazené v seznamu požadavků',
'tense'                   => 'Verze',
'listtensetip'            => 'Minulá, součastná nebo budoucí',
'past'                    => 'Minulá',
'present'                 => 'Součastná',
'future'                  => 'Budoucí',
'oldpass'                 => 'Aktuální heslo',
'nooldpass'               => 'Aktuální heslo není nastaveno',
'oldpasswrong'            => 'Aktuální heslo je špatně zadané',
'changepass'              => 'Změnit heslo',
'confirmpass'             => 'Potvrdit zadání',
'projectmanager'          => 'Správce projektů',
'viewtasks'               => 'Zobrazit požadavky',
'modifyowntasks'          => 'Upravit vlastní požadavky',
'modifyalltasks'          => 'Upravit úkoly, které uživatel nevlastní',
'viewcomments'            => 'Zobrazit komentáře',
'editcomments'            => 'Upravit komentář',
'deletecomments'          => 'Vymazat komentář',
'viewattachments'         => 'Zobrazit přílohy',
'createattachments'       => 'Vytvořit přílohy',
'deleteattachments'       => 'Vymazat přílohy',
'viewhistory'             => 'Zobrazit hystorii',
'closeowntasks'           => 'Uzavřít vlastní požadavky',
'closeothertasks'         => 'Uzavřít úkoly, které uživatel nevlastní',
'assigntoself'            => 'Přiřadit mi požadavky, které doposud nejsou',
'assignotherstoself'      => 'Přiřadit požadavky ostatních mě',
'viewreports'             => 'Zobrazit log událostí',
'othersview'              => 'Povolit všem zobazit tento projekt',
'usersandgroups'          => 'Uživatelé a skupiny',
'globalgroup'             => 'Globální skupina',
'globalgroups'            => 'Globální skupiny',
'defaultglobalgroup'      => 'Výchozí globální skupina pro nové uživatele',
'addtogroup'              => 'Přidat skupinu',
'moveuserstogroup'        => 'Přesunout uživatele do skupiny',
'nogroup'                 => 'Není skupina - Odstranit z projektu',
'eventdesc'               => 'Popis události',
'requestedby'             => 'Požadováno kým',
'daterequested'           => 'Požadované datum',
'closetask'               => 'Uzavřít požadavek',
'reopentask'              => 'Znovu otevřít požadavek',
'applymember'             => 'Použít pro členy projektu',
'forcurrentproj'          => 'Pro aktuální projekt',
'lostpw'                  => 'Obnova zapomenutého hesla',
'lostpwexplain'           => 'Zadejte Vaše uživatelské jméno pro získání odkazu na zadání nového hesla.  Odkaz bude odeslán na adresu zadanou jako notifikační ve Vašem profilu.',
'sendlink'                => 'Obnovit heslo',
'savenewpass'             => 'Uložit nové heslo',
'anonreg'                 => 'Povolit registraci uživatelů',
'allowanonopentask'       => 'Povolit nepřihlášeným zakládat požadavky',
'editglobalgroup'         => 'Upravit globální skupinu',
'editgroupforproj'        => 'Upravit skupinu pro projekt',
'notshownforadmin'        => 'Oprávnění pro skupinu administrátorů nejsou zobrazeny. Administrátoři nemají žádná omezení...',
'general'                 => 'Hlavní',
'userregistration'        => 'Registrace uživatele',
'notifications'           => 'Upozornění',
'resetoptions'            => 'Obnovit výchozí nastavení',
'preferences'             => 'Předvolby',
'tasktypes'               => 'Typy úkolů',
'resolutions'             => 'Řešení',
'categories'              => 'Kategorie',
'operatingsystems'        => 'Operační systémy',
'versions'                => 'Verze',
'admintoolboxlong'        => 'Administrátorovy nástroje',
'newproject'              => 'Nový projekt',
'delete'                  => 'Vymazat',
'listdeletetip'           => 'Vymazat tuto položku ze seznamu',
'lookandfeel'             => 'Vzhled a chování',
'globaltheme'             => 'Globální vzhled',
'emailnotify'             => 'E-mailová upozornění',
'fromaddress'             => 'Z adresy',
'smtpserver'              => 'SMTP server',
'smtpuser'                => 'SMTP přihlašovací jméno',
'smtppass'                => 'SMTP heslo',
'addrewrite'              => 'Použít přepisování adres',
'usereminderdaemon'       => 'povolit službu upozorňování na pozadí',
'tasksperpage'            => 'Požadavků na stránku v seznamu požadavků',
'addtoassignees'          => 'Přidat mě mezi nabyvatele',
'taskstatuses'            => 'Stavy požadavků',
'canvote'                 => 'Může hlasovat pro úkoly',
'loginsuccessful'         => 'Přihlášení úspěšné.',
'youareloggedout'         => 'Jste úspěšně odhlášen.',
'waitwhiletransfer'       => 'Prosím čekejte, dokud nebudete přenesen...',
'clicknowait'             => 'Klikněte zde, pokud nechcete čekat.',
'accountdisabled'         => 'Váš účet je zablokován. Kontaktujte prosím administrátora.',
'task'                    => 'požadavek',
'edittask'                => 'Upravit požadavek',
'openedby'                => 'Otevřel',
'editedby'                => 'Naposledy upravil',
'tasktype'                => 'Typ požadavku',
'category'                => 'Kategorie',
'status'                  => 'Status',
'assignedto'              => 'Přiřazeno k ',
'operatingsystem'         => 'Operační systém',
'severity'                => 'Priorita',
'reportedversion'         => 'Hlášená verze',
'dueinversion'            => 'Vyskytuje se ve verzi',
'undecided'               => 'Nerozhodný',
'percentcomplete'         => 'Procent dokončeno',
'details'                 => 'Detaily',
'savedetails'             => 'Uložit detaily',
'canceledit'              => 'Zrušit změny',
'anonymous'               => 'Anonymní uživatel',
'complete'                => 'completní',
'closedby'                => 'Uzavřeno',
'reasonforclosing'        => 'Důvod uzavření:',
'reopenthistask'          => 'Znovu otevřít požadavek',
'comments'                => 'Komentáře',
'attachments'             => 'Přílohy',
'relatedtasks'            => 'Související požadavky',
'edit'                    => 'Upravit',
'addcomment'              => 'Přiadit komentář',
'fileuploadedby'          => 'Soubor nahrál',
'uploadafile'             => 'Přidat soubor',
'uploadnow'               => 'Nahrát nyní!',
'thesearerelated'         => 'Tyto požadavky souvisí s tímto požadavkem',
'remove'                  => 'Odstranit',
'addnewrelated'           => 'Přidat nový související požadvek',
'add'                     => 'Přidat',
'otherrelated'            => 'Další požadavky vztahující se k tomuto požadavku',
'receivenotify'           => 'Tito uživatelé dostanou upozornění na změnu tohoto požadavku.',
'addusertolist'           => 'Přidat uživatele do seznamu',
'addtolist'               => 'Přidat do seznamu',
'addmyself'               => 'Přidat sebe do tohoto seznamu',
'removemyself'            => 'Odstranit sebe z tohoto seznamu',
'theseusersnotify'        => 'Tito uživatelé budou dostávat detailní informace při změně tohoto požadavku.',
'attachedtoproject'       => 'Přiřazeno k projekru',
'reminders'               => 'Upomínky',
'system'                  => 'Systém',
'remindthisuser'          => 'Upozornit tohoto uživatele',
'thisoften'               => 'Jak často',
'startafter'              => 'Počkejte, než se spustí upomínač',
'hours'                   => 'Hodina(y)',
'days'                    => 'Den(y)',
'weeks'                   => 'Týden(dny)',
'addreminder'             => 'Přidat upomínku',
'defaultreminder'         => 'Toto je připomínka - podívejte se na tento požadavek Flyspray:',
'message'                 => 'Zpráva',
'closed'                  => 'Uzavřeno',
'filename'                => 'Název souboru:',
'date'                    => 'Datum',
'filesize'                => 'Velikost souboru:',
'closurecomment'          => 'Rozšířený komentář k uzavření:',
'history'                 => 'Historie',
'nohistory'               => 'Historie není dostupná.',
'eventdate'               => 'Datum',
'user'                    => 'Uživatel',
'event'                   => 'Událost',
'fieldchanged'            => 'Field changed',
'taskopened'              => 'Požadavek oteřen',
'taskreopened'            => 'Požadavek znovu oteřen',
'taskclosed'              => 'Požadavek uzavřen',
'commentadded'            => 'Přidán komentář',
'commentedited'           => 'Komentář změněn',
'commentdeleted'          => 'Komentář odstraněn',
'attachmentadded'         => 'Příloha přidána',
'attachmentdeleted'       => 'Příloha odstraněna',
'taskedited'              => 'Detail požadavku změněn',
'notificationadded'       => 'Uživatel přidán do seznamu upozorňovaných',
'notificationdeleted'     => 'Uživatel odstraněn ze seznamu upozornění',
'relatedadded'            => 'Související úloha přidána',
'relateddeleted'          => 'Související úloha odstraněna',
'taskassigned'            => 'Požadavek přiřazen',
'taskreassigned'          => 'Požadavek přepřiřazen k',
'assignmentremoved'       => 'Přiřazení odstraněno',
'summary'                 => 'Souhrn',
'addedasrelated'          => 'Požadavek přidán k souvisejícímu seznamu',
'deletedasrelated'        => 'Požadavek odebrán ze souvisejícího seznamu',
'reminderadded'           => 'Připomenutí přidáno',
'reminderdeleted'         => 'Připomenutí odstraněno',
'priority'                => 'Priorita',
'previousvalue'           => 'Minulá hodnota',
'newvalue'                => 'Nová hodnota',
'selectareason'           => 'Select a reason',
'assigntome'              => 'Přiřadit mě',
'reopenrequest'           => 'Požadavek na znovu-otevření',
'requestclose'            => 'Žádost o uzavření',
'ownershiptaken'          => 'Uživatel převzal vlastnictví',
'closerequestmade'        => 'Požadavek na uzavření požadavku',
'reopenrequestmade'       => 'Požadavek na opakované otevření požadavku',
'taskdependson'           => 'Požadavek závisí na',
'taskblocks'              => 'Tento úkol blokuje uzavření',
'depadded'                => 'Přídána závislost:',
'depaddedother'           => 'Požadavek přidán jako závislost:',
'depremoved'              => 'Závislost odstraněna:',
'depremovedother'         => 'Požadavek odstraněn ze seznamu závislostí dalších požadavků:',
'showdetailserror'        => 'Požadavek neexistuje, nebo nemáte právo jeje zobrazit.',
'makeprivate'             => 'označit jako soukromý',
'makepublic'              => 'označit jako veřejný',
'taskmadeprivate'         => 'Požadavek byl označen za soukromý',
'taskmadepublic'          => 'Vlastnictví odstraněno - požadavek je veřejný',
'confirmdeletecomment'    => 'Opravdu odstranit tento komentář?  Veškeré přílohy budou také odstraněny!',
'confirmdeleteattach'     => 'Opravdu odstranit tuto přílohu?',
'selectedhistory'         => 'Zobrazeny vybrané položky historie',
'showallhistory'          => 'Zobrazit plnou záložku historie',
'hidethis'                => 'Znovu skrýt tuto oblast',
'mark100'                 => 'Označit jako 100% dokončený',
'watchtask'               => 'sledování požadavku',
'stopwatching'            => 'konec sledování',
'commentlink'             => 'Odkaz na tento komentář',
'submitreq'               => 'Odeslat požadavek',
'reasonforreq'            => 'Důvod žádosti',
'pmreqdenied'             => 'Manažer projektu odmítnul požadavek',
'taskpendingreq'          => 'Akce probíhá. Podívejte se na záložku historie pro získání více informací.',
'previoustask'            => 'Předešlý požadavek',
'nexttask'                => 'Nalší požadavek',
'duedate'                 => 'Patřící k datu',
'attachnoperms'           => 'Komentář obsahuje přílohu, ale nemáte právo ji zobrazit.',
'open'                    => 'Otevřené',
'depgraph'                => 'Zorazit graf závislostí',
'reset'                   => 'Reset',
'selectusers'             => 'Vybraní užiatelé...',
'addmetoassignees'        => 'Přidat mě kpřiřazeným',
'addedtoassignees'        => 'Uživatel přidám k seznamu přiřazených',
'dependencygraph'         => 'Graf závislostí',
'attachanotherfile'       => 'Připojit další soubor',
'OK'                      => 'OK',
'addvote'                 => 'Podpořit',
'notifyfromfs'            => 'Upozornění z Flyspray',
'autogenerated'           => 'Toto je automaticky generovaná zpráva, prosím NEODPOVÍDEJTE na ni.',
'forward'                 => 'Další',
'previous'                => 'Předešlý',
'next'                    => 'Další',
'first'                   => 'První',
'last'                    => 'Poslední',
'page'                    => 'Strana %d z %d',
'search'                  => 'Hledat',
'alltasktypes'            => 'Všechny typy požadavku',
'allseverities'           => 'Všechny úrovně',
'alldevelopers'           => 'Všichni vývojáři',
'notyetassigned'          => 'Není přiřazeno',
'allcategories'           => 'Všechny kategorie',
'allstatuses'             => 'Všechny stavy',
'allopentasks'            => 'Všechny otevřené požadavky',
'sortthiscolumn'          => 'Třídit podle tohoto sloupce',
'id'                      => 'ID',
'project'                 => 'Projekt',
'dateopened'              => 'Otevřen',
'progress'                => 'Dokončeno',
'searchthisproject'       => 'Vyhledávat v projektu',
'dueanyversion'           => 'Patří k libovolné verzi',
'anyversion'              => 'Reported In Any Version',
'dueversion'              => 'Patřící k verzi',
'lastedit'                => 'Naposledy změněno',
'os'                      => 'Operační systém',
'reportedin'              => 'Reported In',
'taskrange'               => 'Zobrazuji požadavky %d - %d z %d',
'noresults'               => 'Vaše hledání nenašlo žádný výsledek.',
'takeaction'              => 'Provést',
'watchtasks'              => 'Sledovat vybrané požadavky',
'stopwatchingtasks'       => 'Ukončit sledování vybraných požadavků',
'assigntaskstome'         => 'Přiřadit mě vybrané požadavky',
'dueby'                   => 'Patří k',
'dueanytime'              => 'Kdykoliv',
'selectduedate'           => 'Výběr data',
'toggleselected'          => 'Přepnout výběr',
'due'                     => 'Patřící',
'assignedtome'            => 'Přiřazeno mě',
'tasklist'                => 'Požadavky',
'dateclosed'              => 'Datum uzavření',
'advanced'                => 'Rozšířené',
'searchcomments'          => 'Hledat v komentářích',
'searchforall'            => 'Hledat všechna slova',
'anonusers'               => 'Anonymní uživatelé',
'miscellaneous'           => 'Různé',
'users'                   => 'Uživatelé',
'taskproperties'          => 'Vlastnosti požadavku',
'selectsincedate'         => 'Vybrat změněno od',
'changedsince'            => 'Změněno od',
'updatefs'                => 'Prosím aktualizujte Flyspray.',
'currentversion'          => 'Vaše aktuální verze je',
'latestversion'           => 'a poslední verze je',
'hidemessage'             => '(upozornit mě později)',
'saveas'                  => 'Uložit hledání jako',
'nosearches'              => 'Nejsou uložená hledání',
'saving'                   => 'Ukládání...',
'votes'                   => 'Podpory',
'allclosedtasks'          => 'Všechny uzavřené požadavky',
'password'                => 'Heslo',
'login'                   => 'Přihlášení!',
'rememberme'              => 'Zapamatovat si mě',
'lostpassword'            => 'Zapomenuté heslo?',
'lostpwforfs'             => 'Zapomenuté heslo pro Flyspray',
'lostpwmsg1'              => 'Dobrý den.

Zapoměl jsem přístupové heslo do systému hlášení chyb Flyspray',
'lostpwmsg2'              => ', prosím vytvořte mi nové heslo.

Uživatel: ',
'regards'                 => '

S pozdravem,',
'yourusername'            => ' vaše jméno ',
'locale'                  => 'cs',
'filenotexist'            => 'Soubor neexistje, nebo nemáte přístupová práva.',
'showtask'                => 'Zobrazit požadavek',
'now'                     => 'Nyní',
'go'                      => 'Jedeme!',
'opentaskanon'            => 'Otevřít požadavek anonymně',
'register'                => 'Registrovat',
'addnewtask'              => 'Přidat nový požadavek',
'reports'                 => 'Log událostí',
'editmydetails'           => 'Upravit moje údaje',
'logout'                  => 'Odhlásit se',
'disabledaccount'         => 'Váš účet byl zablokován!<br />Budete odhlášen...',
'poweredby'               => 'Spravováno systémem Flyspray',
'projects'                => 'Projekty',
'allprojects'             => 'Všechny projekty',
'selectproject'           => 'pro projekt:',
'tasksall'                => 'Všechny požadavky',
'tasksassigned'           => 'Požadavky mě přiřazené',
'tasksreported'           => 'Mnou hlášené požadavky',
'taskswatched'            => 'Požadavky, které sleduji',
'mysearch'                => 'Moje hledání',
'admintoolbox'            => 'Administrátorský panel',
'manageproject'           => 'Manažer projektu',
'permissions'             => 'Zobrazení práv',
'hide'                    => 'Skrýt',
'pendingreq'              => 'PM požadavků čeká',
'errorpage'               => 'Flyspray nemůže zobrazit Vámi požadovanou stránku.
                                 požádal jste o úkol, který neexistuje, nebo
                                 nemáte právo k zobrazení této stránky.<br /><br />
                                 Možná se pokoušíte o napadení systému SQL injekcí.
                                 Pokud je to tak, styďte se a uvažujte o své osobě!
                                 Až se vrátíte, už to nezkoušejte!',
'permissionsforproject'   => 'Práva pro ',
'switchto'                => 'Přepnout na',
'lastsearch'              => 'Poslední hledání',
'modify'                  => 'Upravit',
'noticefrom'              => 'Upozornění od',
'hasopened'               => 'otevřel nový požadavek a přiřadil jej Vám:',
'moreinfonew'             => 'Více informací získáte na této stránce:',
'newtaskcategory'         => 'Je otevřen nový požadavek v této kategorii',
'categoryowner'           => 'Obdržel jste tuto zprávu, protože jste v seznamu vlastníků kategorie.',
'tasksummary'             => 'Souhrn úkolu:',
'newtaskadded'            => 'Váš nový požadavek byl přidán.',
'summaryanddetails'       => 'Musíte vyplnit obojí souhrn i detaily.',
'goback'                  => 'Zpět.',
'messagefrom'             => 'Toto je zpráva od Flyspray správce požadavků  ',
'hasjustmodified'         => 'Následující požadavek byl právě změněn.',
'changedfields'           => 'Změněné položky jsou označeny hvězdičkami(**)',
'moreinfomodify'          => 'Více informací se dozvíte na následijící stránce:',
'nolongerassigned'        => 'Tento požadavek již není přiřazen Vám. Nyní jej vlastní ',
'hasassigned'             => 'byl Vám přiřazen následjící Flyspray požadavek:',
'taskupdated'             => 'Požadavek byl aktualizován.',
'hasclosedassigned'       => 'byl uzavřen požadavek Flyspray , který Vám je přiřazen:',
'unassigned'              => 'Nepřiřazeno',
'hasclosed'               => 'uzavřel následující požadavek.',
'youonnotify'             => 'Tuto informaci jste dostal protože jste v seznamu upozorňovaných uživatelů.',
'taskclosedmsg'           => 'Požadavek byl uzavřen.',
'returntotask'            => 'Návrat k detailům požadavku',
'backtoindex'             => 'Zpět na seznam požadavků',
'noclosereason'           => 'Vyberte důvod k uzavření požadavku.',
'hasreopened'             => 'Vámi uzavřený požadavek Flyspray byl znovu otevřen:',
'taskreopenedmsg'         => 'Požadavek byl novu otevřen.',
'backtotask'              => 'Zpět na požadavek.',
'commentaddedmsg'         => 'Komentář byl přidán.',
'commenttoassigned'       => 'byl přidán komentář k požadavku Vám přiřazenému:',
'commenttotask'           => 'přidal komentář pro tento požadavek.',
'nocommententered'        => 'Před odesláním je potřeba zadat Váš komentář.',
'fillinfields'            => 'Je třeba vyplnit veškeré položky.',
'notcurrentpass'          => 'Toto není Vaše aktuální heslo!',
'passchanged'             => 'Vaše heslo bylo změněno.',
'closewindow'             => 'Nyní můžete toto okno zavřít.',
'passnomatch'             => 'Vaše nové heslo je stejné jako původní!',
'usernametaken'           => 'Toto uživatelské jméno je již použito. Vyberte prosím jiné.',
'newusercreated'          => 'Nový uživatel byl vytvořen.',
'accountcreated'          => 'Váš účet byl založen.',
'newuserwarning'          => 'Pozor, je možné že nové účty musí aktivovat administrátor, to může být důvod, proč se nemůžete přihlásit...',
'nomatchpass'             => 'Heslo a kontrola nesouhlasí.',
'confirmwrong'            => 'Potvrzovací kód je neplatný!',
'formnotcomplete'         => 'Formulář není kompletně a správně vyplněn.',
'formnotnumeric'          => 'Vložená data nejsou číselná!',
'groupnametaken'          => 'Skupina s tímto názvem již existuje.',
'newgroupadded'           => 'Nová skupina vytvořena.',
'optionssaved'            => 'Nastavení Flyspray uloženo.',
'hasuploaded'             => 'nahraný soubor pro požadavek byl přiřazen:',
'hasattached'             => 'byl přiřazen k požadavku.',
'fileuploaded'            => 'Soubor byl uložen na serveru.',
'fileerror'               => 'Došlo k chybě během nahrávání souoboru. Možná jsou špatně nastavena práva na adresář pro nahrané soubory.',
'contactadmin'            => 'Kontaktujte administrátora tohoto projektu.',
'selectfileerror'         => 'Zapoměl jste vybrat soubor.',
'userupdated'             => 'Nastavení uživatele bylo aktualizováno',
'realandemail'            => 'Musíte vyplnit celé jméno a e-mailovou adresu.',
'groupupdated'            => 'Skupina byla aktualizována.',
'groupanddesc'            => 'Zapoměl jste vyplnit název skupiny.',
'fillallfields'           => 'Prosím vyplňte všechny kolonky.',
'listPmustN'              => '"Třídění" musí být celé číslo.',
'listupdated'             => 'Seznam byl aktualizován.',
'listitemadded'           => 'Nová položka byla přidána.',
'relatedaddedmsg'         => 'Související úkol byl přidán do seznamu.',
'relatederror'            => 'Tento požadavek je již mezi souvisejícími požadavky.',
'relatedremoved'          => 'Související požadavek byl odtraněn ze seznamu.',
'notifyadded'             => 'Uživatel přidán do seznamu upozornění.',
'notifyerror'             => 'Uživatel již je v aktuálním seznamu pro upozornění pro vybraný požadavek.',
'notifyremoved'           => 'Uživatel byl odstraněn ze seznamu upozornění.',
'editcommentsaved'        => 'Změněný komentář uložen.',
'commentdeletedmsg'       => 'Komentář byl odstraněn.',
'gotonewtask'             => 'Jdi na nový požadavek po vytvoření',
'projectcreated'          => 'Váš nový projekt byl založen. Nyní nastavte jeho parametry v oblasti "Manažer projektu".',
'customiseproject'        => 'Nastavení projektu',
'projectupdated'          => 'Nastavení projektu aktualizováno',
'emptytitle'              => 'Nadpis projektu nesmí být prázdný! Vraťte se zpět a doplňte jej.',
'loginbelow'              => 'Nyní se můžete zkusit přihlásit.',
'attachmentdeletedmsg'    => 'Příloha byla odstraněna.',
'reminderaddedmsg'        => 'Vaše připomenutí bylo přidáno.',
'reminderdeletedmsg'      => 'Vybraná připomínka byla odstraněna.',
'flyspraytask'            => 'Flyspray požadavek',
'fieldsmissing'           => 'Některé položky neobsahují žádná, nebo špatná data.',
'relatedinvalid'          => 'Žádný takový požadavek neexistuje.',
'relatedproject'          => 'Požadavek je přiřazen jinému projektu. I tak přidat?',
'addanyway'               => 'Přesto přidat',
'cancel'                  => 'Zrušit',
'alreadyedited'           => 'Požadavek byl pozměněn jiným uživatelem, chcete přesto zapsat vaše změmy?',
'saveanyway'              => 'Přesto uložit moje změny',
'nouserselected'          => 'Uživatel není vybrán. Vyberte alespoň jednoho a zkuste to znovu.',
'groupswitchupdated'      => 'Skupina uživatelů byla změněna.',
'takenownershipmsg'       => 'Požadavek je nyní přiřazen Vám.',
'adminrequestmade'        => 'Váš požadavek byl odeslán správci projektu.',
'newdepnotify'            => 'K požadavku byla přidána nová závislost:',
'dependadded'             => 'Závislost byla přidána',
'dependaddfailed'         => 'Došlo k chybě při přidávání závislosti. Zkontrolujte, zda požadavek existuje a zda není blokován.',
'depremovedmsg'           => 'Závislost požadavku byla odstraněna',
'newdepis'                => 'Nová závislost je',
'magicurlsent'            => 'Zpráva byla odeslána na Vaši notifikační adresu. Obsahuje kompletní postup řešení Vašeho požadavku.',
'changefspass'            => 'Změna Flyspray hesla',
'magicurlmessage'         => 'Prosím následujte níže uvedený odkaz pro obnovu Vašeho hesla do systému Flyspray:',
'erroronform'             => 'Vyskytl se problém s odesláním Vašeho formuáře',
'addressused'             => 'Tato adresa byla použita pro registraci do systému Flyspray. Pokud jste ti tuto zprávu nevyžádal, můžete ji smazat a ignorovat. Navštivte uvedený odkaz pro dokončení registrace:',
'confirmcodeis'           => 'Váš potvrzovací kód je:',
'codesent'                => 'Váš potvrzovací kód byl odeslán. Prosím následujte instrukce z přijaté správy.',
'codenotsent'             => 'Nelze odeslat Váš ověřovací kód, oapkujte později prosím.',
'taskmadeprivatemsg'      => 'Požadavek je označen jako soukromý',
'taskmadepublicmsg'       => 'Požadavek je nyní označen jako veřejný',
'realandnotify'           => 'Musíte vyplnit pole "Skutečné jméno" a e-mailovou, nebo jabber ID.',
'pmreqdeniedmsg'          => 'Správce projektu žádost zamítl',
'massopsuccess'           => 'Hromadná operace dokončena - pokud to povolují práva',
'usernotexist'            => 'Tento uživatel neexistuje v systému Flyspray',
'commentattachperms'      => 'Nemužete odstranit komentář - nemáte právo na odstraňování příloh',
'voterecorded'            => 'Váše přímluva byla evidována',
'votefailed'              => 'Vaši přímluvu nelze nyní akceptovat.',
'createnewgroup'          => 'Založit novou skupinu',
'requiredfields'          => 'Požadovaná pole jsou označna ',
'addthisgroup'            => 'Přidat skupinu',
'createnewproject'        => 'Vytvořit nový projekt',
'addnewproject'           => 'Přidat nový projekt',
'htmlallowed'             => 'HTML kód je povolen',
'createthisproject'       => 'Založit projekt',
'inlineimages'            => 'Zobrazit vložené obrázky v textu',
'createnewtask'           => 'Vytvořitnový požadavek v projektu:',
'addanother'              => 'Přidat další požadavek po tomto',
'addthistask'             => 'Přdat požadavek',
'notifyme'                => 'Upozornit na změnu požadavku',
'newtask'                 => 'Nový požadavek',
'attachafile'             => 'Připojit soubor',
'registernewuser'         => 'Registrovat uživatele',
'none'                    => 'Žádné',
'registeraccount'         => 'Registrovat uživatele',
'both'                    => 'Obě',
'notifyfrom'              => 'Upozorňovat od ',
'donotreply'              => 'Toto je automaticky generovaná zpráva, prosím NEODPOVÍDEJTE na ni.',
'disclaimer'              => 'Obdržel jste tuto zprávu, protože jste si ji vyžádal v systému hlášení chyb Flyspray. Pokud podobné zprávy nechcete nadále dostávat navštivte uvedenou adresu a změňte si nastavení upozornění v nastavení Vašeho účtu.',
'userwho'                 => 'Změnu provedl',
'moreinfo'                => 'Více informací se dozvíte na uvedené adrese:',
'newtaskopened'           => 'Byl otevřen nový požadavek, detaily následují.',
'notify.taskclosed'       => 'Požadavek byl uzavřen:',
'notify.taskreopened'     => 'Požadavek byl znovu otevřen:',
'newdep'                  => 'Požadavek získal novou závislost:',
'notify.depremoved'       => 'Závislost požadavku byla odstraněna:',
'olddepwas'               => 'Stará závislost byla',
'notify.commentadded'     => 'Požadavku byl přidán komentář:',
'commentis'               => 'Text komentáře následuje.',
'newattachment'           => 'K požadavku byl připojen nový soubor:',
'detailsbelow'            => 'Detaily následují.',
'notify.relatedadded'     => 'K požadavku byl přiřazen nový podřízený požadavek:',
'relatedis'               => 'Podřízený požadavek je',
'assignedtoyou'           => 'Byl jste přiřazen k následujícímu požadavku:',
'takenownership'          => 'Vlastník požadavku byl změněn na:',
'requiresaction'          => 'Požadavek vyžaduje zásah v manažeru projektu:',
'requiresactionnotify'    => 'Požadavek vyžaduje zásah v manažeru projektu.',
'pmdeny'                  => 'Manažer projektu zrušil žádost k požadavku:',
'pmdenynotify'            => 'Manažer projektu zrušil požadavek',
'fileaddedtoo'            => 'Jeden, nebo více souborů bylo přidáno.',
'taskwatching'            => 'Následující úkol sledujete',
'isdepfor'                => 'je nová závislost pro',
'denialreason'            => 'Důvod odmítnutí',
'taskchanged'             => 'Požadavek byl změněn. Změny jsou uvedeny níže. Pro detailní informace o požadavku klikněte na odkaz a poté na záložku historie.',
'useraddedtoassignees'    => 'Uživatel byl přidán do seznamu uživatelů přiřazených k projektu.',
'removeddepis'            => 'Odstraněná závislost je',
'isnodepfor'              => 'není žádná závislost pro',
'usergroups'              => 'Uživatelské skupiny',
'pmtoolbox'               => 'Panel manažera projektu',
'groupmanage'             => 'Správce skupin',
'pendingrequests'         => 'Čekající požadavky',
'reasongiven'             => 'Důvod',
'nopendingreq'            => 'Nejsou čekající požadavky správce projektu.',
'givereason'              => 'Zadejte důvod',
'catlisted'               => 'Editor kategorií',
'oslisted'                => 'Editor operačních systémů',
'verlisted'               => 'Editor seznamu verzí',
'tasktypeed'              => 'Editor seznamu typů požadavku',
'resed'                   => 'Editor seznamu řešení',
'deny'                    => 'Zakázat',
'notifiedwhen'            => 'Upozornit při',
'onlynewtasks'            => 'Otevření požadavku',
'allevents'               => 'Veškeré změny',
'feeds'                   => 'RSS',
'feeddescription'         => 'Popis RSS',
'feedimgurl'              => 'ULR obrázku pro RSS (nechte prázdné pokud nechcete obrázky)',
'notifysubject'           => 'Předmět pro upozornění',
'notifysubjectinfo'       => '(%p = název projektu, %s = souhrn požadavků, %t = id požadavku, %a = akce, %u = uživatel)',
'priority6'               => 'Nápad',
'priority5'               => 'Bezodkladný',
'priority4'               => 'Akutní',
'priority3'               => 'Vysoká',
'priority2'               => 'Normální',
'priority1'               => 'Nízká',
'sendcode'                => 'Odeslat kód!',
'entercode'               => 'Zadejte potvrzovací kód přijatý v informační zprávě. Nezapomeňte také zadat heslo k Vašemu účtu.',
'confirmationcode'        => 'Potvrzovací kód',
'registererror'           => 'Ujistěte se, že jste správně vyplnily všechna požadovaná pole, a že jste zadali platné kontaktní údaje.',
'validusername'           => '(jsou povoleny pouze alfanumerické znaky a - _ .)',
'emailtaken'              => 'Tato e-mailová adresa, nebo jabber ID již existuje. Zvolte prosím jinou.',
'note'                    => '<strong>Poznámka:</strong>  Před založením účtu Vám bude zaslán potvrzovací kód.<br />Pokud jste zadal neplatné údaje <strong> pak kód neobdržíte</strong>.',
'changelog'               => 'Log změn',
'changeloggen'            => 'Generátor logu změn',
'listfrom'                => 'Seznam změn od',
'to'                      => 'do',
'oldestfirst'             => 'Nejstarší nejdříve',
'recentfirst'             => 'Most recent first',
'severityrep'             => 'Report priorit',
'totalopen'               => 'Celkem otevřených požadavků',
'age'                     => 'Stáří',
'agerep'                  => 'Report stáří',
'eventsrep'               => 'Report událostí',
'events'                  => 'Události',
'Tasks'                   => 'Požadavky',
'opened'                  => 'Otevřen',
'edited'                  => 'Změněn',
'assigned'                => 'Přiřazen',
'within'                  => 'Probíhá',
'pastday'                 => 'Dnes',
'pastweek'                => 'Tento týden',
'pastmonth'               => 'Tento měsíc',
'pastyear'                => 'Letos',
'nolimit'                 => 'Bez limitu',
'from'                    => 'Od',
'duein'                   => 'K datu',
'selectfromdate'          => 'Výběr od data',
'selecttodate'            => 'Výběr do data',
'showvoters'              => 'Zobrazit / skrýt podpory',
'roadmap'                 => 'Plány',
'roadmapfor'              => 'Plány pro verzi',
'tasks'                   => 'požadavky',
'completed'               => 'dokončeno.',
'opentasks'               => 'otevřené požadavky',
'of'                      => '% z',
'severity5'               => 'Kritická',
'severity4'               => 'Vysoká',
'severity3'               => 'Střední',
'severity2'               => 'Nízká',
'severity1'               => 'Velmi nízká',
'Redirect'                => 'Přesměrování',
'redirectmsg'             => 'Pokud Váš prohlížeč nepodporuje přesměrování klikněte prosím  %sZDE%s',
'allowclosedcomments'     => 'Povolit komentáře uzavřených požadavků',
'comment'                 => 'Komentář',
'editowncomments'         => 'Upravit vlastní komentář',
'reopened'                => 'Znovu otevřen',
'loading'                 => 'Načítání...',
'notifyown'               => 'Upozornit na vlastní změny',
'youremail'               => 'Vaše e-mailová adresa',
'thankyouforbug'          => 'Děkujeme Vám za nahlášení problému. You can see the task and observe its progress any time using the following URL:',
'anonuser'                => 'Anonymní uživatel',
'conflict'                => 'Konflikt',
'file'                    => 'Soubor',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Velikost',
'projectgroup'            => 'Skupina projektů',
'profile'                 => 'Profil:',
'viewprofile'             => 'Zobrazit profil',
'regdate'                 => 'Registered since',
'tasksopened'             => 'Otevřené požadavky',
'replyto'                 => 'Odpovědět kam',
'notifytypes'             => 'Typ upozornění',
'pm.taskchanged'          => 'Požadavek změněn',
'pm.taskreopened'         => 'Požadavek znovu otevřen',
'pm.depadded'             => 'Přidána závislost',
'pm.depremoved'           => 'Odebrána závislost',
'pmrequest'               => 'PM požadavek',
'pmrequestdenied'         => 'PM požadavek zamítnut',
'newassignee'             => 'Nové přiřazení',
'revdepadded'             => 'Přidání reverzní závisloti',
'revdepaddedremoved'      => 'Odstranění reverzní závislosti',
'assigneeadded'           => 'Nové přiřazení',
'addusergroup'            => 'Přidat uživatele do této skupiny',
'groupmembers'            => 'Uživatelé ve skupině',
'deleteuser'              => 'Vymazat uživatele',
'userdeleted'             => 'Uživatel odstraněn',
'autoassign'              => 'Automaticky přiřadit požadavky vlastníkovi kategorie',
'ssl'                     => 'SSL',
'updatewrong'             => 'Máte povolenu kontrolu aktualizací, ale došl k chybě během pokusu
                             kontaktovat aktualizační server, buď Váš hostitel neumožňuje odchozí spojení,
                             nebo došlo k jiné chybě způsobené sítí.
                             Prosím navštivte stránky flyspray pro kontrolu, zda používáte aktuální verzi.',
'deleteproject'           => 'Vymazat projekt a přesunout obsah do',
'projectdeleted'          => 'Projekt byl vymazán',
'feedforall'              => 'RSS pro všechny projekty',
'usercreated'             => 'Uživatel vytvořen',
'userdeleted'             => 'Uživatel smazán',
'created'                 => 'Vytvořen',
'deleted'                 => 'Smazán',
'userid'                  => 'ID uživatele',
'editassignments'         => 'Upravit přiřazení',
'preview'                 => 'Náhled',
'anyprogress'             => 'Libovolný průběh',
'tasksrelated'            => 'Požadavky související s tímto požadavkem',
'duplicatetasks'          => 'Duplicitní požadavky tohoto požadavku',
'databasemodfailed'       => 'Změna databáze selhala. Možná nemáte dostatečné oprávnění.',
'frequency'               => 'Frekvence',
'newuserregistered'       => 'Ve Flyspray byl registrován nový uživatel. Informace následují:',
'newuserregisterednotify' => 'Nový uživatel byl registrován',
'notify_registration'     => 'Upozornit administrátory na nové registrace',
'textversion'             => 'Textová verze',
'onlyprimary'             => 'Požadavky neblokující jiné požadavky',
'switch'                  => 'Přepnout',
'max'                     => 'max.',
'dates'                   => 'Data',
'selectduedatefrom'       => 'Platný od',
'selectduedateto'         => 'do',
'selectsincedatefrom'     => 'Změněn od',
'selectsincedateto'       => 'do',
'selectdate'              => 'Výběr data',
'selectopenedfrom'        => 'Otevřen od',
'selectopenedto'          => 'do',
'selectclosedfrom'        => 'Uzavřen od',
'selectclosedto'          => 'do',
'startat'                 => 'Zahájen od',
'hasattachment'           => 'Má přílohu',
'private'                 => 'Soukromý',
'watching'                => 'Sledovaný',
'alreadyvotedthistask'    => 'tento požadavek jste již podpořil',
'alreadyvotedthisday'     => 'dnes již podpořeno',
'visibility'              => 'Viditelnost',
'public'                  => 'Veřejný',
'leaveemptyauto'          => 'Nezadávejte heslo, pokud jej chcete automaticky vygenerovat.',
'novalidemail'            => 'Nezadal jste platnou e-mailovou adresu.',
'novalidjabber'           => 'Nezadal jste platnou jabber adresu.',
'missingrequired'         => 'Nevyplnil jste všechna požadovaná pole.',
'entervalidusername'      => 'Prosím zadejte platnou přezdívku a celé jméno.',
'couldnotaddusernotif'    => 'Nelze přidat uživatele do seznamu upozornění.',
'defaulttask'             => 'Výchozí popis požadavku',
'all'                     => 'vše',
'events.useraddedtoassignees' => 'Uživatel přidán do nabyvatelů',
'vote(s)'                 => 'hlasování',
'eventlog'                => 'Log událostí',
'assignmentchanged'       => 'Přiřazení změněno',
'detailedinfo'            => 'Detailní informace',
'All'                     => 'Všechny',
'tasksireported'          => 'Mnou hlášené',
'recentlyopened'          => 'Nově otevřené',
'stats'                   => 'Status',
'totaltasks'              => 'požadavků celkem',
'mostwanted'              => 'Nejčastěji hledané',
'defaultentry'            => 'Výchozí vstupní strana',
'toplevel'                => 'Zobrazit nejvyžší úroveň',
'overview'                => 'Přehled',
'error#'                  => 'Chyba #',
'error1'                  => 'Nemáte právo k zobrazení této přílohy.',
'error3'                  => 'Opakování akce, přesměrovávám na hlavní stránku.',
'error4'                  => 'Nemáte administrátorská práva.',
'error5'                  => 'Tento uživatel neexistuje ve Flyspray instalaci.',
'error6'                  => 'Nesprávná administrátorská oblast.',
'error7'                  => 'Přihlášení selhalo, nesprávné heslo!',
'error71'                 => 'Účet je uzamčen na %d minut z důvodu několika neplatných pokusů o přihlášení!',
'error8'                  => 'Nezadal jste přihlašovací jméno i heslo.',
'error9'                  => 'Požadavek neexistuje, nebo nemáte právo k jeho zobrazení.',
'error10'                 => 'Požadavek neexistuje.',
'error101'                => 'Nemáte právo k zobrazení tohoto požadavku.',
'error102'                => 'Nemáte právo k zobrazení tohoto požadavku, mohlo by pomoci přihlášení.',
'error11'                 => 'Nemáte právo upravovat tento komentář.',
'error12'                 => 'Nesprávný klíč! Jste si jist, že jste takový obdržel ve zprávě?',
'error13'                 => 'Anonymní uživatelé nemají profil.',
'error14'                 => 'Nemáte právo k vytváření skupin.',
'error15'                 => 'Nemáte právo k otevírání požadavků.',
'error16'                 => 'Nejste manažer projektu.',
'error17'                 => 'Chybná PM oblast.',
'error18'                 => 'Špatný kouzelný odkaz.',
'error19'                 => 'Takový uživatel neexistuje v této instalaci Flyspray.',
'error20'                 => 'Nesprávná modifikace databáze.',
'error21'                 => 'Jeden, nebo více e-amilů nebyl odeslán. Zkontrolujte konfiguraci.',
'error22'                 => 'Není povolena registrace uživatelů.',
'error23'                 => 'Užiatel, nebo skupina má zakázáno přihlašování.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Roadmapa je dostupná pouze pro určité projekty.',
'done'                    => 'hotovo',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projekt nemohl být odstraněn.',
'GMT'                     => 'GMT',
'timezone'                => 'Časové pásmo',
'accept'                  => 'Akceptovat',
'reasonfordeinal'         => 'Důvod odmítnutí',
'pruneclosedlinks'        => 'Pročistit uzavřené odkazy',
'pruneclosedtasks'        => 'Pročistit uzavřené požadavky',
'pagegenerated'           => 'Strana a obrázek vygenerován za %d sekund.',
'pruninglevel'            => 'Úrověň pročištění',
'lastuser'                => 'Poslední uživatel nemůže být odstraněn.',
'allprivate'              => 'Všechny projekty jsou soukromé.',
'deletegroup'             => 'Vymazat skupinu a přesunout uživatele do',
'parent'                  => 'Nadřazená',
'ordertip'                => 'Tyto položky se zobrazí v seznamu',
'showtip'                 => 'Zobrazit položku v seznamu',
'deletetip'               => 'Smazat tento záznam ze seznamu',
'del'                     => 'vym',
'request1'                => 'Odeslán požadavek na uzavření požadavku.',
'request2'                => 'Odeslán požadavek na znovu otevření požadavku.',
'allpriorities'           => 'Všechny priority',
'noroadmap'               => 'Roadmapa není dostupná (projekt nemá specifikovanou budoucí verzi).',
'expand'                  => 'Rozevřít',
'collapse'                => 'Složit',
'expandall'               => 'Rozevřít vše',
'collapseall'             => 'Složit vše',
'minpwsize'               => 'Heslo musí mít minimálně 5 znaků',
'passwordtoosmall'        => 'Heslo je příliš krátké.',
'accountwaslocked'        => 'Váš účet byl zablokován z důvodu mnoha neplatných pokusů o přihlášení.',
'failedattempts'          => '%d pokusů o neplatné přihlášení.',
'groupnotexist'           => 'Tato skupina v projektu neexistuje.',
'searchindetails'         => 'Prohledávat detaily',
'showasassignees'         => 'Zobrazit jako přiřazené',
'find'                    => 'Hledat',
'tls'                     => 'TLS',
'isadmin'                 => 'Je admin',
'addvotes'                => 'Přidat hlasovní',
'removevote'              => 'Odstranit hlasování',
'voteremoved'             => 'Vaše hlasování je odstraněno',
'voteremovefailed'        => 'V tuto chvíli nelze vaše hlasování odstranit.',
'connectedtasks'          => 'Připojené požadavky:',
'taskdependencies'        => 'Závislosti požadavku',
'viewgraph'               => 'zobrazit graf',
'notaskdependencies'      => 'Tento úkol nezávisí na žádném dalším požadavku.',
'dependson'               => 'Závislosti aktivní',
'blocks'                  => 'Bloky',
'newdependency'           => 'Nová závislost:'
);

?>
