<?php

/*******************************************************************************
 * File:              sk.php
 * Authors:           Mancuska Martin (borgcube) http://blog.borg.sk/
 *                    Pokorny Fridolin (fridex) http://fridex.yw.sk
 *                    Jan Callus(callus) jan.callus@gmail.com
 * Description:
 * Slovak translation of web-based bug tracking system FlySpray.
 * http://flyspray.org/
 *
 * Last modified:     10/13/14
 ******************************************************************************/


$translation = array(
'edituser'                => 'Edituj užívateľa',
'accountenabled'          => 'Konto povolené',
'editallusers'            => 'Zobraz všekých používateľov',
'username'                => 'Užívateľské meno',
'usersupdated'            => 'Užívatelia úspešne aktualizovaný',
'realname'                => 'Skutočné meno',
'emailaddress'            => 'Emailová adresa',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Typ notifikácie',
'group'                   => 'Skupina',
'enableaccounts'          => 'Povoliť účty',
'disableaccounts'         => 'Zakázať účty',
'deleteaccounts'          => 'Zmazať účty',
'updatedetails'           => 'Aktualizovať detaily',
'setglobally'             => 'Toto nastavenie bolo nastavené globálne',
'usergroupmanage'         => 'Správa užívateľov a skupín',
'newuser'                 => 'Registrácia nového užívateľa',
'newuserbulk'             => 'Hromadná registrácia nových užívateľov',
'bulkuserstoadd'          => 'Zoznam nových užívateľov',
'optionsforallusers'      => 'Možnosti pre všetkých nových používateľov',
'newgroup'                => 'Vytvoriť novú skupinu',
'yes'                     => 'Áno',
'no'                      => 'Nie',
'editgroup'               => 'Editovať skupinu',
'groupname'               => 'Názov skupiny',
'description'             => 'Popis',
'admin'                   => 'Admin skupina',
'opennewtasks'            => 'Otvoriť nové dotazy',
'modifytasks'             => 'Upraviť existujúce dotazy',
'addcomments'             => 'Pridať komentáre',
'attachfiles'             => 'Priložiť súbory',
'vote'                    => 'Hlasuj',
'groupenabled'            => 'Členovia sa môžu prihlásiť',
'groupopen'               => 'Členovia sa môžu prihlásiť',
'tasktypelist'            => 'Zoznam typov dotazov',
'categorylist'            => 'Zoznam kategórií',
'oslist'                  => 'Zoznam operačných systémov',
'resolutionlist'          => 'Resolutions list',
'versionlist'             => 'Zoznam verzií',
'severitylist'            => 'Severities list',
'listnote'                => 'Poznámka: Odškrtnutím "zobraziť" sa môžu zmeniť úlohy v režime úprav. Zmenou poľa "Meno/názov" sa zmenia všetky úlohy s daným menom. Veci, ktoré nie je možné odstrániť, sú buď chránené, pretože sú nevyhnutné pre správne fungovanie, alebo sa používajú v úlohách.',
'name'                    => 'Meno/názov',
'order'                   => 'Usporiadať',
'back'                    => 'Späť',
'text'                    => 'Text',
'highlight'               => 'Zvýrazniť',
'show'                    => 'Zobraziť',
'owner'                   => 'Vlastník',
'selectowner'             => 'Zvoľ vlastníka',
'update'                  => 'Aktualizuj',
'addnew'                  => 'Pridať nové',
'flysprayprefs'           => 'Flyspray nastavenia',
'projecttitle'            => 'Titul projektu',
'baseurl'                 => 'Základná URL pre inštaláciu systému:',
'replyaddress'            => 'Odpoveď pre e-mail notifikáciu',
'themestyle'              => 'Téma / Štýl',
'language'                => 'Jazyk',
'anonview'                => 'Povoliť neprihláseným užívateľom prezerať úlohy',
'allowanon'               => 'Povoliť neprihláseným užívateľom otvoriť úlohy',
'never'                   => 'Nikdy',
'anonymously'             => 'Anonymne',
'afterregister'           => 'Len po prihlásení',
'spamproof'               => 'Zapnúť potvrdzujúci kód pri registrácii nových užívateľov',
'anongroup'               => 'Skupina pre nové registrácie užívateľov',
'groupassigned'           => 'Členom tejto skupiny môžu byť priradené úlohy',
'forcenotify'             => 'Force task notifications as',
'neversend'               => 'Nikdy nepodlať',
'userchoose'              => 'Dovoľ každému používateľovi vybrať',
'email'                   => 'Email',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Prednastavený vlastník kategórie',
'noone'                   => 'Nikto',
'jabbernotify'            => 'Jabber Notifikácie',
'jabberserver'            => 'Server',
'jabberport'              => 'Port',
'jabberuser'              => 'Užívateľské konto',
'jabberpass'              => 'Užívateľské heslo',
'saveoptions'             => 'Uložiť voľby',
'editcomment'             => 'Editovať komentár',
'commentby'               => 'Komentoval',
'saveeditedcomment'       => 'Uložiť editovaný komentár',
'projectprefs'            => 'Nastavenia projektu',
'pagetitle'               => 'Titulok stránky',
'defaultproject'          => 'Predvolený projekt',
'projectlists'            => 'Zoznam projektov',
'showlogo'                => 'Zobraziť logo v titulku',
'showgravatars'           => 'Zobraziť Gravatarov',
'emailNoHTML'             => 'Žiadne HTML v E-mailoch',
'intromessage'            => 'Ǔvodná správa',
'isactive'                => 'Projekt je aktívny',
'createproject'           => 'Vytvoriť nový projekt',
'nopermission'            => 'Nemáte oprávnenia na prezeranie tejto stránky',
'listordertip'            => 'The order these items will appear in the list ',
'listshowtip'             => 'Zobraz túto položku v zozname',
'categoryownertip'        => 'Táto soba bude upozornená pri otvorení novej úlohy v tejto kategórii',
'categoryparenttip'       => ' Rodičovská kategória pod ktorú bude patriť táto nová',
'notsubcategory'          => 'Žiadna (základná kategória)',
'showinlineimages'        => 'Zobraziť vložené obrázky príloh',
'dateformat'              => 'Formát dátumu',
'dateformat_extended'     => 'Detailný formát dátumu',
'cache_feeds'             => 'Cache feeds',
'no_cache'                => 'No caching',
'cache_disk'              => 'Cache on disk',
'cache_db'                => 'Cache in DB',
'subcategoryof'           => 'Sub-category of',
'visiblecolumns'          => 'Stĺpce zobrazené v zozname dotazov',
'visiblefields'           => 'Zobraz políčka pri pridaj / oprav / zobraz úlohu',
'tense'                   => 'Čas',
'listtensetip'            => 'Minulosť, prítomnosť alebo budúcnosť',
'past'                    => 'Minulosť',
'present'                 => 'Súčastnosť',
'future'                  => 'Budúcnosť',
'oldpass'                 => 'Staré heslo',
'nooldpass'               => 'Nebolo zadané staré heslo',
'oldpasswrong'            => 'Staré heslo je nesprávne',
'changepass'              => 'Zmeniť heslo',
'confirmpass'             => 'Potvrdiť heslo',
'projectmanager'          => 'Project Manager',
'viewtasks'               => 'Zobraz dotazy',
'modifyowntasks'          => 'Upraviť vlastné dotazy',
'modifyalltasks'          => 'Upraviť úlohy, ktoré nie sú užívateľa',
'viewcomments'            => 'Zobraziť komentáre',
'editcomments'            => 'Editovať komentáre',
'deletecomments'          => 'Zmazať komentáre',
'viewattachments'         => 'Zobraziť prílohy',
'createattachments'       => 'Vytvoriť prílohy',
'deleteattachments'       => 'Zmazať prílohy',
'viewhistory'             => 'Zobraziť históriu',
'closeowntasks'           => 'Uzavrieť vlastné dotazy',
'closeothertasks'         => 'Zatvoriť úlohy, ktoré sú užívateľa',
'assigntoself'            => 'Priradiť úlohy sebe (ak nie sú priradené)',
'assignotherstoself'      => 'Priradiť ostatné úlohy sebe',
'viewreports'             => 'Zobraziť log udalostí',
'othersview'              => 'Povoliť všetkým vidieť tento projekt',
'usersandgroups'          => 'Užívatelia a skupiny',
'globalgroup'             => 'Globálna skupina',
'globalgroups'            => 'Globálne skupiny',
'defaultglobalgroup'      => 'Predvolená globálna skupina pre nových užívateľov',
'addtogroup'              => 'Pridať do skupiny',
'moveuserstogroup'        => 'Premiestniť užívateľov do skupiny',
'nogroup'                 => 'Žiadna skupina - odstrániť z projektu',
'eventdesc'               => 'Popis udalosti',
'requestedby'             => 'Vyžiadané od',
'daterequested'           => 'Dátum je požadovaný',
'closetask'               => 'Uzavrieť dotaz',
'reopentask'              => 'Znovuotvoriť dotaz',
'applymember'             => 'Požiadať o členstvo v projekte',
'forcurrentproj'          => 'Pre aktuálny projekt',
'lostpw'                  => 'Lost password retrieval',
'lostpwexplain'           => 'Zadajte Vaľe prihlasovacie meno pre poslanie adresy pre zmeny hesla. Adresa bude poslaná do Vašeho profilu',
'sendlink'                => 'Poslať link',
'savenewpass'             => 'Uložiť nové heslo',
'anonreg'                 => 'Povoliť registráciu nových používateľov',
'allowanonopentask'       => 'Dovoliť neprihláseným používateľom otvoriť úlohy',
'editglobalgroup'         => 'Editovať globálnu skupinu',
'editgroupforproj'        => 'Upraviť skupinu pre projekty',
'notshownforadmin'        => 'Práva nie sú zobrazené pre skupinu administrátorov. Nemusíte ich upravovať',
'general'                 => 'Hlavné',
'userregistration'        => 'Registrácia',
'notifications'           => 'Notifikácie',
'resetoptions'            => 'Resetovať voľby',
'preferences'             => 'Nastavenia',
'tasktypes'               => 'Typy dotazov',
'resolutions'             => 'Rozlíšenie',
'categories'              => 'Kategórie',
'operatingsystems'        => 'Operačné systémy',
'versions'                => 'Verzie',
'admintoolboxlong'        => 'Administrátorsky Toolbox',
'newproject'              => 'Nový projekt',
'delete'                  => 'Zmazať',
'link'                    => 'Linka',
'referencelinks'          => 'Referenčné odkazy:',
'listdeletetip'           => 'Zmazať túto položku zo zoznamu',
'lookandfeel'             => 'Vzhľad',
'globaltheme'             => 'Globálna téma',
'emailnotify'             => 'Emailové notifikácie',
'fromaddress'             => 'Z adresy',
'smtpserver'              => 'SMTP Server',
'smtpuser'                => 'SMTP užívateľ',
'smtppass'                => 'SMTP heslo',
'addrewrite'              => 'Použi prepis adresy',
'usereminderdaemon'       => 'Povoliť pripomínajúceho daemona bežiaceho na pozadí',
'tasksperpage'            => 'Úloh na stranu v zozname úloh',
'addtoassignees'          => 'Add self to assignees',
'taskstatuses'            => 'Statusy úloh',
'canvote'                 => 'Môže hlasovať za úlohy',
'loginsuccessful'         => 'Prihlásenie bolo úspešné.',
'youareloggedout'         => 'Boli ste úspešne odhlásený.',
'waitwhiletransfer'       => 'Prosím čakajte na presmerovanie...',
'clicknowait'             => 'Kliknite sem, ak nechcete čakať.',
'accountdisabled'         => 'Vaš účet bol pozastavený. Kontaktujte prosím hlavného administrátora pre informácie.',
'task'                    => 'Úlohy',
'edittask'                => 'Upraviť túto ulohu',
'openedby'                => 'Založené',
'editedby'                => 'Naposledy upravené',
'tasktype'                => 'Typ úlohy',
'category'                => 'Kategória',
'status'                  => 'Status',
'assignedto'              => 'Pridelené',
'operatingsystem'         => 'Operačný systém',
'severity'                => 'Záležitosť',
'reportedversion'         => 'Hlásená verzia',
'dueinversion'            => 'Kvôli verzii',
'defaultdueinversion'     => 'Predvolený dôvod vo verzii pre nové úlohy',
'undecided'               => 'Nerozhodnuté',
'percentcomplete'         => 'Percent Complete',
'details'                 => 'Podrobnosti',
'savedetails'             => 'Uložiť podrobnosti',
'canceledit'              => 'Zružiť úpravu',
'anonymous'               => 'Anonymný prispievateľ',
'complete'                => 'Ukončené',
'closedby'                => 'Uzamknuté',
'reasonforclosing'        => 'Dôvod zamknutia:',
'reopenthistask'          => 'Znovu otvoriť túto úlohu',
'comments'                => 'Komentáre',
'attachments'             => 'Prílohy',
'relatedtasks'            => 'Podobné úlohy',
'edit'                    => 'Upraviť',
'addcomment'              => 'Pridať komentár',
'fileuploadedby'          => 'Súbor pridaný užívateľom',
'uploadafile'             => 'Pridať prílohu',
'addalink'                => 'Pridaj linku',
'addanotherlink'          => 'Pridaj ďalšiu linku',
'uploadnow'               => 'Poslať',
'thesearerelated'         => 'Tieto úlohy sú podobné',
'remove'                  => 'Vymazať',
'addnewrelated'           => 'Pridať podobnú úlohu',
'add'                     => 'Pridať!',
'otherrelated'            => 'Úlohy, ktoré sô podobné tejto: ',
'receivenotify'           => 'Týto užívatelia budú upozornení pri zmene úlohy.',
'addusertolist'           => 'Pridaj používateľa do zoznamu',
'addtolist'               => 'Pridaj do zoznamu',
'addmyself'               => 'Pridaj sa do tohto zoznamu',
'removemyself'            => 'Odstrániť sa z tohto zoznamu',
'theseusersnotify'        => 'Týto užívatelia budú upozornení pri akejkoľvek zmene tejto úlohy.',
'attachedtoproject'       => 'Pridané k projektu',
'reminders'               => 'Pripomienky',
'system'                  => 'System',
'remindthisuser'          => 'Pripomenúť tohto používateľa',
'thisoften'               => 'This often',
'startafter'              => 'Wait before starting reminders',
'hours'                   => 'Hodín',
'days'                    => 'Dní',
'weeks'                   => 'Týždňov',
'addreminder'             => 'Pridať upomienku',
'defaultreminder'         => 'Pripomienka: Pozrite sa na nasledujúcu úlohu:',
'message'                 => 'Správa',
'closed'                  => 'Zamknuté',
'filename'                => 'Názov súboru:',
'date'                    => 'Dátum',
'filesize'                => 'Veľkosť súboru:',
'closurecomment'          => 'Pripomienky k zamknutiu:',
'history'                 => 'História',
'nohistory'               => 'Žiadna história nie je k dispozícii.',
'eventdate'               => 'Dátum',
'user'                    => 'Používateľ',
'event'                   => 'Udalosť',
'fieldchanged'            => 'Pole zmenené',
'taskopened'              => 'Úloha otvorená',
'taskreopened'            => 'Úloha bola znovu otvorená',
'taskclosed'              => 'Úloha uzavretá',
'commentadded'            => 'Pridaný komentár',
'commentedited'           => 'Upravený komentár',
'commentdeleted'          => 'Komentár bol zmazaný',
'attachmentadded'         => 'Príloha pridaná',
'attachmentdeleted'       => 'Priloha zmazaná',
'taskedited'              => 'Zmenené podrobnosti úlohy',
'notificationadded'       => 'Používateľ bol pridaný do zoznamu notifikácií',
'notificationdeleted'     => 'Používateľ bol zmazaný zo zoznamu notifikácií',
'relatedadded'            => 'Podobné úlohy pridané',
'relateddeleted'          => 'Podobné úlohy zmazané',
'taskassigned'            => 'Úlohy pridelené ku',
'taskreassigned'          => 'Ǔlohy znovu pridelené ku',
'assignmentremoved'       => 'Odstránené priradenia',
'summary'                 => 'Súhrn',
'addedasrelated'          => 'Úlohy pridané do zoznamu podobných ku',
'deletedasrelated'        => 'Úlohy zmazané zo zoznamu podobných ku',
'reminderadded'           => 'Poznámka pridaná',
'reminderdeleted'         => 'Poznámka odstránená',
'priority'                => 'Priorita',
'previousvalue'           => 'Predchádzajúca hodnota',
'newvalue'                => 'Nová hodnota',
'selectareason'           => 'Vyberte dôvod',
'assigntome'              => 'Prideľ ku mne',
'reopenrequest'           => 'Znovuotvoriť požiadavku',
'requestclose'            => 'Zatvoriť požiadavku',
'ownershiptaken'          => 'Používateľ prevzal vlastníctvo',
'closerequestmade'        => 'Requested task closure',
'reopenrequestmade'       => 'Požadované na znovuotvorenie',
'taskdependson'           => 'Táto úloha závisí na',
'taskblocks'              => 'Táto úloha blokuje pre uzatvorenie',
'depadded'                => 'Pridaná závislosť',
'depaddedother'           => 'Táto úloha pridaná ako závislosť',
'depremoved'              => 'Závislosť zmazaná',
'depremovedother'         => 'Táto úloha bola odstránená zo zosnamu závislostí',
'showdetailserror'        => 'Táto úloha neexistuje, alebo nemáte právo na prezeranie.',
'makeprivate'             => 'Súkromné',
'makepublic'              => 'Verejné',
'taskmadeprivate'         => 'Úloha je súkromná',
'taskmadepublic'          => 'Úloha je už verejná',
'confirmdeletecomment'    => 'Skutočne si želáte vymazať? %s',
'confirmdeleteattach'     => 'Skutočne si prajete odtrániť túto prílohu?',
'selectedhistory'         => 'Zobrazije podrobnosti vybranej histórie ',
'showallhistory'          => 'Znovu zobraziť celú históriu',
'hidethis'                => 'Znovu skry túto oblasť',
'mark100'                 => 'Označ úlohu 100% splnenú',
'watchtask'               => 'sleduj úlohu',
'stopwatching'            => 'ukončiť sledovanie',
'commentlink'             => 'Odkazovať na tento komentár',
'submitreq'               => 'Poslať požiadavku',
'reasonforreq'            => 'Dôvod požiadavky',
'pmreqdenied'             => 'Vedúci projektu zamietol požiadavku',
'taskpendingreq'          => 'Čaká sa na odpoveď vedúceho projektu. Viac informácií je možné nájsť v histórii',
'previoustask'            => 'Predchádzajúca úloha',
'nexttask'                => 'Nasledujúca úloha',
'duedate'                 => 'Kvôli dátumu',
'attachnoperms'           => 'Tento komentár obsahuje prílohy, ale nemáte právo na ich prezeranie',
'linknoperms'             => 'Existujú odkazy s týmto komentárom, ale nemáte oprávnenie na ich zobrazenie.',
'open'                    => 'Otvoriť',
'depgraph'                => 'Zobraz graf závislosti',
'reset'                   => 'Reset',
'selectusers'             => 'Vyber používateľov...',
'addmetoassignees'        => 'Pridaj ma k nástupcovi',
'addedtoassignees'        => 'Používatelia pridaní do zoznamu nástupcov',
'dependencygraph'         => 'Graf závislosti',
'attachanotherfile'       => 'Pripojiť ďalší súbor',
'OK'                      => 'OK',
'addvote'                 => 'Hlasovať',
'disable_lostpw'          => 'Zakázať stratené vyhľadanie hesla',
'disable_changepw'        => 'Zakázať vytvoriť / editovať heslo',
'notifyfromfs'            => 'Upozornenie od Flyspray',
'autogenerated'           => 'TÁTO SPRÁVA BOLA AUTOMATICKY VYGENEROVANÁ. PROSÍM NEODPOVEDAJTE NA ŇU',
'forward'                 => 'Nasledujúci',
'previous'                => 'Predchádzajúci',
'next'                    => 'Ďalší',
'first'                   => 'Prvý',
'last'                    => 'Posledný',
'page'                    => 'Strana %d z %d',
'search'                  => 'Hľadaj',
'alltasktypes'            => 'Typ všetkých úloh',
'allseverities'           => 'All Severities',
'alldevelopers'           => 'Všetci vývojári',
'notyetassigned'          => 'Ešte nepriradené',
'allcategories'           => 'Všetky kategórie',
'allstatuses'             => 'Všetky statusy',
'allopentasks'            => 'Všetky otvorené úlohy',
'sortthiscolumn'          => 'Usporiadať podľa tohto stĺpca',
'id'                      => 'ID',
'project'                 => 'Projekt',
'dateopened'              => 'Otvorené',
'progress'                => 'Stav',
'searchthisproject'       => 'Vyhľadať v tomto projekte',
'dueanyversion'           => 'Rôznu verziu',
'anyversion'              => 'Reported In Any Version',
'dueversion'              => 'Due In Version',
'lastedit'                => 'Naposledy upravené',
'os'                      => 'Operačný systém',
'reportedin'              => 'Zoradené v',
'taskrange'               => 'Zobrazemé úlohy %d - %d z %d',
'noresults'               => 'Neboli nájdené žiadne výsledky.',
'takeaction'              => 'Take action.',
'watchtasks'              => 'Sledovať vybrané úlohy.',
'stopwatchingtasks'       => 'Prestať sledovať úlohy',
'assigntaskstome'         => 'Priraď mi úlohu',
'dueby'                   => 'Due by',
'dueanytime'              => 'Due anytime',
'selectduedate'           => 'Select Due Date',
'toggleselected'          => 'Toggle Selected',
'due'                     => 'Due',
'assignedtome'            => 'Priraď ku mne',
'tasklist'                => 'Zoznam úloh',
'dateclosed'              => 'Dátum uzavretý',
'advanced'                => 'Pokročilé',
'searchcomments'          => 'Hľadaj v komentároch',
'searchforall'            => 'Hľadaj vo všekých slovách',
'anonusers'               => 'Anonymní používatelia',
'miscellaneous'           => 'Rôzne',
'users'                   => 'Používatelia',
'taskproperties'          => 'Podrobnosti úlohy',
'selectsincedate'         => 'Vyber zmenené od',
'changedsince'            => 'Zmenené od',
'updatefs'                => 'Vykonajte update FlySpray, prosím.',
'currentversion'          => 'Aktuálna verzia je',
'latestversion'           => 'a najnovšia verzia je',
'hidemessage'             => '(upozorni ma neskôr)',
'saveas'                  => 'Ulož výsledok hľadania ako',
'nosearches'              => 'Žiadne uložené výsledky hľadania',
'saving'                  => 'Ukladám...',
'votes'                   => 'Hlasy',
'allclosedtasks'          => 'Všetky uzatvorené úlohy',
'password'                => 'Heslo',
'login'                   => 'Prihlásiť!',
'rememberme'              => 'Upozorni ma',
'lostpassword'            => 'Zabudnuté heslo?',
'lostpwforfs'             => 'Zabudnuté heslo pre Flyspray',
'lostpwmsg1'              => "Ahoj.\n\nI have lost my password for Flyspray on ",
'lostpwmsg2'              => ", prosím poskytni mi nové heslo.\n\nPoužívateľské heslo: ",
'regards'                 => "\n\nS pozdravom,",
'yourusername'            => ' Vaše prihlasovacie meno ',
'locale'                  => 'sk-SK',
'filenotexist'            => 'Súbor neexistuje alebo nemáte oprávnenia na jeho prezeranie',
'showtask'                => 'Zobraz úlohy',
'now'                     => 'Teraz',
'go'                      => 'Ísť',
'opentaskanon'            => 'Anonymne vytvoriť novú úlohu',
'register'                => 'Registrovať',
'addnewtask'              => 'Pridať novú úlohu',
'reports'                 => 'Log udalosti',
'editmydetails'           => 'Upraviť moje nastavenia',
'logout'                  => 'Odhlásiť',
'disabledaccount'         => 'Vaš účet bol pozastavený!<br />Odhlasovanie...',
'poweredby'               => 'Powered by Flyspray',
'sponsoredby'             => 'Flyspray je hrdo sponzorovaný',
'projects'                => 'Projekty',
'allprojects'             => 'Všetky projekty',
'selectproject'           => 'pre projekt:',
'tasksall'                => 'Všetky úlohy',
'tasksassigned'           => 'Úlohy mne pipísané',
'tasksreported'           => 'Úlohy mi oznámené',
'taskswatched'            => 'Sledované úlohy',
'mysearch'                => 'Moje výsledky hľadania',
'admintoolbox'            => 'Admin Toolbox',
'manageproject'           => 'Spravovať projekt',
'permissions'             => 'Zobraz oprávnenia',
'hide'                    => 'Skry',
'pendingreq'              => 'PM požiadavka čaká',
'errorpage'               => "Flyspray nemôže poskytnúť požadovanô stránku.\n                                 Pravdepodobne neexistuje, alebo nemáte oprávnenia pre jej zobrazenie.<br /><br />\n                                 Prípadne sa nepokúšajte o SQL Injection",
'permissionsforproject'   => 'Práva pre ',
'switchto'                => 'Prepnúť do',
'lastsearch'              => 'Posledné hľadanie',
'modify'                  => 'Upraviť',
'noticefrom'              => 'Oznámenie od',
'hasopened'               => 'hotvoril novú úlohu a priradil ju ku Vám:',
'moreinfonew'             => 'Viac informácií o tejto chybe je možné nájsť na Flyspray adrese:',
'newtaskcategory'         => 'Nová Flyspray úloha bola vytvorená v kategórii',
'categoryowner'           => 'Táto správa Vám bola poslaná, pretože ste majiteľ tejto katogórie.',
'tasksummary'             => 'Súhrn úlohy:',
'newtaskadded'            => 'Vaša nová úloha bola pridaná.',
'summaryanddetails'       => 'Musíte vyplniť aj súhrn aj podrobnosti.',
'goback'                  => 'Ísť späť.',
'messagefrom'             => 'Táto správa je od ',
'hasjustmodified'         => 'práve upravil nasledujúcu úlohu.',
'changedfields'           => 'Zmenené polia sú vyznačene hviezdičkami (**)',
'moreinfomodify'          => 'Viac informácií o tejto úlohe je možné nájsť na:',
'nolongerassigned'        => 'Táto úloha už nie je pripísaná Vám. Je pripísaná ',
'hasassigned'             => 'pripísal úlohu:',
'taskupdated'             => 'Úloha bola aktualizovaná.',
'tasksupdated'            => 'Úlohy boli aktualizované.',
'hasclosedassigned'       => 'uzavrel úlohu, ku ktorej si bol pripísaný :',
'unassigned'              => 'Odznačené',
'hasclosed'               => 'uzavrel túto úlohu.',
'youonnotify'             => 'Táto správa Vám bola zaslaná, pretože ste v zozname oznámení.',
'taskclosedmsg'           => 'Úloha bola uzavretá.',
'returntotask'            => 'Späť na podrobnosti úlohy.',
'backtoindex'             => 'Ísť späť na zoznam',
'noclosereason'           => 'Nevybrali ste dôvod uzatvorenia tejto úlohy.',
'hasreopened'             => 'otvoril úlohu, ktorú ste zatvorili:',
'taskreopenedmsg'         => 'Úloha bola znovu otvorená.',
'backtotask'              => 'Ísť späť na úlohy.',
'commentaddedmsg'         => 'Komentár bol pridaný.',
'commenttoassigned'       => 'pridal komentár k úlohe, ku ktorej ste bol pripísaný: ',
'commenttotask'           => 'pridal nasledujúci komentár k úlohe.',
'nocommententered'        => 'Vložte prosím komentár.',
'fillinfields'            => 'Nevyplnili ste všetky polia.',
'notcurrentpass'          => 'Vložili ste zlé aktuálne heslo!',
'passchanged'             => 'Vaše heslo bolo zmenené.',
'closewindow'             => 'Môžete zavrieť okno.',
'passnomatch'             => 'Nové heslá sa nezhodujú!',
'usernametaken'           => 'Vybrané používateľské heslo sa už používa. Vyberte iné.',
'usernametakenbulk'       => 'Užívateľské meno je už použité',
'newusercreated'          => 'Nový účet bol vytvorený.',
'accountcreated'          => 'Vaš účet bol úspešne vytvorený.',
'newuserwarning'          => 'Note that the global preferences might require your account to be approved by an admin.  If you cannot login, this is probably why.',
'nomatchpass'             => 'Heslá sa nezhodujú.',
'confirmwrong'            => 'Potvrdzovací kód je nesprávny!',
'formnotcomplete'         => 'Formulár nebol kompletne vyplnený.',
'formnotnumeric'          => 'Zadané dáta musia byť číselné',
'groupnametaken'          => 'Názov skupiny sa už používa.',
'newgroupadded'           => 'Nová skupina bola pridaná.',
'optionssaved'            => 'Nastavenia Flyspray boli uložené.',
'hasuploaded'             => 'has uploaded a file attachment to a task that have been assigned:',
'hasattached'             => 'has attached a file to the following task.',
'fileuploaded'            => 'Súbor bol nahraný.',
'fileerror'               => 'Počas nahrávania súboru sa vyskytla chyba. Pravdepodobne sú nesprávne nastavené prístupové práva pre adresár <i>attachments/</i>.',
'contactadmin'            => 'Kontaktujte Administrátora pre tento projekt.',
'selectfileerror'         => 'Nevybrali ste žiadny súbor.',
'userupdated'             => 'Údaje o používateľovi boli upravené',
'realandemail'            => 'Nevyplnili ste polia skutočné meno a e-mailová adresa.',
'groupupdated'            => 'Definícia skupiny bolo upravená.',
'groupanddesc'            => 'Nevyplnili ste názov skupiny.',
'fillallfields'           => 'Prosím, vyplňte všetky polia.',
'listPmustN'              => '"Poradie" musí byť číslo.',
'listupdated'             => 'Zoznam bol upravený.',
'listitemadded'           => 'Nová položka bola pridaná.',
'relatedaddedmsg'         => 'Úloha bola pridaná do zoznamu..',
'relatederror'            => 'That task is already on this related task list.',
'relatedremoved'          => 'Related task removed from list.',
'notifyadded'             => 'Používateľ bol pridaný do zoznamu notifikácií.',
'notifyerror'             => 'Tento používateľ sa už nachádza v notifikačnom zozname pre túto úlohu.',
'notifyremoved'           => 'Používateľ bol odstránený z notifikačného zoznamu.',
'editcommentsaved'        => 'Upravený komentár bol uložený.',
'commentdeletedmsg'       => 'Komentár bol zmazaný.',
'gotonewtask'             => 'Choď do práve vytvorenej úlohy.',
'projectcreated'          => 'Váš nový projekt bol vytvorený. Teraz môžete upraviť projekt v sekcii správy projektov.',
'customiseproject'        => 'Upraviť tento projekt',
'projectupdated'          => 'Nastavenia projektu boli upravené',
'emptytitle'              => 'Názov projektu ste nechali prázdny. Vráťte sa a upravte to.',
'loginbelow'              => 'Teraz sa môžete skúsiť prihlásiť.',
'attachmentdeletedmsg'    => 'Príloha bola zmazaná.',
'reminderaddedmsg'        => 'Váš pripomienkovač bol pridaný.',
'reminderdeletedmsg'      => 'Vybraný pripomienkovač bol zmazaný.',
'flyspraytask'            => 'Flyspray úloha',
'fieldsmissing'           => 'Niektoré polia obsahovali nesprávne dáta alebo neobsahovali nič.',
'relatedinvalid'          => 'Táká úloha neexistuje.',
'relatedproject'          => 'Táto úloha je pridelená k inému projektu. Chcete napriek tomu pričleniť úlohu k tomuto projektu?',
'addanyway'               => 'Pridať',
'cancel'                  => 'Zrušiť',
'alreadyedited'           => 'Táto úloha bola upravená niekým iným pred tým, ako ste ju uložili. Chcete napriek tomu uložiť zmeny?',
'saveanyway'              => 'Uložiť napriek tomu.',
'nouserselected'          => 'Žiadny užívateľ nebol vybraný. Vyberte aspoň jedného užívateľa a skúste znovu.',
'groupswitchupdated'      => 'Skupina užívateľov bola úspešne upravená.',
'takenownershipmsg'       => 'Táto úloha bola Vám pripísana.',
'adminrequestmade'        => 'Vaša požiadavka bola poslaná vedúcemu projektu.',
'newdepnotify'            => 'Nová závislosť bola pridaná k nasledujúcej úlohe:',
'dependadded'             => 'Závislosť úlohy bola pridaná',
'dependaddfailed'         => 'Vyskytol sa problém pri pridávaní závislosti. Uistite sa, že úloha existuje a nie je blokovaná.',
'depremovedmsg'           => 'Závislosť na úlohe bola zmazaná.',
'newdepis'                => 'Nová závislosť je ',
'magicurlsent'            => 'Bola Vám poslaná správa na Váš e-mail. Obsahuje adresu, na ktorej môžete dokončiť túto úlohu.',
'changefspass'            => 'Zmeniť heslo',
'magicurlmessage'         => 'Kliknite na dole uvedenú adresu pre zmenu Vašeho hesla:',
'erroronform'             => 'Vyskytol sa problém v posielaných dátach.',
'addressused'             => 'Táto e-mailová adresa bola použitá pri registrácii Flyspray účtu. Ak ste túto adresu dostali náhodne vymaže ju. Pre dokončenie registrácie navštívte nasledujúcu adresu:',
'confirmcodeis'           => 'Váš povrdzujúci kót je:',
'codesent'                => 'Váš potvrdzujúci kod bol poslaný. Nasledujte inštrukcie obsiahnuté v poslanej správe.en sent.',
'codenotsent'             => 'Nebolo Vám možné poslať kód. Skúste neskôr, prosím.',
'taskmadeprivatemsg'      => 'Táto úloha je súkromná.',
'taskmadepublicmsg'       => 'Táto úloha je znovu verejná.',
'realandnotify'           => 'Musíte zadať skutočné meno a taktiež e-mail, Jabber.',
'pmreqdeniedmsg'          => 'Vedúci projektu žiadosť zamietol.',
'massopsuccess'           => 'Hromadné operácie boli uskutočnené - práva povolili ich úpravu.',
'usernotexist'            => 'Užívateľ neexistuje.',
'commentattachperms'      => 'Komentár nemôže byť zmazaný - nemáte práva na mazanie prílohh.',
'voterecorded'            => 'Váš hlas bol zaznamenaný',
'votefailed'              => 'Váš hlas nemožno momentálne spracovať.',
'createnewgroup'          => 'Vytvoriť novú skupinu',
'requiredfields'          => 'Povinné údaje sú vyznačené',
'addthisgroup'            => 'Pridať túto skupinu',
'createnewproject'        => 'Vytvoriť nový projekt',
'addnewproject'           => 'Pridať nový projekt',
'htmlallowed'             => 'HTML kódy sú povolené',
'createthisproject'       => 'Vytvoriť tento projekt',
'inlineimages'            => 'Zobraziť obrazové prílohy v texte.',
'createnewtask'           => 'Vytvoriť nový dotaz v tomto projekte:',
'addanother'              => 'Vytvoriť ďalšiu úlohu.',
'addthistask'             => 'Pridať úlohu',
'notifyme'                => 'Upozorni ma pri akejkoľvek zmene v tejto úlohe.',
'newtask'                 => 'Nová úloha',
'attachafile'             => 'Priložiť súbor',
'registernewuser'         => 'Registrovať nového užívateľa',
'none'                    => 'Žiadne',
'registeraccount'         => 'Registrovať toto konto',
'registerbulkaccount'     => 'Zoznam účtov',
'both'                    => 'Oboje',
'notifyfrom'              => 'Notifikácia od ',
'donotreply'              => 'TÁTO SPRÁVA JE AUTOMATICKÁ SPRÁVA SYSTÉMU. NEODPOVEDAJTE NA ŇU.',
'disclaimer'              => 'Táto správa Vám bola poslaná, pretože ste si ju vyžiadali od Flyspray. Ak si neželáte, alebo ste túto správu neočakávali, môžete upraviť nastavenia na adrese uvedenej vyššie.',
'userwho'                 => 'Užívateľ, ktorý to urobil',
'moreinfo'                => 'Viac informácií môžete nájsť na nasledovnej adrese:',
'newtaskopened'           => 'Nová Flypray úloha bola vytvorená. Podrobnosti nájdete nižšie.',
'notify.taskclosed'       => 'Nasledujúca úloha sa uzavrela:',
'notify.taskreopened'     => 'Nasledujúca úloha bola znovu otvorená.',
'newdep'                  => 'Nasledujúca úloha má novú závislosť.',
'notify.depremoved'       => 'Nasledujúca úloha mala odstránenú závislosť:',
'olddepwas'               => 'Bývalá závislosť bola',
'notify.commentadded'     => 'Nasledujúca úloha má nový komentár:',
'commentis'               => 'Text komentáru je uvedený nižšie.',
'newattachment'           => 'Nový súbor bol priložený k nasledovnej úlohe:',
'detailsbelow'            => 'Detaily sú nižšie.',
'notify.relatedadded'     => 'Nová podobná úloha bola pridaná k tejto úlohe:',
'relatedis'               => 'Podobná úloha je',
'assignedtoyou'           => 'Boli ste priradený k nasledovnej úlohe:',
'takenownership'          => 'prevzal vlastníctvo nasledovnej úlohe:',
'requiresaction'          => 'Nasledovná úloha vyžaduje zásah vedúceho projektu:',
'requiresactionnotify'    => 'Úloha vyžaduje zásah vedúceho projektu',
'pmdeny'                  => 'Vedúci projektu zamietol požiadavku k nasledujúcej úlohe:',
'pmdenynotify'            => 'Vedúci projektu zamietol požiadavku',
'fileaddedtoo'            => 'Jeden alebo viac súborov bolo priložených.',
'taskwatching'            => 'Nasledujúca úloha, ktorú sledujete,',
'isdepfor'                => 'je nová závislosť k',
'denialreason'            => 'Dôvod zamietnutia',
'taskchanged'             => 'Nasledujúca úloha bola zmenená. Zmeny sú uvedené nižšie. Pre viac informácií o zmenách sa nachádza na nasledujúcej adrese v sekcii história.',
'useraddedtoassignees'    => 'Užívateľ sa pridal do zoznamu pridelených užívateľov úlohy.',
'removeddepis'            => 'Zmazaná závislosť je',
'isnodepfor'              => 'už nie je závislosť pre',
'usergroups'              => 'Užívateľské skupiny',
'pmtoolbox'               => 'Toolbox vedúceho projektu',
'groupmanage'             => 'Management skupín',
'pendingrequests'         => 'Čakajúce žiadosti',
'reasongiven'             => 'Dôvod zadaný',
'nopendingreq'            => 'Žiadne žiadosti pre projektového manažéra.',
'givereason'              => 'Podať riešenie',
'catlisted'               => 'Editor zoznamu kategórií',
'oslisted'                => 'Editor zoznamu operačných systémov',
'verlisted'               => 'Editor verzií',
'tasktypeed'              => 'Editor typov úloh',
'resed'                   => 'Editor rozdelenia',
'deny'                    => 'Zakáž',
'notifiedwhen'            => 'Notifikovať keď',
'onlynewtasks'            => 'Nové úlohy boli otvorené',
'allevents'               => 'Any event occurs in any task',
'feeds'                   => 'Odobery',
'feeddescription'         => 'Popis oderu',
'feedimgurl'              => 'Feed adresa obrázku URL (pre žiadny obrázok nechajte prázdne)',
'notifysubject'           => 'Predmet pre notifikácie',
'notifysubjectinfo'       => '(%p = názov projektu, %s = zhrnutie úlohy, %t = id úlohy, %a = akcia, %u = užívateľ)',
'priority6'               => 'BLESK',
'priority5'               => 'Mimoriadna',
'priority4'               => 'Naliehavá',
'priority3'               => 'Vysoká',
'priority2'               => 'Normalna',
'priority1'               => 'Nízka',
'sendcode'                => 'Posielam kód!',
'entercode'               => 'Vložte potvrdzujúci kód, ktorý ste obdržali v správe, a želané užívateľské heslo.',
'confirmationcode'        => 'Potvrdzujúci kód',
'registererror'           => 'Uistite sa, že ste zadali všetky povinné údaje a korektne vyplnili podrobnosti pre Váš požadovaný typ notifikácie.',
'validusername'           => '(iba písmená a - _ . sú povolené)',
'validemail'              => '(Použite ; na oddelenie viac e-mailových adries)',
'emailtakenbulk'          => 'Email adresa je už použitá',
'emailtaken'              => 'Táto emailová adresa alebo Jabber-ID je už evidované. Zvoľte si inú.',
'note'                    => '<strong>Poznámka:</strong> Bude vám zaslaný potvrdzujúci kód pred vytvorením účtu. Potvrdzujúci kód bude zaslaný preferovanou metódou notifikácie.<br />Ak ste zadali nesprávne kontaktné údaje, <strong>nebude Vám možné potvrdzujúci kód poslať</strong>.',
'changelog'               => 'Changelog',
'changeloggen'            => 'Changelog Generator',
'listfrom'                => 'Zoznam zmien (changelog) od',
'to'                      => 'do',
'oldestfirst'             => 'Od najstarších',
'recentfirst'             => 'Od najnovších',
'severityrep'             => 'Severity Report',
'totalopen'               => 'Celkovo otvorených úloh',
'age'                     => 'Vek',
'agerep'                  => 'Vek správy',
'eventsrep'               => 'Správa udalosti',
'events'                  => 'Udalosti',
'Tasks'                   => 'Úlohy',
'opened'                  => 'Otvorené',
'edited'                  => 'Editované',
'assigned'                => 'Priradené',
'within'                  => 'V rámci',
'pastday'                 => 'Predchádzajúci deň',
'pastweek'                => 'Predchádzajúci víkend',
'pastmonth'               => 'Predchádzajúci mesiac',
'pastyear'                => 'Predchádzajúci rok',
'nolimit'                 => 'Bez limitu',
'from'                    => 'Od',
'duein'                   => 'Kvôli',
'selectfromdate'          => 'Vybrať od dátumu',
'selecttodate'            => 'Vybrať po dátum',
'showvoters'              => 'Zobraziť/skryť hlasujúcich',
'roadmap'                 => 'Plán',
'roadmapfor'              => 'Plán pre verziu',
'tasks'                   => 'úlohy',
'completed'               => 'hotové.',
'opentasks'               => 'otvorené úlohy',
'of'                      => '% z',
'severity5'               => 'Kritická',
'severity4'               => 'Vysoká',
'severity3'               => 'Stredná',
'severity2'               => 'Nízka',
'severity1'               => 'Veľmi nízka',
'Redirect'                => 'Presmerovanie',
'redirectmsg'             => 'Ak Váš prehliadač nepodporuje meta presmerovanie, prosim kliknite %sTU%s na presmerovanie',
'allowclosedcomments'     => 'Povoliť komentáre na uzavretých úlohách',
'comment'                 => 'Komentár',
'editowncomments'         => 'Editovať vlastné komentáre',
'reopened'                => 'Znovuotvorené',
'loading'                 => 'Nahrávam...',
'notifyown'               => 'Notifikovať vlastné zmeny',
'youremail'               => 'Vaša emailová adresa',
'thankyouforbug'          => 'Ďakujeme za nahlásenie problému. Možete túto úlohu sledovať a vidieť jej priebeh kedykoľvek navštívením nasledovnej URL:',
'anonuser'                => 'Anonymný užívateľ',
'conflict'                => 'Konflikt',
'file'                    => 'Súbor',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Veľkosť',
'projectgroup'            => 'Skupina projektu',
'profile'                 => 'Profil:',
'viewprofile'             => 'Zobraziť profil',
'regdate'                 => 'Registrovaný od',
'tasksopened'             => 'Úloha otvorená',
'replyto'                 => 'Odpovedať na',
'notifytypes'             => 'Typy notifikácie',
'pm.taskchanged'          => 'Úloha zmenená',
'pm.taskreopened'         => 'Úloha znovuotvorená',
'pm.depadded'             => 'Závislosti pridané',
'pm.depremoved'           => 'Závislosti odobraté',
'pmrequest'               => 'PM požiadavka',
'pmrequestdenied'         => 'PM požiadavka zamietnutá',
'newassignee'             => 'Nové priradenie',
'revdepadded'             => 'Spätná závislosť pridaná',
'revdepaddedremoved'      => 'Spätná závislosť odobraná',
'assigneeadded'           => 'Priradenie pridané',
'addusergroup'            => 'Pridať užívateľa do tejto skupiny',
'groupmembers'            => 'Členovia skupiny',
'deleteuser'              => 'Zmazať tohto užívateľa',
'userdeleted'             => 'Užívateľ zmazaný',
'autoassign'              => 'Auto-priradenie úlohy na majiteľa kategórie',
'ssl'                     => 'SSL',
'updatewrong'             => 'Máte povolenú kontrolu aktualizácií, ale vyskytol sa problém pri pripojení k aktualizačnému serveru. Problém môže byť vo Vašom hostingu (nepodporuje odchádzajúce spojenia), alebo v sieti. Skontrolujte verziu Flyspray na domovskej stránke projektu Flyspray.',
'deleteproject'           => 'Zmazať tento projekt a presunúť obsah do',
'projectdeleted'          => 'Zmazanie projektu úspešné',
'feedforall'              => 'Feed pre všetky projekty',
'usercreated'             => 'Užívateľ vytvorený',
'created'                 => 'Vytvorené',
'deleted'                 => 'Zmazané',
'userid'                  => 'Užívateľské ID',
'editassignments'         => 'Editovať priradenia',
'preview'                 => 'Náhľad',
'anyprogress'             => 'Rôzny priebeh',
'tasksrelated'            => 'Úlohy podobné tejto úlohe',
'duplicatetasks'          => 'Duplicita úlohy',
'databasemodfailed'       => 'Chyba úpravy databázy. Pravdepodobne nemáte oprávnenia na jej úpravu.',
'frequency'               => 'Frekvencia',
'newuserregistered'       => 'Nový užívateľ bol zaregistrovaný. Detail užívateľa je nasledovný:',
'newuserregisterednotify' => 'Nový užívateľ bol zaregistrovaný',
'notify_registration'     => 'Notifikovať administrátorov pri nových registráciach',
'textversion'             => 'Textová verzia',
'onlyprimary'             => 'Úlohy neblokujú ostatné úlohy',
'switch'                  => 'Prepnúť',
'max'                     => 'max.',
'dates'                   => 'Dátumy',
'selectduedatefrom'       => 'Kvôli od',
'selectduedateto'         => 'po',
'selectsincedatefrom'     => 'Zmenené od',
'selectsincedateto'       => 'do',
'selectdate'              => 'Vyber dátum',
'selectopenedfrom'        => 'Otvorené od',
'selectopenedto'          => 'do',
'selectclosedfrom'        => 'Zatvorené od',
'selectclosedto'          => 'do',
'startat'                 => 'Začiatok o',
'hasattachment'           => 'Má prílohu',
'private'                 => 'Súkromné',
'watching'                => 'Sledovanie',
'alreadyvotedthistask'    => 'už ste hlasovali za túto úlohu',
'alreadyvotedthisday'     => 'už dnes zahlasované',
'visibility'              => 'Viditeľnosť',
'public'                  => 'Verejné',
'leaveemptyauto'          => 'Nechajte polia na heslo prázne, ak chcete , aby sa heslo vygenerovalo automaticky.',
'novalidemail'            => 'Nezadali ste platnú e-mailovú adresu.',
'novalidjabber'           => 'Nezadali ste platnú Jabber adresu.',
'missingrequired'         => 'Nevyplnili ste všetky povinné položky.',
'entervalidusername'      => 'Prosím vložte platné užívateľské a reálne meno.',
'couldnotaddusernotif'    => 'Nedá sa pridať tohto užívateľa do notifikačného zoznamu.',
'defaulttask'             => 'Predvolený popis úlohy',
'all'                     => 'všetko',
'events.useraddedtoassignees'=> 'Užívateľ pridaný do priradení',
'vote(s)'                 => 'hlas(ov)',
'eventlog'                => 'Log udalostí',
'assignmentchanged'       => 'Priradenie zmenené',
'detailedinfo'            => 'Detailné informácie',
'All'                     => 'Všetko',
'tasksireported'          => 'Mnou pridané úlohy',
'recentlyopened'          => 'AKtuálne otvorené',
'stats'                   => 'Štatistiky',
'totaltasks'              => 'celkom úloh',
'mostwanted'              => 'Najžiadanejšie úlohy',
'defaultentry'            => 'Predvolená vstupná stránka',
'toplevel'                => 'Domov',
'overview'                => 'Prehľad',
'error#'                  => 'Chyba #',
'error1'                  => 'Nemáte oprávnenia na prezeranie tejto prílohy.',
'error3'                  => 'Opakovaná akcia, presmerúvam na hlavnú stránku.',
'error4'                  => 'Nemáte administrátorské oprávnenia.',
'error5'                  => 'Tento užívateľ neexistuje v tejto inštalácii.',
'error6'                  => 'Zlá administrátorská sekcia',
'error7'                  => 'Prihlásenie zlyhalo, nesprávne heslo!',
'error71'                 => 'Konto zablokované na %d minút z dôvodu opakovaných nesprávnych prihlásení!',
'error8'                  => 'Nezadali ste heslo alebo užívateľské meno.',
'error9'                  => 'Táto úloha neexistuje alebo nemáte oprávnenia na jej zobrazenie.',
'error10'                 => 'Táto úloha neexistuje.',
'error101'                => 'Nemáte oprávnenie na zobrazenie tejto úlohy.',
'error102'                => 'Prihláste sa prosím. Ako anonymný užívateľ nemáte oprávnenie na zobrazenie tejto úlohy.',
'error11'                 => 'Nedostatočné oprávnenia na editáciu tohto komentáru.',
'error12'                 => 'Nesprávny kód. Zadali ste správny kód?',
'error13'                 => 'Anonymní užívatelia nemajú profil.',
'error14'                 => 'Nemáte oprávnenia na vytvorenie novej skupiny.',
'error15'                 => 'Nemáte oprávnenia na vytvorenie novej úlohy.',
'error16'                 => 'Nie ste vedúci projektu.',
'error17'                 => 'Zlá PM oblasť',
'error18'                 => 'Nesprávna adresa',
'error19'                 => 'Tento užívateľ neexistuje v tejto inštalácii.',
'error20'                 => 'Nesprávna modifikácia databázy.',
'error21'                 => 'Jeden alebo viac emailov sa nepodarilo odoslať. Skontrolujte Vašu konfiguráciu.',
'error22'                 => 'Registrácia nových užívateľov je povolená.',
'error23'                 => 'Užívateľ alebo skupina nie sú oprávnené k prihláseniu.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Plán je dostupný len pre špecifický projekt.',
'done'                    => 'hotovo',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Projekt nemohol byť zmazaný.',
'GMT'                     => 'GMT',
'timezone'                => 'Časové pásmo',
'accept'                  => 'Schváliť',
'reasonfordeinal'         => 'Dôvod zamietnutia',
'pruneclosedlinks'        => 'Prune zatvorené odkazy',
'pruneclosedtasks'        => 'Prune zatvorené úlohy',
'pagegenerated'           => 'Stránka a obrázok vygenerované za %d sekúnd.',
'pruninglevel'            => 'Pruning Level',
'lastuser'                => 'Posledný užívateľ nemohol byť zmazaný.',
'allprivate'              => 'Všetky projekty sú súkromné.',
'deletegroup'             => 'Zmazať túto skupinu a presunúť užívateľov do',
'parent'                  => 'Rodičovský',
'ordertip'                => 'Usporiadanie sa zobrazí v zozname',
'showtip'                 => 'Zobraziť túto položku v zozname',
'deletetip'               => 'Zmazať položku zo zoznamu',
'del'                     => 'del',
'request1'                => 'Bola podaná požiadavka na uzatvorenie úlohy.',
'request2'                => 'Bola podaná požiadavka na znovuotvorenie úlohy.',
'allpriorities'           => 'Všetky priority',
'noroadmap'               => 'Plán nie je dostupný (neexistujú budúce verzie).',
'expand'                  => 'Rozbaliť',
'collapse'                => 'Zbaliť',
'expandall'               => 'Rozbaliť všetko',
'collapseall'             => 'Zbaliť všetko',
'minpwsize'               => 'Minimálna dĺžka hesla je 5 znakov',
'passwordtoosmall'        => 'Dĺžka hesla je príliš malá.',
'accountwaslocked'        => 'Vaše heslo bolo zablokované z dôvodu príliš mnohých neplatných pokusov o prihlásenie.',
'failedattempts'          => 'Zaznamenané %d neplatné pokusy o prihlásenie.',
'groupnotexist'           => 'Zvolená skupina neexistuje v tomto projekte.',
'searchindetails'         => 'Hľadať detaily',
'showasassignees'         => 'Zobraz ako priradenie',
'find'                    => 'Nájsť',
'tls'                     => 'TLS',
'isadmin'                 => 'Je admin',
'addvotes'                => 'Pridať hlasy',
'removevote'              => 'Zmaž hlasovanie',
'voteremoved'             => 'Tvoj hlas bol zmazaný',
'voteremovefailed'        => 'Váš hlas v tomto okamihu nemohol byť odstránený.',
'connectedtasks'          => 'Pripojené úlohy:',
'taskdependencies'        => 'Závislosti úloh',
'viewgraph'               => 'Zobrazenie grafu',
'notaskdependencies'      => 'Táto úloha nezávisí na iných úlohách.',
'dependson'               => 'Závisí na',
'blocks'                  => 'Blokuje',
'newdependency'           => 'Nová závislosť:',
'nouserstoadd'            => 'Žiadny užívateľ  nepridaný. Uistite sa prosím, meno, užívateľské meno a e-mail sú definované pre každého užívateľa.',
'dispintro'               => 'Dobraz hlavnú úvodnú správu',
'mainmessage'             => 'Hlavná úvodná správa',
'setsupertask'            => 'Nastav ID Nad-úlohy:',
'supertaskmodified'       => 'Nad-úloha bola modifikovaná',
'set'                     => 'Množina',
'supertask'               => 'Nad-úloha',
'setparent'               => 'Nastav ID rodičovskej úlohy pre túto úlohu',
'selfsupertasknotallowed' => 'ID nad-úlohy nemôže byť rovnaké ako ID úlohy samotnej',
'quickaction'             => 'Rýchle akcie',
'updateselectedtasks'     => 'Aktualizovať vybrané úlohy',
'notspecified'            => 'Nešpecifikované',
'editselectedtasks'       => 'Upraviť vybrané úlohy',
'information'             => 'Informácie',
'taskclosedisabled'       => 'Zatvorenie úlohy je v súčasnosti zakázané nakoľko nasledujúce závislé úlohy sú stále otvorené: -',
'daysleft'                => 'Zvyšné dni',
'dayoverdue'              => 'dní oneskorenia',
'duetoday'                => 'Očakávané dnes.',
'daysbeforealert'         => 'Dní pred výstrahou',
'associatedsubtask'       => 'Úspešne prepojená pod-úloha #FS',
'associatesubtask'        => 'Prepoj pod-úlohu s touto úlohou',
'subtaskid'               => 'Pod-úloha ID',
'subtaskalreadyhasparent' => 'Zadaná pod-úloha už má nadradenú úlohu, prosím, zrušte tamto prepojenie pred pripojením.',
'subtaskisparent'         => 'Zadaná pod-úloha je rodičovskou úlohou tejto úlohy. Pod-úloha nie je spojená.',
'subtasknotexist'         => 'Zadaná pod-úloha neexistuje.',
'subtaskremovedmsg'       => 'Pod-úloha bola úspešne zmazaná',
'subtaskadded'            => 'Pod-úloha pridaná',
'subtaskremoved'          => 'Pod-úloha zmazaná',
'addnewsubtask'           => 'Pridať novú pod-úloha',
'hidesubtasks'            => 'Skryť pod-podúlohy',
'voteforthistask'         => 'Hlasujte pre túto úlohu',
'watchthistask'           => 'Sledujte túto úlohu',
'privatethistask'         => 'Urobiť túto úlohu súkromnú',
'adddependenttask'        => 'Pripojte závislú úlohu',
'associatetaskid'         => 'ID pod-úlohy',
'parenttaskid'            => 'ID Rodičovskej-úlohy',
'invalidsupertaskid'      => 'ID Rodičovskej-úlohy neplatné',
'supertaskadded'          => 'Nad-úloha pridaná',
'effort'                  => 'Vynaložené úsilie',
'efforttracking'          => 'Sledovanie vynaloženého úsilia',
'useeffort'               => 'Projekt používa sledovanie vynaloženého úsilia',
'estimatedeffort'         => 'Odhadované úsilie',
'totalestimatedeffort'    => 'Celkovo odhadované úsilie',
'actualeffort'            => 'Aktuálne vznaložené úsilie',
'starteffort'             => 'Začni sledovať',
'endeffort'               => 'Ukonči sledovanie',
'cleareffort'             => 'Vymaž sledovanie',
'addeffort'               => 'Pridaj úsilie',
'manualeffort'            => 'Manuálne pridaj úsilie (H:M)',
'efforttrackingstarted'   => 'Sledovanie úsilia pre túto úlohu zahajené.',
'efforttrackingnotstarted'=> 'Nemožno spustiť sledovanie na problém, ktorý je už sledovaný',
'efforttrackingstopped'   => 'Sledovanie úsilia pre túto úlohu ukončené.',
'efforttrackingcancelled' => 'Sledovanie úsilia pre túto úlohu prerušené.',
'efforttrackingadded'     => 'Manuálne pridanie úsilia pre túto úlohu  zaznamenané.',
'trackinginprogress'      => 'Sledovanie prebieha',
'vieweffort'              => 'Je možné zobraziť sledovanie úsilia',
'trackeffort'             => 'Je možné sledovať úsilie',
'invalideffort'           => 'Úsilie ktoré ste zadali, je neplatné. Musíte zadať číslo',
'showpass'                => 'Zobraz heslo',
'addmultipletasks'        => 'Pridať viac úloh',
'pendingnewuserrequest'   => 'Čakajúce požiadavky nových používateľov',
'adminrequestswaiting'    => 'Čakajúce požiadavkz administrátora',
'regapprovedbyadmin'      => 'Registrácia schválená administrátorom (zakázaný potvrdzovací kód)'
);

?>
