<?php
//
// This file is auto generated with .langedit.php
// Characters are UTF-8 encoded
//
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
//
// Furthermore, nothing else than the language array is saved
// when using the .langedit.php editor!
//
$translation = array(
'edituser'                => 'Bewerk gebruiker',
'username'                => 'Gebruikersnaam',
'realname'                => 'Echte naam',
'emailaddress'            => 'E-mailadres',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Notificatietype',
'group'                   => 'Groep',
'accountenabled'          => 'Account ingeschakeld',
'updatedetails'           => 'Details bijwerken',
'setglobally'             => 'Deze voorkeur is globaal ingesteld',
'usergroupmanage'         => 'Gebruiker- en groepsbeheer',
'newuser'                 => 'Registeer nieuwe gebruiker',
'newgroup'                => 'Maak nieuwe groep',
'yes'                     => 'Ja',
'no'                      => 'Nee',
'editgroup'               => 'Bewerk groep',
'groupname'               => 'Groepsnaam',
'description'             => 'Beschrijving',
'admin'                   => 'Beheerdersgroep',
'opennewtasks'            => 'Open nieuwe taken',
'modifytasks'             => 'Pas bestaande taken aan',
'addcomments'             => 'Voeg commentaar toe',
'attachfiles'             => 'Voeg bijlagen toe',
'vote'                    => 'Leden kunnen inloggen',
'groupenabled'            => 'Leden kunnen inloggen',
'groupopen'               => 'Leden kunnen inloggen',
'tasktypelist'            => 'Lijst met taaktypes',
'categorylist'            => 'Categorielijst',
'oslist'                  => 'Besturingssysteemlijst',
'resolutionlist'          => 'Lijst met oplossingen',
'versionlist'             => 'Versielijst',
'severitylist'            => 'Lijst met ernstigheden',
'listnote'                => 'Let op: Het uitvinken van de toonoptie in de bewerkmodus kan een paar taken wijzigen. Veranderen van het naamveld verandert alle taken met die naam',
'name'                    => 'Naam',
'order'                   => 'Volgorde',
'back'                    => 'Terug',
'text'                    => 'Tekst',
'highlight'               => 'Markeer',
'show'                    => 'Toon',
'owner'                   => 'Eigenaar',
'selectowner'             => 'Selecteer eigenaar',
'update'                  => 'Aanpassen',
'addnew'                  => 'Nieuwe toevoegen',
'flysprayprefs'           => 'Flyspray voorkeuren',
'projecttitle'            => 'Projecttitel',
'baseurl'                 => 'Basis-URL voor deze installatie',
'replyaddress'            => 'Antwoordadres voor notificaties',
'themestyle'              => 'Thema / Stijl',
'language'                => 'Taal',
'anonview'                => 'Laat anonieme gebruikers de taken zien',
'allowanon'               => 'Laat anonieme gebuikers nieuwe taken openen',
'never'                   => 'Nooit',
'anonymously'             => 'Anoniem',
'afterregister'           => 'Enkel na registratie',
'spamproof'               => 'Schakel bevestigingscode in voor nieuwe gebruikers',
'anongroup'               => 'Groep voor nieuwe gebruikersregistraties',
'groupassigned'           => 'Leden van deze groep kunnen taken toegewezen krijgen',
'forcenotify'             => 'Forceer taaknotificaties als',
'neversend'               => 'Verstuur nooit',
'userchoose'              => 'Laat elke gebruiker kiezen',
'email'                   => 'E-mail',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Standaard categorie-eigenaar',
'noone'                   => 'Niemand',
'jabbernotify'            => 'Jabber notificaties',

'jabberserver'            => 'Server',
'jabberport'              => 'Poort',
'jabberuser'              => 'Account gebruikersnaam',
'jabberpass'              => 'Account wachtwoord',
'saveoptions'             => 'Opties opslaan',
'editcomment'             => 'Bewerk commentaar',
'commentby'               => 'Commentaar door',
'saveeditedcomment'       => 'Sla bewerkte commentaar op',
'projectprefs'            => 'Projecteigenschappen',
'pagetitle'               => 'Paginatitel',
'defaultproject'          => 'Standaard Project',
'projectlists'            => 'Projectlijsten',
'showlogo'                => 'Toon titellogo',
'intromessage'            => 'Welkomstbericht',
'isactive'                => 'Project is actief',
'createproject'           => 'Maak een nieuw project',
'nopermission'            => 'U hebt geen toestemming om deze pagina te gebruiken',
'listordertip'            => 'De volgorde van deze items zal verschijnen in de lijst',
'listshowtip'             => 'Toon dit item in de lijst',
'categoryownertip'        => 'Deze persoon ontvangt notificaties als een taak in deze categorie geopend wordt',
'categoryparenttip'       => 'Bovenliggende categorie waaronder deze nieuwe valt',
'notsubcategory'          => 'Geen - top-niveau categorie',
'showinlineimages'        => 'Toon afbeeldingbijlagen in het bericht',
'dateformat'              => 'Datumformaat',
'dateformat_extended'     => 'Gedetailleerd datum formaat',
'cache_feeds'             => 'Cache feeds',
'no_cache'                => 'Geen caching',
'cache_disk'              => 'Cache op schijf',
'cache_db'                => 'Cache in DB',
'subcategoryof'           => 'Sub-categorie van',
'visiblecolumns'          => 'Kolommen getoond in takenlijst',
'tense'                   => 'Tijd',
'listtensetip'            => 'Verleden, Nu of Toekomst',
'past'                    => 'Verleden',
'present'                 => 'Nu',
'future'                  => 'Toekomst',
'oldpass'                 => 'Oude wachtwoord',
'nooldpass'               => 'Er was geen oud wachtwoord opgeslagen',
'oldpasswrong'            => 'Oude wachtwoord was niet correct',
'changepass'              => 'Wijzig wachtwoord',
'confirmpass'             => 'Bevestig wachtwoord',
'projectmanager'          => 'Projectleider',
'viewtasks'               => 'Bekijk taken',
'modifyowntasks'          => 'Bewerk eigen taken',
'modifyalltasks'          => 'Bewerk taken die niet van de gebruiker zelf zijn',
'viewcomments'            => 'Bekijk opmerkingen',
'editcomments'            => 'Bewerk opmerkingen',
'deletecomments'          => 'Verwijder opmerkingen',
'viewattachments'         => 'Bekijk bijlagen',
'createattachments'       => 'Maak bijlagen',
'deleteattachments'       => 'Verwijder bijlagen',
'viewhistory'             => 'Bekijk geschiedenis',
'closeowntasks'           => 'Sluit eigen taken',
'closeothertasks'         => 'Sluit taken die niet van de gebruiker zelf zijn',
'assigntoself'            => 'Taak aan uzelf toewijzen als deze nog niet toegewezen is',
'assignotherstoself'      => 'Wijs andermans taak aan uzelf toe',
'viewreports'             => 'Bekijk rapporten',
'othersview'              => 'Iedereen toestaan dit project te bekijken',
'usersandgroups'          => 'Gebruikers en Groepen',
'globalgroup'             => 'Globale groep',
'globalgroups'            => 'Globale Groepen',
'defaultglobalgroup'      => 'Standaard globale groep voor nieuwe gebruikers',
'addtogroup'              => 'Toevoegen aan groep',
'moveuserstogroup'        => 'Verplaats gebruikers naar groep',
'nogroup'                 => 'Geen groep - verwijder uit project',
'eventdesc'               => 'Gebeurtenis omschrijving',
'requestedby'             => 'Aangevraagd door',
'daterequested'           => 'Datum aanvraag',
'closetask'               => 'Sluit taak',
'reopentask'              => 'Heropen taak',
'applymember'             => 'Projectlidmaatschap aanvragen',
'forcurrentproj'          => 'Voor huidige project',
'lostpw'                  => 'Verloren wachtwoord opvragen',
'lostpwexplain'           => 'Voer u gebruikersnaam in om uw wachtwoord op te vragen. Er wordt een e-mail gestuurd naar het notificatieadres dat u in uw profiel ingesteld hebt.',
'sendlink'                => 'Verstuur link',
'savenewpass'             => 'Nieuwe wachtwoord opslaan',
'anonreg'                 => 'Nieuwe gebruikersregistraties toestaan',
'allowanonopentask'       => 'Anonieme gebruikers toestaan taken te openen',
'editglobalgroup'         => 'Bewerk globale groep',
'editgroupforproj'        => 'Bewerk groep voor project',
'notshownforadmin'        => 'Machtigingen worden niet getoond voor de beheerdersgroep. U hoeft deze niet te bewerken.',
'general'                 => 'Algemeen',
'userregistration'        => 'Gebruikersregistratie',
'notifications'           => 'Notificaties',
'resetoptions'            => 'Reset opties naar beginwaarden',
'preferences'             => 'Voorkeuren',
'tasktypes'               => 'Taaktypen',
'resolutions'             => 'Oplossingen',
'categories'              => 'Categoriën',
'operatingsystems'        => 'Besturingssystemen',
'versions'                => 'Versies',
'admintoolboxlong'        => 'Beheerders gereedschap',
'newproject'              => 'Nieuw Project',
'delete'                  => 'Verwijder',
'listdeletetip'           => 'Verwijder dit item uit de lijst',
'lookandfeel'             => 'Uiterlijk en gedrag',
'globaltheme'             => 'Globaal Uiterlijk',
'emailnotify'             => 'E-mailnotificatie',
'fromaddress'             => 'Van het adres',
'smtpserver'              => 'SMTP Server',
'smtpuser'                => 'SMTP Gebruikersnaam',
'smtppass'                => 'SMTP Wachtwoord',
'addrewrite'              => 'Gebruik adresherschrijving',
'usereminderdaemon'       => 'Enable background reminder daemon',
'tasksperpage'            => 'Taken per pagina van de takenlijst',
'addtoassignees'          => 'Voeg mijzelf toe als toegewezen persoon',
'taskstatuses'            => 'Taakstatussen',
'canvote'                 => 'Kan op taken stemmen',
'loginsuccessful'         => 'Login succesvol.',
'youareloggedout'         => 'U bent uitgelogd',
'waitwhiletransfer'       => 'Wacht alstublieft terwijl u doorverwezen wordt...',
'clicknowait'             => 'Klik hier als u niet wenst te wachten',
'accountdisabled'         => 'Uw account is uitgeschakeld. Neem contact op met een beheerder.',
'task'                    => 'Taak',
'edittask'                => 'Bewerk deze taak',
'openedby'                => 'Geopend door',
'editedby'                => 'Laatst bewerkt door',
'tasktype'                => 'Taaktype',
'category'                => 'Categorie',
'status'                  => 'Status',
'assignedto'              => 'Toegekend aan',
'operatingsystem'         => 'Besturingssysteem',
'severity'                => 'Ernstigheid',
'reportedversion'         => 'Gerapporteerde versie',
'dueinversion'            => 'Toe te schrijven aan versie',
'undecided'               => 'Onbeslist',
'percentcomplete'         => 'Percentage voltooid:',
'details'                 => 'Details',
'savedetails'             => 'Sla details op',
'canceledit'              => 'Annuleer bewerking',
'anonymous'               => 'Anonieme toevoeger',
'complete'                => 'voltooid',
'closedby'                => 'Gesloten door',
'reasonforclosing'        => 'De reden voor sluiting is:',
'reopenthistask'          => 'Heropen deze taak',
'comments'                => 'Commentaar',
'attachments'             => 'Bijlagen',
'relatedtasks'            => 'Gerelateerde taken',
'edit'                    => 'Bewerk',
'addcomment'              => 'Voeg commentaar toe',
'fileuploadedby'          => 'Bestand geüpload door',
'uploadafile'             => 'Voeg een bestand toe',
'uploadnow'               => 'Upload nu!',
'thesearerelated'         => 'Deze taken zijn verwant aan deze taak',
'remove'                  => 'Verwijder',
'addnewrelated'           => 'Voeg een nieuwe verwante taak toe',
'add'                     => 'Voeg toe!',
'otherrelated'            => 'Andere verwante taken van deze taak',
'receivenotify'           => 'Deze gebruikers krijgen gedetailleerde berichten wanneer deze taak verandert.',
'addusertolist'           => 'Voeg gebruiker toe aan deze lijst',
'addtolist'               => 'Voeg toe aan de lijst',
'addmyself'               => 'Voeg mijzelf toe aan deze lijst',
'removemyself'            => 'Verwijder mijzelf van deze lijst',
'theseusersnotify'        => 'Deze gebruikers krijgen gedetailleerde berichten wanneer deze taak verandert.',
'attachedtoproject'       => 'Toegevoegd aan project',
'reminders'               => 'Herinneringen',
'system'                  => 'Systeem',
'remindthisuser'          => 'Herinner deze gebruiker',
'thisoften'               => 'Zo vaak',
'startafter'              => 'Wachten voordat herinneringen gestart worden',
'hours'                   => 'Uren',
'days'                    => 'Dag(en)',
'weeks'                   => 'Week(en)',
'addreminder'             => 'Herinnering toevoegen',
'defaultreminder'         => 'Dit is een herinnering om naar de volgende Flyspray taak te kijken:',
'message'                 => 'Bericht',
'closed'                  => 'Gesloten',
'filename'                => 'Bestandsnaam:',
'date'                    => 'Datum',
'filesize'                => 'Bestandsgrootte:',
'closurecomment'          => 'Meer commentaar over de sluiting:',
'history'                 => 'Geschiedenis',
'nohistory'               => 'Geen geschiedenis beschikbaar.',
'eventdate'               => 'Datum',
'user'                    => 'Gebruiker',
'event'                   => 'Gebeurtenis',
'fieldchanged'            => 'Veld veranderd',
'taskopened'              => 'Taak geopend',
'taskreopened'            => 'Taak is heropend.',
'taskclosed'              => 'Taak is gesloten',
'commentadded'            => 'Commentaar is toegevoegd',
'commentedited'           => 'Commentaar gewijzigd',
'commentdeleted'          => 'Commentaar is verwijderd.',
'attachmentadded'         => 'Bijlage toegevoegd',
'attachmentdeleted'       => 'De bijlage is verwijderd',
'taskedited'              => 'Taakdetails gewijzigd',
'notificationadded'       => 'Gebruiker toegevoegd aan de notificatielijst',
'notificationdeleted'     => 'Gebruiker verwijderd van de notificatielijst',
'relatedadded'            => 'Gerelateerde taak toegevoegd aan lijst.',
'relateddeleted'          => 'Gerelateerde taak verwijderd',
'taskassigned'            => 'Taak toegekend aan',
'taskreassigned'          => 'Taak opnieuw toegekend aan',
'assignmentremoved'       => 'Toewijzing verwijderd',
'summary'                 => 'Samenvatting',
'addedasrelated'          => 'Taak toegevoegd aan de gerelateerde lijst van',
'deletedasrelated'        => 'Taak verwijderd van de gerelateerde lijst van',
'reminderadded'           => 'Uw herinnering is toegevoegd.',
'reminderdeleted'         => 'De geselecteerde herinnering is verwijderd.',
'priority'                => 'Prioriteit',
'previousvalue'           => 'Vorige waarde',
'newvalue'                => 'Nieuwe waarde',
'selectareason'           => 'Selecteer een reden',
'assigntome'              => 'Aan mijzelf toewijzen',
'reopenrequest'           => 'Heropening aanvragen',
'requestclose'            => 'Sluiting aanvragen',
'ownershiptaken'          => 'Gebruiker nam lidmaatschap',
'closerequestmade'        => 'Aanvragen taak sluiting',
'reopenrequestmade'       => 'Aanvragen taak heropening',
'taskdependson'           => 'Deze taak is afhankelijk van',
'taskblocks'              => 'Deze taak blokkeert de volgende taken tot sluiting',
'depadded'                => 'Afhankelijkheid toegevoegd',
'depaddedother'           => 'Deze taak heeft als afhankelijkheden',
'depremoved'              => 'Taakafhankelijkheid is verwijderd',
'depremovedother'         => 'Deze taak is verwijderd uit de afhankelijkhedenlijst van een andere taak',
'showdetailserror'        => 'Deze taak bestaat niet, of u hebt geen rechten om de taak te bekijken.',
'makeprivate'             => 'Maak Privé',
'makepublic'              => 'Maak Publiekelijk',
'taskmadeprivate'         => 'Deze taak is omgezet naar een privétaak',
'taskmadepublic'          => 'Deze taak is weer publiekelijk gemaakt',
'confirmdeletecomment'    => 'Weet u zeker dat u dit commentaar wilt verwijderen? %s',
'confirmdeleteattach'     => 'Weet u zeker dat u dit toegevoegde bestand wilt verwijderen?',
'selectedhistory'         => 'Toon geselecteerde geschiedenisdetails',
'showallhistory'          => 'Toon opnieuw de volledige Geschiedenistab',
'hidethis'                => 'Verberg dit gebied',
'mark100'                 => 'Markeer taak als 100% af',
'watchtask'               => 'Houd deze taak in de gaten',
'stopwatching'            => 'Stop met het in de gaten houden van deze taak',
'commentlink'             => 'Link naar dit commentaar',
'submitreq'               => 'Stuur verzoek op',
'reasonforreq'            => 'Reden voor deze aanvraag',
'pmreqdenied'             => 'Projectleider heeft het verzoek afgewezen',
'taskpendingreq'          => 'Wachtende acties van projectleider. Bekijk de geschiedenistab voor details.',
'previoustask'            => 'Vorige taak',
'nexttask'                => 'Volgende taak',
'duedate'                 => 'Beoogde datum',
'attachnoperms'           => 'Er zijn bestanden aan dit commentaar toegevoegd, maar u heeft niet genoeg rechten om deze te bekijken.',
'open'                    => 'Open',
'depgraph'                => 'Bekijk afhangeklijkheidsgraaf',
'reset'                   => 'Reset',
'selectusers'             => 'Selecteer gebruikers...',
'addmetoassignees'        => 'Voeg mij toe als toegewezen persoon',
'addedtoassignees'        => 'Gebruiker toegevoegd aan lijst toegekende personen',
'dependencygraph'         => 'Afhankelijkheidsgraaf',
'attachanotherfile'       => 'Voeg nog een bestand toe',
'OK'                      => 'Oké',
'addvote'                 => 'Voeg stem toe',
'notifyfromfs'            => 'Notificatie van Flyspray',
'autogenerated'           => 'DIT IS EEN AUTOMATISCH BERICHT, NIET ANTWOORDEN AUB',
'forward'                 => 'Vooruit',
'previous'                => 'Vorige',
'next'                    => 'Volgende',
'first'                   => 'Eerste',
'last'                    => 'Laatste',
'page'                    => 'Pagina %d van %d',
'search'                  => 'Zoeken',
'alltasktypes'            => 'Alle taaktypen',
'allseverities'           => 'Alle ernstigheden',
'alldevelopers'           => 'Alle ontwikkelaars',
'notyetassigned'          => 'Nog niet toegekend',
'allcategories'           => 'Alle categoriën',
'allstatuses'             => 'Alle statussen',
'allopentasks'            => 'Alle open taken',
'sortthiscolumn'          => 'Sorteer op deze kolom',
'id'                      => 'ID',
'project'                 => 'Project:',
'dateopened'              => 'Openingsdatum',
'progress'                => 'Vooruitgang',
'searchthisproject'       => 'Zoek in dit project',
'dueanyversion'           => 'Iedere versie',
'anyversion'              => 'Geraporteerd in Elke Versie',
'dueversion'              => 'Toe te schrijven aan',
'lastedit'                => 'Laatst gewijzigd',
'os'                      => 'Besturingssysteem',
'reportedin'              => 'Gemeld in',
'taskrange'               => 'Taken %d - %d van %d',
'noresults'               => 'Geen resultaten gevonden.',
'takeaction'              => 'Onderneem actie',
'watchtasks'              => 'Houd geselecteerde taken in de gaten',
'stopwatchingtasks'       => 'Stop met het in de gaten houden van de geselecteerde taken',
'assigntaskstome'         => 'Ken geselecteerde taken aan mij toe',
'dueby'                   => 'Beoogt voor ',
'dueanytime'              => 'Elk moment',
'selectduedate'           => 'Selecteer beoogde datum',
'toggleselected'          => 'Keer selectie om',
'due'                     => 'Beoogd voor',
'assignedtome'            => 'Aan mijzelf toegekend',
'tasklist'                => 'Takenlijst',
'dateclosed'              => 'Sluitdatum',
'advanced'                => 'Geavanceerd',
'searchcomments'          => 'Zoek binnen commentaren',
'searchforall'            => 'Zoek voor alle woorden',
'anonusers'               => 'Anonieme gebruikers',
'miscellaneous'           => 'Overige',
'users'                   => 'Gebruikers',
'taskproperties'          => 'Taakeigenschappen',
'selectsincedate'         => 'Selecteer Aangepast sinds',
'changedsince'            => 'Aangepast sinds',
'updatefs'                => 'Gaarna update Flyspray.',
'currentversion'          => 'Uw huidige versie is',
'latestversion'           => 'en de nieuwste versie is',
'hidemessage'             => '(herinner me op een later tijdstip)',
'saveas'                  => 'Sla zoektocht op als',
'nosearches'              => 'Geen opgeslagen zoekopdrachten',
'saving'                  => 'Bezig met oplaan...',
'votes'                   => 'Stemmen',
'allclosedtasks'          => 'Alle gesloten taken',
'password'                => 'Wachtwoord',
'login'                   => 'Login!',
'rememberme'              => 'Onthoud login',
'lostpassword'            => 'Wachtwoord verloren?',
'lostpwforfs'             => 'Verloren wachtwoord voor Flyspray',
'lostpwmsg1'              => "Gegroet,\n\nHet wachtwoord ben ik kwijtgeraakt voor ",
'lostpwmsg2'              => ", voorzie mij gaarne van een nieuw wachtwoord.\n\nGebruikersnaam: ",
'regards'                 => "\n\nMet vriendelijke groeten,",
'yourusername'            => ' uw gebruikersnaam ',
'locale'                  => 'nl',
'filenotexist'            => 'Bestand bestaat niet, of u heeft niet genoeg rechten het te bekijken.',
'showtask'                => 'Toon taak',
'now'                     => 'Nu',
'go'                      => 'Toon',
'opentaskanon'            => 'Open anoniem een nieuwe taak',
'register'                => 'Registreer als een nieuwe gebruiker',
'addnewtask'              => 'Voeg nieuwe taak toe',
'reports'                 => 'Rapporten',
'editmydetails'           => 'Bewerk mijn details',
'logout'                  => 'Uitloggen',
'disabledaccount'         => 'Uw account is uitgeschakeld.<br />U wordt onmiddellijk uitgelogd!',
'poweredby'               => 'Aangedreven door Flyspray',
'projects'                => 'Projecten',
'allprojects'             => 'Alle projecten',
'selectproject'           => 'voor project:',
'tasksall'                => 'Alle taken',
'tasksassigned'           => 'Taken toegewezen aan mijzelf',
'tasksreported'           => 'Taken door mij gerapporteerd ',
'taskswatched'            => 'Taken die u in de gaten houdt',
'mysearch'                => 'Mijn zoekopdrachten',
'admintoolbox'            => 'Beheerders gereedschap',
'manageproject'           => 'Beheer project',
'permissions'             => 'Bekijk permission',
'hide'                    => 'Verberg',
'pendingreq'              => 'Verzoeken aan projectleider wachtende',
'errorpage'               => "Flyspray kan de opgevraagde pagina niet tonen. Wellicht heeft u een taak proberen op te vragen die niet bestaat, of heeft u geen toegangsrechten om de pagina te bekijken.<br /><br />\nMisschien heeft u geprobeerd de URL aan te passen om het database aan te sturen door middel van een SQL Injection. In dat geval, ga in de hoek staan en schaam u !",
'permissionsforproject'   => 'Permissies voor ',
'switchto'                => 'Schakel over op',
'lastsearch'              => 'Mijn laatste zoekopdracht',
'modify'                  => 'Aanpassen',
'noticefrom'              => 'Bericht van',
'hasopened'               => 'heeft een NIEUWE Flyspray taak GEOPEND en aan u toegekend:',
'moreinfonew'             => 'U kunt meer informatie over deze bug vinden op de Flyspray pagina:',
'newtaskcategory'         => 'Een nieuwe Flayspray taak is geopend in deze categorie',
'categoryowner'           => 'U ontvangt dit omdat u op de lijst staat als categorie-eigenaar',
'tasksummary'             => 'Taak samenvatting:',
'newtaskadded'            => 'Uw nieuwe taak is toegevoegd',
'summaryanddetails'       => 'U moet de samenvatting en de details invullen.',
'goback'                  => 'Ga terug en voer uit.',
'messagefrom'             => 'Dit is een bericht van het Flyspray Bug Tracking System op',
'hasjustmodified'         => 'Heeft juist de volgende taak aangepast',
'changedfields'           => 'Aangepaste velden woorden voorgegaan door asterisken (***)',
'moreinfomodify'          => 'U kunt meer informatie krijgen over deze taak op de volgende URL:',
'nolongerassigned'        => 'De volgende taak is niet langer aan u toegekend. Het is nu toegekend aan',
'hasassigned'             => 'heeft aan u de volgende Flyspray taak toegekend:',
'taskupdated'             => 'Taak is bijgewerkt',
'hasclosedassigned'       => 'heeft de volgende, aan u toegekende, taak gesloten:',
'unassigned'              => 'Niet toegekend',
'hasclosed'               => 'heeft de volgende taak gesloten.',
'youonnotify'             => 'U ontvangt dit omdat u op de notificatielijst staat.',
'taskclosedmsg'           => 'Taak is gesloten.',
'returntotask'            => 'Ga terug naar de taakdetails',
'backtoindex'             => 'Ga terug naar de takenlijst',
'noclosereason'           => 'U selecteerde geen reden voor het sluiten van deze taak.',
'hasreopened'             => 'heeft de volgende Flyspray taak heropend die door u gesloten was:',
'taskreopenedmsg'         => 'Taak is heropend.',
'backtotask'              => 'Ga terug naar de taak.',
'commentaddedmsg'         => 'Commentaar is toegevoegd.',
'commenttoassigned'       => 'heeft commentaar toegevoegd aan de aan u toegekende taak:',
'commenttotask'           => 'heeft de volgende commentaar toegevoegd aan deze taak.',
'nocommententered'        => 'U moet echt een commentaar toevoegen voor u op de \'toevoegen\'-knop drukt.',
'fillinfields'            => 'U heeft niet alle velden ingevuld.',
'notcurrentpass'          => 'Dat is niet uw huidige wachtwoord!',
'passchanged'             => 'Uw wachtwoord is veranderd.',
'closewindow'             => 'U kunt nu dit venster sluiten.',
'passnomatch'             => 'Uw nieuwe wachtwoorden kwamen niet overeen!',
'usernametaken'           => 'Die gebruikersnaam is reeds in gebruik. U zal een andere naam moeten kiezen.',
'newusercreated'          => 'Nieuw gebruikersaccount is aangemaakt.',
'accountcreated'          => 'Uw account is aangemaakt.',
'newuserwarning'          => 'Het kan zijn dat de beheerder uw account moet goedkeuren. Dit kan de reden zijn waarom u niet kunt inloggen.',
'nomatchpass'             => 'Wachtwoorden kwamen niet overeen.',
'confirmwrong'            => 'Bevestigingscode is incorrect!',
'formnotcomplete'         => 'Formulier was niet volledig ingevuld.',
'formnotnumeric'          => 'Ingevoegde data was niet numeriek!',
'groupnametaken'          => 'Die groepsnaam is reeds in gebruik.',
'newgroupadded'           => 'Nieuwe groep toegevoegd.',
'optionssaved'            => 'Flyspray opties opgeslagen.',
'hasuploaded'             => 'heeft een bijlage geüpload naar een taak die toegekend is:',
'hasattached'             => 'heeft een bestand toegevoegd aan de volgende taak.',
'fileuploaded'            => 'Bestand is geüpload.',
'fileerror'               => 'Er is fout opgetreden tijdens het uploaden van het bestand. Misschien zijn de machtigingen van de <i>attachments</i>/map incorrect.',
'contactadmin'            => 'Neem contact op met de beheerder van dit project.',
'selectfileerror'         => 'U selecteerde geen bestand en/of gaf geen beschrijving op.',
'userupdated'             => 'Gebruikersdetails zijn bijgewerkt',
'realandemail'            => 'U heeft velden \'Echte naam\' en \'E-mailadres\' niet ingevuld.',
'groupupdated'            => 'Groepsdefinities bijgewerkt.',
'groupanddesc'            => 'U vulde de Groepsnaam en de Beschrijving niet in.',
'fillallfields'           => 'Vult u alstublieft alle velden in.',
'listPmustN'              => '"Volgorde"-veld moet numeriek zijn.',
'listupdated'             => 'Lijst is bijgewerkt.',
'listitemadded'           => 'Nieuw lijst item toegevoegd.',
'relatedaddedmsg'         => 'Gerelateerde taak toegevoegd aan de lijst.',
'relatederror'            => 'Deze taak staat reeds op de lijst met gerelateerde taken.',
'relatedremoved'          => 'Gerelateerde taak verwijdert van de lijst.',
'notifyadded'             => 'Gebruiker toegevoegd aan de notificatielijst',
'notifyerror'             => 'De gebruiker staat reeds op de notificatielijst van deze taak.',
'notifyremoved'           => 'Gebruiker verwijdert van de notificatielijst.',
'editcommentsaved'        => 'Bijgewerkte commentaar opgeslagen.',
'commentdeletedmsg'       => 'Commentaar is verwijderd.',
'gotonewtask'             => 'Ga direct naar de taak die u net aangemaakt hebt',
'projectcreated'          => 'Uw nieuwe project is toegevoegd. Volg onderstaande link om de categorie, besturingssystemen en versielijsten in te stellen',
'customiseproject'        => 'Pas dit project aan',
'projectupdated'          => 'Projectvoorkeuren aangepast',
'emptytitle'              => 'U liet het projecttitelveld leeg. Ga terug en pas dit aan.',
'loginbelow'              => 'U kunt nu proberen in te loggen.',
'attachmentdeletedmsg'    => 'De toegevoegde bestanden zijn verwijderd',
'reminderaddedmsg'        => 'Uw herinnering is toegevoegd.',
'reminderdeletedmsg'      => 'De geselecteerde herinnering is verwijderd.',
'flyspraytask'            => 'Flyspray taak',
'fieldsmissing'           => 'Sommige velden bevatten geen of foute gegevens.',
'relatedinvalid'          => 'Taak is niet gevonden.',
'relatedproject'          => 'Taak is aan een ander project gekoppeld.',
'addanyway'               => 'Toch toevoegen',
'cancel'                  => 'Annuleren',
'alreadyedited'           => 'Deze taak is door iemand anders gewijzigd voordat u hem opgeslagen had.',
'saveanyway'              => 'Sla de wijzigingen toch op',
'nouserselected'          => 'Geen gebruiker geselecteerd. Gebruik de terugknop van uw browser en selecteer er minstens één.',
'groupswitchupdated'      => 'Gebruiker groepen succesvol gewijzigd.',
'takenownershipmsg'       => 'Deze taak is nu aan u toegekend.',
'adminrequestmade'        => 'Uw aanvraag is verzonden naar een projectleider.',
'newdepnotify'            => 'Een nieuwe afhankelijkheid is toegevoegd aan de volgende taak:',
'dependadded'             => 'Taakafhankelijkheid is toegevoegd',
'dependaddfailed'         => 'U kunt op het moment geen taak als afhankelijkheid toevoegen',
'depremovedmsg'           => 'Taakafhankelijkheid is verwijderd',
'newdepis'                => 'De nieuwe afhankelijkheid is',
'magicurlsent'            => 'Er is een bericht verzonden naar uw notificatieadres. Hierin staat een link waarmee u de taak kunt afronden.',
'changefspass'            => 'Wijzig Flyspray wachtwoord',
'magicurlmessage'         => 'Gebruik onderstaande link om uw Flyspray wachtwoord te wijzigen:',
'erroronform'             => 'Er is een probleem met het versturen van het formulier',
'addressused'             => 'Op dit adres is zojuist een Flyspray account geregisteerd.  Als u dit bericht niet verwachtte, gelieve het dan te negeren. Uw bevestigingscode is:',
'confirmcodeis'           => 'Uw bevestingings code is:',
'codesent'                => 'Uw bevestingingscode is verzonden. Volg de instructies in het bericht op.',
'codenotsent'             => 'De code kon niet verstuurd worden, gaarne probeer het later opnieuw.',
'taskmadeprivatemsg'      => 'Deze taak is privé gemaakt',
'taskmadepublicmsg'       => 'Deze taak is weer publiekelijk gemaakt',
'realandnotify'           => 'Het is verplicht uw volledige naam in te vullen, en uw E-mailadres of uw Jabber-ID veld.',
'pmreqdeniedmsg'          => 'Verzoek aan projectleider afgewezen',
'massopsuccess'           => 'Massaopdrachten succesvol waar er genoeg rechten waren',
'usernotexist'            => 'Die gebruikersnaam bestaat niet binnen deze Flyspray installatie',
'commentattachperms'      => 'U kunt dat commentaar niet verwijderen - niet genoeg rechten om bijgevoegde bestanden te verwijderen',
'voterecorded'            => 'Uw stem is geregistreerd',
'votefailed'              => 'Uw stem kon niet worden geregistreerd',
'createnewgroup'          => 'Maak nieuwe groep aan',
'requiredfields'          => 'Vereiste velden zijn gemarkeerd met een a',
'addthisgroup'            => 'Voeg deze groep to',
'createnewproject'        => 'Maak een nieuw project aan',
'addnewproject'           => 'Nieuw project toevoegen',
'htmlallowed'             => 'HTML-code is toegestaan',
'createthisproject'       => 'Maak dit project',
'inlineimages'            => 'Toon afbeeldingbijlagen inline',
'createnewtask'           => 'Maak een nieuwe taak aan',
'addanother'              => 'Voeg nog een andere taak toe',
'addthistask'             => 'Voeg deze taak toe',
'notifyme'                => 'Houd mij op de hoogte als deze taak veranderd',
'newtask'                 => 'Nieuwe taak',
'attachafile'             => 'Voeg toe als bestand',
'registernewuser'         => 'Registreer nieuwe gebruiker',
'none'                    => 'Geen',
'registeraccount'         => 'Registreer dit account',
'both'                    => 'Beide',
'notifyfrom'              => 'Notificatie van ',
'donotreply'              => 'DIT IS EEN AUTOMATISCH VERSTUURD BERICHT, REAGEER ER NIET OP.',
'disclaimer'              => 'U ontvangt dit bericht omdat u het heeft aangevraagd bij het Flyspray bug-volgsysteem. U kunt toekomstige notificaties uitzetten door de URL hierboven weergegeven te bezoeken.',
'userwho'                 => 'Gebruiker die dit gedaan heeft',
'moreinfo'                => 'Meer informatie kan op de volgende URL gevonden worden:',
'newtaskopened'           => 'Een nieuwe Flyspray-taak is geopend. Details volgend hieronder.',
'notify.taskclosed'       => 'De volgende taak is nu gesloten:',
'notify.taskreopened'     => 'De volgende taak is heropend:',
'newdep'                  => 'De volgende taak heeft een nieuwe afhankelijkheid:',
'notify.depremoved'       => 'Een afhankelijkheid is verwijderd van de volgende taak:',
'olddepwas'               => 'De oude afhankelijkheid was',
'notify.commentadded'     => 'Nieuw commentaar is aan de volgende taak toegevoegd:',
'commentis'               => 'Het commentaar volgt hieronder.',
'newattachment'           => 'Een nieuw bestand is toegevoegd aan de volgende taak:',
'detailsbelow'            => 'De details volgen hieronder.',
'notify.relatedadded'     => 'Een nieuwe gerelateerde taak is toegevoegd aan de volgende taak:',
'relatedis'               => 'De gerelateerde taak is',
'assignedtoyou'           => 'U is de volgende taak toegekend:',
'takenownership'          => 'Deze taak is nu aan u toegewezen.',
'requiresaction'          => 'De volgende taken wachten op een actie van een projectbeheerder:',
'requiresactionnotify'    => 'Taak vereist actie van een projectleider',
'pmdeny'                  => 'Een projectleider heeft het verzoek afgewezen aanhangig de volgende taak:',
'pmdenynotify'            => 'Een projectleider heeft het verzoek afgewezen',
'fileaddedtoo'            => 'Één of meerdere bestanden zijn toegevoegd aan dit commentaar.',
'taskwatching'            => 'De volgende taken houdt u in de gaten',
'isdepfor'                => 'is een nieuwe afhankelijkheid voor',
'denialreason'            => 'Reden voor afwijzing',
'taskchanged'             => 'De volgende taken zijn veranderd. De veranderingen zijn hieronder weergegeven. Voor de volledige informatie over wat er veranderd is, bezoek de URL en klik op de Geschiedenistab.',
'useraddedtoassignees'    => 'Een gebruiker heeft zichzelf toegevoegd aan de lijst van gebruikers die aan deze taak zijn toegewezen',
'removeddepis'            => 'De verwijderde afhankelijkheid is',
'isnodepfor'              => 'is geen afhankelijkheid meer voor',
'usergroups'              => 'Gebruikers en groepen',
'pmtoolbox'               => 'Projectleiders gereedschap',
'groupmanage'             => 'Groepsbeheer',
'pendingrequests'         => 'Openstaande aanvragen',
'reasongiven'             => 'Reden opgegeven',
'nopendingreq'            => 'Er zijn geen onafgehandelde projectleiderverzoeken.',
'givereason'              => 'Geef een reden op',
'catlisted'               => 'Categoriënlijsteditor',
'oslisted'                => 'Besturingssysteemlijsteditor',
'verlisted'               => 'Versielijsteditor',
'tasktypeed'              => 'Taaktypelijsteditor',
'resed'                   => 'Oplossingenlijsteditor',
'deny'                    => 'Wijs af',
'notifiedwhen'            => 'Stuur notificatie als',
'onlynewtasks'            => 'Niuewe taken zijn geopend',
'allevents'               => 'Elk mogelijke gebeurtenis van elke taak',
'feeds'                   => 'Feeds',
'feeddescription'         => 'Feed omschrijving',
'feedimgurl'              => 'Feedafbeelding URL (laat leeg voor geen afbeeldingen)',
'notifysubject'           => 'Onderwerp voor notificaties',
'notifysubjectinfo'       => '(%p = projectnaam, %s = taaksamenvatting, %t = taak-ID, %a = actie, %u = gebruikersnaam)',
'priority6'               => 'Kritiek',
'priority5'               => 'Onmiddelijk',
'priority4'               => 'Dringend',
'priority3'               => 'Hoog',
'priority2'               => 'Normaal',
'priority1'               => 'Laag',
'sendcode'                => 'Verzend code!',
'entercode'               => 'Voer de bevestigingscode in, zoals u die ontvangen heeft in het notificatiebericht. Typ ook uw gewenste wachtwoord in.',
'confirmationcode'        => 'Bevestigingscode',
'registererror'           => 'Verzeker u ervan dat u alle vereiste velden ingevuld hebt en dat u de correcte details voor uw gewenste notificatietype ingevuld hebt.',
'validusername'           => '(alleen letters en - _ . zijn toegestaan)',
'emailtaken'              => 'Dat e-mailadres of Jabber-ID is al bezet. Kies een andere.',
'note'                    => '<b>Opmerking:</b>  U krijgt een bevestigingscode voordat uw account aangemaakt wordt. Deze code wordt verzonden naar uw gekozen notificatietype hierboven. ALS U VALSE GEGEVENS INVULT, ONTVANGT U UW CODE NIET.',
'changelog'               => 'Changelog',
'changeloggen'            => 'Changelog generator',
'listfrom'                => 'Toon changelog toevoegingen van',
'to'                      => 'naar',
'oldestfirst'             => 'Oudste eerst',
'recentfirst'             => 'Meest recente eerst',
'severityrep'             => 'Overzicht ernstigheden',
'totalopen'               => 'Totaal open taken',
'age'                     => 'Leeftijd',
'agerep'                  => 'Leeftijdrapport',
'eventsrep'               => 'Gebeurtenissenrapport',
'events'                  => 'Gebeurtenissen',
'Tasks'                   => 'Taken',
'opened'                  => 'Geopend',
'edited'                  => 'Bewerkt',
'assigned'                => 'Toegekend',
'within'                  => 'Periode',
'pastday'                 => 'Vorige dag',
'pastweek'                => 'Vorige week',
'pastmonth'               => 'Vorige maand',
'pastyear'                => 'Vorig jaar',
'nolimit'                 => 'Geen limiet',
'from'                    => 'Van',
'duein'                   => 'Geimplementeerd in',
'selectfromdate'          => 'Selecteer van-datum',
'selecttodate'            => 'Selecteer naar-datum',
'showvoters'              => 'Toon/verberg stemmers',
'roadmap'                 => 'Planning',
'roadmapfor'              => 'Planning voor versie',
'tasks'                   => 'Taken',
'completed'               => 'kompleet.',
'opentasks'               => 'open taken:',
'of'                      => '% van',
'severity5'               => 'Kritisch',
'severity4'               => 'Hoog',
'severity3'               => 'Gemiddeld',
'severity2'               => 'Laag',
'severity1'               => 'Zeer laag',
'Redirect'                => 'Doorsturen',
'redirectmsg'             => 'In het geval uw browser meta-redirections niet ondersteunt klik %sHERE%s om doorgestuurd te worden',
'allowclosedcomments'     => 'Sta commentaar aan gesloten taken toe',
'comment'                 => 'Commentaar',
'editowncomments'         => 'Bewerk eigen commentaar',
'reopened'                => 'Heropend',
'loading'                 => 'Bezig met laden...',
'notifyown'               => 'Stuur een notificatie voor eigen aanpassingen',
'youremail'               => 'Uw e-mailadres',
'thankyouforbug'          => 'Bedankt voor het rapporteren van uw probleem. U kunt de taak bekijken en de voortgang bestuderen met de volgende URL:',
'anonuser'                => 'Anonieme gebruiker',
'conflict'                => 'Bosting',
'file'                    => 'Bestand',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Grootte',
'projectgroup'            => 'Projectgroep',
'profile'                 => 'Profiel:',
'viewprofile'             => 'Bekijk profiel',
'regdate'                 => 'Geregisteerd sinds',
'tasksopened'             => 'Geopende taken',
'replyto'                 => 'Antwoord naar',
'notifytypes'             => 'Notificatietypen',
'pm.taskchanged'          => 'Taak veranderd',
'pm.taskreopened'         => 'Taak heropend',
'pm.depadded'             => 'Afhankelijkheid toegevoegd',
'pm.depremoved'           => 'Afhankelijkheid verwijderd',
'pmrequest'               => 'Verzoek aan projectleider',
'pmrequestdenied'         => 'Projectmaangerverzoek afgewezen',
'newassignee'             => 'Nieuwe persoon voor toegewezen personen',
'revdepadded'             => 'Omgekeerde afhankelijkheid toegevoegd',
'revdepaddedremoved'      => 'Omgekeerde afhankelijkheid verwijderd',
'assigneeadded'           => 'Persoon toegevoegd',
'addusergroup'            => 'Voeg gebruiker aan deze groep toe',
'groupmembers'            => 'Groepleden',
'deleteuser'              => 'Verwijder deze gebruiker',
'userdeleted'             => 'Gebruiker verwijderd',
'autoassign'              => 'Ken taken automatisch aan categorie-eigenaar aan',
'ssl'                     => 'SSL',
'updatewrong'             => 'De versiecontroleoptie is actief, maar er is een fout opgetreden bij het benaderen van de updateserver. Wellicht mag uw host geen uitgaande verbindingen aanmaken, of er zijn problemen met het netwerk. Bezoek de Flyspray webstek om er van verzekerd te zijn dat u de laatste versie draait.',
'deleteproject'           => 'Verwijder dit project en verplaats de inhoud naar',
'projectdeleted'          => 'Project succesvol verwijderd',
'feedforall'              => 'Feed voor alle projecten',
'usercreated'             => 'Gebruiker aangemaakt',
'created'                 => 'Gecreëerd',
'deleted'                 => 'Verwijderd',
'userid'                  => 'Gebruikers-ID',
'editassignments'         => 'Bewerk toegekende taken',
'preview'                 => 'Voorbeeld',
'anyprogress'             => 'Elke voortgang',
'tasksrelated'            => 'Taken gerelateerd aan deze taak',
'duplicatetasks'          => 'Dubbele versies van deze taak',
'databasemodfailed'       => 'Database-aanpassing mislukt. Mogelijke oorzaak is het hebben van onvoldoende rechten.',
'frequency'               => 'Frequentie',
'newuserregistered'       => 'Een nieuwe gebruiker heeft zich geregisteerd bij uw Flyspray installation. De gebruikersdetails zijn als volgt:',
'newuserregisterednotify' => 'Een nieuwe gebruiker heeft zich geregisteerd',
'notify_registration'     => 'Licht beheerders in bij een nieuwe gebruikersregistratie',
'textversion'             => 'Tekstversie',
'onlyprimary'             => 'Taken die geen andere taken blokkeren',
'switch'                  => 'Schakel over',
'max'                     => 'Max.',
'dates'                   => 'Data',
'selectduedatefrom'       => 'Beoogd vanaf',
'selectduedateto'         => 'tot',
'selectsincedatefrom'     => 'Veranderd vanaf',
'selectsincedateto'       => 'tot',
'selectdate'              => 'Selecteer datum',
'selectopenedfrom'        => 'Geopend vanaf',
'selectopenedto'          => 'tot',
'selectclosedfrom'        => 'Gesloten vanaf',
'selectclosedto'          => 'tot',
'startat'                 => 'Begin vanaf',
'hasattachment'           => 'Heeft een bijlage',
'private'                 => 'Privé',
'watching'                => 'In de gaten houden',
'alreadyvotedthistask'    => 'U heeft reeds voor deze taak gestemd',
'alreadyvotedthisday'     => 'U heeft reeds vandaag gestemd',
'visibility'              => 'Zichtbaarheid',
'public'                  => 'Publiekelijk',
'leaveemptyauto'          => 'Laat het wachtwoordveld leeg als u een wachtwoord toegewezen wilt krijgen.',
'novalidemail'            => 'U heeft geen geldig e-mailadres ingevuld.',
'novalidjabber'           => 'U heeft geen geldig Jabberadres ingevuld.',
'missingrequired'         => 'U heeft niet alle benodigde velden ingevuld.',
'entervalidusername'      => 'Gaarne vul een geldig gebruikers- en echte naam in.',
'couldnotaddusernotif'    => 'Kon de gebruiker niet toevoegen aan de ',
'defaulttask'             => 'Standaard taakomschrijving',
'all'                     => 'Alle',
'events.useraddedtoassignees'=> 'Gebruiker toegevoegd aan toegewezen personen',
'vote(s)'                 => 'Stem(men)',
'eventlog'                => 'Logboek',
'assignmentchanged'       => 'Toekenning aangepast',
'detailedinfo'            => 'Gedetailleerde informatie',
'All'                     => 'Alle',
'tasksireported'          => 'Taken die u heeft aangemeld',
'recentlyopened'          => 'Recentelijk geopend',
'stats'                   => 'Statistieken',
'totaltasks'              => 'Totaal aantal taken',
'mostwanted'              => 'Meest gewilde taken',
'defaultentry'            => 'Standaard opgavepagina',
'toplevel'                => 'Topniveau-overzicht',
'overview'                => 'Overzicht',
'error#'                  => 'Fout #',
'error1'                  => 'U heeft niet genoeg rechten om deze bijlage te bekijken.',
'error3'                  => 'Herhaalde actie, u wordt doorverwezen naar de hoofdpagina.',
'error4'                  => 'U heeft geen beheerdersrechten.',
'error5'                  => 'Die gebruiker bestaat niet.',
'error6'                  => 'Ongeldig beheerdersgebied.',
'error7'                  => 'Inloggen mislukt, verkeerde gebruikersnaam of wachtwoord.',
'error71'                 => 'Account voor %d minuten bevroren omdat er te veel mislukte inlogpogingen gedaan zijn.',
'error8'                  => 'U moet zowel een gebruikersnaam als een wachtwoord opgeven.',
'error9'                  => 'Onbekende taak, of u heeft niet genoeg rechten om de taak te bekijken.',
'error10'                 => 'Onbekende taak, of u heeft niet genoeg rechten om de taak te bekijken.',
'error101'                => 'U heeft niet genoeg rechten om deze taak te bekijken.',
'error102'                => 'U heeft niet genoeg rechten op deze taak te bekijken, wellicht helpt het om in te loggen.',
'error11'                 => 'U heeft geen toestemming om het commentaar te bewerken.',
'error12'                 => 'Dit is een ongeldige magische sleutel! Weet u zeker dat deze sleutel in uw notificatiebericht stond?',
'error13'                 => 'Anonieme gebruikers hebben geen profiel.',
'error14'                 => 'U heeft niet genoeg rechten om een nieuwe groep aan te maken.',
'error15'                 => 'U heeft niet genoeg rechten om een taak te openen.',
'error16'                 => 'U bent geen projectleider.',
'error17'                 => 'Ongeldig PM-gebied.',
'error18'                 => 'Ongeldige magische URL.',
'error19'                 => 'Die gebruiker bestaat niet.',
'error20'                 => 'Ongeldige databaseaanpassing.',
'error21'                 => 'Één of meer e-mails konden niet verstuurd worden. Controleer uw configuratiebestand.',
'error22'                 => 'Nieuwe gebruikersregistraties niet toegestaan.',
'error23'                 => 'Gebruiker of groep heeft geen toestemming om in te loggen.',
'error24'                 => 'Er is noch een dotprogramma, noch een publiekelijk toegankelijke dotserver ingesteld.',
'error25'                 => 'Roadmap alleen beschikbaar voor specifieke projecten.',
'done'                    => 'Klaar',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Project kon niet verwijderd worden.',
'GMT'                     => 'GMT',
'timezone'                => 'Tijdzone',
'accept'                  => 'Accepteer',
'reasonfordeinal'         => 'Reden voor weigering',
'pruneclosedlinks'        => 'Schoon gesloten links op',
'pruneclosedtasks'        => 'Schoon gesloten taken op',
'pagegenerated'           => 'Pagina en afbeeldig gegenereerd in %d seconden.',
'pruninglevel'            => 'Opschoonniveau',
'lastuser'                => 'De laatste gebruiker kan niet verwijderd worden.',
'allprivate'              => 'Alle projecten zijn privé.',
'deletegroup'             => 'Verwijder deze groep en verplaats de gebruikers naar',
'parent'                  => 'Ouder',
'ordertip'                => 'Op welke manier items geordend worden',
'showtip'                 => 'Toon dit item in de lijst',
'deletetip'               => 'Verwijder dit item van de lijst',
'del'                     => 'Verwijder',
'request1'                => 'Er is een verzoek gedaan om een taak te sluiten.',
'request2'                => 'Er is een verzoek gedaan om een taak te heropenen.',
'allpriorities'           => 'Alle prioriteiten',
'noroadmap'               => 'Geen planning beschikbaar, omdat er geen toekomstige versies bestaan binnen dit project.',
'expand'                  => 'Uitklappen',
'collapse'                => 'Inklappen',
'expandall'               => 'Alles uitklappen',
'collapseall'             => 'Alles inklappen',
'minpwsize'               => 'Minimale wachtwoordlengte is 5 karakters',
'passwordtoosmall'        => 'Wachtwoordlength is te klein',
'accountwaslocked'        => 'Uw account is uitgeschakeld, omdat er te veel mislukte inlogpogingen gedaan zijn.',
'failedattempts'          => 'Er hebben %d mislukte inlogpogingen plaatsgevonden.',
'groupnotexist'           => 'Geselecteerde groep bestaat niet in dit project.',
);

?>
