<?php
$permicons=array(
'view_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_groups_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_own_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_roadmap'=>'<span class="fa fa-stack"><i class="fa fa-road fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_history'=>'<span class="fa fa-stack"><i class="fa fa-history fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_reports'=>'<span class="fa fa-stack"><i class="fa fa-line-chart fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_estimated_effort'=>'<span class="fa fa-stack"><i class="fa fa-clock-o fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_current_effort_done'=>'<span class="fa fa-stack"><i class="fa fa-clock-o fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'track_effort'=>'<span class="fa fa-stack"><i class="fa fa-clock-o fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'open_new_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-plus fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'add_multiple_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-plus fa-stack" style="padding-top:8px;padding-top:8px;"></i></span>',
'modify_own_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-pencil fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'modify_all_tasks'=>'<span class="fa fa-stack"><i class="fa fa-tasks fa-stack-2x"></i><i class="fa fa-pencil fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'close_own_tasks'=>'<i class="fa fa-check fa-lg"></i>',
'close_other_tasks'=>'<i class="fa fa-check fa-lg"></i>',
'create_attachments'=>'<span class="fa fa-stack"><i class="fa fa-paperclip fa-flip-horizontal fa-stack-2x"></i><i class="fa fa-plus fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'delete_attachments'=>'<span class="fa fa-stack"><i class="fa fa-paperclip fa-flip-horizontal fa-stack-2x"></i><i class="fa fa-remove fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'assign_to_self'=>'<span class="fa fa-stack"><i class="fa fa-hand-o-right fa-stack-2x"></i></span>',
'assign_others_to_self'=>'<span class="fa fa-stack"><i class="fa fa-hand-o-right  fa-stack-2x"></i></span>',
'edit_assignments'=>'<span class="fa fa-stack"><i class="fa fa-hand-o-right fa-stack-2x"></i><i class="fa fa-pencil fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'add_votes'=>'<span class="fa fa-stack"><i class="fa fa-star-o fa-stack-2x"></i><i class="fa fa-plus fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'view_comments'=>'<span class="fa fa-stack"><i class="fa fa-comments fa-stack-2x"></i><i class="fa fa-eye fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'add_comments'=>'<span class="fa fa-stack"><i class="fa fa-comments fa-stack-2x"></i><i class="fa fa-plus fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'edit_comments'=>'<span class="fa fa-stack"><i class="fa fa-comments fa-stack-2x"></i><i class="fa fa-pencil fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'edit_own_comments'=>'<span class="fa fa-stack"><i class="fa fa-comments fa-stack-2x"></i><i class="fa fa-pencil fa-stack" style="padding-top:8px;padding-left:12px"></i></span>',
'delete_comments'=>'<span class="fa fa-stack"><i class="fa fa-comments fa-stack-2x"></i><i class="fa fa-remove fa-stack" style="padding-top:8px;padding-left:12px"></i></span>'
);
?>
