<?php
//
// This file is auto generated with langedit.php
// Characters are UTF-8 encoded
// 
// Be careful when editing this file manually, some text editors
// may convert text to UCS-2 or similar (16-bit) which is NOT
// readable by the PHP parser
// 
// Furthermore, nothing else than the language array is saved
// when using the langedit.php editor!
//
$translation = array(
'edituser'                => 'Επεξεργασία χρήστη',
'accountenabled'          => 'Ο λογαριασμός ενεργοποιήθηκε',
'editallusers'            => 'Προβολή όλων των χρηστών',
'username'                => 'Όνομα χρήστη',
'usersupdated'            => 'Οι χρήστες ενημερώθηκαν επιτυχώς',
'realname'                => 'Πραγματικό όνομα',
'emailaddress'            => 'Διεύθυνση ηλεκτρονικού ταχυδρομείου',
'jabberid'                => 'Αναγνωριστικό Jabber',
'profileimage'            => 'Εικόνα προφίλ',
'notifytype'              => 'Τύπος ειδοποίησης',
'group'                   => 'Ομάδα',
'enableaccounts'          => 'Ενεργοποίηση λογαριασμών',
'disableaccounts'         => 'Απενεργοποίηση λογαριασμών',
'deleteaccounts'          => 'Διαγραφή λογαριασμών',
'updatedetails'           => 'Ενημέρωση πληροφοριών',
'setglobally'             => 'Αυτή η προτίμηση έχει οριστεί καθολικά.',
'usergroupmanage'         => 'Διαχείριση χρηστών και ομάδων',
'newuser'                 => 'Εγγραφή νέου χρήστη',
'newuserbulk'             => 'Μαζική εγγραφή νέων χρηστών',
'bulkuserstoadd'          => 'Κατάλογος νέων χρηστών',
'optionsforallusers'      => 'Επιλογές για όλους τους νέους χρήστες',
'newgroup'                => 'Δημιουργία νέας ομάδας',
'yes'                     => 'Ναι',
'no'                      => 'Όχι',
'editgroup'               => 'Επεξεργασία ομάδας',
'groupname'               => 'Όνομα ομάδας',
'description'             => 'Περιγραφή',
'admin'                   => 'Ομάδα διαχειριστών',
'opennewtasks'            => 'Άνοιγμα νέων εργασιών',
'modifytasks'             => 'Τροποποίηση υπαρχουσών εργασιών',
'addcomments'             => 'Προσθήκη σχολίων',
'attachfiles'             => 'Επισύναψη αρχείων',
'vote'                    => 'Ψήφος',
'groupenabled'            => 'Δυνατότητα σύνδεσης',
'groupopen'               => 'Δυνατότητα σύνδεσης',
'tasktypelist'            => 'Λίστα τύπων εργασιών',
'categorylist'            => 'Λίστα κατηγοριών',
'oslist'                  => 'Λίστα λειτουργικών συστημάτων',
'resolutionlist'          => 'Λίστα επιλύσεων',
'versionlist'             => 'Λίστα εκδόσεων',
'severitylist'            => 'Λίστα βαθμών σοβαρότητας',
'listnote'                => 'Σημείωση: Αν ξετσεκάρετε το κουτάκι «Εμφάνιση» μπορεί να μεταβληθούν κάποιες εργασίες εφόσον βρίσκονται σε κατάσταση επεξεργασίας. Αν αλλάξετε το πεδίο «Όνομα» θα τροποποιηθούν όλες οι εργασίες με αυτό το όνομα. Στοιχεία που δεν μπορούν να διαγραφούν είναι είτε προστατευμένα γιατί χρειάζονται για σωστή λειτουργία, είτε χρησιμοποιούνται σε εργασίες.',
'name'                    => 'Όνομα',
'order'                   => 'Σειρά',
'back'                    => 'Πίσω',
'text'                    => 'Κείμενο',
'highlight'               => 'Επισήμανση',
'show'                    => 'Εμφάνιση',
'owner'                   => 'Κάτοχος',
'selectowner'             => 'Επιλογή κατόχου',
'update'                  => 'Ενημέρωση',
'addnew'                  => 'Προσθήκη νέου στοιχείου',
'flysprayprefs'           => 'Προτιμήσεις Flyspray',
'projecttitle'            => 'Τίτλος έργου',
'baseurl'                 => 'Διεύθυνση URL βάσης για αυτήν την εγκατάσταση',
'replyaddress'            => 'Διεύθυνση απάντησης ηλεκτρονικού ταχυδρομείου για ειδοποιήσεις',
'themestyle'              => 'Θέμα / Στυλ',
'customstyle'             => 'τροποποίηση',
'language'                => 'Γλώσσα',
'anonview'                => 'Να επιτρέπεται σε ανώνυμους χρήστες να προβάλλουν εργασίες',
'allowanon'               => 'Να επιτρέπεται σε ανώνυμους χρήστες να ανοίγουν νέες εργασίες',
'never'                   => 'Ποτέ',
'anonymously'             => 'Ανώνυμα',
'afterregister'           => 'Μόνο μετά από εγγραφή',
'spamproof'               => 'Ενεργοποίηση κωδικού επαλήθευσης για εγγραφές νέων χρηστών',
'anongroup'               => 'Ομάδα για εγγραφές νέων χρηστών',
'groupassigned'           => 'Στα μέλη αυτών των ομάδων μπορούν να ανατίθενται ενέργειες',
'forcenotify'             => 'Εξαναγκασμός των ειδοποιήσεων εργασιών σε',
'neversend'               => 'Να μην αποστέλλονται ποτέ',
'userchoose'              => 'Να μπορεί ο κάθε χρήστης να επιλέγει',
'email'                   => 'Ηλεκτρονικό ταχυδρομείο',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Προεπιλεγμένος κάτοχος κατηγορίας',
'noone'                   => 'Κανείς',
'jabbernotify'            => 'Ειδοποιήσεις Jabber',
'jabberserver'            => 'Διακομιστής',
'jabberport'              => 'Θύρα',
'jabberuser'              => 'Όνομα χρήστη λογαριασμού',
'jabberpass'              => 'Συνθηματικό λογαριασμού',
'saveoptions'             => 'Αποθήκευση επιλογών',
'editcomment'             => 'Επεξεργασία σχολίου',
'commentby'               => 'Σχόλιο από',
'saveeditedcomment'       => 'Αποθήκευση επεξεργασμένου σχολίου',
'projectprefs'            => 'Προτιμήσεις έργου',
'pagetitle'               => 'Τίτλος σελίδας',
'defaultproject'          => 'Προεπιλεγμένο έργο',
'projectlists'            => 'Λίστα έργων',
'showlogo'                => 'Εμφάνιση εικόνας λογοτύπου τίτλου',
'showgravatars'           => 'Εμφάνιση Gravatar',
'emailNoHTML'             => 'Όχι HTML στα μηνύματα ηλεκτρονικού ταχυδρομείου',
'intromessage'            => 'Εισαγωγικό μήνυμα',
'active'                  => 'ενεργό',
'inactive'                => 'μη ενεργό',
'isactive'                => 'Το έργο είναι ενεργό',
'showinactive'            => 'Εμφάνιση ανενεργών έργων',
'hideinactive'            => 'Απόκρυψη ανενεργών έργων',
'createproject'           => 'Δημιουργία νέου έργου',
'nopermission'            => 'Δεν έχετε εξουσιοδότηση να χρησιμοποιήσετε αυτήν τη σελίδα.',
'listordertip'            => 'Η σειρά με την οποίαν αυτά τα στοιχεία θα εμφανίζονται στη λίστα',
'listshowtip'             => 'Εμφάνιση αυτού του στοιχείου στη λίστα',
'categoryownertip'        => 'Αυτό το άτομο θα λάβει ειδοποιήσεις όταν ανοιχτεί εργασία σε αυτήν την κατηγορία',
'categoryparenttip'       => 'Η μητρική κατηγορία κάτω από την οποία θα υπαχθεί αυτή εδώ η κατηγορία',
'notsubcategory'          => 'Καμία (κατηγορία ανωτάτου επιπέδου)',
'showinlineimages'        => 'Εμφάνιση συνημμένων εικόνων ένθετα στο κείμενο',
'dateformat'              => 'Μορφή ημερομηνίας',
'dateformat_extended'     => 'Αναλυτική μορφή ημερομηνίας',
'cache_feeds'             => 'Προσωρινή αποθήκευση ροών',
'no_cache'                => 'Χωρίς προσωρινή αποθήκευση',
'cache_disk'              => 'Προσωρινή αποθήκευση στο δίσκο',
'cache_db'                => 'Προσωρινή αποθήκευση στη βάση δεδομένων',
'subcategoryof'           => 'Υποκατηγορία του',
'visiblecolumns'          => 'Στήλες που να εμφανίζονται στη λίστα εργασιών',
'visiblefields'           => 'Πεδία κατά την προσθήκη/επεξεργασία/προβολή εργασίας',
'tense'                   => 'Χρόνος',
'listtensetip'            => 'Παρελθόν, παρόν και μέλλον',
'past'                    => 'Παρελθόν',
'present'                 => 'Παρόν',
'future'                  => 'Μέλλον',
'oldpass'                 => 'Παλιό συνθηματικό',
'nooldpass'               => 'Δεν ορίστηκε παλιό συνθηματικό',
'oldpasswrong'            => 'Το παλιό συνθηματικό ήταν λάθος',
'changepass'              => 'Αλλαγή συνθηματικού',
'confirmpass'             => 'Επιβεβαίωση συνθηματικού',
'projectmanager'          => 'Διαχειριστής έργου',
'viewtasks'               => 'Προβολή εργασιών',
'modifyowntasks'          => 'Τροποποίηση ιδίων εργασιών',
'modifyalltasks'          => 'Τροποποίηση μη ιδίων εργασιών',
'viewcomments'            => 'Προβολή σχολίων',
'editcomments'            => 'Επεξεργασία σχολίων',
'deletecomments'          => 'Διαγραφή σχολίων',
'viewattachments'         => 'Προβολή συνημμένων',
'createattachments'       => 'Δημιουργία συνημμένων',
'deleteattachments'       => 'Διαγραφή συνημμένων',
'viewhistory'             => 'Προβολή ιστορικού',
'closeowntasks'           => 'Κλείσιμο ιδίων εργασιών',
'closeothertasks'         => 'Κλείσιμο μη ιδίων εργασιών',
'assigntoself'            => 'Αυτοανάθεση εργασιών αν δεν είναι ήδη ανατεθειμένες',
'assignotherstoself'      => 'Αυτοανάθεση εργασιών που είναι ανατεθειμένες σε άλλους',
'viewreports'             => 'Προβολή καταγραφής συμβάντων',
'othersview'              => 'Να επιτρέπεται στον οποιονδήποτε να προβάλλει αυτό το έργο',
'othersviewroadmap'       => 'Να επιτρέπεται σε οποιονδήποτε να δει το χάρτη πορείας αυτού του έργου',
'usersandgroups'          => 'Χρήστες και ομάδες',
'globalgroup'             => 'Καθολική ομάδα',
'globalgroups'            => 'Καθολικές ομάδες',
'defaultglobalgroup'      => 'Προεπιλεγμένη καθολική ομάδα για νέους χρήστες',
'addtogroup'              => 'Προσθήκη στην ομάδα',
'moveuserstogroup'        => 'Μετακίνηση χρηστών στην ομάδα',
'nogroup'                 => 'Καμία ομάδα - Αφαίρεση από το έργο',
'eventdesc'               => 'Περιγραφή γεγονότος',
'requestedby'             => 'Το αίτημα έγινε από',
'daterequested'           => 'Ημερομηνία αιτήματος',
'closetask'               => 'Κλείσιμο εργασίας',
'reopentask'              => 'Εν νέου άνοιγμα εργασίας',
'applymember'             => 'Αίτηση για να γίνετε μέλος στο έργο',
'forcurrentproj'          => 'Για το τρέχον έργο',
'lostpw'                  => 'Ανάκτηση απωλεσθέντος συνθηματικού',
'lostpwexplain'           => 'Εισαγάγετε το όνομα χρήστη σας για να σας αποσταλεί ένας σύνδεσμος για να αλλάξετε το συνθηματικό σας. Αυτός ο σύνδεσμος θα αποσταλεί στην διεύθυνση ειδοποιήσεων που έχετε ορίσει στο προφίλ σας.',
'sendlink'                => 'Αποστολή συνδέσμου',
'savenewpass'             => 'Αποθήκευση νέου συνθηματικού',
'anonreg'                 => 'Να επιτρέπονται εγγραφές νέων χρηστών',
'allowanonopentask'       => 'Να επιτρέπεται σε ανώνυμους χρήστες να ανοίγουν εργασίες',
'editglobalgroup'         => 'Επεξεργασία καθολικής ομάδας',
'editgroupforproj'        => 'Επεξεργασία ομάδας έργου',
'notshownforadmin'        => 'Οι άδειες για την ομάδα διαχειριστών δεν εμφανίζονται. Δεν χρειάζεται να τις επεξεργαστείτε.',
'general'                 => 'Γενικά',
'userregistration'        => 'Εγγραφή χρήστη',
'notifications'           => 'Ειδοποιήσεις',
'resetoptions'            => 'Επαναφορά επιλογών',
'preferences'             => 'Προτιμήσεις',
'tasktypes'               => 'Τύποι εργασιών',
'resolutions'             => 'Επιλύσεις',
'categories'              => 'Κατηγορίες',
'operatingsystems'        => 'Λειτουργικά συστήματα',
'versions'                => 'Εκδόσεις',
'admintoolboxlong'        => 'Εργαλειοθήκη διαχειριστή',
'newproject'              => 'Νέο έργο',
'delete'                  => 'Διαγραφή',
'link'                    => 'Υπερσύνδεσμος',
'referencelinks'          => 'Υπερσύνδεσμοι αναφοράς:',
'listdeletetip'           => 'Διαγραφή αυτού του στοιχείου από τη λίστα',
'lookandfeel'             => 'Όψη και αίσθηση',
'globaltheme'             => 'Καθολικό θέμα',
'emailnotify'             => 'Ειδοποιήσεις ηλεκτρονικού ταχυδρομείου',
'fromaddress'             => 'Από τη διεύθυνση',
'smtpserver'              => 'Διακομιστής SMTP',
'smtpuser'                => 'Όνομα χρήστη SMTP',
'smtppass'                => 'Συνθηματικό SMTP',
'addrewrite'              => 'Χρήση μεταγραφής διεύθυνσης',
'usereminderdaemon'       => 'Ενεργοποίηση δαίμονα υπενθυμίσεων παρασκηνίου',
'tasksperpage'            => 'Εργασίες ανά σελίδα της λίστας εργασιών',
'addtoassignees'          => 'Αυτοπροσθήκη στους αναδόχους',
'taskstatuses'            => 'Καταστάσεις εργασιών',
'canvote'                 => 'Δικαίωμα ψήφου σε εργασίες',
'loginsuccessful'         => 'Επιτυχής σύνδεση.',
'youareloggedout'         => 'Έχετε αποσυνδεθεί.',
'waitwhiletransfer'       => 'Παρακαλούμε περιμένετε καθώς μεταφέρεστε...',
'clicknowait'             => 'Κάντε κλικ εδώ αν δεν επιθυμείτε να περιμένετε.',
'accountdisabled'         => 'Ο λογαριασμός σας έχει απενεργοποιηθεί. Επικοινωνήστε με έναν πλήρη διαχειριστή.',
'task'                    => 'Εργασία',
'edittask'                => 'Επεξεργασία αυτής της εργασίας',
'openedby'                => 'Ανοίχτηκε από',
'editedby'                => 'Τελευταία επεξεργασία από',
'tasktype'                => 'Τύπος εργασίας',
'category'                => 'Κατηγορία',
'status'                  => 'Κατάσταση',
'assignedto'              => 'Ανάδοχος',
'operatingsystem'         => 'Λειτουργικό σύστημα',
'severity'                => 'Σοβαρότητα',
'reportedversion'         => 'Η αναφορά έγινε στην έκδοση',
'dueinversion'            => 'Αναμενόμενη στην έκδοση',
'defaultdueinversion'     => 'Προεπιλογή για νέες εργασίες της έκδοσης στην οποία η εργασία θα είναι αναμενόμενη',
'undecided'               => 'Μη αποφασισμένη',
'percentcomplete'         => 'Ολοκληρωμένη σε ποσοστό',
'details'                 => 'Λεπτομέρειες',
'savedetails'             => 'Αποθήκευση λεπτομερειών',
'canceledit'              => 'Ακύρωση επεξεργασίας',
'anonymous'               => 'Ανώνυμος υποβάλλων',
'complete'                => 'ολοκληρωμένη',
'closedby'                => 'Κλείστηκε από',
'reasonforclosing'        => 'Αιτιολογία κλεισίματος:',
'reopenthistask'          => 'Άνοιγμα εκ νέου αυτής της εργασίας',
'comments'                => 'Σχόλια',
'attachments'             => 'Συνημμένα',
'relatedtasks'            => 'Σχετικές εργασίες',
'edit'                    => 'Επεξεργασία',
'addcomment'              => 'Προσθήκη σχολίου',
'fileuploadedby'          => 'Το αρχείο ανέβηκε από',
'uploadafile'             => 'Επισύναψη αρχείου',
'addalink'                => 'Προσθήκη υπερσυνδέσμου',
'addanotherlink'          => 'Προσθήκη κι άλλου υπερσυνδέσμου',
'uploadnow'               => 'Ανέβασμα τώρα!',
'thesearerelated'         => 'Αυτές οι εργασίες σχετίζονται με αυτήν την εργασία',
'remove'                  => 'Κατάργηση',
'addnewrelated'           => 'Προσθήκη νέα σχετικής εργασίας',
'add'                     => 'Προσθήκη',
'otherrelated'            => 'Άλλες εργασίες με τις οποίες σχετίζεται αυτή η εργασία',
'receivenotify'           => 'Αυτοί οι χρήστες θα λάβουν αναλυτικές ειδοποιήσεις όταν τροποποιηθεί αυτή η εργασία.',
'addusertolist'           => 'Προσθήκη χρήστη σε αυτή τη λίστα',
'addtolist'               => 'Προσθήκη σε λίστα',
'addmyself'               => 'Προσθήκη του εαυτού μου σε αυτήν τη λίστα',
'removemyself'            => 'Αφαίρεση του εαυτού μου από αυτήν τη λίστα',
'theseusersnotify'        => 'Αυτοί οι χρήστες θα λάβουν αναλυτικές ειδοποιήσεις οποτεδήποτε τροποποιηθεί αυτή η εργασία.',
'attachedtoproject'       => 'Συνημμένη στο έργο',
'reminders'               => 'Υπενθυμίσεις',
'system'                  => 'Σύστημα',
'systemvalues'            => 'Λίστα τιμών σε εύρος συστήματος',
'projectvalues'           => 'Λίστα τιμών στο συγκεκριμένο έργο',
'remindthisuser'          => 'Υπενθύμιση σε αυτόν το χρήστη',
'thisoften'               => 'Τόσο συχνά',
'startafter'              => 'Αναμονή πριν την εκκίνηση των υπενθυμίσεων',
'hour'                    => 'ώρα',
'hours'                   => 'Ώρα(ες)',
'day'                     => 'ημέρα',
'days'                    => 'Μέρα(ες)',
'week'                    => 'εβδομάδα',
'weeks'                   => 'Εβδομάδα(ες)',
'addreminder'             => 'Προσθήκη υπενθύμισης',
'defaultreminder'         => 'Αυτή είναι μια υπενθύμιση για να κοιτάξετε την ακόλουθη εργασία στο Flyspray:',
'message'                 => 'Μήνυμα',
'closed'                  => 'Κλεισμένες',
'filename'                => 'Όνομα αρχείου:',
'date'                    => 'Ημερομηνία',
'filesize'                => 'Μέγεθος αρχείου:',
'closurecomment'          => 'Συμπληρωματικές παρατηρήσεις σχετικά με το κλείσιμο:',
'history'                 => 'Ιστορικό',
'nohistory'               => 'Δεν υπάρχει διαθέσιμο ιστορικό.',
'eventdate'               => 'Ημερομηνία',
'user'                    => 'Χρήστης',
'event'                   => 'Συμβάν',
'fieldchanged'            => 'Το πεδίο άλλαξε',
'taskopened'              => 'Άνοιγμα εργασίας',
'taskreopened'            => 'Εκ νέου άνοιγμα εργασίας',
'taskclosed'              => 'Κλείσιμο εργασίας',
'commentadded'            => 'Προσθήκη σχολίου',
'commentedited'           => 'Τροποποίηση σχολίου',
'commentdeleted'          => 'Διαγραφή σχολίου',
'attachmentadded'         => 'Προσθήκη συνημμένου',
'attachmentdeleted'       => 'Διαγραφή συνημμένου',
'taskedited'              => 'Τροποποίηση λεπτομερειών της εργασίας',
'notificationadded'       => 'Ο χρήστης προστέθηκε στη λίστα ειδοποιήσεων',
'notificationdeleted'     => 'Ο χρήστης αφαιρέθηκε από τη λίστα ειδοποιήσεων',
'relatedadded'            => 'Η σχετική εργασία προστέθηκε',
'relateddeleted'          => 'Η σχετική εργασία καταργήθηκε',
'taskassigned'            => 'Η εργασία ανατέθηκε σε',
'taskreassigned'          => 'Η εργασία ανατέθηκε σε',
'assignmentremoved'       => 'Η εργασία ανατέθηκε εκ νέου σε',
'summary'                 => 'Σύνοψη',
'addedasrelated'          => 'Η εργασία προστέθηκε στη λίστα με τις σχετικές εργασίες της',
'deletedasrelated'        => 'Η εργασία αφαιρέθηκε από τη λίστα με τις σχετικές εργασίες της',
'reminderadded'           => 'Η υπενθύμιση προστέθηκε',
'reminderdeleted'         => 'Η υπενθύμιση καταργήθηκε',
'priority'                => 'Προτεραιότητα',
'previousvalue'           => 'Προηγούμενη τιμή',
'newvalue'                => 'Νέα τιμή',
'selectareason'           => 'Επιλογή αιτιολογίας',
'assigntome'              => 'Ανάθεση σε εμένα',
'reopenrequest'           => 'Αίτημα να ανοίξει εκ νέου',
'requestclose'            => 'Αίτημα κλεισίματος',
'ownershiptaken'          => 'Ο χρήστης ανέλαβε την κυριότητα',
'closerequestmade'        => 'Αίτημα κλεισίματος εργασίας',
'reopenrequestmade'       => 'Αιτηθέν εκ νέου άνοιγμα εργασίας',
'taskdependson'           => 'Αυτή η εργασία εξαρτάται από',
'taskdependsontask'       => 'Η εργασία εξαρτάται από',
'taskdependsontasks'      => 'Η εργασία εξαρτάται από',
'taskblock'               => 'Η εργασία κωλύει το κλείσιμο των',
'taskblocks'              => 'Αυτή η εργασία κωλύει αυτές να κλειστούν',
'depadded'                => 'Η εξάρτηση προστέθηκε',
'depaddedother'           => 'Αυτή η εργασία προστέθηκε ως εξάρτηση',
'depremoved'              => 'Η εξάρτηση καταργήθηκε',
'depremovedother'         => 'Αυτή η εργασία καταργήθηκε από τη λίστα εξαρτήσεων άλλης εργασίας',
'showdetailserror'        => 'Εκείνη η εργασία δεν υπάρχει, ή δεν έχετε εξουσιοδότηση για να τη δείτε.',
'makeprivate'             => 'να γίνει ιδιωτική',
'makepublic'              => 'να γίνει δημόσια',
'taskmadeprivate'         => 'Η εργασία έγινε ιδιωτική',
'taskmadepublic'          => 'Η ιδιωτικότητα καταργήθηκε - η εργασία έγινε δημόσια',
'confirmdeletecomment'    => 'Σίγουρα να διαγραφεί αυτό το σχόλιο; Όλα τα συνημμένα θα διαγραφούν επίσης!',
'attachementswilldeleted' => 'Όλα τα συνημμένα θα διαγραφούν επίσης!',
'confirmdeleteattach'     => 'Σίγουρα να διαγραφεί αυτό το συνημμένο;',
'selectedhistory'         => 'Γίνεται εμφάνιση επιλεγμένων λεπτομεριών ιστορικού',
'showallhistory'          => 'Εμφάνιση καρτέλας πλήρους ιστορικού ξανά',
'hidethis'                => 'Απόκρυψη αυτής της περιοχής ξανά',
'mark100'                 => 'Σήμανση εργασίας ως 100% ολοκληρωμένη',
'watchtask'               => 'παρακολούθηση εργασίας',
'stopwatching'            => 'σταμάτημα παρακολούθησης',
'commentlink'             => 'Σύνδεσμος προς αυτό το σχόλιο',
'submitreq'               => 'Υποβολή αιτήματος',
'reasonforreq'            => 'Αιτιολογία για το αίτημα',
'pmreqdenied'             => 'Ο διαχειριστής έργου αρνήθηκε το αίτημα',
'taskpendingreq'          => 'Η ενέργεια του διαχειριστή έργου εκκρεμεί. Βλ. καρτέλα Ιστορικό για λεπτομέρειες.',
'previoustask'            => 'Προηγούμενη εργασία',
'nexttask'                => 'Επόμενη εργασία',
'duedate'                 => 'Προθεσμία',
'attachnoperms'           => 'Υπάρχουν συνημμένα με αυτό το σχόλιο, αλλά δεν έχετε εξουσιοδότηση να τα δείτε.',
'linknoperms'             => 'Υπάρχουν υπερσύνδεσμοι με αυτό το σχόλιο, αλλά δεν έχετε εξουσιοδότηση να τους προβάλετε.',
'open'                    => 'Ανοικτές',
'depgraph'                => 'Προβολή γραφήματος εξάρτησης',
'reset'                   => 'Επαναφορά',
'selectusers'             => 'Επιλογή χρηστών...',
'addmetoassignees'        => 'Να προστεθώ στους αναδόχους',
'addedtoassignees'        => 'Ο χρήστης προστέθηκε στη λίστα αναδόχων',
'dependencygraph'         => 'Γράφημα εξαρτήσης',
'attachanotherfile'       => 'Επισύναψη κι άλλου αρχείου',
'OK'                      => 'Εντάξει',
'addvote'                 => 'προσθήκη ψήφου',
'disable_lostpw'          => 'Απενεργοποίηση ανάκτησης απολεσθέντος συνθηματικού',
'disable_changepw'        => 'Απενεργοποίηση δημιουργίας/επεξεργασίας συνθηματικού',
'notifyfromfs'            => 'Ειδοποίηση από Flyspray',
'autogenerated'           => 'ΑΥΤΟ ΕΙΝΑΙ ΕΝΑ ΑΥΤΟΜΑΤΑ ΔΗΜΙΟΥΡΓΗΜΕΝΟ ΜΗΝΥΜΑ, ΜΗΝ ΑΠΑΝΤΗΣΕΤΕ',
'forward'                 => 'Προς τα εμπρός',
'previous'                => 'Προηγούμενη',
'next'                    => 'Επόμενη',
'first'                   => 'Πρώτη',
'last'                    => 'Τελευταία',
'page'                    => 'Σελίδα %d από %d',
'search'                  => 'Αναζήτηση',
'alltasktypes'            => 'Όλοι οι τύποι εργασιών',
'allseverities'           => 'Όλοι οι βαθμοί σοβαρότητας',
'alldevelopers'           => 'Όλοι οι προγραμματιστές',
'notyetassigned'          => 'Μη ανατεθειμένη ακόμα',
'allcategories'           => 'Όλες οι κατηγορίες',
'allstatuses'             => 'Όλες οι καταστάσεις',
'allopentasks'            => 'Όλες οι ανοιχτές εργασίες',
'sortthiscolumn'          => 'Ταξινόμηση με βάση αυτήν τη στήλη',
'id'                      => 'FS#',
'project'                 => 'Έργο',
'dateopened'              => 'Ανοιγμένη στις',
'progress'                => 'Πρόοδος',
'searchthisproject'       => 'Αναζήτηση σε αυτό το έργο για',
'dueanyversion'           => 'Αναμενόμενη σε οποιαδήποτε έκδοση',
'anyversion'              => 'Οποιαδήποτε έκδοση',
'dueversion'              => 'Αναμενόμενη στην έκδοση',
'lastedit'                => 'Τελευταία επεξεργασία',
'os'                      => 'Λειτουργικό σύστημα',
'reportedin'              => 'Αναφέρθηκε στις',
'taskrange'               => 'Εμφάνιση εργασιών %d - %d από %d',
'noresults'               => 'Η αναζήτησή σας δεν επέστρεψε κανένα αποτέλεσμα.',
'takeaction'              => 'Εκτέλεση ενέργειας',
'watchtasks'              => 'Παρακολούθηση επιλεγμένων εργασιών',
'stopwatchingtasks'       => 'Διακοπή παρακολούθησης επιλεγμένων εργασιών',
'assigntaskstome'         => 'Ανάθεση επιλεγμένων εργασιών σε εμένα',
'dueby'                   => 'Προθεσμία',
'dueanytime'              => 'Προσθεσμία οποτεδήποτε',
'selectduedate'           => 'Επιλογή προθεσμίας',
'toggleselected'          => 'Αντιστροφή επιλογής',
'due'                     => 'Λήξη',
'assignedtome'            => 'Ανατεθειμένες σε εμένα',
'tasklist'                => 'Λίστα εργασιών',
'dateclosed'              => 'Ημερομηνία κλεισίματος',
'advanced'                => 'Προχωρημένη αναζήτηση',
'searchcomments'          => 'Αναζήτηση σε σχόλια',
'searchforall'            => 'Αναζήτηση για όλες τις λέξεις',
'anonusers'               => 'Ανώνυμοι χρήστες',
'miscellaneous'           => 'Διάφορα',
'users'                   => 'Χρήστες',
'taskproperties'          => 'Ιδιότητες εργασίας',
'selectsincedate'         => 'Επιλογή αλλαγμένων από τις',
'changedsince'            => 'Τροποποιήθηκε από',
'updatefs'                => 'Παρακαλούμε να αναβαθμίσετε το Flyspray.',
'currentversion'          => 'Η τρέχουσα έκδοσή σας είναι',
'latestversion'           => 'και η πιο πρόσφατη έκδοση είναι',
'hidemessage'             => '(υπενθύμιση αργότερα)',
'saveas'                  => 'Αποθήκευση αναζήτησης ως',
'nosearches'              => 'Δεν υπάρχουν αποθηκευμένες αναζητήσεις',
'saving'                  => 'Αποθήκευση σε εξέλιξη...',
'votes'                   => 'Ψήφοι',
'tovote'                  => 'Ψήφος',
'allclosedtasks'          => 'Όλες οι κλεισμένες εργασίες',
'password'                => 'Συνθηματικό',
'login'                   => 'Σύνδεση!',
'rememberme'              => 'Να με θυμάσαι',
'lostpassword'            => 'Απώλεια συνθηματικού;',
'lostpwforfs'             => 'Απώλεια συνθηματικού για το Flyspray',
'lostpwmsg1'              => "Χαίρετε.\n\nΈχω απωλέσει το συνθηματικό μου στο Flyspray στις _",
'lostpwmsg2'              => ", παρακαλώ να μου χορηγήσετε ένα νέο συνθηματικό.\n\nΌνομα χρήστη: _",
'regards'                 => "Φιλικά,\n\n",
'yourusername'            => '_ το όνομα χρήστη σας _',
'locale'                  => 'el-GR',
'filenotexist'            => 'Το αρχείο δεν υπάρχει, ή δεν έχετε εξουσιοδότηση πρόσβασης σε αυτό.',
'showtask'                => 'Εμφάνιση εργασίας',
'now'                     => 'Τώρα',
'go'                      => 'Μετάβαση!',
'opentaskanon'            => 'Άνοιγμα νέας εργασίας ανώνυμα',
'register'                => 'Εγγραφή',
'addnewtask'              => 'Νέα εργασία',
'reports'                 => 'Μητρώο συμβάντων',
'editmydetails'           => 'Επεξεργασία των στοιχείων μου',
'logout'                  => 'Αποσύνδεση',
'disabledaccount'         => 'Ο λογαριασμός σας έχει απενεργοποιηθεί!<br />Γίνεται άμεση αποσύνδεσή σας...',
'poweredby'               => 'Λειτουργεί με το Flyspray',
'sponsoredby'             => 'Το Flyspray είναι με υπερηφάνεια υπό την αιγίδα του',
'projects'                => 'Έργα',
'allprojects'             => 'Όλα τα έργα',
'selectproject'           => 'για το έργο:',
'tasksall'                => 'Όλες οι εργασίες',
'tasksassigned'           => 'Εργασίες που έχουν ανατεθεί σε εμένα',
'tasksreported'           => 'Εργασίες που έχουν αναφερθεί από εμένα',
'taskswatched'            => 'Εργασίες που παρακολουθώ',
'mysearch'                => 'Οι αναζητήσεις μου',
'admintoolbox'            => 'Εργαλειοθήκη διαχειριστή',
'manageproject'           => 'Διαχείριση έργου',
'permissions'             => 'Προβολή αδειών',
'hide'                    => 'Απόκρυψη',
'pendingreq'              => 'εκκρεμή αιτήματα ΔΕ',
'errorpage'               => "Το Flyspray δεν μπορεί να παράσχει τη σελίδα που ζητήσατε. \nΊσως ζητήσατε μια εργασία που δεν υπάρχει, ή δεν έχετε εξουσιοδότηση να προβάλετε τη σελίδα που θέλατε.<br /><br /> \nΜπορεί να αποπειραθήκατε να χρησιμοποιήσετε ένα πονηρό URL για να αλληλεπιδράσετε με τη βάση δεδομένων χρησιμοποιώντας ένεση SQL. Αν αυτό είναι αλήθεια, πηγαίνετε τιμωρία στη γωνία να αναλογιστείτε τις πράξεις. Όταν επιστρέψετε, σας παρακαλούμε να μην το ξανακάνετε!",
'permissionsforproject'   => 'Άδειες για _',
'switchto'                => 'Εναλλαγή σε',
'lastsearch'              => 'Τελευταία αναζήτηση',
'modify'                  => 'Τροποποίηση',
'noticefrom'              => 'Ειδοποίηση από',
'hasopened'               => 'ΑΝΟΙΞΕ ΜΙΑ ΝΕΑ εργασία στο Flyspray και την ανέθεσε σε εσάς:',
'moreinfonew'             => 'Μπορείτε να βρείτε περισσότερες πληροφορίες σχετικά με αυτό το bug στη σελίδα του Flyspray:',
'newtaskcategory'         => 'Μια νέα εργασία Flyspray έχει ανοιχτεί σε αυτήν την κατηγορία',
'categoryowner'           => 'Αυτό το λαμβάνετε γιατί έχετε καταχωριστεί ως κάτοχος της κατηγορίας.',
'tasksummary'             => 'Σύνοψη εργασίας:',
'newtaskadded'            => 'Η νέα σας εργασία έχει προστεθεί.',
'summaryanddetails'       => 'Πρέπει να συμπληρώσετε και τη σύνοψη και τις αναλυτικές πληροφορίες.',
'summaryrequired'         => 'Χρειάζεται να συμπληρώσετε μια σύντομη σύνοψη της εργασίας.',
'goback'                  => 'Επιστροφή πίσω.',
'messagefrom'             => 'Αυτό είναι ένα μήνυμα από το σύστημα παρακολούθησης σφαλμάτων Flyspray στις _',
'hasjustmodified'         => 'μόλις τροποποίησε  την ακόλουθη εργασία.',
'changedfields'           => 'Τα τροποποιημένα πεδία έχουν πρόθεμα αστερίσκους (**)',
'moreinfomodify'          => 'Μπορείτε να βρείτε περισσότερες πληροφορίες για αυτήν την εργασία στην ακόλουθη διεύθυνση URL:',
'nolongerassigned'        => 'Η ακόλουθη εργασία δεν είναι πια ανατεθειμένη σε εσάς. Είναι πλέον ανατεθειμένη σε',
'hasassigned'             => 'σας ανέθεσε την ακόλουθη εργασία στο Flyspray:',
'taskupdated'             => 'Η εργασία ενημερώθηκε.',
'tasksupdated'            => 'Οι εργασίες έχουν ενημερωθεί.',
'hasclosedassigned'       => 'έκλεισε την ακόλουθη εργασία στο Flyspray η οποία σας είχε ανατεθεί:',
'unassigned'              => 'Μη ανατεθειμένη',
'hasclosed'               => 'έκλεισε την ακόλουθη εργασία',
'youonnotify'             => 'Αυτό το λαμβάνετε γιατί είστε στη λίστα ειδοποιήσεων.',
'taskclosedmsg'           => 'Η εργασία έχει κλειστεί.',
'returntotask'            => 'Επιστροφή στην περιγραφή της εργασίας',
'backtoindex'             => 'Επιστροφή στη λίστα εργασιών',
'noclosereason'           => 'Δεν επιλέξατε αιτιολογία για το κλείσιμο αυτής της εργασίας.',
'hasreopened'             => 'άνοιξε εκ νέου την ακόλουθη εργασία στο Flyspray την οποία είχατε κλείσει:',
'taskreopenedmsg'         => 'H εργασία ανοίχτηκε εκ νέου.',
'backtotask'              => 'Επιστροφή στην εργασία.',
'commentaddedmsg'         => 'Το σχόλιο προστέθηκε.',
'commenttoassigned'       => 'προσέθεσε ένα σχόλιο σε μια εργασία που σας έχει ανατεθεί:',
'commenttotask'           => 'προσέθεσε το ακόλουθο σχόλιο σε αυτήν την εργασία.',
'nocommententered'        => 'Πρέπει να εισαγάγετε όντως κάποιο σχόλιο πριν κάνετε κλικ στο κουμπί υποβολής.',
'fillinfields'            => 'Δεν συμπληρώσατε όλα τα πεδία.',
'notcurrentpass'          => 'Δεν είναι αυτό το τρέχον συνθηματικό σας!',
'passchanged'             => 'Το συνθηματικό σας άλλαξε.',
'closewindow'             => 'Μπορείτε τώρα να κλείσετε αυτό τα παράθυρο.',
'passnomatch'             => 'Τα νέα συνθηματικά σας δεν ήταν ίδια μεταξύ τους!',
'usernametaken'           => 'Αυτό το όνομα χρήστη είναι κατειλημμένο. Θα χρειαστεί να επιλέξετε κάποιο άλλο. ',
'usernametakenbulk'       => 'Το όνομα χρήστη είναι κατειλημμένο.',
'newusercreated'          => 'Ο νέος λογαριασμός χρήστη δημιουργήθηκε.',
'accountcreated'          => 'Ο λογαριασμός σας δημιουργήθηκε.',
'newuserwarning'          => 'Να σημειωθεί ότι οι γενικές ρυθμίσεις μπορεί να απαιτούν έγκριση του λογαριασμού σας από διαχειριστή. Εάν δεν μπορείτε να συνδεθείτε, μάλλον αυτός είναι ο λόγος.',
'nomatchpass'             => 'Τα συνθηματικά δεν ταιριάζουν.',
'confirmwrong'            => 'Ο κωδικός επαλήθευσης είναι εσφαλμένος!',
'formnotcomplete'         => 'Η φόρμα δεν συμπληρώθηκε πλήρως.',
'formnotnumeric'          => 'Τα εισαχθέντα δεδομένα δεν ήταν αριθμητικά!',
'groupnametaken'          => 'Αυτό το όνομα ομάδας είναι ήδη κατειλημμένο.',
'newgroupadded'           => 'Προστέθηκε νέα ομάδα.',
'optionssaved'            => 'Οι επιλογές του Flyspray αποθηκεύτηκαν.',
'hasuploaded'             => 'ανέβασε ένα συνημμένο αρχείο σε μια εργασία που έχει ανατεθεί σε:',
'hasattached'             => 'επισύναψε ένα αρχείο στην ακόλουθη εργασία.',
'fileuploaded'            => 'Το αρχείο ανέβηκε.',
'fileerror'               => 'Παρουσιάστηκε ένα σφάλμα κατά το ανέβασμα του αρχείου σας. Ίσως τα δικαιώματα στο φάκελο <i>attachments/</i> να μην είναι σωστά.',
'contactadmin'            => 'Επικοινωνήστε με το διαχειριστή για αυτό το έργο.',
'selectfileerror'         => 'Δεν επιλέξατε αρχείο.',
'userupdated'             => 'Τα στοιχεία χρήστη ενημερώθηκαν',
'realandemail'            => 'Δεν συμπληρώσατε και τα δύο πεδία, πραγματικό όνομα και διεύθυνση ηλεκτρονικού ταχυδρομείου.',
'groupupdated'            => 'Ο ορισμός ομάδας ενημερώθηκε.',
'groupanddesc'            => 'Δεν συμπληρώσατε το όνομα ομάδας.',
'fillallfields'           => 'Παρακαλούμε συμπληρώστε όλα τα πεδία.',
'listPmustN'              => 'Η καταχώριση στη «Σειρά» πρέπει να είναι αριθμητική.',
'listupdated'             => 'Η λίστα ενημερώθηκε.',
'listitemadded'           => 'Προστέθηκε νέο στοιχείο στη λίστα.',
'relatedaddedmsg'         => 'Η σχετική εργασία προστέθηκε στη λίστα.',
'relatederror'            => 'Αυτή η εργασία είναι ήδη στη λίστα σχετικών εργασιών.',
'relatedremoved'          => 'Η σχετική εργασία καταργήθηκε από τη λίστα.',
'notifyadded'             => 'Ο χρήστης προστέθηκε στη λίστα ειδοποιήσεων.',
'notifyerror'             => 'Ο χρήστης είναι ήδη στη λίστα ειδοποιήσεων αυτής της εργασίας.',
'notifyremoved'           => 'Ο χρήστης καταργήθηκε από τη λίστα ειδοποιήσεων.',
'editcommentsaved'        => 'Το ενημερωμένο σχόλιο αποθηκεύτηκε.',
'commentdeletedmsg'       => 'Το σχόλιο διεγράφη.',
'gotonewtask'             => 'Μετάβαση στην νέα εργασία που μόλις δημιουργήσατε',
'projectcreated'          => 'Το νέο σας έργο έχει δημιουργηθεί. Μπορείτε τώρα να προσαρμόσετε το έργο στην περιοχή διαχείρισης έργου.',
'customiseproject'        => 'Προσαρμογή αυτού του έργου',
'projectupdated'          => 'Οι προτιμήσεις του έργου ενημερώθηκαν',
'emptytitle'              => 'Αφήσατε ασυμπλήρωτο τον τίτλο του έργου. Πηγαίνετε πίσω και διορθώστε το.',
'loginbelow'              => 'Τώρα μπορείτε να προσπαθήσετε να συνδεθείτε.',
'attachmentdeletedmsg'    => 'Το συνημμένο διεγράφη',
'reminderaddedmsg'        => 'Η υπενθύμισή σας προστέθηκε.',
'reminderdeletedmsg'      => 'Η επιλεγμένη υπενθύμιση διεγράφη.',
'flyspraytask'            => 'Εργασία Flyspray',
'fieldsmissing'           => 'Μερικά πεδία περιέχουν μη έγκυρα ή καθόλου δεδομένα.',
'relatedinvalid'          => 'Δεν υπάρχει τέτοια εργασία.',
'relatedproject'          => 'Αυτή η εργασία είναι συνημμένη σε άλλο έργο. Να προστεθεί σχέση ούτως ή άλλως;',
'addanyway'               => 'Προσθήκη ούτως ή άλλως',
'cancel'                  => 'Ακύρωση',
'alreadyedited'           => 'Αυτή η εργασία τροποποιήθηκε από κάποιον άλλον πριν την αποθηκεύσετε. Θέλετε ακόμα να αποθηκεύσετε τις αλλαγές;',
'saveanyway'              => 'Αποθήκευση των αλλαγών μου ούτως ή άλλως',
'nouserselected'          => 'Δεν επιλέγη χρήστης. Επιλέξτε τουλάχιστον έναν χρήστη πριν ξαναπροσπαθήσετε.',
'groupswitchupdated'      => 'Οι ομάδες χρηστών τροποποιήθηκαν επιτυχώς.',
'takenownershipmsg'       => 'Αυτή η εργασία έχει πλέον ανατεθεί σε εσάς.',
'adminrequestmade'        => 'Το αίτημά σας απεστάλη σε διαχειριστή έργου.',
'newdepnotify'            => 'Μια νέα εξάρτηση προστέθηκε στην ακόλουθη εργασία:',
'dependadded'             => 'Η εξάρτηση από άλλη εργασία προστέθηκε',
'dependaddfailed'         => 'Υπήρξε ένα σφάλμα κατά την προσθήκη της εξάρτησης. Ελέγξτε ότι η εργασία υπάρχει και ότι δεν υπάρχει κώλυμα και από τις δύο πλευρές.',
'depremovedmsg'           => 'Η εξάρτηση της εργασίας καταργήθηκε',
'newdepis'                => 'Η νέα εξάρτηση είναι',
'magicurlsent'            => 'Εστάλη μήνυμα στη διεύθυνση ειδοποιήσεών σας. Περιέχει σύνδεσμο που θα σας μεταφέρει σε μια σελίδα για να ολοκληρώσετε αυτήν την εργασία.',
'changefspass'            => 'Αλλαγή συνθηματικού στο Flyspray',
'magicurlmessage'         => 'Παρακαλούμε ακολουθήστε τον παρακάτω σύνδεσμο για να αλλάξετε το συνθηματικό σας στο Flyspray:',
'erroronform'             => 'Υπήρξε κάποιο πρόβλημα με την υποβολή της φόρμας σας',
'addressused'             => 'Η παρούσα διεύθυνση ηλεκτρονικού ταχυδρομείου χρησιμοποιήθηκε για την εγγραφή ενός λογαριασμού στο Flyspray. Αν δεν αναμένατε αυτό το μήνυμα, παρακαλούμε αγνοήστε το και διαγράψτε το.',
'confirmcodeis'           => 'Ο κωδικός επαλήθευσής σας είναι:',
'codesent'                => 'Ο κωδικός επαλήθευσής σας έχει αποσταλεί. Παρακαλούμε ακολουθήστε τις οδηγίες που υπάρχουν στο μήνυμα.',
'codenotsent'             => 'Ο κωδικός σας δεν ήταν δυνατόν να αποσταλεί, παρακαλούμε ξαναδοκιμάστε αργότερα.',
'taskmadeprivatemsg'      => 'Αυτή η εργασία μετετράπη σε ιδιωτική',
'taskmadepublicmsg'       => 'Αυτή η εργασία μετετράπη ξανά σε δημόσια',
'realandnotify'           => 'Πρέπει να συμπληρώσετε το πεδίο «Πραγματικό όνομα» καθώς επίσης και, είτε το πεδίο «Διεύθυνση ηλεκτρονικού ταχυδρομείου» είτε το πεδίο «Αναγνωριστικό Jabber».',
'pmreqdeniedmsg'          => 'Το αίτημα του διαχειριστή έργου απορρίφθηκε',
'massopsuccess'           => 'Οι μαζικές ενέργειες ήταν επιτυχείς - όπου το επιτρέπουν τα δικαιώματα',
'usernotexist'            => 'Αυτός ο χρήστης δεν υπάρχει σε αυτό το Flyspray',
'commentattachperms'      => 'Δεν μπορείτε να διαγράψετε αυτό το σχόλιο - δεν έχετε εξουσιοδότηση να διαγράφετε συνημμένα',
'voterecorded'            => 'Η ψήφος σας καταγράφηκε',
'votefailed'              => 'Η ψήφος δεν ήταν δυνατόν να προστεθεί αυτή τη στιγμή.',
'createnewgroup'          => 'Δημιουργία νέας ομάδας',
'requiredfields'          => 'Τα απαιτούμενα πεδία σημειώνονται με',
'addthisgroup'            => 'Προσθήκη αυτής της ομάδας',
'createnewproject'        => 'Δημιουργία νέου έργου',
'addnewproject'           => 'Προσθήκη νέου έργου',
'htmlallowed'             => 'Επιτρέπεται κώδικας HTML',
'createthisproject'       => 'Δημιουργία αυτού του έργου',
'inlineimages'            => 'Εμφάνιση των συνημμένων εικόνων ένθετα',
'createnewtask'           => 'Δημιουργία νέας εργασίας στο έργο:',
'addanother'              => 'Προσθήκη κι άλλης εργασίας μετά από αυτήν εδώ',
'addthistask'             => 'Προσθήκη αυτής της εργασίας',
'notifyme'                => 'Να ειδοποιούμαι κάθε φορά που τροποποιείται αυτή η εργασία',
'newtask'                 => 'Νέα εργασία',
'attachafile'             => 'Επισύναψη αρχείου',
'registernewuser'         => 'Εγγραφή νέου χρήστη',
'none'                    => 'Κανένα',
'registeraccount'         => 'Εγγραφή αυτού του λογαριασμού',
'registerbulkaccount'     => 'Εγγραφή λογαριασμών',
'both'                    => 'Και τα δύο',
'notifyfrom'              => 'Ειδοποίηση από _',
'donotreply'              => 'ΑΥΤΟ ΕΙΝΑΙ ΕΝΑ ΑΥΤΟΜΑΤΟΠΟΙΗΜΕΝΟ ΜΗΝΥΜΑ, ΜΗΝ ΑΠΑΝΤΑΤΕ.',
'disclaimer'              => 'Λαμβάνετε αυτό το μήνυμα γιατί το έχετε ζητήσει από το σύστημα παρακολούθησης σφαλμάτων Flyspray. Αν δεν αναμένατε αυτό το μήνυμα ή αν δεν επιθυμείτε να λαμβάνετε μηνύματα στο μέλλον, μπορείτε να αλλάξετε τις ρυθμίσεις ειδοποιήσεών σας στην παραπάνω διεύθυνση URL.',
'userwho'                 => 'Χρήστης που το έκανε αυτό',
'moreinfo'                => 'Μπορείτε να βρείτε περισσότερες πληροφορίες στην ακόλουθη διεύθυνση URL:',
'newtaskopened'           => 'Μια νέα εργασία έχει ανοιχτεί στο Flyspray. Όλες οι λεπτομέρειες παρακάτω.',
'notify.taskclosed'       => 'Η ακόλουθη εργασία είναι πλέον κλεισμένη:',
'notify.taskreopened'     => 'Η ακόλουθη εργασία ανοίχτηκε εκ νέου:',
'newdep'                  => 'Η ακόλουθη εργασία έχει νέα εξάρτηση:',
'notify.depremoved'       => 'Η ακόλουθη εργασία είχε μια εξάρτηση που καταργήθηκε:',
'olddepwas'               => 'Η παλιά εξάρτηση ήταν',
'notify.commentadded'     => 'Στην ακόλουθη εργασία προστέθηκε νέο σχόλιο:',
'commentis'               => 'Το κείμενο του σχολίου είναι παρακάτω.',
'newattachment'           => 'Ένα νέο αρχείο προστέθηκε στην ακόλουθη εργασία:',
'detailsbelow'            => 'Οι λεπτομέρειες είναι παρακάτω.',
'notify.relatedadded'     => 'Μια νέα σχετική εργασία προστέθηκε στην ακόλουθη εργασία:',
'relatedis'               => 'Η σχετική εργασία είναι',
'assignedtoyou'           => 'Σας έχει ανατεθεί η ακόλουθη εργασία:',
'takenownership'          => 'ανέλαβε την κυριότητα της ακόλουθης εργασίας:',
'requiresaction'          => 'Η ακόλουθη εργασία απαιτεί ενέργεια από διαχειριστή έργου:',
'requiresactionnotify'    => 'Εργασίες που απαιτούν ενέργεια από διαχειριστή έργου',
'pmdeny'                  => 'Ένας διαχειριστής έργου απέρριψε το αίτημα που εκκρεμούσε για την ακόλουθη εργασία:',
'pmdenynotify'            => 'Ένας διαχειριστής έργου απέρριψε το αίτημα',
'fileaddedtoo'            => 'Ένα ή περισσότερα αρχεία επισυνάφθηκαν.',
'taskwatching'            => 'Η ακόλουθη εργασία την οποίαν παρακαλουθείτε',
'isdepfor'                => 'αποτελεί νέα εξάρτηση για',
'denialreason'            => 'Αιτιολογία απόρριψης',
'taskchanged'             => 'Η ακόλουθη εργασία έχει τροποποιηθεί. Οι αλλαγές καταγράφονται παρακάτω. Για πλήρεις πληροφορίες σχετικά με το τι έχει αλλάξει, επισκεφτείτε τη διεύθυνση URL και κάντε κλικ στην καρτέλα «Ιστορικό».',
'useraddedtoassignees'    => 'Ένας χρήστης προσέθεσε τον εαυτό του στη λίστα χρηστών που τους έχει ανατεθεί αυτή η εργασία.',
'removeddepis'            => 'Η εξάρτηση που καταργήθηκε ήταν',
'isnodepfor'              => 'δεν αποτελεί πλέον εξάρτηση για',
'usergroups'              => 'Ομάδες χρηστών',
'pmtoolbox'               => 'Εργαλειοθήκη διαχειριστή έργου',
'groupmanage'             => 'Διαχείριση ομάδων',
'pendingrequests'         => 'Εκκρεμή αιτήματα',
'reasongiven'             => 'Αιτιολογία που δόθηκε',
'nopendingreq'            => 'Δεν υπάρχουν εκκρεμή αιτήματα προς το διαχειριστή έργου.',
'givereason'              => 'Αιτιολόγηση',
'catlisted'               => 'Επεξεργασία λίστας κατηγοριών',
'oslisted'                => 'Επεξεργασία λίστας λειτουργικών συστημάτων',
'verlisted'               => 'Επεξεργασία λίστας εκδόσεων',
'tasktypeed'              => 'Επεξεργασία λίστας τύπων εργασιών',
'resed'                   => 'Επεξεργασία λίστας επιλύσεων',
'deny'                    => 'Απόρριψη',
'notifiedwhen'            => 'Ειδοποίηση όταν',
'onlynewtasks'            => 'Ανοίχτηκαν νέες εργασίες',
'allevents'               => 'Οποιαδήποτε εργασία που απαντά σε οποιοδήποτε έργο',
'feeds'                   => 'Ροές',
'feeddescription'         => 'Περιγραφή ροής',
'feedimgurl'              => 'Διεύθυνση URL εικόνας ροής (να αφεθεί κενό για μη εικόνα)',
'notifysubject'           => 'Θέμα ειδοποιήσεων',
'notifysubjectinfo'       => '(%p = τίτλος έργου, %s = σύνοψη εργασίας, %t = αναγνωριστικό εργασίας, %a = ενέργεια, %u = χρήστης)',
'priority6'               => 'Αστραπιαία',
'priority5'               => 'Άμεση',
'priority4'               => 'Επείγουσα',
'priority3'               => 'Υψηλή',
'priority2'               => 'Κανονική',
'priority1'               => 'Χαμηλή',
'sendcode'                => 'Αποστολή κωδικού!',
'entercode'               => 'Εισαγάγετε τον κωδικό επαλήθευσης που λάβατε στο ειδοποιητήριο μήνυμά σας. Επίσης εισαγάγετε το επιθυμητό συνθηματικό για το λογαριασμό σας.',
'confirmationcode'        => 'Κωδικός επιβεβαίωσης',
'registererror'           => 'Σιγουρευτείτε ότι έχετε συμπληρώσει όλα τα απαιτούμενα πεδία και ότι έχετε εισαγάγει ακριβή στοιχεία για τον επιθυμητό τύπο ειδοποιήσεων.',
'validusername'           => '(επιτρέπονται μόνο λατινικοί χαρακτήρες, νούμερα και κάτω παύλα «_»)',
'validemail'              => '(χρησιμοποιήστε ; για να διαχωρίσετε πολλαπλές διευθύνσεις ηλεκτρονικού ταχυδρομείου)',
'emailtakenbulk'          => 'Η διεύθυνση ηλεκτρονικού ταχυδρομείου είναι κατειλημμένη ',
'emailtaken'              => 'Αυτή η διεύθυνση ηλεκτρονικού ταχυδρομείου ή το αναγνωριστικό Jabber είναι κατειλημμένη. Θα χρειαστεί να επιλέξετε κάποια άλλη.',
'note'                    => '<strong>Σημείωση:</strong> Προτού να δημιουργηθεί ο λογαριασμός σας θα σας αποσταλεί ένας κωδικός επαλήθευσης. Ο κωδικός θα αποσταλεί μέσω της προτιμώμενης μεθόδου ειδοποιήσεων, παραπάνω.<br />Αν εισαγάγετε ψευδείς πληροφορίες <strong>δεν θα λάβετε τον κωδικό σας</strong>.',
'changelog'               => 'Μητρώο αλλαγών',
'changeloggen'            => 'Γεννήτρια μητρώου αλλαγών',
'listfrom'                => 'Λίστα εγγραφών στο μητρώο αλλαγών από',
'to'                      => 'έως',
'oldestfirst'             => 'Οι πιο παλιές πρώτες',
'recentfirst'             => 'Οι πιο πρόσφατες πρώτες',
'severityrep'             => 'Αναφορά σοβαρότητας',
'totalopen'               => 'Συνολικές ανοιχτές εργασίες',
'age'                     => 'Ηλικία',
'agerep'                  => 'Αναφορά ηλικίας',
'eventsrep'               => 'Αναφορά συμβάντων',
'events'                  => 'Συμβάντα',
'Tasks'                   => 'Εργασίες',
'opened'                  => 'Ανοικτές',
'edited'                  => 'Τροποποιημένες',
'assigned'                => 'Ανατεθειμένες',
'within'                  => 'Εντός',
'pastday'                 => 'Την προηγούμενη ημέρα',
'pastweek'                => 'Την προηγούμενη εβδομάδα',
'pastmonth'               => 'Τον προηγούμενο μήνα',
'pastyear'                => 'Το προηγούμενο έτος',
'nolimit'                 => 'Χωρίς όριο',
'from'                    => 'Από',
'duein'                   => 'Προθεσμία',
'selectfromdate'          => 'Επιλογή ημερομηνίας «Από»',
'selecttodate'            => 'Επιλογή ημερομηνίας «Έως»',
'showvoters'              => 'Εμφάνιση/απόκρυψη ψηφοφόρων',
'roadmap'                 => 'Χάρτης πορείας',
'roadmapfor'              => 'Χάρτης πορείας για',
'tasks'                   => 'εργασίες',
'completed'               => 'ολοκληρώθηκε.',
'opentasks'               => 'ανοικτές εργασίες',
'of'                      => '% από',
'severity5'               => 'Κρίσιμη',
'severity4'               => 'Υψηλή',
'severity3'               => 'Μέτρια',
'severity2'               => 'Χαμηλή',
'severity1'               => 'Πολύ χαμηλή',
'Redirect'                => 'Ανακατεύθυνση',
'redirectmsg'             => 'Αν ο περιηγητής σας δεν υποστηρίζει ανακατεύθυνση meta παρακαλούμε κάντε κλικ %sΕΔΩ%s για να ανακατευθυνθείτε.',
'allowclosedcomments'     => 'Να επιτρέπονται σχόλια σε κλεισμένες εργασίες',
'comment'                 => 'Σχόλιο',
'editowncomments'         => 'Επεξεργασία ιδίων σχολίων',
'reopened'                => 'Εκ νέου ανοιγμένες ',
'loading'                 => 'Φόρτωση σε εξέλιξη...',
'notifyown'               => 'Ειδοποίηση για ιδίες αλλαγές',
'youremail'               => 'Διεύθυνση ηλεκτρονικού ταχυδρομείου σας',
'thankyouforbug'          => 'Ευχαριστούμε που υποβάλλατε αναφορά για το πρόβλημά σας. Μπορείτε να δείτε την εργασία και να παρακολουθείτε την πρόοδό της οποιαδήποτε στιγμή χρησιμοποιώντας την ακόλουθη διεύθυνση URL:',
'anonuser'                => 'Ανώνυμος χρήστης',
'conflict'                => 'Σύγκρουση',
'file'                    => 'Αρχείο',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Μέγεθος',
'projectgroup'            => 'Ομάδα έργου',
'profile'                 => 'Προφίλ:',
'viewprofile'             => 'Προβολή προφίλ',
'regdate'                 => 'Εγγεγραμμένος από',
'tasksopened'             => 'Εργασίες που έχει ανοίξει',
'replyto'                 => 'Απάντηση σε',
'notifytypes'             => 'Τύποι ειδοποιήσεων',
'pm.taskchanged'          => 'Τροποποίηση εργασίας',
'pm.taskreopened'         => 'Εκ νέου άνοιγμα εργασίας',
'pm.depadded'             => 'Προσθήκη εξάρτησης',
'pm.depremoved'           => 'Κατάργηση εξάρτησης',
'pmrequest'               => 'PM request',
'pmrequestdenied'         => 'PM request denied',
'newassignee'             => 'Νέος ανάδοχος',
'revdepadded'             => 'Προσθήκη αντίστροφης εξάρτησης',
'revdepaddedremoved'      => 'Κατάργηση αντίστροφης εξάρτησης',
'assigneeadded'           => 'Προσθήκη αναδόχου',
'addusergroup'            => 'Προσθήκη χρήστη σε αυτήν την ομάδα',
'groupmembers'            => 'Μέλη ομάδας',
'deleteuser'              => 'Διαγραφή χρήστη',
'userdeleted'             => 'Ο χρήστης διεγράφη',
'autoassign'              => 'Αυτόματη ανάθεση των εργασιών σε αυτόν που έχει την κυριότητα της κατηγορίας',
'ssl'                     => 'SSL',
'updatewrong'             => 'Έχετε ενεργοποιημένη τη λειτουργία ελέγχου για ενημερώσεις, αλλά συνέβη κάποιο σφάλμα κατά τη σύνδεση στο διακομιστή ενημερώσεων, είτε γιατί ο πάροχός σας δεν επιτρέπει εξερχόμενες συνδέσεις, είτε το σφάλμα προκλήθηκε από πρόβλημα δικτύου.',
'deleteproject'           => 'Διαγραφή αυτού του έργου και μετακίνηση των περιεχομένων του σε',
'projectdeleted'          => 'Το έργο διαγράφηκε επιτυχώς',
'feedforall'              => 'Ροή για όλα τα έργα',
'usercreated'             => 'Ο χρήστης δημιουργήθηκε',
'created'                 => 'Δημιουργήθηκε',
'deleted'                 => 'Διεγράφη',
'userid'                  => 'Αναγνωριστικό χρήστη',
'editassignments'         => 'Επεξεργασία αναθέσεων',
'preview'                 => 'Προεπισκόπηση',
'anyprogress'             => 'Οποιοδήποτε ποσοστό',
'tasksrelated'            => 'Εργασίες που σχετίζονται με αυτήν την εργασία',
'duplicatetasks'          => 'Διπλότυπες εργασίες αυτής της εργασίας',
'databasemodfailed'       => 'Η τροποποίηση της βάσης δεδομένων απέτυχε. Πιθανός λόγος είναι να μην υπάρχουν επαρκή δικαιώματα.',
'frequency'               => 'Συχνότητα',
'newuserregistered'       => 'Ένας νέος χρήστης έχει εγγραφεί στο Flyspray σας. Τα στοιχεία του χρήστη είναι τα ακόλουθα:',
'newuserregisterednotify' => 'Ένας νέος χρήστης έχει εγγραφεί',
'notify_registration'     => 'Ειδοποίηση διαχειριστών κατά την εγγραφή νέου χρήστη',
'textversion'             => 'Έκδοση κειμένου',
'onlyprimary'             => 'Εργασίες που δεν κωλύουν άλλες εργασίες',
'onlyblocker'             => 'Εργασίες που κωλύουν άλλες εργασίες',
'blockerornoblocker'      => 'Ή κωλύουν ή δεν κωλύουν, το να επιλέγετε και τα δύο φίλτρα είναι άτοπο.',
'switch'                  => 'Εναλλαγή',
'max'                     => 'μέγιστο μέγεθος',
'dates'                   => 'Ημερομηνίες',
'selectduedatefrom'       => 'Προθεσμία από',
'selectduedateto'         => 'έως',
'selectsincedatefrom'     => 'Τροποποιημένες από',
'selectsincedateto'       => 'έως',
'selectdate'              => 'Επιλογή ημερομηνίας',
'selectopenedfrom'        => 'Έχουν ανοιχτεί από',
'selectopenedto'          => 'έως',
'selectclosedfrom'        => 'Κλεισμένες από',
'selectclosedto'          => 'έως',
'startat'                 => 'Έναρξη σε',
'hasattachment'           => 'Έχει συνημμένο',
'private'                 => 'Ιδιωτική',
'watching'                => 'Παρακολούθηση',
'alreadyvotedthistask'    => 'έχετε ψηφίσει αυτήν την εργασία',
'alreadyvotedthisday'     => 'συμπληρώθηκαν οι ψήφοι για σήμερα',
'visibility'              => 'Ορατότητα',
'public'                  => 'Δημόσια',
'leaveemptyauto'          => 'Αφήστε τα πεδία συνθηματικών κενά αν θέλετε το συνθηματικό να παραχθεί αυτόματα.',
'novalidemail'            => 'Δεν εισαγάγατε έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου.',
'novalidjabber'           => 'Δεν εισαγάγατε έγκυρη διεύθυνση Jabber.',
'missingrequired'         => 'Δεν συμπληρώσατε όλα τα απαιτούμενα πεδία.',
'entervalidusername'      => 'Παρακαλούμε εισαγάγετε έγκυρο όνομα χρήστη και πραγματικό όνομα.',
'couldnotaddusernotif'    => 'Δεν ήταν δυνατή η προσθήκη αυτού του χρήστη στη λίστα ειδοποιήσεων.',
'defaulttask'             => 'Περιγραφή προεπιλεγμένης εργασίας',
'all'                     => 'όλα',
'events.useraddedtoassignees'=> 'Ο χρήστης προστέθηκε στους αναδόχους',
'eventlog'                => 'Μητρώο συμβάντων',
'assignmentchanged'       => 'Η ανάθεση άλλαξε',
'detailedinfo'            => 'Αναλυτικές πληροφορίες',
'All'                     => 'Όλες',
'tasksireported'          => 'Εργασίες που έχω αναφέρει',
'recentlyopened'          => 'Πρόσφατα ανοιγμένες',
'stats'                   => 'Στατιστικά',
'totaltasks'              => 'συνολικές εργασίες',
'mostwanted'              => 'Οι πιο επιθυμητές εργασίες',
'defaultentry'            => 'Προεπιλεγμένη σελίδα εισόδου',
'toplevel'                => 'Προβολή του ανώτερου επιπέδου',
'overview'                => 'Επισκόπηση',
'error#'                  => 'Σφάλμα Νο',
'error1'                  => 'Δεν έχετε επαρκή δικαιώματα για να προβάλετε αυτό το συνημμένο.',
'error3'                  => 'Επαναλαμβανόμενη ενέργεια. Γίνεται ανακατεύθυνση στην αρχική σελίδα.',
'error4'                  => 'Δεν έχετε διαχειριστικά δικαιώματα.',
'error5'                  => 'Αυτός ο χρήστης δεν υπάρχει σε αυτό το Flyspray',
'error6'                  => 'Μη έγκυρη διαχειριστική περιοχή.',
'error7'                  => 'Η σύνδεση απέτυχε, εσφαλμένο συνθηματικό!',
'error71'                 => 'Ο λογαριασμός κλειδώθηκε για %d λεπτά λόγω πολλών αποτυχημένων αποπειρών σύνδεσης!',
'error8'                  => 'Δεν εισηγάγατε και όνομα χρήστη και συνθηματικό.',
'error9'                  => 'Η εργασία δεν υπάρχει ή δεν έχετε εξουσιοδότηση να την προβάλετε.',
'error10'                 => 'Αυτή η εργασία δεν υπάρχει.',
'error101'                => 'Δεν έχετε εξουσιοδότηση να προβάλετε αυτήν την εργασία.',
'error102'                => 'Δεν έχετε εξουσιοδότηση να προβάλετε αυτήν την εργασία, ίσως αν συνδεόσασταν να βοηθούσε.',
'error11'                 => 'Δεν έχετε εξουσιοδότηση να επεξεργαστείτε αυτό το σχόλιο.',
'error12'                 => 'Το μαγικό κλειδί δεν είναι έγκυρο!  Είστε βέβαιος ότι το λάβατε από το μήνυμα ειδοποίησής σας;',
'error13'                 => 'Οι ανώνυμοι χρήστες δεν έχουν προφίλ.',
'error14'                 => 'Δεν έχετε επαρκή δικαιώματα για να δημιουργήσετε ομάδα.',
'error15'                 => 'Δεν έχετε επαρκή δικαιώματα για να ανοίξετε εργασία.',
'error16'                 => 'Δεν είστε διαχειριστής έργου.',
'error17'                 => 'Μη έγκυρη περιοχή διαχείρισης έργου.',
'error18'                 => 'Μη έγκυρη μαγική διεύθυνση URL.',
'error19'                 => 'Αυτός ο χρήστης δεν υπάρχει σε αυτό το Flyspray.',
'error20'                 => 'Μη έγκυρη τροποποίηση βάσης δεδομένων.',
'error21'                 => 'Δεν ήταν δυνατόν να αποσταλούν ένα ή περισσότερα μηνύματα ηλεκτρονικού ταχυδρομείου. Ελέγξτε τις ρυθμίσεις σας.',
'error22'                 => 'Δεν επιτρέπεται εγγραφή νέων χρηστών.',
'error23'                 => 'Ο χρήστης ή η ομάδα του δεν είναι εξουσιοδιοτημένοι για σύνδεση.',
'error24'                 => 'Το πρόγραμμα dot δεν έχει οριστεί ούτε τοπικά ούτε σε δημόσιο εξυπηρετητή.',
'error25'                 => 'Δεν υπάρχει διαθέσιμος χάρτης πορείας για το συγκεκριμένο έργο.',
'error26'                 => 'Μη υποστηριζόμενος πάροχος OAuth',
'error27'                 => 'Αδυναμία σύνδεσης. Εξουσιοδοτήστε μας να μπορούμε προβάλουμε τη διεύθυνση ηλεκτρονικού σας ταχυδρομείου.',
'error28'                 => 'Δεν έχετε εξουσιοδότηση να προσπελάσετε αυτήν την περιοχή.',
'done'                    => 'ολοκληρωμένο',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Το έργο δεν ήταν δυνατόν να διαγραφεί.',
'GMT'                     => 'Ώρα Γκρήνουιτς',
'timezone'                => 'Ζώνη ώρας',
'accept'                  => 'Αποδοχή',
'reasonfordeinal'         => 'Αιτιολογία άρνησης',
'pruneclosedlinks'        => 'Κλάδεμα κλεισμένων συνδέσμων',
'pruneclosedtasks'        => 'Κλάδεμα κλεισμένων εργασιών',
'pagegenerated'           => 'Σελίδα και εικόνα παρήχθησαν σε %d δευτερόλεπτα.',
'pruninglevel'            => 'Επίπεδο κλαδέματος',
'lastuser'                => 'Ο τελευταίος χρήστης δεν μπορεί να διαγραφεί.',
'allprivate'              => 'Όλα τα έργα είναι ιδιωτικά.',
'deletegroup'             => 'Διαγραφή αυτής της ομάδας και μετακίνηση των χρηστών σε',
'parent'                  => 'Μητρική',
'ordertip'                => 'Η σειρά με την οποίαν αυτά τα στοιχεία θα εμφανίζονται στη λίστα',
'showtip'                 => 'Εμφάνιση αυτού του στοιχείου στη λίστα',
'deletetip'               => 'Διαγραφή αυτού του στοιχείου από τη λίστα',
'del'                     => 'διαγρ',
'request1'                => 'Έγινε αίτημα για κλείσιμο εργασίας.',
'request2'                => 'Ο λογαριασμός σας έχει κλειδωθεί λόγω πολλών αποτυχημένων αποπειρών πρόσβασης.',
'allpriorities'           => 'Όλοι οι βαθμοί προτεραιότητας',
'noroadmap'               => 'Δεν υπάρχει διαθέσιμος χάρτης πορείας (καθώς δεν έχουν οριστεί «μελλοντικές» εκδόσεις του συγκεκριμένου έργου)',
'expand'                  => 'Ανάπτυξη',
'collapse'                => 'Σύμπτυξη',
'expandall'               => 'Ανάπτυξη όλων',
'collapseall'             => 'Σύμπτυξη όλων',
'minpwsize'               => 'Το ελάχιστο μέγεθος συνθηματικού είναι 5 χαρακτήρες',
'passwordtoosmall'        => 'Πολύ μικρό μέγεθος συνθηματικού.',
'accountwaslocked'        => 'Ο λογαριασμός σας έχει κλειδωθεί λόγω των πολλών αποτυχημένων αποπειρών σύνδεσης.',
'failedattempts'          => 'Υπήρξαν %d αποτυχημένες απόπειρες πρόσβασης.',
'groupnotexist'           => 'Η επιλεγμένη ομάδα δεν υπάρχει σε αυτό το έργο.',
'searchindetails'         => 'Λεπτομέρειες αναζήτησης',
'showasassignees'         => 'Εμφάνιση στους υποψήφιους αναδόχους',
'find'                    => 'Εύρεση',
'tls'                     => 'TLS',
'isadmin'                 => 'Είναι διαχειριστής',
'addvotes'                => 'Προσθήκη ψήφων',
'removevote'              => 'Κατάργηση ψήφου',
'voteremoved'             => 'Η ψήφος σας έχει καταργηθεί',
'voteremovefailed'        => 'Η ψήφος σας δεν ήταν δυνατόν να καταργηθεί αυτή τη στιγμή.',
'novotes'                 => 'Επί του παρόντος δεν έχετε ψήφους σε εργασίες.',
'connectedtasks'          => 'Συνδεδεμένες εργασίες:',
'taskdependencies'        => 'Εξαρτήσεις εργασίας',
'viewgraph'               => 'προβολή διαγράμματος',
'notaskdependencies'      => 'Αυτή η εργασία δεν εξαρτάται από άλλες εργασίες.',
'dependson'               => 'Εξαρτάται από',
'blocks'                  => 'Προαπαιτούμενη της',
'newdependency'           => 'Νέα εξάρτηση:',
'nouserstoadd'            => 'Δεν υπάρχουν χρήστες για προσθήκη. Παρακαλούμε βεβαιωθείτε ότι έχουν οριστεί όνομα, όνομα χρήστη και διεύθυνση ηλεκτρονικού ταχυδρομείου για κάθε χρήστη.',
'dispintro'               => 'Παρουσίαση κύριου εισαγωγικού μηνύματος',
'mainmessage'             => 'Κύριο εισαγωγικό μήνυμα',
'setsupertask'            => 'Ορισμός αναγνωριστικού υπερεργασίας:',
'supertaskmodified'       => 'Το αναγνωριστικό υπερεργασίας τροποποιήθηκε',
'set'                     => 'Ορισμός',
'supertask'               => 'Υπερεργασία',
'setparent'               => 'Ορισμός αναγνωριστικού γονικής εργασίας για αυτήν την εργασία',
'selfsupertasknotallowed' => 'Το αναγνωριστικό της υπερ-εργασίας δεν μπορεί να είναι το ίδιο με το αναγνωριστικό της παρούσας εργασίας',
'quickaction'             => 'Γρήγορες ενέργειες',
'updateselectedtasks'     => 'Ενημέρωση επιλεγμένων εργασιών',
'notspecified'            => 'Δεν έχει οριστεί',
'editselectedtasks'       => 'Επεξεργασία επιλεγμένων εργασιών',
'information'             => 'Πληροφορίες',
'taskclosedisabled'       => 'Το κλείσιμο της εργασίας είναι επί του παρόντος ανενεργό καθώς οι ακόλουθες εργασίες από τις οποίες εξαρτάται η εργασία είναι ακόμα ανοικτές:',
'daysleft'                => 'ημέρες απομένουν',
'dayoverdue'              => 'ημέρες εκπρόθεσμη',
'duetoday'                => 'Προθεσμία μέχρι σήμερα.',
'daysbeforealert'         => 'Ημέρες πριν από προειδοποίηση',
'associatedsubtask'       => 'Επιτυχής σύνδεση υποεργασίας FS#',
'associatesubtask'        => 'Σύνδεση αναγνωριστικού υποεργασίας με αυτήν την εργασία',
'subtaskid'               => 'Αναγνωριστικό υπο-εργασίας',
'subtaskalreadyhasparent' => 'Η υποεργασία που εισηγάγατε έχει ήδη γονική εργασία, παρακαλούμε απαλείψτε την πριν κάνετε τη σύνδεση.',
'subtaskisparent'         => 'Η υποεργασία που εισηγάγατε είναι η γονική εργασία αυτής της εργασίας. Η υποεργασία δεν συνδέθηκε.',
'subtasknotexist'         => 'Η υποεργασία που εισηγάγατε δεν υπάρχει.',
'subtaskremovedmsg'       => 'Η υποεργασία έχει αφαιρεθεί με επιτυχία',
'subtaskadded'            => 'Προστέθηκε υποεργασία',
'subtaskremoved'          => 'Η υποεργασία αφαιρέθηκε',
'addnewsubtask'           => 'Προσθήκη νέας υποεργασίας',
'hidesubtasks'            => 'Απόκρυψη υποεργασιών',
'voteforthistask'         => 'Ψήφο σε αυτήν την εργασία',
'watchthistask'           => 'Παρακολούθηση αυτής της εργασίας',
'privatethistask'         => 'Να γίνει αυτή η εργασία ιδιωτική',
'adddependenttask'        => 'Σύνδεση εξαρτώμενης εργασίας',
'associatetaskid'         => 'Αναγνωριστικό υποεργασίας',
'parenttaskid'            => 'Αναγνωριστικό γονικής εργασίας',
'invalidsupertaskid'      => 'Το αναγνωριστικό γονικής εργασίας δεν είναι έγκυρο.',
'supertaskadded'          => 'Προστέθηκε υπερεργασία',
'supertaskremoved'        => 'Η υπερεργασία αφαιρέθηκε',
'effort'                  => 'Προσπάθεια',
'efforttracking'          => 'Παρακολούθηση προσπάθειας',
'useeffort'               => 'Το έργο χρησιμοποιεί παρακολούθηση προσπάθειας',
'estimatedeffort'         => 'Εκτιμώμενη προσπάθεια',
'totalestimatedeffort'    => 'Συνολική εκτιμώμενη προσπάθεια',
'currenteffortdone'       => 'Τρέχουσα προσπάθεια που έχει επιτευχθεί',
'starteffort'             => 'Έναρξη παρακολούθησης',
'endeffort'               => 'Διακοπή παρακολούθησης',
'cleareffort'             => 'Διαγραφή παρακολούθησης',
'addeffort'               => 'Προσθήκη προσπάθειας',
'manualeffort'            => 'Προσθήκη προσπάθειας με το χέρι (Ω:Λ)',
'efforttrackingstarted'   => 'Η παρακολούθηση προσπάθειας ξεκίνησε για αυτήν την εργασία.',
'efforttrackingnotstarted'=> 'Αδύνατη η έναρξη παρακολούθησης σε ένα θέμα που ήδη παρακολουθείται',
'efforttrackingstopped'   => 'Η παρακολούθηση προσπάθειας έληξε για αυτήν την εργασία.',
'efforttrackingcancelled' => 'Η παρακολούθηση προσπάθειας ακυρώθηκε για αυτήν την εργασία.',
'efforttrackingadded'     => 'Καταγράφηκε με το χέρι προσπάθεια για αυτήν την εργασία.',
'trackinginprogress'      => 'Παρακολούθηση σε εξέλιξη',
'viewestimatedeffort'     => 'Δυνατότητα προβολής παρακολούθησης προσπάθειας',
'viewcurrenteffortdone'   => 'Δυνατότητα προβολής τρέχουσας προσπάθειας που έχει δαπανηθεί',
'trackeffort'             => 'Δυνατότητα παρακολούθησης προσπάθειας',
'invalideffort'           => 'Η προσπάθεια που εισήχθη είναι μη έγκυρη. Πρέπει να είναι αριθμός.',
'showpass'                => 'Εμφάνιση συνθηματικού',
'chooseafile'             => 'Παρακαλούμε επιλέξτε κάποιο αρχείο!',
'incorrectfiletype'       => 'Λανθασμένος τύπος αρχείου. Επιτρεπτοί: jpg, jpeg, gif, png.',
'oauthreqpass'            => 'Δεν υπάρχει δυνατότητα αίτησης συνθηματικού. Εγγραφήκατε μέσω %s',
'addmultipletasks'        => 'Μαζική προσθήκη εργασιών',
'pendingnewuserrequest'   => 'Εκκρεμή αιτήματα νέων χρηστών',
'adminrequestswaiting'    => 'εκκρεμή διαχειριστικά αιτήματα',
'clicktoedit'             => 'Κλικ σε κάθε ένα πεδίο για γρήγορη επεξεργασία',
'confirmedit'             => 'επιβεβαίωση',
'regapprovedbyadmin'      => 'Οι εγγραφές να εγκρίνονται από διαχειριστές (απενεργοποίηση κωδικού επαλήθευσης)',
'activity'                => 'Δραστηριότητα',
'myactivity'              => 'Η δραστηριότητά μου',
'emailverificationwrong'  => 'Η επαλήθευση ηλεκτρονικού ταχυδρομείου δεν ταιριάζει με τη δεδομένη διεύθυνση ηλεκτρονικού ταχυδρομείου',
'verifyemailaddress'      => 'Επιβεβαίωση διεύθυνσης ηλεκτρονικού ταχυδρομείου',
'hideemails'              => 'Απόκρυψη της διεύθυνσης ηλεκτρονικού ταχυδρομείου των χρηστών',
'hidemyemail'             => 'Απόκρυψη της διεύθυνσης ηλεκτρονικού μου ταχυδρομείου',
'exporttasklist'          => 'Εξαγωγή λίστας εργασιών',
'onedecimal'              => 'ένα δεκαδικό',
'manday'                  => 'εργατοημέρα',
'mandays'                 => 'εργατοημέρες',
'mandayabbrev'            => 'εη',
'hourspermanday'          => 'Ώρες ανά εργατοημέρα (ΩΩ:λλ)',
'itemexists'              => 'Το στοιχείο %s υπάρχει ήδη στη βάση δεδομένων.',
'categoryitemexists'      => 'Το στοιχείο %s υπάρχει ήδη στην κατηγορία %s στη βάση δεδομένων.',
'pageswelcomemsg'         => 'Σελίδες στις οποίες να εμφανίζεται το κύριο εισαγωγικό μήνυμα',
'pagesintromsg'           => 'Σελίδες στις οποίες να εμφανίζεται το εισαγωγικό μήνυμα',
'activeoauths'            => 'Ενεργοί πάροχοι OAuth',
'onlyoauthreg'            => 'Να επιτρέπονται μόνο εγγραφές OAuth',
'estimatedeffortformat'   => 'Μορφή εμφάνισης εκτιμώμενης προσπάθειας',
'currenteffortdoneformat' => 'Μορφή εμφάνισης τρέχουσας προσπάθειας που έχει επιτευχθεί',
'minute'                  => 'λεπτό',
'minutes'                 => 'λεπτά',
'minuteplural'            => 'λεπτά',
'minutesingular'          => 'λεπτό',
'minuteabbrev'            => 'λεπ',
'hourplural'              => 'ώρες',
'hoursingular'            => 'ώρα',
'hourabbrev'              => 'ω',
'estimatedeffortopen'     => 'Εκτιμώμενη προσπάθεια για ανοικτές εργασίες',
'currenteffortdoneopen'   => 'Τρέχουσα προσπάθεια που έχει δαπανηθεί σε ανοικτές εργασίες',
'signinwith'              => 'Σύνδεση με %s',
'canviewroadmap'          => 'Δυνατότητα προβολής χάρτη πορείας',
'enableavatars'           => 'Ενεργοποίηση άβαταρ',
'maxavatarsize'           => 'Μέγιστο μέγεθος άβαταρ σε εικονοστοιχεία',
'taskhassubtask'          => 'Αυτή η εργασία έχει την ακόλουθη υποεργασία',
'taskhassubtasks'         => 'Αυτή η εργασία έχει τις ακόλουθες υποεργασίες',
'translations'            => 'Μεταφράσεις',
'translate'               => 'Μετάφραση',
'taskdescription'         => 'Περιγραφή εργασίας',
'notaskdescription'       => 'χωρίς περιγραφή εργασίας',
'pleaseselect'            => 'Παρακαλούμε επιλέξτε',
'closeselectedtasks'      => 'Κλείσιμο επιλεγμένων εργασιών',
'closetasks'              => 'κλείσιμο εργασιών',
'hintforbulkimport'       => "<b>Συμβουλές για μαζική εισαγωγή:</b>\n<ol>\n<li>Αντιγράψτε και επικολλήστε από ένα λογιστικό φύλλο Excel ή ένα CSV επικολλώντας μία ολόκληρη στήλη.</li>\n<li>Προς το παρόν μπορείτε να επικολλήσετε μόνο Σύνοψη και Λεπτομέρειες.</li>\n<li>Υπάρχουν προτάσεις όταν αναθέτετε σε κάποιον, και σε κανέναν αν δεν υπάρχει αντιστοίχιση ονόματος.</li>\n</ol>",
'taskissubtaskof'         => 'Αυτή η εργασία είναι υποεργασία της',
'applyfirstline'          => 'Εφαρμογή πρώτης γραμμής',
'addmorerows'             => 'Προσθήκη περισσότερων γραμμών',
'addtasks'                => 'Προσθήκη εργασιών',
'massopsdisabled'         => 'Λυπούμαστε, η μαζική επεξεργασία είναι επί του παρόντος απενεργοποιημένη για το Flyspray 1.0. Σχεδιάζουμε να ολοκληρώσουμε την υλοποίηση σε μια νεότερη έκδοση του Flyspray. Μπορείτε να τους ενεργοποιήσετε στον πηγαίο κώδικα ξανά με δική σας ευθύνη, αλλά διαβάστε τα σχόλια εκεί πριν το κάνετε.',
'viewroadmap'             => 'Δυνατότητα προβολής χάρτη πορείας',
'nosuicide'               => 'Αγαπητέ χρήστη, ο προγραμματισμός μου δεν επιτρέπει να καταστρέψεις την πρόσβασή σου στο Flyspray απενεργοποιώντας τον ίδιο το λογαριασμό σου ή αλλάζοντας την ομάδα χρηστών σου. Ο ενσυναίσθητικός αδελφός του HAL9000',
'movingtodifferentproject'=> 'Η μετακίνηση μιας εργασίας που έχει είτε γονική εργασία είτε υποεργασία δεν επιτρέπεται. Πρέπει πρώτα να σπάσετε τη σύνδεση μεταξύ τους.',
'musthavesameproject'     => 'Γονική εργασία και υποεργασία πρέπει να ανήκουν στο ίδιο έργο.',
'defaultorderby'          => 'Προεπιλεγμένη ταξινόμηση λίστας εργασιών κατά',
'defaultorderby2'         => 'μετά κατά',
'viewowntasks'            => 'Προβολή ιδίων εργασιών',
'viewgroupstasks'         => 'Προβολή εργασιών ομάδων',
'urlrewriting'            => 'Επανεγγραφή διεύθυνσης url',
'enablehtaccess'          => 'Παρακαλούμε ενεργοποιήστε το αρχείο .htaccess σας στον ριζικό κατάλογο του Flyspray πριν ενεργοποιήσετε την επανεγγραφή διεύθυνσης url',
'nomodrewrite'            => 'Η μονάδα επανεγγραφής (mod rewrite) δεν φαίνεται να είναι διαθέσιμη σε αυτόν τον εξυπηρετητή, λυπούμαστε αλλά δεν μπορούμε να ενεργοποιήσουμε την επανεγγραφή διεύθυνσης url.',
'on'                      => 'Ενεργό',
'off'                     => 'Μη ενεργό',
'defaultorderbydirection' => 'Προεπιλεγμένη σειρά κατά διεύθυνση',
'ascending'               => 'Αύξουσα',
'descending'              => 'Φθίνουσα',
'myassignedtasks'         => 'Οι ανατεθειμένες μου εργασίες',
'commentedon'             => 'σχολίασε στις',
'maxvoteperday'           => 'Μέγιστες ψήφοι ανά ημέρα',
'votesperproject'         => 'Όριο ψήφων χρήστη ανά έργο',
'votelimitreached'        => 'Φτάσατε το όριο ψήφων σας για το έργο αυτό. Δείτε τη σελίδα του προφίλ σας για το ποιες εργασίες έχετε ψηφισμένες επί του παρόντος. Εκεί μπορείτε επίσης να αποσύρετε ψήφους. Έτσι μπορούμε να δούμε ποιες εργασίες είναι πιο σημαντικές για εσάς. Επιλυθείσες εργασίες επιστρέφουν την ψήφο στο διαθέσιμο όριο ψήφων σας.',
'myvotes'                 => 'Οι ψήφοι μου',
'tag'                     => 'Ετικέτα',
'tags'                    => 'Ετικέτες',
'tagsinfo'                => 'Ελεύθερη χρήση ετικετών εργασιών στο Flyspray: Διαχωρίστε τις ετικέτες με ; Δεν χρησιμοποιούνται ακόμα για αναζήτηση, ταξινόμηση ή φιλτράρισμα.',
'novalues'                => 'καμία καταχώριση',
'youhaveregistered'       => 'Έχετε εγγραφεί στο Flyspray. Τα στοιχεία σας είναι ως ακολούθως:',
'youhaveregisterednotify' => 'Η εγγραφή σας στο Flyspray έχει γίνει δεκτή από τους διαχειριστές.',
'usedintasks'             => 'Χρήση',
'freetagging'             => 'Να επιτρέπονται ετικέτες ορισμένες από χρήστη',
'keyboardshortcuts'       => 'Συντομεύσεις πληκτρολογίου',
'testmailsettings'        => 'Δοκιμή τρεχουσών ενεργών ρυθμίσεων ηλεκτρονικού ταχυδρομείου',
'test'                    => 'Δοκιμή',
'testmailsettingsnotice'  => 'Και επίσης ελέγξτε αν λάβατε το δοκιμαστικό μήνυμα ηλεκτρονικού ταχυδρομείου στο λογαριασμό ηλεκτρονικού ταχυδρομείου του τρέχοντος χρήστη (βλ. σελίδα προφίλ σας)',
'invalidinput'            => 'Ωπ! υπάρχουν κάποιες ασύμβατες ιδιότητες που έχουν οριστεί οι οποίες πρέπει να επιλυθούν πριν τη μετακίνηση αυτής της εργασίας σε διαφορετικό έργο.',
'invalidprogress'         => 'Παρακαλούμε επιλέξτε έγκυρη τιμή προόδου.',
'invalidpriority'         => 'Παρακαλούμε επιλέξτε έγκυρη τιμή προτεραιότητας.',
'invalidseverity'         => 'Παρακαλούμε επιλέξτε έγκυρη τιμή σοβαρότητας.',
'invalidstatus'           => 'Παρακαλούμε επιλέξτε έγκυρη κατάσταση εργασίας κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'invalidcategory'         => 'Παρακαλούμε επιλέξτε έγκυρη κατηγορία κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'invalidreportedversion'  => 'Παρακαλούμε επιλέξτε έγκυρη έκδοση στην οποία έγινε η αναφορά κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'invaliddueversion'       => 'Παρακαλούμε επιλέξτε έγκυρη έκδοση στην οποία αναμένεται κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'invalidos'               => 'Παρακαλούμε επιλέξτε έγκυρο λειτουργικό σύστημα κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'invalidtags'             => 'Παρακαλούμε επιλέξτε μόνο επιτρεπτές ετικέτες κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'invalidassignees'        => 'Παρακαλούμε επιλέξτε μόνο έγκυρους αναδόχους κατά τη μετακίνηση εργασίας σε διαφορετικό έργο.',
'customize'               => 'τροποποίηση',
'hidesubs'                => 'απόκρυψη υποεργασιών',
'hideprivate'             => 'απόκρυψη ιδιωτικών εργασιών',
'hideclosed'              => 'απόκρυψη κλεισμένων εργασιών',
'currentproject'          => 'τρέχον έργο',
'targetproject'           => 'έργο προορισμού',
'availablekeybshortcuts'  => 'Διαθέσιμες συντομεύσεις πληκτρολογίου',
'logindialoglogout'       => 'Πλαίσιο διαλόγου σύνδεσης / αποσύνδεσης',
'focustaskidsearch'       => 'εστίαση στο πλαίσιο αναζήτησης εργασιών με αναγνωριστικό',
'openselectedtask'        => 'άνοιγμα επιλεγμένης εργασίας',
'movecursorup'            => 'μετακίνηση δρομέα επάνω',
'movecursordown'          => 'μετακίνηση δρομέα κάτω',
'taskdetails'             => 'Λεπτομέρειες εργασίας',
'taskediting'             => 'Επεξεργασία εργασιών',
'savetask'                => 'αποθήκευση εργασίας',
);

?>
