/* ------------------ IMPORTS -------------------- */
@import url("../../js/jscalendar/calendar-system.css");
@import url("geshi.css");
/*@import url("./fonts/octicons/octicons.css");*/
/*@import url("calendar.css");*/
/* reset.css - Resets default browser CSS.
putting it here saves one extra http request.
*/
html { margin:0;padding:0;border:0;}
body, div, span, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, code,
del, dfn, em, img, q, dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, dialog, figure, footer, header,
hgroup, nav, section {
margin: 0;padding: 0;border: 0;font-size: 100%;vertical-align: baseline;
}
/* This helps to make newer HTML5 elements behave like DIVs in older browsers */
article, aside, details, figcaption, figure, dialog,
footer, header, hgroup, menu, nav, section {
display:block;
}

/* Central default color scheme for Flyspray.
You can overwrite it by grouping the same css rules to your colors later in the file.
Or better load an extra 'customxxx.css' file in the header.tpl after loading theme.css.
*/
.button,
button,
input[type=submit],
input[type=text],
input[type=password],
fieldset,
body.toplevel .box,
div.box,
p.box,
div.roadmap,
.descbox,
#toolboxmenu a.active,
#submenu a.active,
#tasklist,
#search,
#search fieldset,
#intromessage,
#toolbox,
#toolbox div.tab,
#taskdetails,
#taskdetails #showvotes,
#comments, #related, #notify, #remind, #effort, #history,
#events,
div#taskclosed,
#tasklist_table th,
#controlBox {
	background-color:#fff;
}
div.denyform,
div.popup, div#mysearches {
	background-color:#fafafa;
}
tr.active,
body a.button.positive, body button.positive,
#pm-menu-list a.active, #pm-menu-list a.active:hover,
#menu-list a.active, #menu-list a.active:hover,
#s_loginbox:checked ~ #show_loginbox,
#s_quickactions:checked ~ #actions,
#menu-list a#show_loginbox:hover,
.pagenums .active {
	background-color: #5f9729;
}
body a.button.positive, body button.positive, .pagenums .active {
	color: #fff;
}

#disp_intro:not(:checked) ~ .disp_introdep{
        background-color:#ddd;
}
#disp_intro:not(:checked) ~ .disp_introdep select,
#disp_intro:not(:checked) ~ .disp_introdep textarea{
        background-color:#eee;
        color:#666;
}

/*
 highlight advanced search fields that have input 
 no pure CSS styling of options of multiselects possible (it was back in time in some web browsers, a shame!)
*/
#search #searchtext:not(:placeholder-shown),
#search #duedatefrom:not(:placeholder-shown), #search #duedateto:not(:placeholder-shown),
#search #changedfrom:not(:placeholder-shown), #search #changedto:not(:placeholder-shown),
#search #openedfrom:not(:placeholder-shown), #search #openedto:not(:placeholder-shown),
#search #closedfrom:not(:placeholder-shown), #search #closedto:not(:placeholder-shown),
#search input.users:not(:placeholder-shown) {
    background-color: #ff9;
}

.dbtable {background-color:#ccc;}
.dbtable td {border-bottom:1px solid #999;}
.dbfield {background-color:#eee;}
.dbfield em {
    background-color: #ccc;
    padding: 0.2em;
}

.overdue {color:#f00;}
.duetoday {color:#f00;}
.duewarn {color:#660;}

/* end default Flyspray color scheme */

body {
line-height: 1.5; /* Line-height should always be unitless! */
/* direction:rtl; */
}
table {border-collapse: separate;border-spacing: 0;}
caption, th, td {
text-align: left;
font-weight: normal;
float:none !important; /* float:none prevents the span-x classes from breaking table-cell display */
}
table, th, td {vertical-align: middle;}
/* Remove possible quote marks (") from <q>, <blockquote>. */
blockquote:before, blockquote:after, q:before, q:after { content: ''; }
blockquote, q { quotes: "" ""; }
/* Remember to define your own focus styles! */
:focus { outline: 0; }
/* end import reset.css */

/* start typography.css */
/* no colors here. Lets do colors,font-style and text-decoration in extra css files for easy customization */
body {font-family: "Helvetica Neue", Arial, Helvetica, sans-serif; font-size:12px;}
h1,h2,h3,h4,h5,h6 { font-weight: normal; }
h1 { font-size: 3em; line-height: 1; margin-bottom: 0.5em; }
h2 { font-size: 2em; margin-bottom: 0.75em; }
h3 { font-size: 1.5em; line-height: 1; margin-bottom: 1em; }
h4 { font-size: 1.2em; line-height: 1.25; margin-bottom: 1.25em; }
h5 { font-size: 1em; font-weight: bold; margin-bottom: 1.5em; }
h6 { font-size: 1em; font-weight: bold; }
h1 img, h2 img, h3 img, h4 img, h5 img, h6 img {
margin: 0;
}
p { margin: 0 0 1.5em; }
/*
These can be used to pull an image at the start of a paragraph, so
that the text flows around it (usage: <p><img class="left">Text</p>)
*/
/*.left { float: left !important; }*/
p .left { margin: 1.5em 1.5em 1.5em 0; padding: 0; }
/*.right { float: right !important; }*/
p .right { margin: 1.5em 0 1.5em 1.5em; padding: 0; }
/*
a:focus, a:hover { color: #09f; }
a { color: #06c; text-decoration: underline; }
*/
blockquote { margin: 1.5em; font-style: italic;}
strong, dfn { font-weight: bold; }
em, dfn { font-style: italic; }
em.u {text-decoration: underline;} /* dokuwiki underline*/
sup, sub { line-height: 0; }
/*
abbr,acronym { border-bottom: 1px dotted #666; }
*/
address { margin: 0 0 1.5em; font-style: italic; }
/*
del { color:#666; }
*/
pre { margin: 1.5em 0; white-space: pre; }
pre,code,tt { font: 1em 'andale mono', 'lucida console', monospace; line-height: 1.5; }
/* only matches pre tags if there is a language set too e.g. '<pre class="php code">' */
pre[class*=" code"]::before {
    background: #eee none repeat scroll 0 0;
    content: attr(class);
    display: block;
}
pre.code {
    background-color: #fff;
    border: 1px solid #ddd;
    overflow:auto;
}

li ul, li ol { margin: 0; }
ul, ol { margin: 0 1.5em 1.5em 0; padding-left: 2em; }
ul { list-style-type: disc; }
ol { list-style-type: decimal; }
li.level1 {padding-bottom:0.2em;}
dl { margin: 0 0 1.5em 0; }
dl dt { font-weight: bold; }
dd { margin-left: 1.5em;}
/*
Because of the need for padding on th and td, the vertical rhythm
on table cells has to be 27px, instead of the standard 18px or 36px
of other elements.
*/
table { margin-bottom: 1.4em; }
th { font-weight: bold; }
th,td,caption { padding: 4px 10px 4px 5px; }
tfoot { font-style: italic; }
/*
caption { background: #eee; }
*/
.small { font-size: .8em; margin-bottom: 1.875em; line-height: 1.875em; }
.large { font-size: 1.2em; line-height: 2.5em; margin-bottom: 1.25em; }
.hide { display: none; }
/*
.quiet { color: #666; }
.loud { color: #000; }
.highlight { background:#ff0; }
.added { background:#060; color: #fff; }
.removed { background:#900; color: #fff; }
*/
.first { margin-left:0; }
.last { margin-right:0; padding-right:0; }
.top { margin-top:0; padding-top:0; }
.bottom { margin-bottom:0; padding-bottom:0; }

/* ----------------- VARIABLES --------------------- */
/*$far_background: #dcdcdc;*/
/*$far_background: #ededed;*/
/*$top1: lighten(#292626, 2%);*/
/*$dominant: #2C6FB2;*/
/*$dominant: #A82F21;*/
/*$link: #0066CC;*/
/*lighten(#F9F2F2, 1%);*/
/* ----------------- MIXINS --------------------- */
/* ------------------ HELPER CLASSES -------------------- */

.hide {
  display: none;
  visibility: hidden;
}
.clear {clear: both;}
.fade {color: gray; background: pink !important; border: 1px solid blue !important;}
.search_hit {background: rgba(255,255,0,.4);}
img:-moz-broken {
  /* show broken images */
  -moz-force-broken-image-icon: 1;
  width: 24px;
  height: 24px;
  border: solid 2px red;
}
div.popup {
  position: absolute;
  border: #e1e1e1 1px solid;
  margin-top: 5px;
  padding: 5px;
  box-shadow: 0px 1px 2px #f9f9f9;
}

/* ------------------ STYLE -------------------- */
body {background: #f9f9f9; /* direction:rtl;*/}
a {color: #336699;}
a:hover {color: #6699cc;}
#content { padding: 0 20px 10px 20px; margin-top:10px; clear:both; }
#footer {
  display: block;
  margin: 0px 20px 20px 20px;
  padding-top: 10px;
  text-align: right;
}
#title {
  background-color: #3c4041; /* fallback/image non-cover color */
  background-image: -moz-linear-gradient(#3c4041, #242627); /* Firefox 3.6+ */
  background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#3c4041), to(#242627)); /* Safari 4+, Chrome 1+ */
  background-image: -webkit-linear-gradient(#3c4041, #242627); /* Safari 5.1+, Chrome 10+ */
  background-image: linear-gradient(#3c4041, #242627); /* CSS3 CR, IE10+ */
  /*border-bottom: 1px solid #6cab2e;*/
  /*border-bottom: 4px solid $dominant;*/
  margin: 0;
}
#title a {color: white; text-decoration: none; display: inline-block; padding: 25px 50px; }
#title img { float: left; margin-right: 20px; height: 36px;}
#labelpmmenu,#labelmenu1{display:none; cursor:pointer;}
#pmmenu,#menu1{display:none;}
#menu {position: absolute; top:5px; right:5px;}
#menu-list {display: inline;margin: 0;padding: 0;list-style: none; }
#menu-list a, #menu-list label{color: #ddd;text-decoration: none;padding: 3px 7px; }
#menu-list a:hover {
  background: #000;
  border-radius: 3px;
}
#s_loginbox, #s_quickactions { display: none;}
#loginbox, #actionsform { display: none;}
#s_loginbox:checked ~ #loginbox, #s_quickactions:checked ~ #actionsform { display: block; }
tr.active, #menu-list a.active, #s_loginbox:checked ~ #show_loginbox, #s_quickactions:checked ~ #actions {
  /*background: $inverse_link; */
  color: #fff;
  border-radius: 3px;
}
#s_loginbox:checked ~ #show_loginbox{border-radius: 3px 3px 0 0;}
#menu-list a#lastsearchlink.active {
      border-radius: 3px 3px 0px 0px;
}
#menu-list li {
      display: block;
      padding: 0px 2px;
      float: left;
      height: 1.4em;
      border-left: dotted 1px #888888;
}
#menu-list li:first-child {border: none; }
#menu-list #locked { margin-left: 7px; color: red; }
div#mysearches {
  border-radius: 4px;
  border: solid 3px #5f9729;
  overflow: auto;
  min-width:240px;
  max-height: 25em;
  display: none;
  position: absolute;
  right: 0;
  top: 1.4em;
  margin-top: 1px;
  z-index: 5;
  padding: 2px 5px 3px;
  box-sizing:border-box;
}
div#mysearches table#mysearchestable {border-collapse: collapse;width: 100%;margin-bottom: 0;}
div#mysearches table#mysearchestable a {color: #3c4041;font-weight: normal;}
div#mysearches table#mysearchestable a:hover {background: none; text-decoration: underline;}
div#mysearches .searches_delete {width: 20px;}
div#mysearches a {padding: 0 0 0 0.2em;font-weight: bold;}
div#mysearches table tr {border-bottom: dotted 1px gray;text-align: left;padding: 0.1em 0;}
div#mysearches table tr.last {border: 0;}
div#mysearches td {vertical-align: middle;}
#pmcontrol div {
  vertical-align:middle;
  display: -moz-inline-stack; /* optional */
  display: inline-block;
  zoom: 1; /* triggers hasLayout for IE */
  *display: inline; /* target IE7 only */
}
#pmcontrol input[type="text"]{
	height:auto;
}
#showtask #taskid {width: 50px;}
#projectselector { /*margin-top: 3px;*/ margin-right: 10px; }
#projectselector button { margin-bottom: 2px;}
#projectselector option[selected] { font-weight: bold;}
#pm-menu{background-color:#222;	border-bottom: solid 4px #5f9729;padding: 0px 0px 0px 10px; /*text-align:center;*/ }
#pm-menu-list {list-style: none;display: inline-block;margin:0;min-height:30px;}
#pmcontrol{display: inline-block;float: right;margin: 6px 20px 0px 0px;}
#pm-menu-list li {display: inline-block;}
#pm-menu-list li a {display: block; line-height: 1.4em; padding: 11px 11px 8px 35px; color: #f9f9f9;
        text-decoration: none; border-left: dotted 1px #3c4041; border-top-left-radius: 3px; border-top-right-radius: 3px;
        background-repeat: no-repeat; background-position: 12px 50%;
}
#pm-menu-list a:hover { background-color: #000; border-left: 1px solid #000;}
#pm-menu-list a.active {
        border-left: none;
        border-top: 1px solid #6cab2e;
        border-right: 1px solid #6cab2e;
}
#pm-menu-list li:first-child a {border-left: none;}
#toplevellink {background-image: url("img/gray/folder_stroke_12x12.png");}
#homelink {background-image: url("img/gray/list_12x11.png");}
#newtasklink {background-image: url("img/gray/document_alt_stroke_9x12.png"); }
#newmultitaskslink {background-image: url("img/gray/document_alt_stroke_9x12.png");}
#mytaskslink {background-image: url("img/gray/calendar_alt_stroke_12x12.png");}
#reportslink {background-image: url("img/gray/calendar_alt_stroke_12x12.png");}
#roadmaplink {background-image: url("img/gray/compass_12x12.png");}
#projectslink {background-image: url("img/gray/cog_alt_12x12.png");}
.active#toplevellink {background-image: url("img/white/folder_stroke_12x12.png");}
.active#homelink {background-image: url("img/white/list_12x11.png");}
.active#newtasklink {background-image: url("img/white/document_alt_stroke_9x12.png");}
.active#mytaskslink {background-image: url("img/white/calendar_alt_stroke_12x12.png");}
.active#reportslink {background-image: url("img/white/calendar_alt_stroke_12x12.png");}
.active#roadmaplink {background-image: url("img/white/compass_12x12.png");}
.active#projectslink {background-image: url("img/white/cog_alt_12x12.png");}
/* --- buttons --- */
#actionbar { /*height: 4em;*/ position: relative;}
#actionbar a.button, #actionbar button.button { margin-bottom: 0;}
#actionbar .main {float: right;}
.button, button, input[type=submit] {
  display: -moz-inline-stack; /* optional */
  display: inline-block;
  zoom: 1; /* triggers hasLayout for IE */
  *display: inline; /* target IE7 only */
  margin: 0.3em 0.3em 0.3em 0;
  padding: 4px;
  /* Links */
  border: 1px solid #bbb;
  border-radius: 4px;
  box-shadow: 0px 1px 1px #ddd;
  font-family: "Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
  font-size: 100%;
  line-height: 130%;
  text-decoration: none;
  font-weight: bold;
  color: #565656;
  cursor: pointer;
}
a.button img, button.button img {
  margin: 0 3px -3px 0 !important;
  padding: 0;
  border: none;
  width: 16px;
  height: 16px;
  float: none;
}
a.button:hover, button:hover, .button:hover, input[type=submit] {background-color: #f2f2f2;border: 1px solid #a1a1a1;}
a.button.disabled{background-color: #f2f2f2; border: 1px solid #a1a1a1;color: #9e9e9e;}
a.button:active, button.button:active {background-color: #6299c5;border: 1px solid #6299c5;color: #fff;}
body a.positive, body button.positive {
  border: solid 1px #5a8f27;
  border-top: solid 1px #85cb41;
  border-right: solid 1px #85cb41;
}
a.positive:hover, button.positive:hover {
  background-color: #78bf34;
  border: solid 1px #5f9729;
}
a.positive:active, button.positive:active {
  background-color: #529214;
  border: 1px solid #529214;
}
.button.img.delete {
	background-image: url('./img/red/x_alt_24x24.png');
	background-size: contain;
	background-repeat: no-repeat;
	background-color:transparent;
	box-shadow:none;
	border:none;
}
#table tr:first-child td:first-child button.img.delete {display: none;}

body .negative {color: #d12f19;}
a.negative:hover {background-color: #fbe3e4;border: 1px solid #fbc2c4;color: #d12f19;}
a.negative:active {background-color: #d12f19;border: 1px solid #d12f19;color: #fff;}
#intromessage {display: block;}
#tasklist {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
#tasklist_table {width: 100%;}
.pagenums{display:inline-block;}
.pagenums a, .pagenums .active {
	display:inline-block;
	margin-left:0.1em;
	margin-right:0.1em;
	min-width:1em;
	border-radius:3px;
	text-align:center;
}
.pagenums .active {padding:0.2em 0.5em;}
.pagenums a {
	padding:0.2em 0.4em;
	border:1px solid #ddd;
	background-color:#fff;
}
/*
.pagenums a.first::before { content:'<<';padding-right:0.5em;}
.pagenums a.previous::before { content:'<';padding-right:0.5em;}
.pagenums a.next::after { content:'>';padding-left:0.5em;}
.pagenums a.last::after { content:'>>';padding-left:0.5em;}
*/
.pagenums span.ellipsis::before {content:'…';padding-left:0.5em;padding-right:0.5em;}
.pagerange, .taskrange{padding-top:0.2em;padding-bottom:0.2em;}
#search {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
  position:relative;
}
#search fieldset {
    margin: 10px 0px 10px 0px;
    padding: 10px;
    border: solid 1px #e1e1e1;
    border-radius: 3px;
}
#search #exporttasklist {
	position:absolute;
	right:0;
	top:0;
}
#intromessage {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
body.toplevel .box {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
  margin: 10px 0 0 10px;
  width: 400px;
  /*@include inline-block;*/
  /*vertical-align: middle;*/
  float: left;
}
body.toplevel .single-project {
  width: auto;
  float: none;
  display: block;
  height: auto;
}
body.myprofile .box {display:inline-block;vertical-align:top;}
body.myprofile .box .permissions {
	display:flex;
}
.permissions thead th {
	height:3em;
}
.permissions tbody th,
.permissions tbody td {
	height: 22px;
	white-space: nowrap;
	border-bottom: 1px solid #999;
	display: table-cell;
}
#editgroup, #userlist{display:inline-block;vertical-align:top;}
.progress_bar_container {
  width: 150px;
  margin:0;
  border: solid 1px rgba(0,0,0,0.3);
  height: 15px;
  position: relative;
  border-radius: 2px;
  display: -moz-inline-stack; /* optional */
  display: inline-block;
  zoom: 1; /* triggers hasLayout for IE */
  *display: inline; /* target IE7 only */
  vertical-align: sub;
}
.progress_bar_container .progress_bar {
  height: 100%;
  position: absolute;
  left: 0;
  top: 0;
  background-color: #78bf34; /* fallback/image non-cover color */
  background-image: -moz-linear-gradient(#acdc7d, #78bf34); /* Firefox 3.6+ */
  background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#acdc7d), to(#78bf34)); /* Safari 4+, Chrome 1+ */
  background-image: -webkit-linear-gradient(#acdc7d, #78bf34); /* Safari 5.1+, Chrome 10+ */
  background-image: linear-gradient(#acdc7d, #78bf34); /* CSS3, IE10+ */
}
.progress_bar_container span {
    text-align: center;
    position: absolute;
    z-index: 1;
    width: 100%;
    font-size: 10px;
    line-height: 1em;
    text-shadow: 0 0 6px white;
    top:2px;
}
td.task_progress .progress_bar_container {width: 100%;box-sizing:border-box;}
a {text-decoration: none;}
#tasklist_table th img {position: relative;top: 2px;}
#tasklist_table .caret {width:10px; padding-left:2px; padding-right:0px;}
#tasklist_table tr.current_row td.caret::after {
	font-family: fontawesome;
	content: '\f054'; /* fa-chevron-right */
}
#tasklist_table .ttcolumn {width: 10px;text-align: center;}
#tasklist_table .ttcolumn input {margin: 0;}
#tasklist_table .ttcolumn a::after, a.toggle_selected::after {
        font-family: fontawesome;
        content: '\f0ec'; /* fa-exchange */
}

#tasklist_table thead th {line-height:1;}
#tasklist_table tbody td {border-top:1px solid transparent;border-bottom:1px solid transparent;line-height:1.2;vertical-align:middle;}
.task_summary {word-wrap:break-word;word-wrap:anywhere;/* css3, ff65+ */}
#tasklist_table tbody tr:hover td {border-color:#ddd;}
#tasklist_table tr.closed, #myvotes tr.closed {background-color:#ddd;}
tr.severity1 .task_severity {background-color: #fff;}
tr.severity2 .task_severity {background-color: #fff;}
tr.severity3 .task_severity {background-color: #f5e7e7;}
tr.severity4 .task_severity {background-color: #f5dddd;}
tr.severity5 .task_severity {background-color: #f5d1d1;}


td.task_openedby > a, td.task_editedby > a,  td.task_assignedto > a {white-space:nowrap;position:relative;line-height:1;display:block;padding:3px;}
td.task_openedby > a .fa-user, td.task_editedby > a .fa-user {color:#eee;}
td.task_assignedto > a {margin-right:2px;}
/* small names over avatars */
td.task_openedby > a::after, td.task_editedby > a::after, td.task_assignedto > a::after {
	background-color: rgba(255, 255, 255, 0);
	bottom: 0;
	color: rgba(0,0,0,0);
	content: attr(title);
	/*font-size: 8px;*/
	left: 0;
	line-height:1;
	position: absolute;
	text-align: center;
	padding-left:1px;
	padding-right:1px;
}
td.task_openedby > a:hover::after, td.task_editedby > a:hover::after, td.task_assignedto > a:hover::after {color:#000;background-color:rgba(255,255,255,0.9);}

#toolbox {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
  margin-left: 120px;
  min-height: 450px;
  height: 1%; /* Fix for IE bug */
  padding: 20px;
}
#toolbox div.tab {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
#toolbox h3 {
  margin-bottom: 1em;
  padding-bottom: 5px;
  border-bottom: 1px solid #ddd;
}
#toolboxmenu {position: relative;float: left;padding-top: 10px;}
#toolboxmenu a {
  display: block;
  border: 1px solid #d4d4d4;
  /*border-right: none; */
  padding: 1em 5px;
  margin-left: 10px;
  width: 100px;
  text-align: center;
  background: #e5e5e5;
  color: #3c4041;
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
}
#toolboxmenu a:hover {background-color: #d6d8d9; /*color: $inverse_link;*/ }
#toolboxmenu a.active {
  margin-left: 0;
  font-weight: bold;
  width: 100px;
  padding: 1em 10px;
  color: #3c4041;
  border: 1px solid #e1e1e1;
  border-right: none;
  /*border-left: 1px solid lighten($top1, 30%);*/
  border-left: 2px solid #78bf34;
}
#prefslogo {max-width:200px;}
#controlBox {
  border: 1px solid gray;
  padding: 1px;
  width: auto !important;
  width: 90px;
  margin-left: 40px;
  display: table;
  position: absolute;
}
#controlBox div.grip {
  background: #ccc;
  cursor: move;
  height: 12px;
}
.grip::after {
    content: '\2550\2550';
    text-align: center;
    display: block;
    color: #999;
    line-height: 10px;
    font-size: 16px;
}
#controlBox div.inner {
  padding: 5px 5px 4px 5px;
  white-space: nowrap;
  opacity: .2;
}
#controlBox.active div.inner {opacity: 1;}
div#fineprint {
  font-size: smaller;
  margin: 5px 0;
  padding: 0;
  color: #555;
}
#controlBox #controlBoxUp,
#controlBox #controlBoxDown {
	display:block;
}

.dokuwiki_toolbar {
	display:inline;
	vertical-align:bottom;
}

/* can be overwritten by darkmode.css */
.dokuwiki_toolbar a {
	display:inline-block;
	width:30px;
	height:28px;
	text-align:center;
	border-radius:3px;
	background-color:transparent;
	border:1px solid transparent;
	vertical-align:bottom;
	color:#555;
}

.dokuwiki_toolbar a:hover {
	background-color:#eee;
	color:#000;
	border-color:#666;
}

.dokuwiki_toolbar .divider {
	display:inline-block;
	width:0;
	height:20px;
	border-left:1px solid #aaa;
	vertical-align:bottom;
	margin-bottom:4px;
}

.dokuwiki_toolbar a i {
	vertical-align:bottom;
	line-height:1.8em;
}
span.hdepth {
	display:inline-block;
	vertical-align:bottom;
	height:20px;
	font-size:16px;
	margin-bottom:6px;
}
hr.editorhr {
	margin-top:14px;
	height:0;
	border-color:#666;
	border-top-width:2px;
	width:16px;
	display:inline-block;
}

a.urlextern::after {
	content: '\f08e';
	font-family: fontawesome;
	display:inline-block;
	padding-left:0.3em;
	font-size:10px;
	opacity:0.6;
}

form #taskfields { width: 335px;}
form #taskdetailsfull {
  position: relative;
  top: -20px;
  margin-left: 355px;
}

#taskdetailstext table,
.commenttext table,
table.inline {
	border-collapse:collapse;
}
#taskdetailstext table td,
#taskdetailstext table th,
.commenttext table td,
.commenttext table th,
table.inline td,
table.inline th {
	border:1px solid #ccc;
	padding:4px;
}

#shortcutlabel { cursor:pointer;padding-left:1em;}
#shortcutclose { cursor:pointer;float:right; }
#shortcuts {
  display:none;
  position:fixed;
  z-index:100;
  background:#fff;
  border:1px solid #999;
  border-radius:10px;
  padding:10px;
  box-shadow:0 0 400px #000;
  top:50%;
  margin-top:-260px;
  max-height:540px;
  left:50%;
  width:360px;
  margin-left:-180px;
  box-sizing:border-box;
}
#shortcutsmodal {
  background-color: rgba(0, 0, 0, 0.3);
  display: none;
  height: 100%;
  left: 0;
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 99;
  cursor:pointer;
}
#s_shortcuts {display:none;}
#s_shortcuts:checked ~ #shortcuts, #s_shortcuts:checked ~ #shortcutsmodal {display: block;}
#shortcuts > ul {
    list-style: outside none none;
    margin-left: 0;
    padding-left: 0;
}
#shortcuts li{line-height:2em;}
kbd {
	color:#000;
	background-color: #eee;
	border: 1px solid #ccc;
	border-radius: 4px;
	padding: 2px;
}

#taskdetails {
  margin: 10px 0px 10px 0px;
  padding: 0px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
#taskdetails #navigation {float: right;padding:6px;}
#taskdetails h2 {color: #555;display:inline-block;max-width:100%;/* for word-wrap working chrome+safari */}
#taskdetailsfull p,
#taskdetailsfull li,
.commenttext p,
.commenttext li {
max-width:40em;
}
.links a,
#taskdetailstext,
#taskdetailsfull h2,
.commenttext{
	word-wrap:break-word;
	word-wrap:anywhere; /* css3, firefox65+ */
}
.group.inactive{ background-color:#eee;}
.tag {
    background: #ccc none repeat scroll 0 0;
    border-radius: 3px;
    margin-left: 3px;
    padding: 1px 3px;
    font-style:normal;
    white-space: nowrap;
    vertical-align:text-bottom;
}

.details .tag {
	position:relative;
}
.details .tag span.added { display:none; position:absolute; left:0;top:1.2em;}
.details .tag span.addedby { display:none; position:absolute; left:0;top:2.2em;}
.details .tag:hover span.added {display:block;}
.details .tag:hover span.addedby {display:block;}

.tag:before {font-family:fontawesome; padding-right:3px;}
.tag:after {content:attr(title);}
/* style your tags by their tag_id, may be managed by tag list management in admin/project settings */
/*
.tag.t1{background-color:#666;}
.tag.t1:before{content:'\f153';color:#cc0;}
.tag.t2{background-color:#0c0;}
.tag.t3{background-color:#09c;}
*/
#taskfields {
  width: 290px;
  float: left;
  border-right: 1px solid #eee;
  padding-top: 5px;
  background: #f9f9f9;
  margin: 0;
}
#taskfields ul.fieldslist {
  margin-bottom: 5px;
  list-style: none;
  margin-right: 0;
  padding-left: 0;
}
#taskfields ul.fieldslist li {
  clear: both;
  padding-top: 2px;
  padding-bottom: 2px;
  overflow: auto;
  width: 100%;
  border-radius: 4px;
}
#taskfields ul.fieldslist li .label {
  display: block;
  float: left;
  width: 45%;
  text-align: right;
  color: #888;
}
#taskfields ul.fieldslist li .value {display:block;float:right;width:50%;}
#taskfields ul.fieldslist > li:nth-child(2n-1) {background-color: #f1f1f1;}
#taskdetails #showvotes {
  position: absolute;
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
  z-index:100;
}
.fieldslist .reopened{display:inline-block;font-size:10px;line-height:10px;vertical-align:middle;width:60px;}
#taskdetailsfull {margin-left: 291px;padding: 2em 3em;}
#itemsummary, #tags {width:100%;box-sizing:border-box;height:auto;margin-bottom:10px;margin-top:8px;}
.descbox table, #taskdetailstext table{border-collapse:collapse; border:1px solid #999;}
.descbox td, .descbox th, #taskdetailstext td, #taskdetailstext th{border:1px solid #999;}
#taskinfo {
  margin-left: 291px;
  margin-top: 15px;
  border-top: 1px solid #e1e1e1;
  padding: 8px 5px;
}
#comments, #related, #notify, #remind, #effort, #history {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
#comments h4 {margin:1em 0 0.5em 0;}
.userlist th {background-color: #e0e0e0;}
.userlist tbody tr:nth-child(2n) td {background-color: #f1f1f1;}
#related .related {display:inline-block;vertical-align:top;margin-right: 0;}
#submenu {margin-bottom: 0;height: 25px;}
#submenu a {
  border: 1px solid #d4d4d4;
  background: #e5e5e5;
  color: #3c4041;
  display: block;
  float: left;
  height: 21px;
  margin: 4px 0 0 2px;
  padding: 7px 10px 1px 10px;
  border-top-left-radius: 5px;
  border-top-right-radius: 5px;
}
#submenu a:hover {background-color: #d6d8d9;}
#submenu a.active {
  height: 26px;
  margin-top: 0;
  font-weight: bold;
  border-bottom: 1px solid white;
  border-right: bottom;
  /*border-top: 1px solid lighten($top1, 30%);*/
  border-top: 2px solid #78bf34;
  z-index: 5;
}
#submenu li {display: inline;}
div.tab {margin: 10px 1ex 10px 0;padding: 1ex 1ex 0;}
.tab{display:none;}
.tab.active{display:block;}
* html .tab div.clear {clear: none;height: 14em;}
div.comment_container {margin: 5px;}
div.comment_container .comment_avatar {	min-width: 50px;display: inline-block;}
div.comment_container .comment_avatar .av_comment img { width: 50px; height: 50px }
div.comment_container .comment {
	position: relative;
	display: inline-block;
	margin-left: 10px;
	border: 1px solid #e1e1e1;
	vertical-align: top;
	width: 700px;
	border-radius: 3px;
}
div.comment_container .comment:before {
	content: ' ';
	position: absolute;
	width: 0;
	height: 0;
	left: -16px;
	top: 3px;
	border: 8px solid;
	border-color: transparent #e1e1e1 transparent transparent;
}
div.comment_container .comment:after {
	content: ' ';
	position: absolute;
	width: 0;
	height: 0;
	left: -12px;
	top: 5px;
	border: 6px solid;
	border-color: transparent #f1f1f1 transparent transparent;
}
div.comment_container .comment_header {
	min-height: 30px;
	background-color: #f1f1f1;
	line-height: 30px;
	vertical-align: middle;
	padding-left: 10px;
	border-bottom: 1px solid #e1e1e1;
}
div.comment_container .comment_header_infos {max-width: 60%;}
div.comment_container .comment_header_actions {float: right;margin-right: 10px;}
div.comment_container .comment_header_usertype {
	border: 1px solid #e1e1e1;
	padding: 3px;
	margin-right: 10px;
	border-radius: 3px;
}
div.comment_container .commenttext {clear: both;padding: 10px;}
.commenttext pre {overflow:auto;}
div.comment_container .attachments {
	display: inline-block;
	width: 45%;
	margin-top: 10px;
	padding: 10px;
	border: solid 1px #e1e1e1;
	border-radius: 3px;
	width: 300px;
	background-color: #ffc;
	/*
	background-image: url(img/gray/pin_24x24.png);
	background-repeat: no-repeat;
	background-position: 270px 5px;
	*/
	vertical-align: top;
}
div.attachments::after {
    color: #999;
    content: "\f0c6"; /*fa-paperclip*/
    float: right;
    font-family: FontAwesome;
    font-size: large;
}
div.comment_container .links {
	display: inline-block;
	width: 45%;
	margin-right: 3%;
	margin-top: 10px;
	padding: 10px;
	border: solid 1px #e1e1e1;
	border-radius: 3px;
	width: 300px;
	background-color: #fefefe;
	vertical-align: top;
}
div.comment_container .attachments img {
	position: relative;
	top: 4px;
}
div.comment_container #addlinkbox, #taskdetailsfull #addlinkbox {
	display: inline-block;
	width: 50%;
	vertical-align: top;
}
div.comment_container #uploadfilebox, #taskdetailsfull #uploadfilebox {
	display: inline-block;
	width: 49%;
	vertical-align: top;
}
div.comment_container .commentlink {
  background-image: url(img/gray/comment_stroke_16x14.png);
  background-repeat: no-repeat;
  display: block;
  float: left;
  height: 14px;
  width: 16px;
  margin: 2px 4px 0 2px;
}
div.comment_container .commentlink:hover {background-image: url(img/black/comment_stroke_16x14.png);}
textarea {width: 99%;}
#events {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
.eventlist.hasresult {height: 150px;}
table th {vertical-align: middle;}
table td {vertical-align: top;}
div.box, p.box {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
div.roadmap {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
div#successanderrors {
  border: none;
  border-radius: 3px;
  z-index: 50;
  margin: 30px auto 0 auto;
  position: absolute;
  top: 0;
  width: 30%;
  min-width:300px;
  left: 35%;
}
div.error, div.success {
  border-bottom: 1px solid rgba(0,0,0,0.5);
  padding: 6px;
}
div.error {
  color: #4b1710;
  background: #ffe6e2;
}
div.success {
  color: #24380d;
  background: #e8f9d4;
}
.warning {background-color:#fc0; color:#333;}
a#show_loginbox {margin-right: 5px;}
#loginbox {
  border-radius: 3px 0 3px 3px;
  background: #ddd;
  border: solid 3px #5f9729;
  right: 2px;
  z-index: 200;
  min-width: 240px;
  padding-top: 15px;
  margin-top: 1px;
  box-shadow: none;
}
#login_input {text-align: center;}
#login_links {text-align: center;}
#login_oauth {margin-top: 10px;}
#loginbox #login label {color: #222;}
#loginbox #login a {color: #222;text-decoration: underline;}
#loginbox #login a:hover {color: #fff;}
form#login {position: relative;}
form#login #lbl_user_name, form#login #lbl_password {
  display:block;
  margin: 10px auto;
  padding: 5px 2px;
}
form#login label {width: 50px;color: #ddd;width: 100px;margin: 0 2px 0 20px;}
form#login #links {position: absolute;top: 30px;left: 20px;}
form#login #links a {padding: 3px 7px;}
form#login #links a:hover {
  background: #494d4e;
  text-decoration: none;
  color: #dddddd;
  border-radius: 10px;
}
form#login #links a.active {
  background: #dddddd;
  color: #3c4041;
  border-radius: 10px;
}
form#login .remember_me {float: right;}
span#advancedsearchstate img {vertical-align: middle;}
fieldset {
  margin: 10px 0px 10px 0px;
  padding: 10px;
  border: solid 1px #e1e1e1;
  border-radius: 3px;
}
/*
#content > fieldset legend {
  color: #3c4041;
  background: #f9f9f9;
  padding: 2px 9px;
  border: solid 1px #e1e1e1;
  border-radius: 10px;
}
*/
#content > h3 {margin-top: 1em;}
thead th {
  border-bottom: solid 1px #a1a6a8;
  background: none;
}
div#taskstatus {border-bottom: 1px solid #ccc;padding: 4px;margin-bottom: 5px;}
div#taskclosed {
  padding: 5px;
  margin: 5px 5px 10px;
  clear: both;
  width: 20em;
  border: solid 1px red;
}
div#taskdeps {float: left;width: 50%; margin-bottom: 8px;}
div#subtasks {display: inline;align: right;float: left;width: 50%;margin-bottom: 8px;}
div#taskblocks { float: left; width: 45%;}
a.datebutton {
	display:inline-block;
	vertical-align: middle;
}
a.datebutton::before {
        font-family:fontawesome;
        content:"\f133";
        color:#555;
        font-size:large;
}
a.datebutton:hover::before {
        content:"\f073";
        color:#000;
}
a.datelink{
	white-space:nowrap;
}
hr { /*color: $box_border;*/ border: none; border-top: 1px solid #e1e1e1;}
.perms{display:inline-block;vertical-align:top;}
.bad{color:#900;}
.good{color:#090;}

fieldset.advsearch_misc input {vertical-align: middle;}
fieldset.advsearch_misc label {margin-right: 10px; white-space: nowrap;}
fieldset.advsearch_dates label {margin: 0 5px;}
.search_select {float: left;position: relative;margin-right: 10px;}
.search_select .multisel {position: absolute;white-space: nowrap;}
.search_select select {margin-top: 1.5em;height:158px;}
.search_select select#percent option {font-size: 10px;height: 12px;}
fieldset.advsearch_users .multisel {position: absolute;white-space: nowrap;}
fieldset.advsearch_users input {margin-top: 1.5em;}
/* --------------------------- FORMS -----------------------*/
.bulkuser {padding-left: 120px;}

.bulkedituser td.inactive{color:#888;}
.account_header {background-color: #ddd;}
.account_enabled {background-color: #efd;}
.account_enabled:nth-child(2n) {background-color: #dfb;}
.account_enabled:hover, .account_enabled:nth-child(2n):hover {background-color: #af8;}
.account_disabled {background-color: #fdd;}
.account_disabled:nth-child(2n) {background-color: #fcc;}
.account_disabled:hover, .account_disabled:nth-child(2n):hover {background-color: #f99;}

ul.form_elements {list-style: none;padding: 0;margin: 0 0 0 1em;}
ul.form_elements li {padding: 2px;margin-bottom: 9px;}
ul.form_elements label {
      width: 200px;
      display: -moz-inline-stack;
      /* optional */
      display: inline-block;
      zoom: 1; /* triggers hasLayout for IE */
      *display: inline; /* target IE7 only */
      vertical-align: top;
      text-align: end;
      padding-right: 1ex;
      padding-top: 2px;
      color: #555;
}
ul.form_elements label.inline {display: inline;vertical-align:middle;}
ul.form_elements label.labeltextarea {width:auto;display:block;text-align:left;}
ul.form_elements input {vertical-align: middle;}
ul.form_elements input[type="text"], ul.form_elements input[type="password"] {width:300px;}
ul.slim li {margin-bottom:0;padding-bottom:4px;}
ul.slim input[type="text"], ul.slim input[type="password"] {width:auto;}
ul.slim label {width:110px;}
ul.form_elements li.required label {font-weight: bold;}
ul.form_elements span.note {margin-left:205px;}
ul.wide label {width:250px;}
ul.slim {margin:0;}
ul.slim .userSelectWidget {width:95%;margin-left:auto;margin-right:auto;}
ul.slim .userSelectWidget input {width:100px;}
ul.slim .userSelectWidget select {width:100%;}
.dateselect {clear: both;}
.dateselect label:first-child {
  width: 120px;
  text-align: right;
  padding-right: 5px;
  float: left;
}
/* fancy dual selects */
.double_select {position: relative;}
.double_select .dualselect_selectable {
  height: 220px;
  width: 40%;
  display: -moz-inline-stack; /* optional */
  display: inline-block;
  zoom: 1; /* triggers hasLayout for IE */
  *display: inline; /* target IE7 only */
  vertical-align: middle;
}
.double_select .dualselect_buttons {
  width: 16%;
  display: -moz-inline-stack; /* optional */
  display: inline-block;
  zoom: 1; /* triggers hasLayout for IE */
  *display: inline; /* target IE7 only */
  vertical-align: middle;
}
.double_select .dualselect_buttons button {width: 100%;padding: 3px;}
.double_select .dualselect_selected {
  height: 220px;
  /*min-width: 12em;*/
  display: -moz-inline-stack;
  /* optional */
  display: inline-block;
  zoom: 1;
  /* triggers hasLayout for IE */
  *display: inline;
  /* target IE7 only */
   vertical-align: middle;
   width: 40%;
}
.double_select .dualselect_selected select {
  width: 100%;
  height: 80%;
}
.double_select .dualselect_selected button {
  height: 16px;
  line-height:0;
  width: 100%;
  margin:0;
}
.double_select .c1 select {
  height: 24em;
  min-width: 12em;
  width: auto;
}
.double_select td {
  text-align: center;
  vertical-align: middle;
}
.double_select .c3 button {
  height: 2em;
  width: 12em;
}
.double_select .c3 select {
  height: 20em;
  min-width: 12em;
  width: auto;
}

#disp_intro + label{text-align:start;}

/* list management */
.list .cname {width:200px;}
.list .cuser {width:100px;}
.list .corder {width:50px;}
.list .cshow {width:50px;}
.list .ctense {width:80px;}
.list input[id^='listname'], .list input[id^='listposition'] {width:100%;}
#catTable .first{ white-space:nowrap;min-width:120px;}
#listTable thead#globalentries td {background-color: #eee;}
#listpositionnew {width:100%;}

.perms tbody th[title] {text-decoration: underline dotted;}
.perms .everybody{
	position:relative;
	position:-webkit-sticky; /* fix for safari */
}
.perms .everybody th:before {content:'Allowed for everybody - project setting overrules this group setting!';color:#900;position:absolute;left:2px;z-index:2;text-shadow:0 0 2px #fff;top:-2px;}
.perms .everybody > * { background-color: #6c6; }

/* closing and requestreopen task form */
div#requestreopen,
div#closeform {
  border-radius: 3px;
  box-shadow: 0px 1px 1px #ddd;
  padding: 2em;
  position: absolute;
  right: 5px;
  top: 3em;
  z-index:300;
}
/* 'quick actions' on the right side */
#actionsform {
    border-radius: 3px;
	box-shadow: 0px 1px 1px #ddd;
    position: absolute;
    right: 5px;
    top: 3em;
    z-index: 200;
}
#actionsform ul {
    font-family: Arial, Verdana;
    font-size: 12px;
    margin: 0;
    padding: 0;
    list-style: none;
}
#actionsform li {
	border-top: 1px solid #fff;
	display: block;
	position: relative;
	background: #363a3b;
	color:#fff;
	padding: 0px;
}
#actionsform li a, #actionsform li label, #actionsform li button{
  display: block;
  text-decoration: none;
  color: #fff;
  white-space: nowrap;
  padding:5px 15px;
  background:none;
  margin:0;
  border:none;
  font-weight:normal;
  font-size:12px;
  box-shadow:none;
}
#actionsform ul li:hover { background: #617F8A; }
#actionsform li:hover ul {display:none;}
#actionsform li:hover ul {
    display: block;
    position: absolute;
}
#actionsform li:hover li {float: none;font-size: 11px;}
#edit_add_comment{display:none;}
#setparentform, #associateform, #adddepform {
	display:none;
	background: #363a3b;
	color:#fff;
	padding-left: 5px;
}
#s_parent, #s_associate, #s_adddependent, #s_addcomment {
	display:none;
}
#s_addcomment:checked ~ #edit_add_comment,
#s_parent:checked ~ #setparentform,
#s_associate:checked ~ #associateform,
#s_adddependent:checked ~ #adddepform{
	display:block;
}
#actionsform #setparentform *, #actionsform #associateform *, #actionsform #adddepform * {display: inline-block;}
#actionsform #setparentform button, #actionsform #associateform button, #actionsform #adddepform button {
	background-color:#fff;
	color:#000;
	margin-right:4px;
	margin-bottom:4px;
}
#actionsform #setparentform input[type=text],
#actionsform #associateform input[type=text],
#actionsform #adddepform input[type=text] {
	width:60px;
}
#taskdeps h4 {margin-bottom:0.3em;}
#taskdeps table {margin:0 0 0.8em -0.2em;}
#taskdeps td {padding:0.2em 0.4em;}
#taskdeps img {vertical-align:middle;margin-top:-1px;}
input[type=text], input[type=password]{
    color: #000;
    border: 1px solid #ccc;
    padding: 2px;
    vertical-align: middle;
}
input[type=text], input[type=password]{
    height: 19px;
}
#table input[type=text] {
    width: 120px;
}
input[type=text], input[type=submit], button {
    border-radius: 3px;
}
#show_loginbox {
	cursor:pointer;
	background: #494D4E;
	border-radius: 3px;
}
#login_button {display: block;margin: 6px auto;vertical-align: baseline;}
div.denyform {
	visibility:hidden;
	position:absolute;
	right:10px;
	background-image: none;
	border: 1px solid #E1E1E1;
	margin-top:5px;
	display:block;
	width:280px;
	height:auto;
	padding:5px 5px 5px 5px;
}
/*#notify_types {height: 10em;}*/
#rassigned_to {height: 12em; }

/* Stuff for the autocomplete lists {{{ */
.autocomplete {
	background-color:#fff;
	position: absolute;
	width: auto !important;
	box-shadow:0 5px 7px #ccc;
	padding: 0px;
	margin:-1px 0 0;
	text-align:left;
	display:block;
}
.autocomplete ul {
	list-style-type: none;
	margin: 0px;
	padding: 0px;
}
.autocomplete ul li {
	list-style-type: none;
	display: block;
	margin: 0;
	padding:0;
	height: 25px;
	white-space:nowrap;
	vertical-align:middle;
}
.autocomplete ul li span.informal {
	color: #333;
}
.autocomplete ul li.selected {
	background-color: #5F9729;
	cursor:pointer;
	color:HighlightText;
}
.autocomplete img, .autocomplete .noavatar{
	width:25px;
	height:25px;
	display:inline-block;
}

#actionbuttons {
	margin-left: 300px;
	margin-top: 15px;
	min-height: 50px;
	padding: 8px 5px;
}
table.assignedto {border:0px;border-collapse: collapse;}
table.assignedto tr {height: 30px;}
table.assignedto td {
	margin:0px;
	padding:0px;
	padding-right: 5px;
	vertical-align: middle;
}
table.assignedto img {padding-top: 2px;width: 25px;height:25px;}
a.tooltip {outline:none; }
a.tooltip strong {line-height:30px;}
a.tooltip:hover {text-decoration:none;}
a.tooltip span {
    z-index:10;display:none; padding:14px 20px;
    margin-top:60px; margin-left:-160px;
    width:240px; line-height:16px;
}
a.tooltip:hover span{
    display:inline; position:absolute;
    border:2px solid #FFF;  color:#EEE;
    background:#000;
}
.callout {z-index:20;position:absolute;border:0;top:-14px;left:120px;}
/*CSS3 extras*/
a.tooltip span{
    border-radius:2px;
    -moz-box-shadow: 0px 0px 8px 4px #666;
    -webkit-box-shadow: 0px 0px 8px 4px #666;
    box-shadow: 0px 0px 8px 4px #666;
    opacity: 0.8;
}
/* for float box in ticket list */
.descbox {
	display:none;
	border: 1px solid #e1e1e1;
	border-radius: 3px;
	background-image: none;
    	margin: 10px 0;
    	padding: 10px;
	max-height: 144px;
	width: 400px;
	position: absolute;
	z-index: 1000;
	padding-top: 10px;
	padding-bottom: 10px;
	color: #686868;
	font-weight: normal;
	text-overflow:ellipsis;
	overflow:hidden;
}
span.warning {
    color: red;
    font-weight: bold;
}

#globoslink .fa, #projoslink .fa{padding-right: 3px;}
/* typical colorings for task type and permissions */
.fa-bug{color:#c30;}
.fa-star{color:#ee0;text-shadow: 0 0 1px rgba(128, 0, 0, 1);}
.fa-exclamation-triangle{color:#c00;}
.fa-check{color:#090;}
.global.fa-check{color:#990;} /* got permission by global settings, not project settings */
.fa-ban{color:#900;}

button.fakelinkbutton {
	display: inline-block;
	background: none;
	border: none;
	padding: 0;
	margin: 0;
	font: inherit;
	cursor: pointer;
	color: #369;
	box-shadow:none;
}

button.fakelinkbutton:hover {
	color: #69c;
}

button.fakelinkbutton:visited {
	color: #69c;
}

@media only screen and (max-width: 640px) {
	#content {padding:0;}
	#tasklist {padding:0;}
	#tasklist th.caret {padding:0;}
	.taskrange {padding-left:10px;}
	div.comment_container .comment {width:98%;}
        div.comment_container .comment_header_infos {max-width: unset;}
}

@media only screen and (max-width: 480px) and (orientation: portrait) {

th, td, caption {padding: 5px 2px;}
#menu { position:static;clear:both;background-color:#111;}
#title {font-size:1.2em;line-height:1.2em;background-color:#111;}
#title a {padding:0;}
#title a span{display:none;}
#title img {float:none;margin:4px;}
#menu-list {display:block;}
#menu-list li {float:none;display:block;padding:0;height:auto;border-left:none;text-align:center;}
#menu-list li > a, #menu-list li > label {display:block;border:1px solid #333;height:24px;}
#menu-list a:hover {border-radius:unset;}
#labelpmmenu, #labelmenu1{text-align:center;color:#fff;display:block;position:absolute;top:0;width:15%;height:48px;left:20%;}
#labelmenu1{left:35%;}
#labelmenu1:before{content:"\f013";font-family:fontawesome;font-size:30px;} /* cog */
#labelpmmenu:before{content:"\f0c9";font-family:fontawesome;font-size:30px;} /* bars */
#menu1:checked ~ #menu{right:0;transition:0.5s;display:block;}
#pmmenu:checked ~ #pm-menu-list{left:0;transition:0.5s;display:block;}
#labelpmmenu:hover, #labelmenu1:hover, #menu1:checked ~ #labelmenu1, #pmmenu:checked ~ #labelpmmenu {background-color:rgba(0,0,0,0.3);}
#pm-menu {padding:0;}
#menu {z-index:111;padding:0;display:none;width:100%;position:absolute;background-color:#333;top:48px;right:-100%;transition:0.5s;}
#pm-menu-list {z-index:110;padding:0;display:none;width:100%;position:absolute;background-color:#333;top:48px;left:-100%;transition:0.5s;}
#pm-menu-list li {display:block;border-top:1px dotted #3c4041;}
#pm-menu-list a {border:none;border-radius:0;margin:0;}
#pmcontrol {margin:0;display:block;float:none;padding:10px;}
#task_id {width:120px;}
#projectselector {position:absolute;top:0;right:0;margin:0;text-align:center;max-width:40%;}
#projectselector select{height:40px;padding-right:4px;max-width:100%;}
#content {padding:0;min-width:unset;}
#tasklist {padding:0;}
.pagenums a.distancefar {display:none;}
.pagenums .distancefargap::after {content:'…';padding-left:0.5em;padding-right:0.5em;}
table.toplevel th, table.toplevel td {display:block;}
body.toplevel .box {margin:0 0 10px 0;}
body.toplevel.p0 .box {width:auto;}
div.box, p.box {padding:0;}
#event1 td {display:block;}
body.admin {background-color:#300;} /* experimental: danger zone */
body.admin h1#title {background-color: #900;background-image: none;} /* danger zone */
body.admin #pm-menu {background-color:#600;border-bottom-color:#300;} /* danger zone */
body.reports .box button {display: block;margin-left:auto;margin-right:auto;width:70%;}
#footer{border-top:none;}
#toolboxmenu {float:none;text-align:center;}
#toolboxmenu a {width:31%;display:inline-block;margin-left:0;border-bottom-left-radius: 0;padding:6px 2px;}
#toolboxmenu a.active {border-top-right-radius:5px;width:31%;padding:6px 2px;float:none;border-color:#78bf34 #78bf34 transparent #78bf34;}
#toolbox {margin:0;padding:0;border-radius:0;padding-top:10px;position:relative;}
#controlBox {position:relative;margin-left:140px;}
#shortcuts {border-radius:5px;padding:5px;box-shadow:0 0 400px #000;top:50%;margin-top:-150px;height:300px;overflow:auto;}
h3 {padding-left:6px;}
p { text-align:justify;padding:2px;}
#listTable{width:100%;}
ul.form_elements {margin:0;}
ul.form_elements span.note {margin-left:0;}
ul.form_elements li label {text-align:start;}
ul.form_elements li > input {margin-left:20px;}
ul.form_elements li > input[type="text"],ul.form_elements li > input[type="password"] {display:block;margin-left:auto;margin-right:auto;width:90%;}
.double_select {padding-left:0;}
#toolbox div.tab {padding:0px;}
#submenu {padding-left:0;margin:0;}
#submenu ~ div {clear:both;}
#catTable input[type="text"], #catTable input[type="password"] {width:120px;}
#taskdetails {margin:0;padding:0;margin-top:40px;}
#taskfields {width:auto; float:none; border:none;}
#taskdetailsfull {margin:0;padding:2px;}
#taskinfo {margin:0;}
#actionbuttons {margin:0; min-height:unset;}
form #taskdetails {margin:0;}
form #taskfields {width:auto; margin-top:20px; background-color:#fff;}
form #taskdetailsfull {margin:0;top:auto;}
form #taskdetailsfull button.positive {margin-left:auto;margin-right:auto;width:60%;}
#comments, #related, #notify, #remind, #effort, #history{padding:0;}
div.comment_container {margin:0;}
div.comment_container .commenttext{padding:2px;}
div.comment_container .comment {margin:0;width:auto;}
div#successanderrors {width:auto; min-width:initial; margin-top:initial; position:initial;}
}
