<?php

$translation = array(
'edituser'                => 'Уреди корисник',
'username'                => 'Корисничко име',
'realname'                => 'Вистинско име',
'emailaddress'            => 'Адреса за е-пошта',
'jabberid'                => 'Jabber ID',
'notifytype'              => 'Тип на известување',
'group'                   => 'Група',
'accountenabled'          => 'Сметката е вклучена',
'updatedetails'           => 'Ажурирај детали',
'setglobally'             => 'Оваа преференца е поставена глобално.',
'usergroupmanage'         => 'Менаџмент на групи и корисници',
'newuser'                 => 'Регистрирај нов корисник',
'newgroup'                => 'Креирај нова група',
'yes'                     => 'Да',
'no'                      => 'Не',
'editgroup'               => 'Уреди група',
'groupname'               => 'Име на група',
'description'             => 'Опис',
'admin'                   => 'Администраторска група',
'opennewtasks'            => 'Отвори нови задачи',
'modifytasks'             => 'Измени постоечки задачи',
'addcomments'             => 'Додај коментари',
'attachfiles'             => 'Закачи датотеки',
'vote'                    => 'Глас',
'groupenabled'            => 'Членовите можат да се најавуваат',
'groupopen'               => 'Членовите можат да се најавуваат',
'tasktypelist'            => 'Листа на типови на задачи',
'categorylist'            => 'Листа на категории',
'oslist'                  => 'Листа на оперативни системи',
'resolutionlist'          => 'Resolutions list',
'versionlist'             => 'Листа на верзии',
'severitylist'            => 'Листа на сериозност',
'listnote'                => 'Note:  Unchecking the "show" box may alter some tasks when in edit mode.  Changing the "Name" field will change all tasks with that name. Items that can not be deleted are either protected because they are needed for correct functioning or used in tasks.',
'name'                    => 'Име',
'order'                   => 'Редослед',
'back'                    => 'Назад',
'text'                    => 'Текст',
'highlight'               => 'Осветли',
'show'                    => 'Покажи',
'owner'                   => 'Сопственик',
'selectowner'             => 'Избери сопственик',
'update'                  => 'Ажурирај',
'addnew'                  => 'Додај нова',
'flysprayprefs'           => 'Преференци за Flyspray',
'projecttitle'            => 'Наслов на проект',
'baseurl'                 => 'Основно URL за оваа инсталација',
'replyaddress'            => 'Адреса за известувања',
'themestyle'              => 'Тема / Стил',
'language'                => 'Јазик',
'anonview'                => 'Allow anonymous users to view tasks',
'allowanon'               => 'Allow anonymous users to open new tasks',
'never'                   => 'Никогаш',
'anonymously'             => 'Анонимно',
'afterregister'           => 'Само по регистрација',
'spamproof'               => 'Enable confirmation code for new user registrations',
'anongroup'               => 'Group for new user registrations',
'groupassigned'           => 'Members of these groups can be assigned tasks',
'forcenotify'             => 'Force task notifications as',
'neversend'               => 'Никогаш не испраќај',
'userchoose'              => 'Секој корисник да може да избира',
'email'                   => 'Е-пошта',
'jabber'                  => 'Jabber',
'defaultcatowner'         => 'Default category owner',
'noone'                   => 'Никој',
'jabbernotify'            => 'Известувања преку Jabber',
'jabberserver'            => 'Сервер',
'jabberport'              => 'Порта',
'jabberuser'              => 'Корисничко име',
'jabberpass'              => 'Лозинка',
'saveoptions'             => 'Зачувај опции',
'editcomment'             => 'Уреди коментар',
'commentby'               => 'Коментар од',
'saveeditedcomment'       => 'Зачувај уреден коментар',
'projectprefs'            => 'Преференци за проектот',
'pagetitle'               => 'Наслов на страницата',
'defaultproject'          => 'Стандарден проект',
'projectlists'            => 'Листи на проекти',
'showlogo'                => 'Show title logo image',
'intromessage'            => 'Порака за вовед',
'isactive'                => 'Проектот е активен',
'createproject'           => 'Креирај нов проект',
'nopermission'            => 'You don\'t have permission to use this page.',
'listordertip'            => 'The order these items will appear in the list',
'listshowtip'             => 'Покажи го овој предмет во листата',
'categoryownertip'        => 'This person will receive notifications when a task in this category is opened',
'categoryparenttip'       => 'The parent category this new one will fall under',
'notsubcategory'          => 'None (top-level category)',
'showinlineimages'        => 'Show image attachments inline',
'dateformat'              => 'Формат на датум',
'dateformat_extended'     => 'Детален формат на датум',
'cache_feeds'             => 'Cache feeds',
'no_cache'                => 'Без кеширање',
'cache_disk'              => 'Кеширај на диск',
'cache_db'                => 'Кеширај во база',
'subcategoryof'           => 'Sub-category of',
'visiblecolumns'          => 'Columns displayed in task list',
'tense'                   => 'Време',
'listtensetip'            => 'Старо, Сегашно или Идно',
'past'                    => 'Стари',
'present'                 => 'Сегашни',
'future'                  => 'Идни',
'oldpass'                 => 'Стара лозинка',
'nooldpass'               => 'Не е поставена старата лозинка',
'oldpasswrong'            => 'Старата лозинка е погрешна',
'changepass'              => 'Смени лозинка',
'confirmpass'             => 'Потврди лозинка',
'projectmanager'          => 'Менаџер на проектот',
'viewtasks'               => 'Види задачи',
'modifyowntasks'          => 'Измени сопствени задачи',
'modifyalltasks'          => 'Modify tasks that are not user\'s own',
'viewcomments'            => 'Види коментари',
'editcomments'            => 'Уреди коментари',
'deletecomments'          => 'Избриши коментари',
'viewattachments'         => 'Види привезоци',
'createattachments'       => 'Креирај привезок',
'deleteattachments'       => 'Избриши привезоци',
'viewhistory'             => 'Види историја',
'closeowntasks'           => 'Затвори ја сопствената задача',
'closeothertasks'         => 'Close tasks that are not user\'s own',
'assigntoself'            => 'Assign tasks to self if not already assigned',
'assignotherstoself'      => 'Assign others\' tasks to self',
'viewreports'             => 'Види го логот на настани',
'othersview'              => 'Allow anyone to view this project',
'usersandgroups'          => 'Корисници и групи',
'globalgroup'             => 'Глобална група',
'globalgroups'            => 'Глобални групи',
'defaultglobalgroup'      => 'Default global group for new users',
'addtogroup'              => 'Додај во групата',
'moveuserstogroup'        => 'Премести ги корисниците во групата',
'nogroup'                 => 'Отстрани од проектот',
'eventdesc'               => 'Опис на настанот',
'requestedby'             => 'Побарано од',
'daterequested'           => 'Датум на барањето',
'closetask'               => 'Затвори задача',
'reopentask'              => 'Повторно отвори задача',
'applymember'             => 'Аплицирај за членство во проектот',
'forcurrentproj'          => 'За тековниот проект',
'lostpw'                  => 'Враќање на изгубена лозинка',
'lostpwexplain'           => 'Внеси корисничко име за да ти биде испратена врска за промена на лозинката.  Ова ќе биде испратено на адресата за известување  твојот профил.',
'sendlink'                => 'Испрати врска',
'savenewpass'             => 'Зачувај нова лозинка',
'anonreg'                 => 'Дозволи регистрација на нови корисници',
'allowanonopentask'       => 'Дозволи анонимни корисници да отвораат задачи',
'editglobalgroup'         => 'Уреди глобална група',
'editgroupforproj'        => 'Уреди група за проект',
'notshownforadmin'        => 'Пермисиите за администраторската група не се прикажани.  Не треба да ги уредуваш.',
'general'                 => 'Општо',
'userregistration'        => 'Регистрација на корисници',
'notifications'           => 'Известувања',
'resetoptions'            => 'Ресетирај опции',
'preferences'             => 'Преференци',
'tasktypes'               => 'Типови на задачи',
'resolutions'             => 'Решенија',
'categories'              => 'Категории',
'operatingsystems'        => 'Оперативни системи',
'versions'                => 'Верзии',
'admintoolboxlong'        => 'Администраторски алатник',
'newproject'              => 'Нов проект',
'delete'                  => 'Избриши',
'listdeletetip'           => 'Избриши го овој предмет од поштенската листа',
'lookandfeel'             => 'Изглед и чувство',
'globaltheme'             => 'Глобална тема',
'emailnotify'             => 'Известувања преку е-пошта',
'fromaddress'             => 'Од адреса',
'smtpserver'              => 'SMTP сервер',
'smtpuser'                => 'SMTP корисничко име',
'smtppass'                => 'SMTP лозинка',
'addrewrite'              => 'Use address rewriting',
'usereminderdaemon'       => 'Вклучи даемон за известување во позадина',
'tasksperpage'            => 'Задачи по страница од листата на задачи',
'addtoassignees'          => 'Додај се себеси',
'taskstatuses'            => 'Статуси на задачи',
'canvote'                 => 'Може да се гласа за задачата',
'loginsuccessful'         => 'Најавата е успешна.',
'youareloggedout'         => 'Одјавени сте.',
'waitwhiletransfer'       => 'Те молам почекај...',
'clicknowait'             => 'Кликнете овде ако не сакате да чекате.',
'accountdisabled'         => 'Твојата сметка е исклучена. Контактирај го администраторот.',
'task'                    => 'Задача',
'edittask'                => 'Уреди ја оваа задача',
'openedby'                => 'Отворено од',
'editedby'                => 'Последен пат изменето од',
'tasktype'                => 'Тип на задача',
'category'                => 'Категорија',
'status'                  => 'Статус',
'assignedto'              => 'Доделено на',
'operatingsystem'         => 'Оперативни системи',
'severity'                => 'Сериозност',
'reportedversion'         => 'Пријавена верзија',
'dueinversion'            => 'Доаѓа во верзија',
'undecided'               => 'Нерешено',
'percentcomplete'         => 'Завршено во проценти',
'details'                 => 'Детали',
'savedetails'             => 'Зачувај детали',
'canceledit'              => 'Откажи уредување',
'anonymous'               => 'Анонимен',
'complete'                => 'завршено',
'closedby'                => 'Затворено од',
'reasonforclosing'        => 'Причина за затворање:',
'reopenthistask'          => 'Повторно отвори задача',
'comments'                => 'Коментари',
'attachments'             => 'Привезоци',
'relatedtasks'            => 'Поврзани задачи',
'edit'                    => 'Уреди',
'addcomment'              => 'Додај коментар',
'fileuploadedby'          => 'Датотека качена од',
'uploadafile'             => 'Закачи датотека',
'uploadnow'               => 'Качи сега!',
'thesearerelated'         => 'Овие задачи се поврзани со оваа задача',
'remove'                  => 'Отстрани',
'addnewrelated'           => 'Додај нова поврзана задача',
'add'                     => 'Додај!',
'otherrelated'            => 'Други задачи со кои што е поврзана оваа задача',
'receivenotify'           => 'These users will receive detailed notifications when this task changes.',
'addusertolist'           => 'Додај го корисникот во оваа листа',
'addtolist'               => 'Додај во листа',
'addmyself'               => 'Додај ме во оваа листа',
'removemyself'            => 'Тргни ме од оваа листа',
'theseusersnotify'        => 'Овие корисници ќе добиваат детални известувања секој пат кога ќе се измени задачата.',
'attachedtoproject'       => 'Закачено за проектот',
'reminders'               => 'Потсетници',
'system'                  => 'Систем',
'remindthisuser'          => 'Потсети го корисникот',
'thisoften'               => 'Волку често',
'startafter'              => 'Чекај пред да испратиш потсетници',
'hours'                   => 'Час(а)',
'days'                    => 'Ден(а)',
'weeks'                   => 'Недел(а)',
'addreminder'             => 'Додај потсетник',
'defaultreminder'         => 'Ова е потсетник за да ја провериш следнава задача:',
'message'                 => 'Порака',
'closed'                  => 'Затворено',
'filename'                => 'Име на датотека:',
'date'                    => 'Датум',
'filesize'                => 'Големина на датотеката:',
'closurecomment'          => 'Additional comments about closing:',
'history'                 => 'Историја',
'nohistory'               => 'Не е пронајдена историја.',
'eventdate'               => 'Датум',
'user'                    => 'Корисник',
'event'                   => 'Настан',
'fieldchanged'            => 'Полето е променето',
'taskopened'              => 'Задачата е отворена',
'taskreopened'            => 'Задачате е повторно отворена',
'taskclosed'              => 'Задачата е затворена',
'commentadded'            => 'Коментарот е додаден',
'commentedited'           => 'Коментарот е уреден',
'commentdeleted'          => 'Коментарот е избришан',
'attachmentadded'         => 'Привезокот е додаден',
'attachmentdeleted'       => 'Привезокот е избришан',
'taskedited'              => 'Деталите за задачата се сменети',
'notificationadded'       => 'Корисникот е додаден во листата за известување',
'notificationdeleted'     => 'Корисникот е отстранет од листата за известување',
'relatedadded'            => 'Пповрзаната задача е додадена',
'relateddeleted'          => 'Поврзаната задаче отстранета',
'taskassigned'            => 'Задачата е доделена на',
'taskreassigned'          => 'Задачата е предоделена на',
'assignmentremoved'       => 'Assignment removed',
'summary'                 => 'На кратко',
'addedasrelated'          => 'Task added to the related list of',
'deletedasrelated'        => 'Task removed from the related list of',
'reminderadded'           => 'Reminder added',
'reminderdeleted'         => 'Reminder removed',
'priority'                => 'Приоритет',
'previousvalue'           => 'Претходна вредност',
'newvalue'                => 'Нова вредност',
'selectareason'           => 'Изберете причина',
'assigntome'              => 'Додели ми ја задачата',
'reopenrequest'           => 'Побарај повторно отворање',
'requestclose'            => 'Побарај затворање',
'ownershiptaken'          => 'Корисникот ја зема задачата',
'closerequestmade'        => 'Requested task closure',
'reopenrequestmade'       => 'Requested task to be re-opened',
'taskdependson'           => 'Оваа задача зависи од',
'taskblocks'              => 'Поради оваа задача не можат да бидат затворени',
'depadded'                => 'Зависноста е додадена',
'depaddedother'           => 'Оваа задача е додадена како зависност',
'depremoved'              => 'Зависноста е отстранета',
'depremovedother'         => 'This task removed from other task\'s dependency list',
'showdetailserror'        => 'That task does not exist, or you don\'t have permission to view it.',
'makeprivate'             => 'направи приватно',
'makepublic'              => 'направи јавно',
'taskmadeprivate'         => 'Задачата е сега приватна',
'taskmadepublic'          => 'Задачата е сега јавна',
'confirmdeletecomment'    => 'Really delete this comment? %s',
'confirmdeleteattach'     => 'Really delete this attachment?',
'selectedhistory'         => 'Showing selected history details',
'showallhistory'          => 'Show full history tab again',
'hidethis'                => 'Hide this area again',
'mark100'                 => 'Mark task 100% complete',
'watchtask'               => 'прати задача',
'stopwatching'            => 'престани со пратење',
'commentlink'             => 'Врска до овој коментар',
'submitreq'               => 'Поднеси барање',
'reasonforreq'            => 'Причина за барање',
'pmreqdenied'             => 'Менаџерот на прокетот го одби барањето',
'taskpendingreq'          => 'Project Manager action pending.  See the History tab for details.',
'previoustask'            => 'Претходна задача',
'nexttask'                => 'Следна задача',
'duedate'                 => 'До датум',
'attachnoperms'           => 'There are attachments with this comment, but you have no permission to view them.',
'open'                    => 'Отворени',
'depgraph'                => 'Види графа на зависности',
'reset'                   => 'Ресетирај',
'selectusers'             => 'Избери корисници...',
'addmetoassignees'        => 'Add me to assignees',
'addedtoassignees'        => 'User added to assignees list',
'dependencygraph'         => 'Графа на зависности',
'attachanotherfile'       => 'Закачи друга датотека',
'OK'                      => 'Во ред',
'addvote'                 => 'Додај глас',
'notifyfromfs'            => 'Известување од Flyspray',
'autogenerated'           => 'ОВА Е АВТОМАТСКИ ГЕНЕРИРАНА ПОРАКА, ТЕ МОЛАМ НЕ ОДГОВАРАЈ.',
'forward'                 => 'Напред',
'previous'                => 'Претходна',
'next'                    => 'Следна',
'first'                   => 'Прва',
'last'                    => 'Последна',
'page'                    => 'Страница %d од %d',
'search'                  => 'Барај',
'alltasktypes'            => 'Сите типови на задачи',
'allseverities'           => 'Сите нивоа на сериозност',
'alldevelopers'           => 'Сите програмери',
'notyetassigned'          => 'Сеуште недоделени',
'allcategories'           => 'Сите категории',
'allstatuses'             => 'Сите статуси',
'allopentasks'            => 'Сите отворени задачи',
'sortthiscolumn'          => 'Подреди по оваа колона',
'id'                      => 'ID',
'project'                 => 'Проект',
'dateopened'              => 'Отворена на',
'progress'                => 'Прогрес',
'searchthisproject'       => 'Пребарај го проектот за',
'dueanyversion'           => 'Доаѓа во сите верзии',
'anyversion'              => 'Пријавено во сите верзии',
'dueversion'              => 'Доаѓа во верзија',
'lastedit'                => 'Последен пат изменето',
'os'                      => 'Оперативен систем',
'reportedin'              => 'Пријавено во',
'taskrange'               => 'Покажувам задачи %d - %d од %d',
'noresults'               => 'Твоето пребарување не најде задачи.',
'takeaction'              => 'Превземи дејство',
'watchtasks'              => 'Прати ги избраните задачи',
'stopwatchingtasks'       => 'Престани да ги следиш избраните задачи',
'assigntaskstome'         => 'Префрли ми ги избраните задачи на мене',
'dueby'                   => 'До',
'dueanytime'              => 'Due anytime',
'selectduedate'           => 'Select Due Date',
'toggleselected'          => 'Toggle Selected',
'due'                     => 'Due',
'assignedtome'            => 'Доделено на мене',
'tasklist'                => 'Листа на задачи',
'dateclosed'              => 'Датум на затворање',
'advanced'                => 'Напредно',
'searchcomments'          => 'Барај во коментарите',
'searchforall'            => 'Барај ги сите зборови',
'anonusers'               => 'Анонимни корисници',
'miscellaneous'           => 'Разно',
'users'                   => 'Корисници',
'taskproperties'          => 'Својства на задачата',
'selectsincedate'         => 'Select Changed since',
'changedsince'            => 'Сменето од',
'updatefs'                => 'Надгради го Flyspray.',
'currentversion'          => 'Тековната верзија е',
'latestversion'           => 'а најновата верзија е',
'hidemessage'             => '(потсети ме подоцна)',
'saveas'                  => 'Зачувај го пребарувањето како',
'nosearches'              => 'Нема зачувани пребарувања',
'saving'                   => 'Зачувувам...',
'votes'                   => 'Гласови',
'allclosedtasks'          => 'Сите затворени задачи',
'password'                => 'Лозинка',
'login'                   => 'Најави ме!',
'rememberme'              => 'Запомни ме',
'lostpassword'            => 'Ја изгуби лозинката?',
'lostpwforfs'             => 'Изгубена лозинка за Flyspray',
'lostpwmsg1'              => 'Здраво.

Ја изгубив лозинката за Flyspray на ',
'lostpwmsg2'              => ', ве молам пратете ми .

корисничко име: ',
'regards'                 => '

Поздрав,',
'yourusername'            => ' твоето корисничко име ',
'locale'                  => 'mk-MK',
'filenotexist'            => 'File does not exist, or you do not have permission to access it.',
'showtask'                => 'Покажи задача',
'now'                     => 'Сега',
'go'                      => 'Оди!',
'opentaskanon'            => 'Отвори нова задача анонимно',
'register'                => 'Регистрирај се',
'addnewtask'              => 'Додај нова задача',
'reports'                 => 'Лог на настани',
'editmydetails'           => 'Уреди ги моите детали',
'logout'                  => 'Одјави ме',
'disabledaccount'         => 'Your account has been disabled!<br />Immediately logging you out...',
'poweredby'               => 'Работи на Flyspray',
'projects'                => 'Проекти',
'allprojects'             => 'Сите прокети',
'selectproject'           => 'за проектот:',
'tasksall'                => 'Сите задачи',
'tasksassigned'           => 'Задачи доделени на мене',
'tasksreported'           => 'Задачи испратени од мене',
'taskswatched'            => 'Задачи кои што ги следам',
'mysearch'                => 'Мои пребарувања',
'admintoolbox'            => 'Администраторски алатник',
'manageproject'           => 'Менаџирај проект',
'permissions'             => 'Види пермисии',
'hide'                    => 'Скриј',
'pendingreq'              => 'PM барањето чека',
'errorpage'               => 'Flyspray cannot provide the page you requested.
                                 Perhaps you requested a task that does not exist, or you
                                 do not have permission to view the page you wanted.<br /><br />
                                 You may have tried to use a naughty URL to interact with the database
                                 backend using SQL injection.  If this is true, go to the corner and think
                                 about your actions.  When you return, please do not do it again!',
'permissionsforproject'   => 'Пермисии за ',
'switchto'                => 'Смени на',
'lastsearch'              => 'Последно пребарување',
'modify'                  => 'Измени',
'noticefrom'              => 'Порака од',
'hasopened'               => 'отвори нова задача на Flyspray и ти ја додели на тебе:',
'moreinfonew'             => 'Повеќе информации за задачата можеш да најдеш на страницата:',
'newtaskcategory'         => 'Отворена е нова задача во оваа категорија',
'categoryowner'           => 'Го примаш ова бидејќи си сопственик на оваа категорија.',
'tasksummary'             => 'На кратко за задачата:',
'newtaskadded'            => 'Твојата нова задаче додадена.',
'summaryanddetails'       => 'Треба да ги пополниш и краткиот опис и деталите.',
'goback'                  => 'Оди назад.',
'messagefrom'             => 'Ова е порака од системот за пријавување и пратење на грешки дека некој ',
'hasjustmodified'         => 'само што ја изменил следнава задача.',
'changedfields'           => 'Changed fields are prefixed with asterisks (**)',
'moreinfomodify'          => 'You can get more information about this task at the following URL:',
'nolongerassigned'        => 'The following task is no longer assigned to you.  It is now assigned to',
'hasassigned'             => 'has assigned to you the following Flyspray task:',
'taskupdated'             => 'Задачата е ажурирана.',
'hasclosedassigned'       => 'has closed the following Flyspray task that you were assigned:',
'unassigned'              => 'Недоделено',
'hasclosed'               => 'ја затвори следнава задача.',
'youonnotify'             => 'You are receiving this because you are on the notification list.',
'taskclosedmsg'           => 'Задачата е затворена.',
'returntotask'            => 'Врати ме на деталите за задачата',
'backtoindex'             => 'Врати ме на листата со задачи',
'noclosereason'           => 'Не избра причина за затворање на задачата.',
'hasreopened'             => 'ја отвори следнава задача која што ти претходно ја затвори:',
'taskreopenedmsg'         => 'Задачата е повторно отворена.',
'backtotask'              => 'Врати ме назад на задачата.',
'commentaddedmsg'         => 'Коментарот е додаден.',
'commenttoassigned'       => 'додаде коментар на задачата која што ти е доделена:',
'commenttotask'           => 'го додаде следниов коментар на задачата.',
'nocommententered'        => 'You really should enter a comment before clicking the submit button.',
'fillinfields'            => 'You didn\'t fill in all the fields.',
'notcurrentpass'          => 'Тоа не е твојата тековна лозинка!',
'passchanged'             => 'Твојата лозинка е сменета!.',
'closewindow'             => 'Може да го затвориш прозорецов сега.',
'passnomatch'             => 'Новите лозинки не се исти!',
'usernametaken'           => 'Тоа корисничко име веќе постои.  Треба да избереш друго.',
'newusercreated'          => 'Креирана е нова корисничка сметка.',
'accountcreated'          => 'Твојата сметка е креирана.',
'newuserwarning'          => 'Note that the global preferences might require your account to be approved by an admin.  If you cannot login, this is probably why.',
'nomatchpass'             => 'Лозинките не се исти.',
'confirmwrong'            => 'Кодот за потврда не е точен!',
'formnotcomplete'         => 'Формуларот не е целосно пополнет.',
'formnotnumeric'          => 'Внесените податоци не се броеви!',
'groupnametaken'          => 'Тоа име на група веќе постои.',
'newgroupadded'           => 'Новата група е додадена.',
'optionssaved'            => 'Опциите за Flyspray се зачувани.',
'hasuploaded'             => 'has uploaded a file attachment to a task that have been assigned:',
'hasattached'             => 'has attached a file to the following task.',
'fileuploaded'            => 'Датотеката е качена.',
'fileerror'               => 'There was an error uploading your file.  Perhaps the permissions on the <i>attachments/</i> directory are incorrect.',
'contactadmin'            => 'Контактирај го администраторот за овој проект.',
'selectfileerror'         => 'Не избра датотека.',
'userupdated'             => 'Корисничките детали се ажурирани',
'realandemail'            => 'Не ги пополни полињата за вистинско име и е-пошта.',
'groupupdated'            => 'Дефиницијата за групата е ажурирана.',
'groupanddesc'            => 'Не го пополни полето за името на групата.',
'fillallfields'           => 'Те молам пополни ги сите полиња.',
'listPmustN'              => '"Order" entry has to be numeric.',
'listupdated'             => 'Листата е ажурирана.',
'listitemadded'           => 'Нова задача е додадена во листата.',
'relatedaddedmsg'         => 'Поврзаната задача е додадена во листата.',
'relatederror'            => 'That task is already on this related task list.',
'relatedremoved'          => 'Related task removed from list.',
'notifyadded'             => 'Корисникот е додаден на листата за известување.',
'notifyerror'             => 'That user is already on the notification list for that task.',
'notifyremoved'           => 'Корисникот е отстранет од листата за известување.',
'editcommentsaved'        => 'Ажурираниот коментар е зачуван.',
'commentdeletedmsg'       => 'Коментарот е избришан.',
'gotonewtask'             => 'Оди до новата задача која што ја креираше сега',
'projectcreated'          => 'Новиот проект е креиран.  Можеш да ги менуваш деталите за проектот во делот за менаџирање на проекти.',
'customiseproject'        => 'Смени детали за проектот',
'projectupdated'          => 'Преференците за проектот се ажурирани',
'emptytitle'              => 'You left the Project Title field blank.  Go back and fix it.',
'loginbelow'              => 'Сега можеш да пробаш да се најавиш.',
'attachmentdeletedmsg'    => 'Привезокот е избришан',
'reminderaddedmsg'        => 'Твојот потсетник е додаден.',
'reminderdeletedmsg'      => 'The selected reminder has been deleted.',
'flyspraytask'            => 'Flyspray задача',
'fieldsmissing'           => 'Some fields contained no or invalid data.',
'relatedinvalid'          => 'Не постои таква задача.',
'relatedproject'          => 'This task is attached to a different project. Add relation anyway?',
'addanyway'               => 'Додај сепак',
'cancel'                  => 'Откажи',
'alreadyedited'           => 'This task was edited by someone else before you saved. Do you still want to save your changes?',
'saveanyway'              => 'Зачувај ги моите промени секако',
'nouserselected'          => 'No user selected.  Select at least one user before trying again.',
'groupswitchupdated'      => 'Корисничките групи се успешно изменети.',
'takenownershipmsg'       => 'Оваа задача ти е доделена на тебе.',
'adminrequestmade'        => 'Your request has been sent to a Project Manager.',
'newdepnotify'            => 'A new dependency has been added to the following task:',
'dependadded'             => 'Зависноста е додадена',
'dependaddfailed'         => 'There was an error when adding the dependency. Check that the task exists and there is no mutual block.',
'depremovedmsg'           => 'Зависноста е отстранета',
'newdepis'                => 'Новата зависност е',
'magicurlsent'            => 'A message has been sent to your notification address.  It contains a link that will take you to a page to complete this task.',
'changefspass'            => 'Промени лозинка за Flyspray',
'magicurlmessage'         => 'Please follow the link below to change your Flyspray password:',
'erroronform'             => 'There was an problem with your form submission',
'addressused'             => 'This address has been used to register a Flyspray account.  If you were not expecting this message, please ignore and delete it.  Go to the following URL to complete your registration:',
'confirmcodeis'           => 'Твојот код за потврда е:',
'codesent'                => 'Твојот код за потврда е испратен.  Следи ги упатствата во пораката.',
'codenotsent'             => 'Не можам да го испратам кодот, те молам пробај пак подоцна.',
'taskmadeprivatemsg'      => 'Оваа задача е сега приватна',
'taskmadepublicmsg'       => 'Оваа задача е сега јавна',
'realandnotify'           => 'You need to fill in the Real Name field, and either the Email Address or Jabber ID field.',
'pmreqdeniedmsg'          => 'Project Manager request denied',
'massopsuccess'           => 'Mass operations successful - where permissions allowed',
'usernotexist'            => 'That user does not exist on this Flyspray installation',
'commentattachperms'      => 'You cannot delete that comment - no permission to delete attachments',
'voterecorded'            => 'Твојот глас е запишан',
'votefailed'              => 'Твојот глас не можеше да биде запишан.',
'createnewgroup'          => 'Креирај нова група',
'requiredfields'          => 'Required fields are marked with a',
'addthisgroup'            => 'Додај ја оваа група',
'createnewproject'        => 'Креирај нов проект',
'addnewproject'           => 'Додај нов проект',
'htmlallowed'             => 'HTML код е дозволен',
'createthisproject'       => 'Креирај го овој проект',
'inlineimages'            => 'Show image attachments inline',
'createnewtask'           => 'Креирај нова задача во проектот:',
'addanother'              => 'Додај уште една задача по оваа',
'addthistask'             => 'Додај ја оваа задача',
'notifyme'                => 'Извести ме секој пат кога ќе се промени нешто',
'newtask'                 => 'Нова задача',
'attachafile'             => 'Закачи датотека',
'registernewuser'         => 'Регистрирај нов корисник',
'none'                    => 'Ништо',
'registeraccount'         => 'Регистрирај ја оваа сметка',
'both'                    => 'И двете',
'notifyfrom'              => 'Известување за ',
'donotreply'              => 'ОВА Е АВТОМАТСКА ПОРАКА, ТЕ МОЛАМ НЕ ОДГОВАРАЈ.',
'disclaimer'              => 'You are receiving this message because you have requested it from the Flyspray bugtracking system.  If you did not expect this message or don\'t want to receive mails in future, you can change your notification settings at the URL shown above.',
'userwho'                 => 'Корисникот кој го направил ова',
'moreinfo'                => 'Повеќе информации на следнова адреса:',
'newtaskopened'           => 'Отворена е нова задача.  Деталите се подолу.',
'notify.taskclosed'       => 'Следнава задача е сега затворена:',
'notify.taskreopened'     => 'Следнава задача е повторно отворена:',
'newdep'                  => 'Следнава задача сега има зависност:',
'notify.depremoved'       => 'The following task has had a dependency removed:',
'olddepwas'               => 'Старата зависност беше',
'notify.commentadded'     => 'Следнава задача има нов коментар:',
'commentis'               => 'Коментарот за текстот е подолу.',
'newattachment'           => 'Следнава задача има нов привезок:',
'detailsbelow'            => 'Деталите се подолу.',
'notify.relatedadded'     => 'A new related task has been added to the following task:',
'relatedis'               => 'Поврзаната задача е',
'assignedtoyou'           => 'Доделена ти е следнава задача:',
'takenownership'          => 'ја зема следнава задача:',
'requiresaction'          => 'The following task requires action by a Project Manager:',
'requiresactionnotify'    => 'Task requires action by a Project Manager',
'pmdeny'                  => 'A Project Manager has denied the request pending for the following task:',
'pmdenynotify'            => 'A Project Manager has denied the request',
'fileaddedtoo'            => 'One or more files have been attached.',
'taskwatching'            => 'The following task you are watching',
'isdepfor'                => 'is a new dependency for',
'denialreason'            => 'Reason for denial',
'taskchanged'             => 'The following task has been changed.  The changes are listed below.  For full information about what has changed, visit the URL and click the History tab.',
'useraddedtoassignees'    => 'A user has added themself to the list of users assigned to this task.',
'removeddepis'            => 'The removed dependency is',
'isnodepfor'              => 'is no dependency anymore for',
'usergroups'              => 'Кориснички групи',
'pmtoolbox'               => 'Project Manager\'s Toolbox',
'groupmanage'             => 'Менаџмент на групи',
'pendingrequests'         => 'Барања што чекаат',
'reasongiven'             => 'Причина',
'nopendingreq'            => 'There are no pending Project Manager requests.',
'givereason'              => 'Додај причина',
'catlisted'               => 'Уредувач на листата на категории',
'oslisted'                => 'Уредувач на листата на оперативни системи',
'verlisted'               => 'Уредувач на листата на верзии',
'tasktypeed'              => 'Уредувач на листата на типови на задачи',
'resed'                   => 'Уредувач на листата на решенија',
'deny'                    => 'Одбиј',
'notifiedwhen'            => 'Извести кога',
'onlynewtasks'            => 'Се отвораат нови задачи',
'allevents'               => 'Се случи било каков настан во било која задача',
'feeds'                   => 'Фидови',
'feeddescription'         => 'Опис на фид',
'feedimgurl'              => 'Feed image URL (leave blank for no image)',
'notifysubject'           => 'Наслов за известувања',
'notifysubjectinfo'       => '(%p = наслов на проектот, %s = опис на задачата, %t = id на задачата, %a = дејство, %u = корисник)',
'priority6'               => 'Флеш',
'priority5'               => 'Веднаш',
'priority4'               => 'Итно',
'priority3'               => 'Виско',
'priority2'               => 'Нормално',
'priority1'               => 'Ниско',
'sendcode'                => 'Испрати код!',
'entercode'               => 'Внеси го кодот што го прими во пораката за известување.  Исто така внеси ја и лозинката за твојата сметка.',
'confirmationcode'        => 'Код за потврда',
'registererror'           => 'Ensure that you have filled in all required fields, and that you have entered correct details for your desired notification type.',
'validusername'           => '(only alphanumeric chars and - _ . are allowed)',
'emailtaken'              => 'That email address or Jabber-ID is already taken. You will need to choose another one.',
'note'                    => '<strong>Забелешка:</strong>  Ќе ти биде испратен код за потврда пред да ти биде креирана сметката.  Кодот ќе ти биде испратен преку преферираниот метод за известување.<br />Ако внесеш лажни детали, <strong>нема да го добиеш кодот</strong>.',
'changelog'               => 'Changelog',
'changeloggen'            => 'Генератор на Changelog',
'listfrom'                => 'List changelog entries from',
'to'                      => 'до',
'oldestfirst'             => 'Прво најстарите',
'recentfirst'             => 'Прво најновите',
'severityrep'             => 'Извештај за сериозност',
'totalopen'               => 'Вкупно отворени задачи',
'age'                     => 'Старост',
'agerep'                  => 'Извештај за старост',
'eventsrep'               => 'Извештај за настани',
'events'                  => 'Настани',
'Tasks'                   => 'Задачи',
'opened'                  => 'Отворени',
'edited'                  => 'Уредени',
'assigned'                => 'Доделени',
'within'                  => 'Внатре во',
'pastday'                 => 'Последниот ден',
'pastweek'                => 'Последната недела',
'pastmonth'               => 'Последниот месец',
'pastyear'                => 'Последната година',
'nolimit'                 => 'Без лимит',
'from'                    => 'Од',
'duein'                   => 'Доаѓа во',
'selectfromdate'          => 'Избери од датум',
'selecttodate'            => 'Избери до датум',
'showvoters'              => 'Покажи/скриј гласови',
'roadmap'                 => 'Мапа',
'roadmapfor'              => 'Мапа за верзијата',
'tasks'                   => 'задачи',
'completed'               => 'завршени.',
'opentasks'               => 'отворени задачи',
'of'                      => '% од',
'severity5'               => 'Критично',
'severity4'               => 'Високо',
'severity3'               => 'Средно',
'severity2'               => 'Ниско',
'severity1'               => 'Многу ниско',
'Redirect'                => 'Префрли',
'redirectmsg'             => 'If your browser does not support meta redirection please click %sHERE%s to be redirected',
'allowclosedcomments'     => 'Дозволувај коментари на затворени задачи',
'comment'                 => 'Коментар',
'editowncomments'         => 'Уредувај свои коментари',
'reopened'                => 'Повторно отворено',
'loading'                 => 'Вчитувам...',
'notifyown'               => 'Известувај ме за сопствени промени',
'youremail'               => 'Твојата адреса за е-пошта',
'thankyouforbug'          => 'Ти благодариме што го пријави проблемот. Можеш да ја пратиш задачата и нејзиниот прогрес на следнава адреса:',
'anonuser'                => 'Анонимен корисник',
'conflict'                => 'Конфликт',
'file'                    => 'Датотека',
'KiB'                     => 'KiB',
'MiB'                     => 'MiB',
'size'                    => 'Големина',
'projectgroup'            => 'Група на проектот',
'profile'                 => 'Профил:',
'viewprofile'             => 'Види профил',
'regdate'                 => 'Регистриран од',
'tasksopened'             => 'Отворени задачи',
'replyto'                 => 'Одговори на',
'notifytypes'             => 'Типови на известувања',
'pm.taskchanged'          => 'Задачата е променета',
'pm.taskreopened'         => 'Task reopened',
'pm.depadded'             => 'Dependency added',
'pm.depremoved'           => 'Dependency removed',
'pmrequest'               => 'PM request',
'pmrequestdenied'         => 'PM request denied',
'newassignee'             => 'New assignee',
'revdepadded'             => 'Reverse dependency added',
'revdepaddedremoved'      => 'Reverse dependency removed',
'assigneeadded'           => 'Assignee added',
'addusergroup'            => 'Додај го корисникот во групава',
'groupmembers'            => 'Членови на групата',
'deleteuser'              => 'Избриши го овој корисник',
'userdeleted'             => 'Корисникот е избришан',
'autoassign'              => 'Auto-assign a task to the category owner',
'ssl'                     => 'SSL',
'updatewrong'             => 'You have the update check feature enabled, but an error ocurred while trying
                             to contact the update server, either your host do not allow outbound connections
                             or the error was caused by a network problem.
                             Please visit the flyspray website to make sure you are running the latest version.',
'deleteproject'           => 'Delete this project and move contents to',
'projectdeleted'          => 'Project deleted successfully',
'feedforall'              => 'Feed for all projects',
'usercreated'             => 'Корисникот е креиран',
'userdeleted'             => 'Корисникот е избришан',
'created'                 => 'Креиран',
'deleted'                 => 'Избришан',
'userid'                  => 'Корисничка ID',
'editassignments'         => 'Уреди доделени задачи',
'preview'                 => 'Преглед',
'anyprogress'             => 'Било каков прогрес',
'tasksrelated'            => 'Задачи поврзани со оваа задача',
'duplicatetasks'          => 'Duplicate tasks of this task',
'databasemodfailed'       => 'Database modification failed. Possible reasons are insufficient permissions.',
'frequency'               => 'Редовност',
'newuserregistered'       => 'A new user has registered at your Flyspray installation. The user details are as follows:',
'newuserregisterednotify' => 'Се регистрираше нов корисник',
'notify_registration'     => 'Notify admins on new user registration',
'textversion'             => 'Text Version',
'onlyprimary'             => 'Tasks not blocking other tasks',
'switch'                  => 'Смени',
'max'                     => 'макс.',
'dates'                   => 'Датуми',
'selectduedatefrom'       => 'Доаѓа од',
'selectduedateto'         => 'до',
'selectsincedatefrom'     => 'Сменето од',
'selectsincedateto'       => 'до',
'selectdate'              => 'Избери датум',
'selectopenedfrom'        => 'Отворено од',
'selectopenedto'          => 'до',
'selectclosedfrom'        => 'Затворено од',
'selectclosedto'          => 'до',
'startat'                 => 'Почнува на',
'hasattachment'           => 'Has attachment',
'private'                 => 'Приватно',
'watching'                => 'Се следи',
'alreadyvotedthistask'    => 'веќе гласаше за оваа задача',
'alreadyvotedthisday'     => 'веќе гласаше денес',
'visibility'              => 'Видливост',
'public'                  => 'Јавно',
'leaveemptyauto'          => 'Leave password fields empty if you want the password to be automatically generated.',
'novalidemail'            => 'You did not enter a valid email address.',
'novalidjabber'           => 'You did not enter a valid Jabber address.',
'missingrequired'         => 'You did not fill in all required fields.',
'entervalidusername'      => 'Please enter a valid user and real name.',
'couldnotaddusernotif'    => 'Could not add this user to the notification list.',
'defaulttask'             => 'Default task description',
'all'                     => 'all',
'events.useraddedtoassignees' => 'User added to assignees',
'vote(s)'                 => 'vote(s)',
'eventlog'                => 'Лог на настани',
'assignmentchanged'       => 'Сопственоста е променета',
'detailedinfo'            => 'Детални информации',
'All'                     => 'Сите',
'tasksireported'          => 'Задачи кои што сум ги пријавил',
'recentlyopened'          => 'Скоро отворени',
'stats'                   => 'Статистики',
'totaltasks'              => 'вкупно задачи',
'mostwanted'              => 'Најважни задачи',
'defaultentry'            => 'Default entry page',
'toplevel'                => 'Top level view',
'overview'                => 'Преглед',
'error#'                  => 'Грешка #',
'error1'                  => 'You don\'t have sufficient permissions to view this attachment.',
'error3'                  => 'Repeated action, redirecting to main page.',
'error4'                  => 'You don\'t have administrative rights.',
'error5'                  => 'That user does not exist on this Flyspray installation.',
'error6'                  => 'Invalid admin area.',
'error7'                  => 'Login failed, paassword incorrect!',
'error71'                 => 'Account locked for %d minutes due to too many failed login attempts!',
'error8'                  => 'You didn\'t enter both a username and password.',
'error9'                  => 'Task does not exist or no permissions to view this task.',
'error10'                 => 'This task does not exist.',
'error101'                => 'You have no permission to view this task.',
'error102'                => 'You have no permission to view this task, logging in might help.',
'error11'                 => 'No permission to edit this comment.',
'error12'                 => 'No valid magic key! Are you sure that you got that from your notification message?',
'error13'                 => 'Anonymous users don\'t have a profile.',
'error14'                 => 'You don\'t have sufficient permissions to create a new group.',
'error15'                 => 'You don\'t have sufficient permissions to open a task.',
'error16'                 => 'You are not a project manager.',
'error17'                 => 'Invalid PM area.',
'error18'                 => 'Invalid magic URL.',
'error19'                 => 'That user does not exist on this Flyspray installation.',
'error20'                 => 'Invalid database modification.',
'error21'                 => 'One or more emails could not be sent. Check your config.',
'error22'                 => 'No new user registration allowed.',
'error23'                 => 'User or group not enabled for login.',
'error24'                 => 'Neither the dot executable nor a public dot server has been set.',
'error25'                 => 'Roadmap only available for a specific project.',
'done'                    => 'готово',
'rss'                     => 'RSS',
'atom'                    => 'Atom',
'projectnotdeleted'       => 'Project couldn\'t be deleted.',
'GMT'                     => 'GMT',
'timezone'                => 'Временска зона',
'accept'                  => 'Прифати',
'reasonfordeinal'         => 'Reason for denial',
'pruneclosedlinks'        => 'Prune Closed Links',
'pruneclosedtasks'        => 'Prune Closed Tasks',
'pagegenerated'           => 'Page and image generated in %d seconds.',
'pruninglevel'            => 'Pruning Level',
'lastuser'                => 'The last user cannot be deleted.',
'allprivate'              => 'All projects are private.',
'deletegroup'             => 'Delete this group and move users to',
'parent'                  => 'Parent',
'ordertip'                => 'The order these items will appear in the list',
'showtip'                 => 'Show this item in the list',
'deletetip'               => 'Delete this item from the list',
'del'                     => 'del',
'request1'                => 'A task closure has been requested.',
'request2'                => 'A request to re-open the task has been made.',
'allpriorities'           => 'All Priorities',
'noroadmap'               => 'No roadmap available (no project specific "future" versions exist).',
'expand'                  => 'Прошири',
'collapse'                => 'Собери',
'expandall'               => 'Прошири сè',
'collapseall'             => 'Собери сè',
'minpwsize'               => 'Минималната должина за лозинката е 5 знаци',
'passwordtoosmall'        => 'Лозинката е прекратка.',
'accountwaslocked'        => 'Your account had been locked due to too many failed login attempts.',
'failedattempts'          => 'Се случија %d неуспешни обиди за најава.',
'groupnotexist'           => 'Selected group does not exist in this project.',
'searchindetails'         => 'Детали за пребарување',
'showasassignees'         => 'Show as assignees',
'find'                    => 'Најди',
'tls'                     => 'TLS',
);

?>
